(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  GeneralSimulation
CALLING SEQUENCE:  GeneralSimulation[n, plist, m, print]
PARAMETERS:  
     n, m - integers
     plist - a probability list
     print - a Boolean variable (True or False)
SYNOPSIS:
     -  This program simulates a general experiment in which the outcomes 1, 2, ..., n
        occur with probabilities p(1), p(2), ..., p(n).  These probabilities are entered as a
        list in plist.  The experiment is repeated m times, and the observed frequencies of
        the outcomes are printed.  In addition, spike graphs of the observed data 
        frequencies and  plist data frequencies are displayed on the same set of axes;
        the observed data spikes are topped with blue dots, and the plist data spikes are
        topped with red.  If print = True, the outcomes are printed.  Finally, the program
        returns a list of the n observed frequencies.
      -  Note:  this program requires the programs "SimulateDiscreteVariable[plist]" and
         "SpikegraphWithDots[distributionlist, xmin, xmax, color, print]" be initialized.
RETURNED VALUES:
     -  a list of the n observed frequencies
LOCATION:
     Folder:  Chapter 1
     File:       "GeneralSimulation.Chpt1.mat"
;[s]
1:0,1;1210,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[GeneralSimulation];
GeneralSimulation[n_, plist_, m_, print_] :=
Block[{x,
       observedfreqlist = Table[0, {j, 1, n}],
       j,
       subtotal,
       alist, blist
      },
      For[i = 1, i <= m, i++,
          w = SimulateDiscreteVariable[plist];
          observedfreqlist[[w]]++;
          If[print, Print[w]];
         ];
      Print[" "];
      Print["Outcome  p(k)    p*(k)"];
      Print[" "];
      For[k = 1, k <= n, k++,
          Print[k,  "        ", 
                plist[[k]], "     ",
                N[observedfreqlist[[k]]/m, 5]
               ]; 
         ];
      alist = Table[{i, N[observedfreqlist[[i]]/m, 5]},
                    {i, 1, Length[observedfreqlist]}
                   ];
      blist = Table[{i, plist[[i]]},
                    {i, 1, Length[plist]}
                   ];
      g1 = SpikegraphWithDots[alist, 1, Length[alist],
                              {0.170, 0.110, 1.000}, False
                             ];
      g2 = SpikegraphWithDots[blist, 1, Length[blist],
                              {1.000, 0.030, 0.049}, False
                             ];
      Show[g1, g2, DisplayFunction -> $DisplayFunction];
      Return[N[observedfreqlist/m, 5]]
      ]
(*
:[font = input; preserveAspect; startGroup]
GeneralSimulation[7, {.2, .1, .05, .27, .11, .19, .08}, 1000, 
                  False]
:[font = print; inactive; preserveAspect]
Outcome  p(k)    p*(k)
 
1        0.2     0.207
2        0.1     0.091
3        0.05     0.047
4        0.27     0.272
5        0.11     0.125
6        0.19     0.17
7        0.08     0.088
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.134921 0.15873 0.0147151 2.16398 [
[(1)] .02381 0 0 2 Msboxa
[(2)] .18254 0 0 2 Msboxa
[(3)] .34127 0 0 2 Msboxa
[(4)] .5 0 0 2 Msboxa
[(5)] .65873 0 0 2 Msboxa
[(6)] .81746 0 0 2 Msboxa
[(7)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.05)] -0.0125 .12291 1 0 Msboxa
[(0.1)] -0.0125 .23111 1 0 Msboxa
[(0.15)] -0.0125 .33931 1 0 Msboxa
[(0.2)] -0.0125 .44751 1 0 Msboxa
[(0.25)] -0.0125 .55571 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(1)] .02381 0 0 2 Mshowa
p
.002 w
.18254 0 m
.18254 .00625 L
s
P
[(2)] .18254 0 0 2 Mshowa
p
.002 w
.34127 0 m
.34127 .00625 L
s
P
[(3)] .34127 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(4)] .5 0 0 2 Mshowa
p
.002 w
.65873 0 m
.65873 .00625 L
s
P
[(5)] .65873 0 0 2 Mshowa
p
.002 w
.81746 0 m
.81746 .00625 L
s
P
[(6)] .81746 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(7)] .97619 0 0 2 Mshowa
p
.001 w
.05556 0 m
.05556 .00375 L
s
P
p
.001 w
.0873 0 m
.0873 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.15079 0 m
.15079 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.24603 0 m
.24603 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.37302 0 m
.37302 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.43651 0 m
.43651 .00375 L
s
P
p
.001 w
.46825 0 m
.46825 .00375 L
s
P
p
.001 w
.53175 0 m
.53175 .00375 L
s
P
p
.001 w
.56349 0 m
.56349 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.62698 0 m
.62698 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75397 0 m
.75397 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.84921 0 m
.84921 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.9127 0 m
.9127 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .12291 m
.00625 .12291 L
s
P
[(0.05)] -0.0125 .12291 1 0 Mshowa
p
.002 w
0 .23111 m
.00625 .23111 L
s
P
[(0.1)] -0.0125 .23111 1 0 Mshowa
p
.002 w
0 .33931 m
.00625 .33931 L
s
P
[(0.15)] -0.0125 .33931 1 0 Mshowa
p
.002 w
0 .44751 m
.00625 .44751 L
s
P
[(0.2)] -0.0125 .44751 1 0 Mshowa
p
.002 w
0 .55571 m
.00625 .55571 L
s
P
[(0.25)] -0.0125 .55571 1 0 Mshowa
p
.001 w
0 .03635 m
.00375 .03635 L
s
P
p
.001 w
0 .05799 m
.00375 .05799 L
s
P
p
.001 w
0 .07963 m
.00375 .07963 L
s
P
p
.001 w
0 .10127 m
.00375 .10127 L
s
P
p
.001 w
0 .14455 m
.00375 .14455 L
s
P
p
.001 w
0 .16619 m
.00375 .16619 L
s
P
p
.001 w
0 .18783 m
.00375 .18783 L
s
P
p
.001 w
0 .20947 m
.00375 .20947 L
s
P
p
.001 w
0 .25275 m
.00375 .25275 L
s
P
p
.001 w
0 .27439 m
.00375 .27439 L
s
P
p
.001 w
0 .29603 m
.00375 .29603 L
s
P
p
.001 w
0 .31767 m
.00375 .31767 L
s
P
p
.001 w
0 .36095 m
.00375 .36095 L
s
P
p
.001 w
0 .38259 m
.00375 .38259 L
s
P
p
.001 w
0 .40423 m
.00375 .40423 L
s
P
p
.001 w
0 .42587 m
.00375 .42587 L
s
P
p
.001 w
0 .46915 m
.00375 .46915 L
s
P
p
.001 w
0 .49079 m
.00375 .49079 L
s
P
p
.001 w
0 .51243 m
.00375 .51243 L
s
P
p
.001 w
0 .53407 m
.00375 .53407 L
s
P
p
.001 w
0 .57735 m
.00375 .57735 L
s
P
p
.001 w
0 .59899 m
.00375 .59899 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.18254 .61178 m
.18254 .61803 L
s
P
p
.002 w
.34127 .61178 m
.34127 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.65873 .61178 m
.65873 .61803 L
s
P
p
.002 w
.81746 .61178 m
.81746 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.05556 .61428 m
.05556 .61803 L
s
P
p
.001 w
.0873 .61428 m
.0873 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.15079 .61428 m
.15079 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.24603 .61428 m
.24603 .61803 L
s
P
p
.001 w
.27778 .61428 m
.27778 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.37302 .61428 m
.37302 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.43651 .61428 m
.43651 .61803 L
s
P
p
.001 w
.46825 .61428 m
.46825 .61803 L
s
P
p
.001 w
.53175 .61428 m
.53175 .61803 L
s
P
p
.001 w
.56349 .61428 m
.56349 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.62698 .61428 m
.62698 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.72222 .61428 m
.72222 .61803 L
s
P
p
.001 w
.75397 .61428 m
.75397 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.84921 .61428 m
.84921 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.9127 .61428 m
.9127 .61803 L
s
P
p
.001 w
.94444 .61428 m
.94444 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .12291 m
1 .12291 L
s
P
p
.002 w
.99375 .23111 m
1 .23111 L
s
P
p
.002 w
.99375 .33931 m
1 .33931 L
s
P
p
.002 w
.99375 .44751 m
1 .44751 L
s
P
p
.002 w
.99375 .55571 m
1 .55571 L
s
P
p
.001 w
.99625 .03635 m
1 .03635 L
s
P
p
.001 w
.99625 .05799 m
1 .05799 L
s
P
p
.001 w
.99625 .07963 m
1 .07963 L
s
P
p
.001 w
.99625 .10127 m
1 .10127 L
s
P
p
.001 w
.99625 .14455 m
1 .14455 L
s
P
p
.001 w
.99625 .16619 m
1 .16619 L
s
P
p
.001 w
.99625 .18783 m
1 .18783 L
s
P
p
.001 w
.99625 .20947 m
1 .20947 L
s
P
p
.001 w
.99625 .25275 m
1 .25275 L
s
P
p
.001 w
.99625 .27439 m
1 .27439 L
s
P
p
.001 w
.99625 .29603 m
1 .29603 L
s
P
p
.001 w
.99625 .31767 m
1 .31767 L
s
P
p
.001 w
.99625 .36095 m
1 .36095 L
s
P
p
.001 w
.99625 .38259 m
1 .38259 L
s
P
p
.001 w
.99625 .40423 m
1 .40423 L
s
P
p
.001 w
.99625 .42587 m
1 .42587 L
s
P
p
.001 w
.99625 .46915 m
1 .46915 L
s
P
p
.001 w
.99625 .49079 m
1 .49079 L
s
P
p
.001 w
.99625 .51243 m
1 .51243 L
s
P
p
.001 w
.99625 .53407 m
1 .53407 L
s
P
p
.001 w
.99625 .57735 m
1 .57735 L
s
P
p
.001 w
.99625 .59899 m
1 .59899 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
p
p
.004 w
.02381 .46266 m
.02381 .01472 L
s
.18254 .21164 m
.18254 .01472 L
s
.34127 .11642 m
.34127 .01472 L
s
.5 .60332 m
.5 .01472 L
s
.65873 .28521 m
.65873 .01472 L
s
.81746 .38259 m
.81746 .01472 L
s
.97619 .20515 m
.97619 .01472 L
s
P
p
.17 .11 1 r
p
.02 w
.02381 .46266 Mdot
.18254 .21164 Mdot
.34127 .11642 Mdot
.5 .60332 Mdot
.65873 .28521 Mdot
.81746 .38259 Mdot
.97619 .20515 Mdot
P
P
P
p
p
.004 w
.02381 .44751 m
.02381 .01472 L
s
.18254 .23111 m
.18254 .01472 L
s
.34127 .12291 m
.34127 .01472 L
s
.5 .59899 m
.5 .01472 L
s
.65873 .25275 m
.65873 .01472 L
s
.81746 .42587 m
.81746 .01472 L
s
.97619 .18783 m
.97619 .01472 L
s
P
p
1 .03 .049 r
p
.02 w
.02381 .44751 Mdot
.18254 .23111 Mdot
.34127 .12291 Mdot
.5 .59899 Mdot
.65873 .25275 Mdot
.81746 .42587 Mdot
.97619 .18783 Mdot
P
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
{0.207, 0.091, 0.047, 0.272, 0.125, 0.17, 0.088}
;[o]
{0.207, 0.091, 0.047, 0.272, 0.125, 0.17, 0.088}
^*)
