(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  BranchingSimulation
CALLING SEQUENCE:  BranchingSimulation[n, gmax, plist, changepoint]
PARAMETERS:
     n, gmax, changepoint - integers
     plist - a a probability list
SYNOPSIS:
     -  This program simulates the branching process designated by plist (which states
        that a parent will produce at most Length[plist] offspring, and will produce i
        offspring with probability plist[[i]]), until generation gmax.  When the size of a
        generation becomes greater than changepoint, the size of the next generation is
        determined by the normal density.  The program does n such simulations, and
        plots the branching processes with the x-axis indicating number of generations,
        and the lines y = f(x) indicating the sizes of the generations at time x.
     -  Note:  this program requires the programs "DiscreteMean[distributionlist],"
        "DiscreteVariance[distributionlist]," and "SimulateDiscreteVariable[plist]" be
        initialized.
RETURNED VALUES:
     -  none
LOCATION:
     Folder:  Chapter 10
     File:       "BranchingSimulation.Chpt10.mat"
;[s]
1:0,0;1105,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[BranchingSimulation];
BranchingSimulation[n_, gmax_, plist_, changepoint_] :=
Block[{mean, var, g, gsize, glist,
       offspring, gmean, gstdev, finallist = {}
      },
      pdistlist = Table[{i-1, plist[[i]]}, {i, 1, Length[plist]}];
      mean = DiscreteMean[pdistlist];
      var = DiscreteVariance[pdistlist];
      Do[glist = {};
         g = 0; 
         gsize = 1;
         While[(gsize > 0) && (g < gmax),
               glist = Append[glist, {g, gsize/(mean^g)}];
               g++;
               If[gsize < changepoint,
                  offspring = 0;
                  For[i = 1, i <= gsize, i++,
                      offspring = 
                        offspring + 
                        SimulateDiscreteVariable[plist] - 1
                     ];
                  gsize = offspring,
                  gmean = gsize * mean;
                  gstdev = Sqrt[gsize * var];
                  gsize = gstdev * Sqrt[-2 * Log[Random[]]]
                                 * Cos[2*Pi*Random[]]
                                 + gmean//N
                 ]
              ];
          glist = Append[glist, {g, gsize/(mean^g)}];
          finallist = Append[finallist, 
                             ListPlot[glist, PlotJoined -> True,
                             DisplayFunction -> Identity]
                            ]
          , 
          {n}
         ];
      Show[finallist,
           DisplayFunction -> $DisplayFunction
          ]
     ]
(*
:[font = input; preserveAspect; startGroup]
kp = {.20917, .25838, .23595, .15933, .08275, .03567,
      .01331, .00420, .00106, .00016, .00002}
:[font = output; output; inactive; preserveAspect; endGroup]
{0.20917, 0.25838, 0.23595, 0.15933, 0.08275, 0.03567, 0.01331, 0.0042, 
 
  0.00106, 0.00016, 0.00002}
;[o]
{0.20917, 0.25838, 0.23595, 0.15933, 0.08275, 0.03567, 0.01331, 0.0042, 
 
  0.00106, 0.00016, 0.00002}
:[font = input; preserveAspect; startGroup]
BranchingSimulation[10, 25, kp, 500];
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0380952 0.0147151 0.22805 [
[(5)] .21429 .01472 0 2 Msboxa
[(10)] .40476 .01472 0 2 Msboxa
[(15)] .59524 .01472 0 2 Msboxa
[(20)] .78571 .01472 0 2 Msboxa
[(25)] .97619 .01472 0 2 Msboxa
[(0.5)] .01131 .12874 1 0 Msboxa
[(1)] .01131 .24277 1 0 Msboxa
[(1.5)] .01131 .35679 1 0 Msboxa
[(2)] .01131 .47082 1 0 Msboxa
[(2.5)] .01131 .58484 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .01472 m
.21429 .02097 L
s
P
[(5)] .21429 .01472 0 2 Mshowa
p
.002 w
.40476 .01472 m
.40476 .02097 L
s
P
[(10)] .40476 .01472 0 2 Mshowa
p
.002 w
.59524 .01472 m
.59524 .02097 L
s
P
[(15)] .59524 .01472 0 2 Mshowa
p
.002 w
.78571 .01472 m
.78571 .02097 L
s
P
[(20)] .78571 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(25)] .97619 .01472 0 2 Mshowa
p
.001 w
.0619 .01472 m
.0619 .01847 L
s
P
p
.001 w
.1 .01472 m
.1 .01847 L
s
P
p
.001 w
.1381 .01472 m
.1381 .01847 L
s
P
p
.001 w
.17619 .01472 m
.17619 .01847 L
s
P
p
.001 w
.25238 .01472 m
.25238 .01847 L
s
P
p
.001 w
.29048 .01472 m
.29048 .01847 L
s
P
p
.001 w
.32857 .01472 m
.32857 .01847 L
s
P
p
.001 w
.36667 .01472 m
.36667 .01847 L
s
P
p
.001 w
.44286 .01472 m
.44286 .01847 L
s
P
p
.001 w
.48095 .01472 m
.48095 .01847 L
s
P
p
.001 w
.51905 .01472 m
.51905 .01847 L
s
P
p
.001 w
.55714 .01472 m
.55714 .01847 L
s
P
p
.001 w
.63333 .01472 m
.63333 .01847 L
s
P
p
.001 w
.67143 .01472 m
.67143 .01847 L
s
P
p
.001 w
.70952 .01472 m
.70952 .01847 L
s
P
p
.001 w
.74762 .01472 m
.74762 .01847 L
s
P
p
.001 w
.82381 .01472 m
.82381 .01847 L
s
P
p
.001 w
.8619 .01472 m
.8619 .01847 L
s
P
p
.001 w
.9 .01472 m
.9 .01847 L
s
P
p
.001 w
.9381 .01472 m
.9381 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .12874 m
.03006 .12874 L
s
P
[(0.5)] .01131 .12874 1 0 Mshowa
p
.002 w
.02381 .24277 m
.03006 .24277 L
s
P
[(1)] .01131 .24277 1 0 Mshowa
p
.002 w
.02381 .35679 m
.03006 .35679 L
s
P
[(1.5)] .01131 .35679 1 0 Mshowa
p
.002 w
.02381 .47082 m
.03006 .47082 L
s
P
[(2)] .01131 .47082 1 0 Mshowa
p
.002 w
.02381 .58484 m
.03006 .58484 L
s
P
[(2.5)] .01131 .58484 1 0 Mshowa
p
.001 w
.02381 .03752 m
.02756 .03752 L
s
P
p
.001 w
.02381 .06033 m
.02756 .06033 L
s
P
p
.001 w
.02381 .08313 m
.02756 .08313 L
s
P
p
.001 w
.02381 .10594 m
.02756 .10594 L
s
P
p
.001 w
.02381 .15155 m
.02756 .15155 L
s
P
p
.001 w
.02381 .17435 m
.02756 .17435 L
s
P
p
.001 w
.02381 .19716 m
.02756 .19716 L
s
P
p
.001 w
.02381 .21996 m
.02756 .21996 L
s
P
p
.001 w
.02381 .26557 m
.02756 .26557 L
s
P
p
.001 w
.02381 .28838 m
.02756 .28838 L
s
P
p
.001 w
.02381 .31118 m
.02756 .31118 L
s
P
p
.001 w
.02381 .33399 m
.02756 .33399 L
s
P
p
.001 w
.02381 .3796 m
.02756 .3796 L
s
P
p
.001 w
.02381 .4024 m
.02756 .4024 L
s
P
p
.001 w
.02381 .42521 m
.02756 .42521 L
s
P
p
.001 w
.02381 .44801 m
.02756 .44801 L
s
P
p
.001 w
.02381 .49362 m
.02756 .49362 L
s
P
p
.001 w
.02381 .51643 m
.02756 .51643 L
s
P
p
.001 w
.02381 .53923 m
.02756 .53923 L
s
P
p
.001 w
.02381 .56204 m
.02756 .56204 L
s
P
p
.001 w
.02381 .60765 m
.02756 .60765 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
.004 w
.02381 .24277 m
.0619 .13886 L
.1 .08229 L
.1381 .0515 L
.17619 .03474 L
.21429 .05832 L
.25238 .03845 L
.29048 .0341 L
.32857 .02527 L
.36667 .02046 L
.40476 .01993 L
.44286 .02039 L
.48095 .02074 L
.51905 .02136 L
.55714 .02167 L
.59524 .02172 L
.63333 .02228 L
.67143 .02203 L
.70952 .02195 L
.74762 .02188 L
.78571 .02177 L
.82381 .02175 L
.8619 .02182 L
.9 .02184 L
.9381 .02184 L
.97619 .02188 L
s
.02381 .24277 m
.0619 .01472 L
s
.02381 .24277 m
.0619 .01472 L
s
.02381 .24277 m
.0619 .263 L
.1 .28503 L
.1381 .30902 L
.17619 .29508 L
.21429 .21094 L
.25238 .20462 L
.29048 .20208 L
.32857 .22574 L
.36667 .22532 L
.40476 .24297 L
.44286 .23967 L
.48095 .2443 L
.51905 .24179 L
.55714 .25407 L
.59524 .25902 L
.63333 .26234 L
.67143 .26222 L
.70952 .25958 L
.74762 .25898 L
.78571 .25926 L
.82381 .25907 L
.8619 .25862 L
.9 .25868 L
.9381 .25849 L
.97619 .25863 L
s
.02381 .24277 m
.0619 .263 L
.1 .14987 L
.1381 .0515 L
.17619 .05477 L
.21429 .04742 L
.25238 .05626 L
.29048 .05025 L
.32857 .03406 L
.36667 .04056 L
.40476 .04286 L
.44286 .04507 L
.48095 .04143 L
.51905 .04229 L
.55714 .0424 L
.59524 .04205 L
.63333 .04209 L
.67143 .04171 L
.70952 .04188 L
.74762 .04194 L
.78571 .04183 L
.82381 .04177 L
.8619 .04194 L
.9 .04183 L
.9381 .04189 L
.97619 .04185 L
s
.02381 .24277 m
.0619 .263 L
.1 .08229 L
.1381 .0515 L
.17619 .01472 L
s
.02381 .24277 m
.0619 .38714 L
.1 .55535 L
.1381 .60332 L
.17619 .45529 L
.21429 .31996 L
.25238 .36484 L
.29048 .32161 L
.32857 .31367 L
.36667 .33637 L
.40476 .32582 L
.44286 .31558 L
.48095 .31639 L
.51905 .31676 L
.55714 .31196 L
.59524 .31222 L
.63333 .31014 L
.67143 .31268 L
.70952 .31154 L
.74762 .31117 L
.78571 .31239 L
.82381 .31224 L
.8619 .31244 L
.9 .31284 L
.9381 .31267 L
.97619 .31282 L
s
.02381 .24277 m
.0619 .01472 L
s
.02381 .24277 m
.0619 .51129 L
.1 .48777 L
.1381 .30902 L
.17619 .25503 L
.21429 .21094 L
.25238 .17494 L
.29048 .15686 L
.32857 .15012 L
.36667 .13342 L
.40476 .13978 L
.44286 .13812 L
.48095 .13625 L
.51905 .13647 L
.55714 .13195 L
.59524 .13449 L
.63333 .13406 L
.67143 .13473 L
.70952 .13393 L
.74762 .13485 L
.78571 .13451 L
.82381 .13422 L
.8619 .13397 L
.9 .13375 L
.9381 .13395 L
.97619 .13371 L
s
.02381 .24277 m
.0619 .01472 L
s
P
% End of Graphics
MathPictureEnd

^*)
