(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  AbsorbingChain
CALLING SEQUENCE:  AbsorbingChain[P, stateslist, print]
PARAMETERS:
     P - a Markov chain transition matrix
     stateslist - a list of values, with Length[stateslist] = Length[P]
     print - a Boolean variable (True or False)
SYNOPSIS:
     -  This program takes as its parameters P, a Markov chain transition matrix, and
        stateslist, the list of possible states in the Markov chain, and finds and returns the
        matrices Q, R, N, B, and vector t, as defined in the book.   If print = True, then the
        program also displays these matrices and vector, with rows and columns
        labeled.
    -  Note:  this program requires the program "LabelMatrix[M, rowlabels,
       columnlabels]" be initialized.
   RETURN VALUES:
        -  the list {Q, R, N, t, B}
  LOCATION:
       Folder:  Chapter 11
       File:       "AbsorbingChain.Chpt11.mat"
;[s]
1:0,1;890,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[AbsorbingChain];
AbsorbingChain[P_, stateslist_, print_] :=
Block[{Absorb = {}, Trans = {}, 
       abslist = {}, translist = {},temp,
       Absorb2 = {}, Trans2 = {},
       r, s, Q, Q2, R, R2, N, N2, t, t2, B, B2
      },
      For[i = 1, i <= Length[P], i++,
          If[P[[i]][[i]] == 1,
             If[print,
                abslist = Append[abslist, 
                                 stateslist[[i]]
                                ]
               ];
             Absorb = Append[Absorb, P[[i]]],
             If[print,
                translist = Append[translist, 
                                   stateslist[[i]]
                                  ]
               ];
             Trans = Append[Trans, P[[i]]]
            ]
         ];
      temp = Transpose[Join[Trans, Absorb]];
      For[i = 1, i <= Length[temp], i++,
          If[MemberQ[temp[[i]], 1],
             Absorb2 = Append[Absorb2, temp[[i]]],
             Trans2 = Append[Trans2, temp[[i]]]
            ]
         ];
      temp = Transpose[Join[Trans2, Absorb2]];
      r = Length[Absorb2]; s = Length[P] - r;
      Q = Take[temp, s]; 
      R = Take[temp, s];
      For[i = 1, i <= s, i++,
          Q[[i]] = Drop[Q[[i]], -r];
          R[[i]] = Drop[R[[i]], s]
         ];
      N = Inverse[IdentityMatrix[s] - Q];
      t = N.Table[1, {i, 1, s}];
      B = N.R;
      If[print,
         Print["Matrix Q:"];
         Print[LabelMatrix[Q, translist, translist]];
         Print["  "];  Print["  "];
         Print["Matrix R:"];
         Print[LabelMatrix[R, translist, abslist]];
         Print["  "];  Print["  "];
         Print["Fundamental Matrix N:"];
         Print[LabelMatrix[N, translist, translist]];
         Print["  "];  Print["  "];
         Print["Times to absorption t:"];
         Print[Prepend[{t}, translist]//MatrixForm];
         Print["  "];  Print["  "];
         Print["Absorption probabilities B:"];
         Print[LabelMatrix[B, translist, abslist]]
        ];
      Return[{Q, R, N, t, B}]
      ]
(*
:[font = input; preserveAspect; startGroup]
AbsorbingChain[{{1,0,0,0,0},{.5,0,.5,0,0},
                {0,.5,0,.5,0}, {0,0,.5,0,.5},
                {0,0,0,0,1}},
                {0,1,2,3,4}, True
              ]
:[font = print; inactive; preserveAspect]
Matrix Q:
      1     2     3

1     0     0.5   0

2     0.5   0     0.5

3     0     0.5   0
  
  
Matrix R:
      0     4

1     0.5   0

2     0     0

3     0     0.5
  
  
Fundamental Matrix N:
      1     2     3

1     1.5   1.    0.5

2     1.    2.    1.

3     0.5   1.    1.5
  
  
Times to absorption t:
1    2    3

3.   4.   3.
  
  
Absorption probabilities B:
       0      4

1      0.75   0.25

2      0.5    0.5

3      0.25   0.75
:[font = output; output; inactive; preserveAspect; endGroup]
{{{0, 0.5, 0}, {0.5, 0, 0.5}, {0, 0.5, 0}}, 
 
  {{0.5, 0}, {0, 0}, {0, 0.5}}, 
 
  {{1.5, 1., 0.5}, {1., 2., 1.}, {0.5, 1., 1.5}}, 
 
  {3., 3.999999999999999, 2.999999999999999}, 
 
  {{0.75, 0.25}, {0.5, 0.5}, {0.25, 0.75}}}
;[o]
{{{0, 0.5, 0}, {0.5, 0, 0.5}, {0, 0.5, 0}}, 
 
  {{0.5, 0}, {0, 0}, {0, 0.5}}, 
 
  {{1.5, 1., 0.5}, {1., 2., 1.}, {0.5, 1., 1.5}}, 
 
  {3., 4., 3.}, {{0.75, 0.25}, {0.5, 0.5}, {0.25, 0.75}}}
:[font = input; preserveAspect; startGroup]
AbsorbingChain[{{1,0,0,0,0,0},{.5,0,.5,0,0,0},
                {0,.5,0,.5,0,0}, {0,0,.5,0,.5,0},
                {0,0,0,.5,0,.5},{0,0,0,0,0,1}},
                {0,1,2,3,4,5}, False
              ]
:[font = output; output; inactive; preserveAspect; endGroup]
{{{0, 0.5, 0, 0}, {0.5, 0, 0.5, 0}, {0, 0.5, 0, 0.5}, 
   {0, 0, 0.5, 0}}, {{0.5, 0}, {0, 0}, {0, 0}, {0, 0.5}}, 
  {{1.6, 1.2, 0.7999999999999999, 0.4}, 
   {1.2, 2.399999999999999, 1.6, 0.8}, 
   {0.7999999999999999, 1.6, 2.399999999999999, 1.2}, 
   {0.3999999999999999, 0.7999999999999999, 1.2, 1.6}}, 
  {4., 6., 6., 4.}, {{0.8, 0.2}, {0.5999999999999999, 0.4}, 
   {0.3999999999999999, 0.6}, {0.2, 0.8}}}
;[o]
{{{0, 0.5, 0, 0}, {0.5, 0, 0.5, 0}, {0, 0.5, 0, 0.5}, 
 
   {0, 0, 0.5, 0}}, {{0.5, 0}, {0, 0}, {0, 0}, {0, 0.5}}, 
 
  {{1.6, 1.2, 0.8, 0.4}, {1.2, 2.4, 1.6, 0.8}, 
 
   {0.8, 1.6, 2.4, 1.2}, {0.4, 0.8, 1.2, 1.6}}, 
 
  {4., 6., 6., 4.}, {{0.8, 0.2}, {0.6, 0.4}, {0.4, 0.6}, 
 
   {0.2, 0.8}}}
^*)
