(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  EhrenfestUrn
CALLING SEQUENCE:  EhrenfestUrn[seconds, balls]
PARAMETERS:
     seconds - an integer
     balls - an even integer
SYNOPSIS:
     -  This program simulates the Ehrenfest model for gas diffusion by simulating the
        urn-ball experiment described in the book, with the number of balls = balls, and
        the number of time units being tested = seconds.  The program displays a plot
        of the experiment, with  the x-axis showing time and the graph y = f(x) showing
        how many balls are in the first urn at each second x.  (Note:  the program actually
        plots points only for integer values of x, since the distribution of f(x) is discrete;
        however, for the sake of aesthetics, the computer joins these points with lines.)
RETURNED VALUES:
     -  a list of the number of balls in Urn 1 after each second
LOCATION:
     Folder:  Chapter 11
     File:       "EhrenfestUrn.Chpt11.mat"
;[s]
1:0,0;935,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[EhrenfestUrn];
EhrenfestUrn[seconds_, balls_] :=
Block[{urn1 = Table[i, {i, 1, balls/2}],
       urn2 = Table[i, {i, (balls/2) + 1, balls}],
       ballist = {balls/2}
      },
      For[i = 1, i <= seconds, i++,
          r = Random[Integer, {1, balls}];
          If[MemberQ[urn1, r],
             urn2 = Append[urn2, r];
             urn1 = Complement[Table[i, {i, 1, balls}], 
                               urn2],
             urn1 = Append[urn1, r];
             urn2 = Complement[Table[i, {i, 1, balls}], 
                               urn1]
            ];
          ballist = Append[ballist, Length[urn1]]
         ];
      ListPlot[ballist, PlotJoined -> True];
      Return[ballist]
     ]
(*
:[font = input; preserveAspect; startGroup]
J = EhrenfestUrn[500, 100];
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190096 -0.83549 0.0218001 [
[(100)] .21391 .03652 0 2 Msboxa
[(200)] .404 .03652 0 2 Msboxa
[(300)] .5941 .03652 0 2 Msboxa
[(400)] .78419 .03652 0 2 Msboxa
[(500)] .97429 .03652 0 2 Msboxa
[(45)] .01131 .14552 1 0 Msboxa
[(50)] .01131 .25452 1 0 Msboxa
[(55)] .01131 .36352 1 0 Msboxa
[(60)] .01131 .47252 1 0 Msboxa
[(65)] .01131 .58152 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21391 .03652 m
.21391 .04277 L
s
P
[(100)] .21391 .03652 0 2 Mshowa
p
.002 w
.404 .03652 m
.404 .04277 L
s
P
[(200)] .404 .03652 0 2 Mshowa
p
.002 w
.5941 .03652 m
.5941 .04277 L
s
P
[(300)] .5941 .03652 0 2 Mshowa
p
.002 w
.78419 .03652 m
.78419 .04277 L
s
P
[(400)] .78419 .03652 0 2 Mshowa
p
.002 w
.97429 .03652 m
.97429 .04277 L
s
P
[(500)] .97429 .03652 0 2 Mshowa
p
.001 w
.06183 .03652 m
.06183 .04027 L
s
P
p
.001 w
.09985 .03652 m
.09985 .04027 L
s
P
p
.001 w
.13787 .03652 m
.13787 .04027 L
s
P
p
.001 w
.17589 .03652 m
.17589 .04027 L
s
P
p
.001 w
.25192 .03652 m
.25192 .04027 L
s
P
p
.001 w
.28994 .03652 m
.28994 .04027 L
s
P
p
.001 w
.32796 .03652 m
.32796 .04027 L
s
P
p
.001 w
.36598 .03652 m
.36598 .04027 L
s
P
p
.001 w
.44202 .03652 m
.44202 .04027 L
s
P
p
.001 w
.48004 .03652 m
.48004 .04027 L
s
P
p
.001 w
.51806 .03652 m
.51806 .04027 L
s
P
p
.001 w
.55608 .03652 m
.55608 .04027 L
s
P
p
.001 w
.63212 .03652 m
.63212 .04027 L
s
P
p
.001 w
.67014 .03652 m
.67014 .04027 L
s
P
p
.001 w
.70816 .03652 m
.70816 .04027 L
s
P
p
.001 w
.74617 .03652 m
.74617 .04027 L
s
P
p
.001 w
.82221 .03652 m
.82221 .04027 L
s
P
p
.001 w
.86023 .03652 m
.86023 .04027 L
s
P
p
.001 w
.89825 .03652 m
.89825 .04027 L
s
P
p
.001 w
.93627 .03652 m
.93627 .04027 L
s
P
p
.002 w
0 .03652 m
1 .03652 L
s
P
p
.002 w
.02381 .14552 m
.03006 .14552 L
s
P
[(45)] .01131 .14552 1 0 Mshowa
p
.002 w
.02381 .25452 m
.03006 .25452 L
s
P
[(50)] .01131 .25452 1 0 Mshowa
p
.002 w
.02381 .36352 m
.03006 .36352 L
s
P
[(55)] .01131 .36352 1 0 Mshowa
p
.002 w
.02381 .47252 m
.03006 .47252 L
s
P
[(60)] .01131 .47252 1 0 Mshowa
p
.002 w
.02381 .58152 m
.03006 .58152 L
s
P
[(65)] .01131 .58152 1 0 Mshowa
p
.001 w
.02381 .05832 m
.02756 .05832 L
s
P
p
.001 w
.02381 .08012 m
.02756 .08012 L
s
P
p
.001 w
.02381 .10192 m
.02756 .10192 L
s
P
p
.001 w
.02381 .12372 m
.02756 .12372 L
s
P
p
.001 w
.02381 .16732 m
.02756 .16732 L
s
P
p
.001 w
.02381 .18912 m
.02756 .18912 L
s
P
p
.001 w
.02381 .21092 m
.02756 .21092 L
s
P
p
.001 w
.02381 .23272 m
.02756 .23272 L
s
P
p
.001 w
.02381 .27632 m
.02756 .27632 L
s
P
p
.001 w
.02381 .29812 m
.02756 .29812 L
s
P
p
.001 w
.02381 .31992 m
.02756 .31992 L
s
P
p
.001 w
.02381 .34172 m
.02756 .34172 L
s
P
p
.001 w
.02381 .38532 m
.02756 .38532 L
s
P
p
.001 w
.02381 .40712 m
.02756 .40712 L
s
P
p
.001 w
.02381 .42892 m
.02756 .42892 L
s
P
p
.001 w
.02381 .45072 m
.02756 .45072 L
s
P
p
.001 w
.02381 .49432 m
.02756 .49432 L
s
P
p
.001 w
.02381 .51612 m
.02756 .51612 L
s
P
p
.001 w
.02381 .53792 m
.02756 .53792 L
s
P
p
.001 w
.02381 .55972 m
.02756 .55972 L
s
P
p
.001 w
.02381 .01472 m
.02756 .01472 L
s
P
p
.001 w
.02381 .60332 m
.02756 .60332 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.02571 .25452 m
.02761 .27632 L
.02951 .29812 L
.03141 .31992 L
.03331 .29812 L
.03522 .31992 L
.03712 .29812 L
.03902 .27632 L
.04092 .25452 L
.04282 .27632 L
.04472 .25452 L
.04662 .23272 L
.04852 .25452 L
.05042 .23272 L
.05232 .25452 L
.05422 .27632 L
.05613 .29812 L
.05803 .27632 L
.05993 .29812 L
.06183 .27632 L
.06373 .29812 L
.06563 .27632 L
.06753 .29812 L
.06943 .27632 L
.07133 .25452 L
.07323 .23272 L
.07514 .25452 L
.07704 .23272 L
.07894 .25452 L
.08084 .27632 L
.08274 .29812 L
.08464 .27632 L
.08654 .29812 L
.08844 .31992 L
.09034 .29812 L
.09224 .31992 L
.09415 .29812 L
.09605 .31992 L
.09795 .29812 L
.09985 .27632 L
.10175 .29812 L
.10365 .27632 L
.10555 .29812 L
.10745 .27632 L
.10935 .25452 L
.11125 .23272 L
.11315 .25452 L
.11506 .23272 L
.11696 .21092 L
.11886 .18912 L
Mistroke
.12076 .16732 L
.12266 .14552 L
.12456 .16732 L
.12646 .18912 L
.12836 .21092 L
.13026 .23272 L
.13216 .21092 L
.13407 .23272 L
.13597 .21092 L
.13787 .18912 L
.13977 .16732 L
.14167 .14552 L
.14357 .12372 L
.14547 .10192 L
.14737 .12372 L
.14927 .14552 L
.15117 .16732 L
.15307 .14552 L
.15498 .12372 L
.15688 .14552 L
.15878 .16732 L
.16068 .14552 L
.16258 .16732 L
.16448 .14552 L
.16638 .12372 L
.16828 .14552 L
.17018 .16732 L
.17208 .14552 L
.17399 .16732 L
.17589 .18912 L
.17779 .21092 L
.17969 .18912 L
.18159 .16732 L
.18349 .18912 L
.18539 .21092 L
.18729 .23272 L
.18919 .25452 L
.19109 .27632 L
.19299 .25452 L
.1949 .23272 L
.1968 .25452 L
.1987 .27632 L
.2006 .25452 L
.2025 .27632 L
.2044 .29812 L
.2063 .31992 L
.2082 .34172 L
.2101 .36352 L
.212 .34172 L
.21391 .36352 L
Mistroke
.21581 .38532 L
.21771 .36352 L
.21961 .38532 L
.22151 .40712 L
.22341 .42892 L
.22531 .40712 L
.22721 .38532 L
.22911 .36352 L
.23101 .38532 L
.23292 .36352 L
.23482 .34172 L
.23672 .36352 L
.23862 .34172 L
.24052 .36352 L
.24242 .38532 L
.24432 .36352 L
.24622 .34172 L
.24812 .36352 L
.25002 .34172 L
.25192 .31992 L
.25383 .34172 L
.25573 .31992 L
.25763 .34172 L
.25953 .36352 L
.26143 .34172 L
.26333 .31992 L
.26523 .29812 L
.26713 .27632 L
.26903 .25452 L
.27093 .27632 L
.27284 .25452 L
.27474 .23272 L
.27664 .25452 L
.27854 .27632 L
.28044 .25452 L
.28234 .23272 L
.28424 .21092 L
.28614 .23272 L
.28804 .21092 L
.28994 .23272 L
.29184 .21092 L
.29375 .18912 L
.29565 .21092 L
.29755 .18912 L
.29945 .21092 L
.30135 .18912 L
.30325 .16732 L
.30515 .14552 L
.30705 .16732 L
.30895 .14552 L
Mistroke
.31085 .12372 L
.31276 .10192 L
.31466 .08012 L
.31656 .05832 L
.31846 .08012 L
.32036 .10192 L
.32226 .12372 L
.32416 .14552 L
.32606 .12372 L
.32796 .10192 L
.32986 .12372 L
.33177 .14552 L
.33367 .16732 L
.33557 .14552 L
.33747 .12372 L
.33937 .10192 L
.34127 .12372 L
.34317 .14552 L
.34507 .12372 L
.34697 .10192 L
.34887 .08012 L
.35077 .10192 L
.35268 .12372 L
.35458 .14552 L
.35648 .16732 L
.35838 .18912 L
.36028 .21092 L
.36218 .23272 L
.36408 .21092 L
.36598 .23272 L
.36788 .25452 L
.36978 .27632 L
.37169 .29812 L
.37359 .31992 L
.37549 .34172 L
.37739 .31992 L
.37929 .29812 L
.38119 .31992 L
.38309 .34172 L
.38499 .36352 L
.38689 .34172 L
.38879 .31992 L
.39069 .34172 L
.3926 .36352 L
.3945 .38532 L
.3964 .36352 L
.3983 .34172 L
.4002 .36352 L
.4021 .34172 L
.404 .31992 L
Mistroke
.4059 .34172 L
.4078 .36352 L
.4097 .34172 L
.41161 .36352 L
.41351 .38532 L
.41541 .36352 L
.41731 .34172 L
.41921 .31992 L
.42111 .34172 L
.42301 .36352 L
.42491 .38532 L
.42681 .40712 L
.42871 .42892 L
.43061 .40712 L
.43252 .42892 L
.43442 .45072 L
.43632 .42892 L
.43822 .45072 L
.44012 .47252 L
.44202 .49432 L
.44392 .47252 L
.44582 .45072 L
.44772 .47252 L
.44962 .45072 L
.45153 .47252 L
.45343 .49432 L
.45533 .51612 L
.45723 .49432 L
.45913 .51612 L
.46103 .49432 L
.46293 .47252 L
.46483 .45072 L
.46673 .47252 L
.46863 .49432 L
.47054 .47252 L
.47244 .49432 L
.47434 .51612 L
.47624 .49432 L
.47814 .47252 L
.48004 .49432 L
.48194 .47252 L
.48384 .45072 L
.48574 .42892 L
.48764 .45072 L
.48954 .42892 L
.49145 .40712 L
.49335 .42892 L
.49525 .40712 L
.49715 .38532 L
.49905 .40712 L
Mistroke
.50095 .42892 L
.50285 .45072 L
.50475 .42892 L
.50665 .40712 L
.50855 .42892 L
.51046 .40712 L
.51236 .38532 L
.51426 .40712 L
.51616 .38532 L
.51806 .36352 L
.51996 .38532 L
.52186 .36352 L
.52376 .34172 L
.52566 .31992 L
.52756 .29812 L
.52946 .27632 L
.53137 .29812 L
.53327 .27632 L
.53517 .29812 L
.53707 .31992 L
.53897 .34172 L
.54087 .36352 L
.54277 .38532 L
.54467 .36352 L
.54657 .38532 L
.54847 .36352 L
.55038 .38532 L
.55228 .36352 L
.55418 .34172 L
.55608 .36352 L
.55798 .38532 L
.55988 .36352 L
.56178 .38532 L
.56368 .36352 L
.56558 .34172 L
.56748 .36352 L
.56939 .38532 L
.57129 .36352 L
.57319 .34172 L
.57509 .31992 L
.57699 .29812 L
.57889 .27632 L
.58079 .25452 L
.58269 .27632 L
.58459 .25452 L
.58649 .27632 L
.58839 .29812 L
.5903 .31992 L
.5922 .34172 L
.5941 .36352 L
Mistroke
.596 .34172 L
.5979 .36352 L
.5998 .38532 L
.6017 .36352 L
.6036 .34172 L
.6055 .36352 L
.6074 .34172 L
.60931 .36352 L
.61121 .34172 L
.61311 .31992 L
.61501 .29812 L
.61691 .27632 L
.61881 .29812 L
.62071 .27632 L
.62261 .25452 L
.62451 .27632 L
.62641 .25452 L
.62831 .23272 L
.63022 .25452 L
.63212 .27632 L
.63402 .25452 L
.63592 .27632 L
.63782 .25452 L
.63972 .27632 L
.64162 .25452 L
.64352 .27632 L
.64542 .29812 L
.64732 .31992 L
.64923 .34172 L
.65113 .36352 L
.65303 .38532 L
.65493 .40712 L
.65683 .38532 L
.65873 .40712 L
.66063 .38532 L
.66253 .36352 L
.66443 .34172 L
.66633 .36352 L
.66823 .38532 L
.67014 .40712 L
.67204 .42892 L
.67394 .40712 L
.67584 .42892 L
.67774 .45072 L
.67964 .42892 L
.68154 .40712 L
.68344 .42892 L
.68534 .40712 L
.68724 .42892 L
.68915 .45072 L
Mistroke
.69105 .42892 L
.69295 .45072 L
.69485 .42892 L
.69675 .45072 L
.69865 .47252 L
.70055 .49432 L
.70245 .51612 L
.70435 .49432 L
.70625 .51612 L
.70816 .53792 L
.71006 .55972 L
.71196 .53792 L
.71386 .55972 L
.71576 .58152 L
.71766 .55972 L
.71956 .58152 L
.72146 .60332 L
.72336 .58152 L
.72526 .55972 L
.72716 .58152 L
.72907 .55972 L
.73097 .58152 L
.73287 .55972 L
.73477 .53792 L
.73667 .51612 L
.73857 .53792 L
.74047 .55972 L
.74237 .58152 L
.74427 .55972 L
.74617 .58152 L
.74808 .60332 L
.74998 .58152 L
.75188 .60332 L
.75378 .58152 L
.75568 .60332 L
.75758 .58152 L
.75948 .60332 L
.76138 .58152 L
.76328 .55972 L
.76518 .53792 L
.76708 .51612 L
.76899 .53792 L
.77089 .51612 L
.77279 .53792 L
.77469 .51612 L
.77659 .49432 L
.77849 .47252 L
.78039 .49432 L
.78229 .47252 L
.78419 .49432 L
Mistroke
.78609 .47252 L
.788 .45072 L
.7899 .47252 L
.7918 .49432 L
.7937 .47252 L
.7956 .45072 L
.7975 .42892 L
.7994 .45072 L
.8013 .42892 L
.8032 .40712 L
.8051 .38532 L
.80701 .40712 L
.80891 .38532 L
.81081 .36352 L
.81271 .34172 L
.81461 .31992 L
.81651 .34172 L
.81841 .31992 L
.82031 .29812 L
.82221 .27632 L
.82411 .25452 L
.82601 .27632 L
.82792 .25452 L
.82982 .23272 L
.83172 .21092 L
.83362 .18912 L
.83552 .16732 L
.83742 .14552 L
.83932 .12372 L
.84122 .14552 L
.84312 .16732 L
.84502 .18912 L
.84693 .21092 L
.84883 .18912 L
.85073 .16732 L
.85263 .18912 L
.85453 .16732 L
.85643 .14552 L
.85833 .16732 L
.86023 .18912 L
.86213 .16732 L
.86403 .14552 L
.86593 .12372 L
.86784 .14552 L
.86974 .16732 L
.87164 .14552 L
.87354 .16732 L
.87544 .18912 L
.87734 .16732 L
.87924 .14552 L
Mistroke
.88114 .12372 L
.88304 .10192 L
.88494 .08012 L
.88685 .05832 L
.88875 .08012 L
.89065 .05832 L
.89255 .08012 L
.89445 .10192 L
.89635 .12372 L
.89825 .10192 L
.90015 .12372 L
.90205 .14552 L
.90395 .12372 L
.90585 .10192 L
.90776 .12372 L
.90966 .14552 L
.91156 .12372 L
.91346 .14552 L
.91536 .12372 L
.91726 .10192 L
.91916 .08012 L
.92106 .10192 L
.92296 .12372 L
.92486 .14552 L
.92677 .12372 L
.92867 .14552 L
.93057 .16732 L
.93247 .14552 L
.93437 .12372 L
.93627 .10192 L
.93817 .12372 L
.94007 .10192 L
.94197 .12372 L
.94387 .10192 L
.94578 .08012 L
.94768 .05832 L
.94958 .03652 L
.95148 .01472 L
.95338 .03652 L
.95528 .05832 L
.95718 .08012 L
.95908 .10192 L
.96098 .12372 L
.96288 .10192 L
.96478 .12372 L
.96669 .14552 L
.96859 .12372 L
.97049 .10192 L
.97239 .12372 L
.97429 .14552 L
Mistroke
.97619 .16732 L
Mfstroke
% End of Graphics
MathPictureEnd

:[font = input; preserveAspect; startGroup]
ListPlot[Reverse[J], PlotJoined -> True];
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00190096 -0.83549 0.0218001 [
[(100)] .21391 .03652 0 2 Msboxa
[(200)] .404 .03652 0 2 Msboxa
[(300)] .5941 .03652 0 2 Msboxa
[(400)] .78419 .03652 0 2 Msboxa
[(500)] .97429 .03652 0 2 Msboxa
[(45)] .01131 .14552 1 0 Msboxa
[(50)] .01131 .25452 1 0 Msboxa
[(55)] .01131 .36352 1 0 Msboxa
[(60)] .01131 .47252 1 0 Msboxa
[(65)] .01131 .58152 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21391 .03652 m
.21391 .04277 L
s
P
[(100)] .21391 .03652 0 2 Mshowa
p
.002 w
.404 .03652 m
.404 .04277 L
s
P
[(200)] .404 .03652 0 2 Mshowa
p
.002 w
.5941 .03652 m
.5941 .04277 L
s
P
[(300)] .5941 .03652 0 2 Mshowa
p
.002 w
.78419 .03652 m
.78419 .04277 L
s
P
[(400)] .78419 .03652 0 2 Mshowa
p
.002 w
.97429 .03652 m
.97429 .04277 L
s
P
[(500)] .97429 .03652 0 2 Mshowa
p
.001 w
.06183 .03652 m
.06183 .04027 L
s
P
p
.001 w
.09985 .03652 m
.09985 .04027 L
s
P
p
.001 w
.13787 .03652 m
.13787 .04027 L
s
P
p
.001 w
.17589 .03652 m
.17589 .04027 L
s
P
p
.001 w
.25192 .03652 m
.25192 .04027 L
s
P
p
.001 w
.28994 .03652 m
.28994 .04027 L
s
P
p
.001 w
.32796 .03652 m
.32796 .04027 L
s
P
p
.001 w
.36598 .03652 m
.36598 .04027 L
s
P
p
.001 w
.44202 .03652 m
.44202 .04027 L
s
P
p
.001 w
.48004 .03652 m
.48004 .04027 L
s
P
p
.001 w
.51806 .03652 m
.51806 .04027 L
s
P
p
.001 w
.55608 .03652 m
.55608 .04027 L
s
P
p
.001 w
.63212 .03652 m
.63212 .04027 L
s
P
p
.001 w
.67014 .03652 m
.67014 .04027 L
s
P
p
.001 w
.70816 .03652 m
.70816 .04027 L
s
P
p
.001 w
.74617 .03652 m
.74617 .04027 L
s
P
p
.001 w
.82221 .03652 m
.82221 .04027 L
s
P
p
.001 w
.86023 .03652 m
.86023 .04027 L
s
P
p
.001 w
.89825 .03652 m
.89825 .04027 L
s
P
p
.001 w
.93627 .03652 m
.93627 .04027 L
s
P
p
.002 w
0 .03652 m
1 .03652 L
s
P
p
.002 w
.02381 .14552 m
.03006 .14552 L
s
P
[(45)] .01131 .14552 1 0 Mshowa
p
.002 w
.02381 .25452 m
.03006 .25452 L
s
P
[(50)] .01131 .25452 1 0 Mshowa
p
.002 w
.02381 .36352 m
.03006 .36352 L
s
P
[(55)] .01131 .36352 1 0 Mshowa
p
.002 w
.02381 .47252 m
.03006 .47252 L
s
P
[(60)] .01131 .47252 1 0 Mshowa
p
.002 w
.02381 .58152 m
.03006 .58152 L
s
P
[(65)] .01131 .58152 1 0 Mshowa
p
.001 w
.02381 .05832 m
.02756 .05832 L
s
P
p
.001 w
.02381 .08012 m
.02756 .08012 L
s
P
p
.001 w
.02381 .10192 m
.02756 .10192 L
s
P
p
.001 w
.02381 .12372 m
.02756 .12372 L
s
P
p
.001 w
.02381 .16732 m
.02756 .16732 L
s
P
p
.001 w
.02381 .18912 m
.02756 .18912 L
s
P
p
.001 w
.02381 .21092 m
.02756 .21092 L
s
P
p
.001 w
.02381 .23272 m
.02756 .23272 L
s
P
p
.001 w
.02381 .27632 m
.02756 .27632 L
s
P
p
.001 w
.02381 .29812 m
.02756 .29812 L
s
P
p
.001 w
.02381 .31992 m
.02756 .31992 L
s
P
p
.001 w
.02381 .34172 m
.02756 .34172 L
s
P
p
.001 w
.02381 .38532 m
.02756 .38532 L
s
P
p
.001 w
.02381 .40712 m
.02756 .40712 L
s
P
p
.001 w
.02381 .42892 m
.02756 .42892 L
s
P
p
.001 w
.02381 .45072 m
.02756 .45072 L
s
P
p
.001 w
.02381 .49432 m
.02756 .49432 L
s
P
p
.001 w
.02381 .51612 m
.02756 .51612 L
s
P
p
.001 w
.02381 .53792 m
.02756 .53792 L
s
P
p
.001 w
.02381 .55972 m
.02756 .55972 L
s
P
p
.001 w
.02381 .01472 m
.02756 .01472 L
s
P
p
.001 w
.02381 .60332 m
.02756 .60332 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.02571 .16732 m
.02761 .14552 L
.02951 .12372 L
.03141 .10192 L
.03331 .12372 L
.03522 .14552 L
.03712 .12372 L
.03902 .10192 L
.04092 .12372 L
.04282 .10192 L
.04472 .08012 L
.04662 .05832 L
.04852 .03652 L
.05042 .01472 L
.05232 .03652 L
.05422 .05832 L
.05613 .08012 L
.05803 .10192 L
.05993 .12372 L
.06183 .10192 L
.06373 .12372 L
.06563 .10192 L
.06753 .12372 L
.06943 .14552 L
.07133 .16732 L
.07323 .14552 L
.07514 .12372 L
.07704 .14552 L
.07894 .12372 L
.08084 .10192 L
.08274 .08012 L
.08464 .10192 L
.08654 .12372 L
.08844 .14552 L
.09034 .12372 L
.09224 .14552 L
.09415 .12372 L
.09605 .10192 L
.09795 .12372 L
.09985 .14552 L
.10175 .12372 L
.10365 .10192 L
.10555 .12372 L
.10745 .10192 L
.10935 .08012 L
.11125 .05832 L
.11315 .08012 L
.11506 .05832 L
.11696 .08012 L
.11886 .10192 L
Mistroke
.12076 .12372 L
.12266 .14552 L
.12456 .16732 L
.12646 .18912 L
.12836 .16732 L
.13026 .14552 L
.13216 .16732 L
.13407 .14552 L
.13597 .12372 L
.13787 .14552 L
.13977 .16732 L
.14167 .18912 L
.14357 .16732 L
.14547 .14552 L
.14737 .16732 L
.14927 .18912 L
.15117 .16732 L
.15307 .18912 L
.15498 .21092 L
.15688 .18912 L
.15878 .16732 L
.16068 .14552 L
.16258 .12372 L
.16448 .14552 L
.16638 .16732 L
.16828 .18912 L
.17018 .21092 L
.17208 .23272 L
.17399 .25452 L
.17589 .27632 L
.17779 .25452 L
.17969 .27632 L
.18159 .29812 L
.18349 .31992 L
.18539 .34172 L
.18729 .31992 L
.18919 .34172 L
.19109 .36352 L
.19299 .38532 L
.1949 .40712 L
.1968 .38532 L
.1987 .40712 L
.2006 .42892 L
.2025 .45072 L
.2044 .42892 L
.2063 .45072 L
.2082 .47252 L
.2101 .49432 L
.212 .47252 L
.21391 .45072 L
Mistroke
.21581 .47252 L
.21771 .49432 L
.21961 .47252 L
.22151 .49432 L
.22341 .47252 L
.22531 .49432 L
.22721 .51612 L
.22911 .53792 L
.23101 .51612 L
.23292 .53792 L
.23482 .51612 L
.23672 .53792 L
.23862 .55972 L
.24052 .58152 L
.24242 .60332 L
.24432 .58152 L
.24622 .60332 L
.24812 .58152 L
.25002 .60332 L
.25192 .58152 L
.25383 .60332 L
.25573 .58152 L
.25763 .55972 L
.25953 .58152 L
.26143 .55972 L
.26333 .53792 L
.26523 .51612 L
.26713 .53792 L
.26903 .55972 L
.27093 .58152 L
.27284 .55972 L
.27474 .58152 L
.27664 .55972 L
.27854 .58152 L
.28044 .60332 L
.28234 .58152 L
.28424 .55972 L
.28614 .58152 L
.28804 .55972 L
.28994 .53792 L
.29184 .55972 L
.29375 .53792 L
.29565 .51612 L
.29755 .49432 L
.29945 .51612 L
.30135 .49432 L
.30325 .47252 L
.30515 .45072 L
.30705 .42892 L
.30895 .45072 L
Mistroke
.31085 .42892 L
.31276 .45072 L
.31466 .42892 L
.31656 .40712 L
.31846 .42892 L
.32036 .40712 L
.32226 .42892 L
.32416 .45072 L
.32606 .42892 L
.32796 .40712 L
.32986 .42892 L
.33177 .40712 L
.33367 .38532 L
.33557 .36352 L
.33747 .34172 L
.33937 .36352 L
.34127 .38532 L
.34317 .40712 L
.34507 .38532 L
.34697 .40712 L
.34887 .38532 L
.35077 .36352 L
.35268 .34172 L
.35458 .31992 L
.35648 .29812 L
.35838 .27632 L
.36028 .25452 L
.36218 .27632 L
.36408 .25452 L
.36598 .27632 L
.36788 .25452 L
.36978 .27632 L
.37169 .25452 L
.37359 .23272 L
.37549 .25452 L
.37739 .27632 L
.37929 .25452 L
.38119 .27632 L
.38309 .29812 L
.38499 .27632 L
.38689 .29812 L
.38879 .31992 L
.39069 .34172 L
.3926 .36352 L
.3945 .34172 L
.3964 .36352 L
.3983 .34172 L
.4002 .36352 L
.4021 .38532 L
.404 .36352 L
Mistroke
.4059 .34172 L
.4078 .36352 L
.4097 .34172 L
.41161 .31992 L
.41351 .29812 L
.41541 .27632 L
.41731 .25452 L
.41921 .27632 L
.42111 .25452 L
.42301 .27632 L
.42491 .29812 L
.42681 .31992 L
.42871 .34172 L
.43061 .36352 L
.43252 .38532 L
.43442 .36352 L
.43632 .34172 L
.43822 .36352 L
.44012 .38532 L
.44202 .36352 L
.44392 .38532 L
.44582 .36352 L
.44772 .34172 L
.44962 .36352 L
.45153 .38532 L
.45343 .36352 L
.45533 .38532 L
.45723 .36352 L
.45913 .38532 L
.46103 .36352 L
.46293 .34172 L
.46483 .31992 L
.46673 .29812 L
.46863 .27632 L
.47054 .29812 L
.47244 .27632 L
.47434 .29812 L
.47624 .31992 L
.47814 .34172 L
.48004 .36352 L
.48194 .38532 L
.48384 .36352 L
.48574 .38532 L
.48764 .40712 L
.48954 .38532 L
.49145 .40712 L
.49335 .42892 L
.49525 .40712 L
.49715 .42892 L
.49905 .45072 L
Mistroke
.50095 .42892 L
.50285 .40712 L
.50475 .38532 L
.50665 .40712 L
.50855 .42892 L
.51046 .40712 L
.51236 .42892 L
.51426 .45072 L
.51616 .42892 L
.51806 .45072 L
.51996 .47252 L
.52186 .49432 L
.52376 .47252 L
.52566 .49432 L
.52756 .51612 L
.52946 .49432 L
.53137 .47252 L
.53327 .49432 L
.53517 .47252 L
.53707 .45072 L
.53897 .47252 L
.54087 .49432 L
.54277 .51612 L
.54467 .49432 L
.54657 .51612 L
.54847 .49432 L
.55038 .47252 L
.55228 .45072 L
.55418 .47252 L
.55608 .45072 L
.55798 .47252 L
.55988 .49432 L
.56178 .47252 L
.56368 .45072 L
.56558 .42892 L
.56748 .45072 L
.56939 .42892 L
.57129 .40712 L
.57319 .42892 L
.57509 .40712 L
.57699 .38532 L
.57889 .36352 L
.58079 .34172 L
.58269 .31992 L
.58459 .34172 L
.58649 .36352 L
.58839 .38532 L
.5903 .36352 L
.5922 .34172 L
.5941 .36352 L
Mistroke
.596 .34172 L
.5979 .31992 L
.5998 .34172 L
.6017 .36352 L
.6036 .34172 L
.6055 .36352 L
.6074 .38532 L
.60931 .36352 L
.61121 .34172 L
.61311 .31992 L
.61501 .34172 L
.61691 .36352 L
.61881 .34172 L
.62071 .31992 L
.62261 .29812 L
.62451 .31992 L
.62641 .34172 L
.62831 .31992 L
.63022 .29812 L
.63212 .27632 L
.63402 .25452 L
.63592 .23272 L
.63782 .21092 L
.63972 .23272 L
.64162 .21092 L
.64352 .18912 L
.64542 .16732 L
.64732 .14552 L
.64923 .12372 L
.65113 .10192 L
.65303 .08012 L
.65493 .10192 L
.65683 .12372 L
.65873 .14552 L
.66063 .12372 L
.66253 .10192 L
.66443 .12372 L
.66633 .14552 L
.66823 .16732 L
.67014 .14552 L
.67204 .12372 L
.67394 .10192 L
.67584 .12372 L
.67774 .14552 L
.67964 .12372 L
.68154 .10192 L
.68344 .08012 L
.68534 .05832 L
.68724 .08012 L
.68915 .10192 L
Mistroke
.69105 .12372 L
.69295 .14552 L
.69485 .16732 L
.69675 .14552 L
.69865 .16732 L
.70055 .18912 L
.70245 .21092 L
.70435 .18912 L
.70625 .21092 L
.70816 .18912 L
.71006 .21092 L
.71196 .23272 L
.71386 .21092 L
.71576 .23272 L
.71766 .21092 L
.71956 .23272 L
.72146 .25452 L
.72336 .27632 L
.72526 .25452 L
.72716 .23272 L
.72907 .25452 L
.73097 .27632 L
.73287 .25452 L
.73477 .27632 L
.73667 .29812 L
.73857 .31992 L
.74047 .34172 L
.74237 .36352 L
.74427 .34172 L
.74617 .31992 L
.74808 .34172 L
.74998 .31992 L
.75188 .34172 L
.75378 .36352 L
.75568 .34172 L
.75758 .36352 L
.75948 .38532 L
.76138 .36352 L
.76328 .34172 L
.76518 .36352 L
.76708 .34172 L
.76899 .36352 L
.77089 .38532 L
.77279 .36352 L
.77469 .38532 L
.77659 .40712 L
.77849 .42892 L
.78039 .40712 L
.78229 .38532 L
.78419 .36352 L
Mistroke
.78609 .38532 L
.788 .36352 L
.7899 .34172 L
.7918 .36352 L
.7937 .34172 L
.7956 .31992 L
.7975 .29812 L
.7994 .27632 L
.8013 .25452 L
.8032 .27632 L
.8051 .25452 L
.80701 .23272 L
.80891 .25452 L
.81081 .27632 L
.81271 .25452 L
.81461 .23272 L
.81651 .21092 L
.81841 .18912 L
.82031 .16732 L
.82221 .18912 L
.82411 .21092 L
.82601 .18912 L
.82792 .16732 L
.82982 .14552 L
.83172 .16732 L
.83362 .14552 L
.83552 .12372 L
.83742 .14552 L
.83932 .16732 L
.84122 .14552 L
.84312 .16732 L
.84502 .14552 L
.84693 .12372 L
.84883 .14552 L
.85073 .16732 L
.85263 .14552 L
.85453 .12372 L
.85643 .10192 L
.85833 .12372 L
.86023 .14552 L
.86213 .16732 L
.86403 .18912 L
.86593 .21092 L
.86784 .23272 L
.86974 .21092 L
.87164 .23272 L
.87354 .21092 L
.87544 .18912 L
.87734 .16732 L
.87924 .14552 L
Mistroke
.88114 .16732 L
.88304 .18912 L
.88494 .21092 L
.88685 .23272 L
.88875 .25452 L
.89065 .23272 L
.89255 .25452 L
.89445 .27632 L
.89635 .29812 L
.89825 .27632 L
.90015 .29812 L
.90205 .27632 L
.90395 .29812 L
.90585 .31992 L
.90776 .29812 L
.90966 .31992 L
.91156 .29812 L
.91346 .31992 L
.91536 .29812 L
.91726 .27632 L
.91916 .29812 L
.92106 .27632 L
.92296 .25452 L
.92486 .23272 L
.92677 .25452 L
.92867 .23272 L
.93057 .25452 L
.93247 .27632 L
.93437 .29812 L
.93627 .27632 L
.93817 .29812 L
.94007 .27632 L
.94197 .29812 L
.94387 .27632 L
.94578 .29812 L
.94768 .27632 L
.94958 .25452 L
.95148 .23272 L
.95338 .25452 L
.95528 .23272 L
.95718 .25452 L
.95908 .27632 L
.96098 .25452 L
.96288 .27632 L
.96478 .29812 L
.96669 .31992 L
.96859 .29812 L
.97049 .31992 L
.97239 .29812 L
.97429 .27632 L
Mistroke
.97619 .25452 L
Mfstroke
% End of Graphics
MathPictureEnd

^*)
