(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  ErgodicChain
CALLING SEQUENCE:  ErgodicChain[P, stateslist, print]
PARAMETERS:
     P - a Markov chain transition matrix
     stateslist - a list of values, with Length[stateslist] = Length[P]
     print - a Boolean variable (True or False)
SYNOPSIS:
     -  This program returns a list consisting of the mean recurrence times, and mean
         first passage matrix, for the ergodic chain with transition matrix P and possible
         states in statelist.  If print = True, the program displays P, along with the chain's
         fixed vector w,  list of mean recurrence times r, and mean first passage matrix M.
     -  Note:  this program requires the programs "LabelMatrix[M, rowlabels,
         columnlabels]" and "FixedVector[P, stateslist]", be initialized.  The first of these
         procedures is in the file "ImportantPrograms," the second is in the file 
         "FixedVector.Chpt11."
RETURNED VALUES:
     -  the list {r, M}
LOCATION:
     Folder:  Chapter 11
     File:       "ErgodicChain.Chpt11.mat"

;[s]
1:0,1;1030,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[ErgodicChain];
ErgodicChain[P_, stateslist_, print_] :=
Block[{IdMatrix, B, Z, w, r = {}, M = {}, mrow, m},
      IdMatrix = IdentityMatrix[Length[P]];
      If[print,
         w = FixedVector[P, stateslist, True],
         w = FixedVector[P, stateslist, False]
        ];
      B = Table[w, {i, Length[P]}];
      Z = Inverse[IdMatrix - P + B];
      For[k = 1, k <= Length[stateslist], k++,
          mrow = {};
          For[l = 1, l <= Length[stateslist], l++,
              m = (Z[[l,l]] - Z[[k,l]])/w[[l]];
              mrow = Append[mrow, m]
             ];
          M = Append[M, mrow];
          r = Append[r,(1/w[[k]])]
         ];
      If[print,
         Print["  "];  Print["  "];
         Print["Fundamental matrix Z:"];
         Print[LabelMatrix[Z, stateslist, stateslist]];
         Print["  "];  Print["  "];
         Print["Mean recurrence times r:"];
         Print[Prepend[{r}, stateslist]//MatrixForm];
         Print["  "];  Print["  "];
         Print["Mean first passage matrix M:"];
         Print[LabelMatrix[M, stateslist, stateslist]];
        ];
      Return[{r, M}]
     ]
(*
:[font = input; preserveAspect]
(* NOTE:  Please open and initialize the file
FixedVector.Chpt11.mat before running this program. *)
:[font = input; preserveAspect; startGroup]
P = {{0,1,0,0,0},{.25,0,.75,0,0},{0,.5,0,.5,0},
     {0,0,.75,0,.25}, {0,0,0,1,0}}
:[font = output; output; inactive; preserveAspect; endGroup]
{{0, 1, 0, 0, 0}, {0.25, 0, 0.75, 0, 0}, 
 
  {0, 0.5, 0, 0.5, 0}, {0, 0, 0.75, 0, 0.25}, 
 
  {0, 0, 0, 1, 0}}
;[o]
{{0, 1, 0, 0, 0}, {0.25, 0, 0.75, 0, 0}, 
 
  {0, 0.5, 0, 0.5, 0}, {0, 0, 0.75, 0, 0.25}, 
 
  {0, 0, 0, 1, 0}}
:[font = input; preserveAspect; startGroup]
ErgodicChain[P, {0,1,2,3,4}, True];
:[font = print; inactive; preserveAspect; endGroup]
Transition matrix P:
       0      1      2      3      4

0      0      1      0      0      0

1      0.25   0      0.75   0      0

2      0      0.5    0      0.5    0

3      0      0      0.75   0      0.25

4      0      0      0      1      0
  
  
Fixed vector W:
0        1        2        3        4

0.0625   0.25     0.375    0.25     0.0625
  
  
Fundamental matrix Z:
            0           1           2           3
 
      4

0           1.13542     0.791667    -0.1875     -0.541667
 
      -0.197917

1           0.197917    1.04167     0.1875      -0.291667
 
      -0.135417

2           -0.03125    0.125       0.8125      0.125
 
      -0.03125

3           -0.135417   -0.291667   0.1875      1.04167
 
      0.197917

4           -0.197917   -0.541667   -0.1875     0.791667
 
      1.13542
  
  
Mean recurrence times r:
0         1         2         3         4

16.       4.        2.66667   4.        16.
  
  
Mean first passage matrix M:
          0         1         2         3         4

0         0.        1.        2.66667   6.33333   21.3333

1         15.       0.        1.66667   5.33333   20.3333

2         18.6667   3.66667   0.        3.66667   18.6667

3         20.3333   5.33333   1.66667   0.        15.

4         21.3333   6.33333   2.66667   1.        0.
:[font = input; preserveAspect; startGroup]
ErgodicChain[P, {0,1,2,3,4}, False]
:[font = output; output; inactive; preserveAspect; endGroup]
{{15.99999999999998, 3.999999999999998, 2.666666666666667, 4.000000000000002, 
 
   16.}, {{0., 1., 2.666666666666666, 6.333333333333335, 21.33333333333334}, 
 
   {14.99999999999998, 0., 1.666666666666666, 5.333333333333336, 
 
    20.33333333333334}, {18.66666666666665, 3.666666666666665, 0., 
 
    3.666666666666668, 18.66666666666667}, 
 
   {20.3333333333333, 5.333333333333332, 1.666666666666666, 0., 15.}, 
 
   {21.33333333333331, 6.333333333333332, 2.666666666666666, 1., 0.}}}
;[o]
{{16., 4., 2.66667, 4., 16.}, {{0., 1., 2.66667, 6.33333, 21.3333}, 
 
   {15., 0., 1.66667, 5.33333, 20.3333}, {18.6667, 3.66667, 0., 3.66667, 18.6667}, 
 
   {20.3333, 5.33333, 1.66667, 0., 15.}, {21.3333, 6.33333, 2.66667, 1., 0.}}}
^*)
