(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  SimulateChain
CALLING SEQUENCE:  SimulateChain[n, P, stateslist, startstate, print]
PARAMETERS:
     n - an integer
     P - a Markov chain transition matrix
     stateslist - a list of values, with Length[stateslist] = Length[P]
     startstate - a value found in stateslist
     print - a Boolean variable (True or False)
SYNOPSIS:
     -  This program simulates n steps of a Markov chain with transition matrix P and
         states in stateslist, that begins in state startstate.  For each state, the program
         prints out the number of times that state was reached, and the fraction of the time
         this occurred.  The program returns a list whose ith element is the fraction of the
         time state stateslist[[i]] was reached.  If print = True, the program also prints out
         each state as it is reached.
RETURNED VALUES:
     -  a list whose ith element is the fraction of the time state stateslist[[i]] was reached
LOCATION:
     Folder:  Chapter 11
     File:       "SimulateChain.Chpt11.mat"
;[s]
5:0,0;675,1;677,0;881,1;883,0;1033,-1;
2:3,14,10,Helvetica,0,12,0,0,0;2,22,14,Helvetica,32,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[SimulateChain];
SimulateChain[n_, P_, stateslist_, startstate_, print_] :=
Block[{totallist = Table[0, {i, 1, Length[stateslist]}],
       state
      },
      state = Flatten[Position[stateslist, startstate]][[1]];
      For[j = 1, j <= n, j++,
          r = Random[];
          For[k = 1, k <= Length[stateslist], k++,
              r = r - P[[state]][[k]];
              If[r < 0,
                 state = k;
                 totallist[[k]] = totallist[[k]] + 1;
                 If[print, Print[stateslist[[state]]]];
                 Break[]
                ]
             ]       
         ];
      Print["State  Times  Fraction"];
      Print["  "];
      For[l = 1, l <= Length[totallist], l++,
          Print[stateslist[[l]],  "        ", 
                totallist[[l]], "     ",
                N[totallist[[l]]/n, 5]
               ]
         ];   
      Return[N[totallist/n,5]]
     ]
(*
:[font = input; preserveAspect; startGroup]
P={{.5,.25,.25},{.5,0,.5},{.25,.25,.5}}
:[font = output; output; inactive; preserveAspect; endGroup]
{{0.5, 0.25, 0.25}, {0.5, 0, 0.5}, {0.25, 0.25, 0.5}}
;[o]
{{0.5, 0.25, 0.25}, {0.5, 0, 0.5}, {0.25, 0.25, 0.5}}
:[font = input; preserveAspect; startGroup]
SimulateChain[10000, P, {"R", "N", "S"}, "S", False]
:[font = print; inactive; preserveAspect]
State  Times  Fraction
  
R        4006     0.4006
N        1963     0.1963
S        4031     0.4031
:[font = output; output; inactive; preserveAspect; endGroup]
{0.4006000000000001, 0.1963, 0.4031000000000001}
;[o]
{0.4006, 0.1963, 0.4031}
^*)
