(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  BertrandsParadox
CALLING SEQUENCE:  BertrandsParadox[n, print]
PARAMETERS:
     n - an integer
     print - a Boolean variable (True or False)
SYNOPSIS:
     -  This program illustrates Bertrand's Paradox by choosing n random chords of a
        circle three times, each time using a different one of the three coordinatizations
        described in the book.  For each coordinatization, the program prints the
        proportion of chosen chords with length greater than Sqrt[3] and, if print = True,
        displays a picture of the experiment, drawing  every one-hundredth chord.
RETURNED VALUES:
     -  none
LOCATION:
     Folder:  Chapter 2
     File:       "BertrandsParadox.Chpt2.mat"
;[s]
1:0,1;704,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[BertrandsParadox];
BertrandsParadox[n_, print_] :=
Block[{s, t1, t2, q, theta, x0, x1, y0, y1, 
       r, l2, alpha, l3,
       list1 = {}, list2 = {}, list3 = {},
       total1 = 0, total2 = 0, total3 = 0
      },
(*  circ produces the circle on which the experiments are displayed *)
      circ=Graphics[Circle[{0,0},1]];
      For[i = 1, i <= n , i++,
          s = True;
          While[s,
                t1 = Random[Real, {-1,1}];
                t2 = Random[Real, {-1,1}];
                If[(t1^2)+(t2^2) <= 1, s = False]
               ];
          If[(Mod[i, 100] == 0)&&(print),
             q = Sqrt[(t1^2)+(t2^2)];
             If[Random[Integer, {0,1}] == 0,
                theta = ArcTan[t2/t1],
                theta = ArcTan[t2/t1] + Pi//N
               ];
             x0 = Cos[theta - ArcCos[q]];
             x1 = Cos[theta + ArcCos[q]];
             y0 = Sin[theta - ArcCos[q]];
             y1 = Sin[theta + ArcCos[q]];
             list1 = Append[list1, 
                            Graphics[Line[{{x0, y0},
                                           {x1, y1}
                                          }
                                         ]
                                    ]
                           ]
            ];
          l1 = 2*Sqrt[1-((t1^2)+(t2^2))];
          If[l1 > Sqrt[3]//N, total1++];
          
          r = Random[Real, {-1,1}];
          If[(Mod[i, 100] == 0)&&(print),
             list2 = Append[list2, 
                            Graphics[Line[{{Sqrt[1-(r^2)],r},
                                           {-Sqrt[1-(r^2)],r}
                                          }
                                         ]
                                    ]
                           ]
            ];
          l2 = 2*Sqrt[1-(r^2)];
          If[l2 > Sqrt[3]//N, total2++];
          
          alpha = Random[Real, {0, 2*Pi//N}];
          If[(Mod[i, 100] == 0)&&(print),
             list3 = Append[list3, 
                            Graphics[Line[{{1,0},
                                           {Cos[alpha], Sin[alpha]}
                                          }
                                         ]
                                    ]
                           ]
            ];
          l3 = Sqrt[2 - (2*Cos[alpha])];
          If[l3 > Sqrt[3]//N, total3++]
         ];
      Print["Case 1:  Probability (chord length > Sqrt[3]) = ", total1/n//N];
      Print["Case 2:  Probability (chord length > Sqrt[3]) = ", total2/n//N];
      Print["Case 3:  Probability (chord length > Sqrt[3]) = ", total3/n//N];
      If[print,
         Show[circ, list1, AspectRatio->.95, PlotLabel->"Case 1"];
         Show[circ, list2, AspectRatio->.95, PlotLabel->"Case 2"];
         Show[circ, list3, AspectRatio->.95, PlotLabel->"Case 3"]
        ]
     ]
(*
:[font = input; preserveAspect; startGroup]
BertrandsParadox[5000,True];
:[font = print; inactive; preserveAspect]
Case 1:  Probability chord length > Sqrt[3] = 0.265
Case 2:  Probability chord length > Sqrt[3] = 0.511
Case 3:  Probability chord length > Sqrt[3] = 0.3266
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 267; startGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .95 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.475 0.452381 [
[(Case 1)] .5 .95 0 -2 Msboxa
[ 0 0 0 0 ]
[ 1 .95 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
[(Case 1)] .5 .95 0 -2 Mshowa
P
0 0 m
1 0 L
1 .95 L
0 .95 L
closepath
clip
newpath
p
.004 w
newpath
matrix currentmatrix
.47619 .45238 scale
1.05 1.05 1 0 365.73 arc
setmatrix
s
.80315 .82387 m
.03935 .36038 L
s
.04543 .34022 m
.26427 .08194 L
s
.02519 .44057 m
.44506 .02564 L
s
.90125 .23139 m
.96226 .36639 L
s
.02762 .41788 m
.72042 .074 L
s
.07383 .27316 m
.82733 .14645 L
s
.83046 .80072 m
.03781 .5839 L
s
.82275 .80762 m
.51211 .92723 L
s
.19972 .1239 m
.70672 .06747 L
s
.91667 .256 m
.94333 .30987 L
s
.9328 .66367 m
.37021 .91025 L
s
.55969 .02619 m
.88671 .73898 L
s
.02916 .5426 m
.30732 .06131 L
s
.78685 .83609 m
.0721 .2765 L
s
.92845 .67244 m
.08228 .69219 L
s
.13957 .17935 m
.26213 .0831 L
s
.95326 .33631 m
.66793 .89832 L
s
.75865 .09517 m
.48985 .92728 L
s
.47001 .92648 m
.06185 .29782 L
s
.91741 .69272 m
.04023 .59276 L
s
.02902 .40827 m
.96621 .38287 L
s
.96455 .37557 m
.97605 .46406 L
s
.61986 .91282 m
.15369 .16449 L
s
.19443 .82196 m
.28508 .07132 L
s
.8894 .21461 m
.97592 .49037 L
s
.97499 .44285 m
.64073 .90717 L
s
.80802 .13 m
.39077 .91532 L
s
.50218 .02262 m
.96992 .54815 L
s
.31782 .05703 m
.57521 .0283 L
s
.06677 .66279 m
.33571 .05039 L
s
.62846 .91061 m
.06842 .66618 L
s
.65505 .04727 m
.76108 .85333 L
s
.41648 .02963 m
.83167 .15039 L
s
.03423 .38087 m
.45209 .02491 L
s
.16072 .79243 m
.04228 .59978 L
s
.55804 .02599 m
.85642 .175 L
s
.77462 .84458 m
.09672 .71557 L
s
.59905 .91749 m
.13019 .76 L
s
.96981 .54883 m
.10199 .72336 L
s
.28483 .07144 m
.946 .31648 L
s
.19226 .12978 m
.77502 .1057 L
s
.93468 .29028 m
.97596 .46104 L
s
.85364 .77795 m
.03065 .39857 L
s
.70444 .88357 m
.33088 .89789 L
s
.14505 .77657 m
.69831 .06372 L
s
.08664 .25041 m
.79015 .11629 L
s
.0433 .60311 m
.31935 .05644 L
s
.19562 .8229 m
.16662 .15198 L
s
.2001 .8264 m
.08029 .26131 L
s
.87487 .19604 m
.53201 .92636 L
s
P
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 267]
%!
%%Creator: Mathematica
%%AspectRatio: .95 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.475 0.452381 [
[(Case 2)] .5 .95 0 -2 Msboxa
[ 0 0 0 0 ]
[ 1 .95 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
[(Case 2)] .5 .95 0 -2 Mshowa
P
0 0 m
1 0 L
1 .95 L
0 .95 L
closepath
clip
newpath
p
.004 w
newpath
matrix currentmatrix
.47619 .45238 scale
1.05 1.05 1 0 365.73 arc
setmatrix
s
.93085 .28234 m
.06915 .28234 L
s
.87497 .19615 m
.12503 .19615 L
s
.97265 .41993 m
.02735 .41993 L
s
.9737 .42878 m
.0263 .42878 L
s
.95156 .33139 m
.04844 .33139 L
s
.81949 .81045 m
.18051 .81045 L
s
.90083 .71923 m
.09917 .71923 L
s
.9759 .45926 m
.0241 .45926 L
s
.72753 .0776 m
.27247 .0776 L
s
.90806 .70817 m
.09194 .70817 L
s
.9506 .32871 m
.0494 .32871 L
s
.96767 .56017 m
.03233 .56017 L
s
.72987 .07882 m
.27013 .07882 L
s
.88795 .21267 m
.11205 .21267 L
s
.90062 .71954 m
.09938 .71954 L
s
.97617 .4793 m
.02383 .4793 L
s
.91336 .25041 m
.08664 .25041 L
s
.97455 .5125 m
.02545 .5125 L
s
.76171 .85293 m
.23829 .85293 L
s
.9759 .49072 m
.0241 .49072 L
s
.6752 .89565 m
.3248 .89565 L
s
.94845 .62714 m
.05155 .62714 L
s
.97372 .429 m
.02628 .429 L
s
.96361 .3717 m
.03639 .3717 L
s
.97301 .4228 m
.02699 .4228 L
s
.89083 .21656 m
.10917 .21656 L
s
.72649 .87294 m
.27351 .87294 L
s
.58316 .02957 m
.41684 .02957 L
s
.94372 .31081 m
.05628 .31081 L
s
.94336 .64007 m
.05664 .64007 L
s
.57114 .9223 m
.42886 .9223 L
s
.89687 .725 m
.10313 .725 L
s
.96788 .39087 m
.03212 .39087 L
s
.93348 .66225 m
.06652 .66225 L
s
.89418 .72881 m
.10582 .72881 L
s
.97051 .40531 m
.02949 .40531 L
s
.91426 .6981 m
.08574 .6981 L
s
.96019 .35872 m
.03981 .35872 L
s
.89405 .72899 m
.10595 .72899 L
s
.94279 .30857 m
.05721 .30857 L
s
.73074 .87072 m
.26926 .87072 L
s
.63176 .90972 m
.36824 .90972 L
s
.95678 .60286 m
.04322 .60286 L
s
.97431 .51519 m
.02569 .51519 L
s
.96489 .37702 m
.03511 .37702 L
s
.97113 .40926 m
.02887 .40926 L
s
.96187 .36491 m
.03813 .36491 L
s
.8806 .74687 m
.1194 .74687 L
s
.9751 .44445 m
.0249 .44445 L
s
.93026 .28116 m
.06974 .28116 L
s
P
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 267; endGroup; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .95 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.475 0.452381 [
[(Case 3)] .5 .95 0 -2 Msboxa
[ 0 0 0 0 ]
[ 1 .95 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
[(Case 3)] .5 .95 0 -2 Mshowa
P
0 0 m
1 0 L
1 .95 L
0 .95 L
closepath
clip
newpath
p
.004 w
newpath
matrix currentmatrix
.47619 .45238 scale
1.05 1.05 1 0 365.73 arc
setmatrix
s
.97619 .475 m
.31312 .89109 L
s
.97619 .475 m
.63727 .04182 L
s
.97619 .475 m
.0834 .25588 L
s
.97619 .475 m
.97445 .43637 L
s
.97619 .475 m
.17313 .80397 L
s
.97619 .475 m
.37513 .03845 L
s
.97619 .475 m
.76437 .85126 L
s
.97619 .475 m
.87755 .19931 L
s
.97619 .475 m
.95152 .61873 L
s
.97619 .475 m
.80653 .12881 L
s
.97619 .475 m
.19572 .82298 L
s
.97619 .475 m
.22642 .84527 L
s
.97619 .475 m
.08934 .70402 L
s
.97619 .475 m
.24839 .85907 L
s
.97619 .475 m
.11051 .73526 L
s
.97619 .475 m
.13692 .1823 L
s
.97619 .475 m
.74104 .86515 L
s
.97619 .475 m
.81751 .81214 L
s
.97619 .475 m
.31886 .89337 L
s
.97619 .475 m
.82257 .14222 L
s
.97619 .475 m
.2429 .85578 L
s
.97619 .475 m
.0501 .62323 L
s
.97619 .475 m
.94954 .32579 L
s
.97619 .475 m
.75605 .09358 L
s
.97619 .475 m
.95294 .33537 L
s
.97619 .475 m
.58636 .03012 L
s
.97619 .475 m
.05466 .63518 L
s
.97619 .475 m
.71826 .07294 L
s
.97619 .475 m
.93541 .65817 L
s
.97619 .475 m
.87573 .19708 L
s
.97619 .475 m
.75762 .09454 L
s
.97619 .475 m
.75514 .85697 L
s
.97619 .475 m
.02523 .50988 L
s
.97619 .475 m
.24603 .09233 L
s
.97619 .475 m
.57344 .02803 L
s
.97619 .475 m
.04203 .59893 L
s
.97619 .475 m
.27149 .07811 L
s
.97619 .475 m
.11937 .74684 L
s
.97619 .475 m
.33018 .89764 L
s
.97619 .475 m
.49156 .02269 L
s
.97619 .475 m
.27112 .8717 L
s
.97619 .475 m
.21862 .83995 L
s
.97619 .475 m
.05257 .62984 L
s
.97619 .475 m
.97617 .47907 L
s
.97619 .475 m
.74729 .0884 L
s
.97619 .475 m
.61716 .91347 L
s
.97619 .475 m
.04334 .34677 L
s
.97619 .475 m
.97551 .49909 L
s
.97619 .475 m
.76251 .09757 L
s
.97619 .475 m
.02414 .49178 L
s
P
% End of Graphics
MathPictureEnd

^*)
