(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  MonteCarlo
CALLING SEQUENCE:  MonteCarlo[n, f, xmin, xmax, ymax]
PARAMETERS:
     n - an integer
     f - the name of a pre-defined function of one variable
     xmin, xmax, ymax - real numbers
SYNOPSIS:
     -  This program estimates  the area under the input function f[x] and above the
         interval [xmin, xmax] by choosing n random points in the rectangle above the
         interval [xmin, xmax] and between the y-values 0 and ymax.  The function f[x] is
         assumed to be non-negative on the interval [xmin, xmax], and is assumed to
         have a maximum value which does not exceed ymax.   (Note: it is not necessary
         that the maximum value of f[x] = ymax.)  The program returns its area estimate,
         and also plots the random points and the function f[x] on the interval  [xmin,
         xmax].  
     -  Keep in mind that the function f[x] should be defined before this program is
        called, and  then the name of the function, namely f (or some other name, like
        Cos) should be given to this program.  The expression for the function (such as
        x^2, for example) should not  be given as a parameter.
RETURNED VALUES:
     -  none
LOCATION:
     Folder:  Chapter 2
     File:       "MonteCarlo.Chpt2.mat"
;[s]
1:0,1;1268,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[MonteCarlo];
MonteCarlo[n_, f_, xmin_, xmax_, ymax_] :=
Block[{boxarea = ymax*(xmax - xmin),
       
(*  Because of a bug in the Mathematica function Random, we
    must first take numerical approximations to the input values
    xmin, xmax, and ymax.
*)
     
       nymax = N[ymax],
       nxmax = N[xmax],
       nxmin = N[xmin],
       count = 0,
       randpoint,
       pointlist = {}
       },
      For[i = 1, i <= n, i++,
          randpoint = {Random[Real, {nxmin, nxmax}],
                       Random[Real, {0, nymax}]
                      };
          pointlist = Append[pointlist, randpoint];
          If[(randpoint[[2]] <= f[randpoint[[1]]]), 
             count++
            ];
         ];
      Print[(count/n)*ymax*(xmax - xmin)//N];
      
(* In the following command, the first two graphics calls
are given the option DisplayFunction -> Identity so
that they are not plotted on the screen.  Then the Show
command is given the two plots with the DisplayFunction
option set back to the default value.  This results in
only one graph being shown on the screen, rather than
three.
*)

      Show[{Plot[f[x], {x, xmin, xmax},
            DisplayFunction -> Identity], 
            ListPlot[pointlist, DisplayFunction -> Identity]
           }, DisplayFunction -> $DisplayFunction,
           AspectRatio -> 1
          ];
     ]

(*
;[s]
3:0,0;135,1;146,0;1355,-1;
2:2,12,10,Courier,1,12,0,0,0;1,12,10,Courier,3,12,0,0,0;
:[font = input; preserveAspect]
Clear[f];
f[x_] := x^2
:[font = input; preserveAspect; startGroup]
MonteCarlo[100, f, 0, 1, 1]
:[font = print; inactive; preserveAspect]
0.27
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 282; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0238095 0.952381 [
[(0.2)] .21429 .02381 0 2 Msboxa
[(0.4)] .40476 .02381 0 2 Msboxa
[(0.6)] .59524 .02381 0 2 Msboxa
[(0.8)] .78571 .02381 0 2 Msboxa
[(1)] .97619 .02381 0 2 Msboxa
[(0.2)] .01131 .21429 1 0 Msboxa
[(0.4)] .01131 .40476 1 0 Msboxa
[(0.6)] .01131 .59524 1 0 Msboxa
[(0.8)] .01131 .78571 1 0 Msboxa
[(1)] .01131 .97619 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21429 .02381 m
.21429 .03006 L
s
P
[(0.2)] .21429 .02381 0 2 Mshowa
p
.002 w
.40476 .02381 m
.40476 .03006 L
s
P
[(0.4)] .40476 .02381 0 2 Mshowa
p
.002 w
.59524 .02381 m
.59524 .03006 L
s
P
[(0.6)] .59524 .02381 0 2 Mshowa
p
.002 w
.78571 .02381 m
.78571 .03006 L
s
P
[(0.8)] .78571 .02381 0 2 Mshowa
p
.002 w
.97619 .02381 m
.97619 .03006 L
s
P
[(1)] .97619 .02381 0 2 Mshowa
p
.001 w
.0619 .02381 m
.0619 .02756 L
s
P
p
.001 w
.1 .02381 m
.1 .02756 L
s
P
p
.001 w
.1381 .02381 m
.1381 .02756 L
s
P
p
.001 w
.17619 .02381 m
.17619 .02756 L
s
P
p
.001 w
.25238 .02381 m
.25238 .02756 L
s
P
p
.001 w
.29048 .02381 m
.29048 .02756 L
s
P
p
.001 w
.32857 .02381 m
.32857 .02756 L
s
P
p
.001 w
.36667 .02381 m
.36667 .02756 L
s
P
p
.001 w
.44286 .02381 m
.44286 .02756 L
s
P
p
.001 w
.48095 .02381 m
.48095 .02756 L
s
P
p
.001 w
.51905 .02381 m
.51905 .02756 L
s
P
p
.001 w
.55714 .02381 m
.55714 .02756 L
s
P
p
.001 w
.63333 .02381 m
.63333 .02756 L
s
P
p
.001 w
.67143 .02381 m
.67143 .02756 L
s
P
p
.001 w
.70952 .02381 m
.70952 .02756 L
s
P
p
.001 w
.74762 .02381 m
.74762 .02756 L
s
P
p
.001 w
.82381 .02381 m
.82381 .02756 L
s
P
p
.001 w
.8619 .02381 m
.8619 .02756 L
s
P
p
.001 w
.9 .02381 m
.9 .02756 L
s
P
p
.001 w
.9381 .02381 m
.9381 .02756 L
s
P
p
.002 w
0 .02381 m
1 .02381 L
s
P
p
.002 w
.02381 .21429 m
.03006 .21429 L
s
P
[(0.2)] .01131 .21429 1 0 Mshowa
p
.002 w
.02381 .40476 m
.03006 .40476 L
s
P
[(0.4)] .01131 .40476 1 0 Mshowa
p
.002 w
.02381 .59524 m
.03006 .59524 L
s
P
[(0.6)] .01131 .59524 1 0 Mshowa
p
.002 w
.02381 .78571 m
.03006 .78571 L
s
P
[(0.8)] .01131 .78571 1 0 Mshowa
p
.002 w
.02381 .97619 m
.03006 .97619 L
s
P
[(1)] .01131 .97619 1 0 Mshowa
p
.001 w
.02381 .0619 m
.02756 .0619 L
s
P
p
.001 w
.02381 .1 m
.02756 .1 L
s
P
p
.001 w
.02381 .1381 m
.02756 .1381 L
s
P
p
.001 w
.02381 .17619 m
.02756 .17619 L
s
P
p
.001 w
.02381 .25238 m
.02756 .25238 L
s
P
p
.001 w
.02381 .29048 m
.02756 .29048 L
s
P
p
.001 w
.02381 .32857 m
.02756 .32857 L
s
P
p
.001 w
.02381 .36667 m
.02756 .36667 L
s
P
p
.001 w
.02381 .44286 m
.02756 .44286 L
s
P
p
.001 w
.02381 .48095 m
.02756 .48095 L
s
P
p
.001 w
.02381 .51905 m
.02756 .51905 L
s
P
p
.001 w
.02381 .55714 m
.02756 .55714 L
s
P
p
.001 w
.02381 .63333 m
.02756 .63333 L
s
P
p
.001 w
.02381 .67143 m
.02756 .67143 L
s
P
p
.001 w
.02381 .70952 m
.02756 .70952 L
s
P
p
.001 w
.02381 .74762 m
.02756 .74762 L
s
P
p
.001 w
.02381 .82381 m
.02756 .82381 L
s
P
p
.001 w
.02381 .8619 m
.02756 .8619 L
s
P
p
.001 w
.02381 .9 m
.02756 .9 L
s
P
p
.001 w
.02381 .9381 m
.02756 .9381 L
s
P
p
.002 w
.02381 0 m
.02381 1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
p
.004 w
.02381 .02381 m
.02505 .02381 L
.02629 .02382 L
.02753 .02382 L
.02877 .02384 L
.03001 .02385 L
.03125 .02387 L
.03373 .02391 L
.03621 .02397 L
.03869 .02404 L
.04365 .02422 L
.04861 .02446 L
.05357 .02474 L
.06349 .02546 L
.07341 .02639 L
.08333 .02753 L
.10317 .03042 L
.12302 .03414 L
.14286 .03869 L
.18254 .05026 L
.22222 .06515 L
.2619 .08333 L
.30159 .10483 L
.34127 .12963 L
.38095 .15774 L
.42063 .18915 L
.46032 .22388 L
.5 .2619 L
.53968 .30324 L
.57937 .34788 L
.61905 .39583 L
.65873 .44709 L
.69841 .50165 L
.7381 .55952 L
.77778 .6207 L
.81746 .68519 L
.85714 .75298 L
.89683 .82407 L
.93651 .89848 L
.97619 .97619 L
s
P
P
p
.008 w
.77752 .12796 Mdot
.21285 .34333 Mdot
.09026 .53313 Mdot
.15185 .4506 Mdot
.70607 .85004 Mdot
.66088 .97208 Mdot
.96956 .9603 Mdot
.66369 .37436 Mdot
.23168 .76194 Mdot
.72105 .3859 Mdot
.79828 .87559 Mdot
.32554 .06356 Mdot
.04457 .77144 Mdot
.1365 .69642 Mdot
.93051 .26212 Mdot
.96084 .26964 Mdot
.24824 .38827 Mdot
.32377 .27374 Mdot
.25488 .40417 Mdot
.63627 .87557 Mdot
.04701 .61841 Mdot
.89141 .51347 Mdot
.22491 .71901 Mdot
.58968 .47372 Mdot
.20415 .92376 Mdot
.47698 .75349 Mdot
.24984 .68545 Mdot
.49233 .50766 Mdot
.0254 .32098 Mdot
.19237 .25773 Mdot
.74671 .89301 Mdot
.5323 .35836 Mdot
.72351 .2984 Mdot
.61708 .82107 Mdot
.52241 .55558 Mdot
.05121 .37116 Mdot
.34207 .60801 Mdot
.55041 .59386 Mdot
.11604 .89875 Mdot
.08189 .11001 Mdot
.11445 .60158 Mdot
.86571 .82847 Mdot
.34393 .68477 Mdot
.35722 .49392 Mdot
.5966 .41017 Mdot
.71633 .64904 Mdot
.098 .83078 Mdot
.68893 .30169 Mdot
.73213 .24658 Mdot
.16233 .68402 Mdot
.63989 .32402 Mdot
.10425 .59782 Mdot
.54925 .69863 Mdot
.21474 .74554 Mdot
.22913 .03767 Mdot
.83371 .27543 Mdot
.60872 .60369 Mdot
.14119 .60258 Mdot
.53452 .7491 Mdot
.42844 .3247 Mdot
.77859 .52633 Mdot
.28992 .61687 Mdot
.1625 .22612 Mdot
.20948 .04286 Mdot
.58945 .50368 Mdot
.97094 .27351 Mdot
.38412 .48981 Mdot
.16104 .97427 Mdot
.7516 .86231 Mdot
.04366 .3955 Mdot
.24089 .13702 Mdot
.59141 .09461 Mdot
.43849 .58689 Mdot
.3253 .45392 Mdot
.29979 .38458 Mdot
.13962 .43487 Mdot
.68654 .85709 Mdot
.14488 .18517 Mdot
.32623 .39109 Mdot
.96003 .18709 Mdot
.55082 .50496 Mdot
.94018 .76779 Mdot
.33374 .39175 Mdot
.37258 .69699 Mdot
.87144 .78105 Mdot
.07109 .26687 Mdot
.59546 .42028 Mdot
.90766 .80819 Mdot
.88511 .53938 Mdot
.78659 .64683 Mdot
.58269 .1721 Mdot
.80275 .48355 Mdot
.05568 .64333 Mdot
.83876 .69195 Mdot
.69813 .27538 Mdot
.48999 .97116 Mdot
.80288 .47052 Mdot
.44271 .72809 Mdot
.23123 .07405 Mdot
.51124 .89609 Mdot
P
P
% End of Graphics
MathPictureEnd

:[font = input; preserveAspect; startGroup]
MonteCarlo[Cos, 0, Pi/2, 1, 100]
:[font = print; inactive; preserveAspect]
0.879646
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 282; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.606305 0.0238095 0.952381 [
[(0.25)] .17539  .02381  0 2 Msboxa
[(0.5)] .32696  .02381  0 2 Msboxa
[(0.75)] .47854  .02381  0 2 Msboxa
[(1)] .63011  .02381  0 2 Msboxa
[(1.25)] .78169  .02381  0 2 Msboxa
[(1.5)] .93327  .02381  0 2 Msboxa
[(0.2)] .01131  .21429  1 0 Msboxa
[(0.4)] .01131  .40476  1 0 Msboxa
[(0.6)] .01131  .59524  1 0 Msboxa
[(0.8)] .01131  .78571  1 0 Msboxa
[(1)] .01131  .97619  1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 1.001 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002  w
.17539  .02381  m
.17539  .03006  L
s
P
[(0.25)] .17539  .02381  0 2 Mshowa
p
.002  w
.32696  .02381  m
.32696  .03006  L
s
P
[(0.5)] .32696  .02381  0 2 Mshowa
p
.002  w
.47854  .02381  m
.47854  .03006  L
s
P
[(0.75)] .47854  .02381  0 2 Mshowa
p
.002  w
.63011  .02381  m
.63011  .03006  L
s
P
[(1)] .63011  .02381  0 2 Mshowa
p
.002  w
.78169  .02381  m
.78169  .03006  L
s
P
[(1.25)] .78169  .02381  0 2 Mshowa
p
.002  w
.93327  .02381  m
.93327  .03006  L
s
P
[(1.5)] .93327  .02381  0 2 Mshowa
p
.001  w
.05412  .02381  m
.05412  .02756  L
s
P
p
.001  w
.08444  .02381  m
.08444  .02756  L
s
P
p
.001  w
.11476  .02381  m
.11476  .02756  L
s
P
p
.001  w
.14507  .02381  m
.14507  .02756  L
s
P
p
.001  w
.2057  .02381  m
.2057  .02756  L
s
P
p
.001  w
.23602  .02381  m
.23602  .02756  L
s
P
p
.001  w
.26633  .02381  m
.26633  .02756  L
s
P
p
.001  w
.29665  .02381  m
.29665  .02756  L
s
P
p
.001  w
.35728  .02381  m
.35728  .02756  L
s
P
p
.001  w
.38759  .02381  m
.38759  .02756  L
s
P
p
.001  w
.41791  .02381  m
.41791  .02756  L
s
P
p
.001  w
.44822  .02381  m
.44822  .02756  L
s
P
p
.001  w
.50885  .02381  m
.50885  .02756  L
s
P
p
.001  w
.53917  .02381  m
.53917  .02756  L
s
P
p
.001  w
.56948  .02381  m
.56948  .02756  L
s
P
p
.001  w
.5998  .02381  m
.5998  .02756  L
s
P
p
.001  w
.66043  .02381  m
.66043  .02756  L
s
P
p
.001  w
.69074  .02381  m
.69074  .02756  L
s
P
p
.001  w
.72106  .02381  m
.72106  .02756  L
s
P
p
.001  w
.75137  .02381  m
.75137  .02756  L
s
P
p
.001  w
.81201  .02381  m
.81201  .02756  L
s
P
p
.001  w
.84232  .02381  m
.84232  .02756  L
s
P
p
.001  w
.87264  .02381  m
.87264  .02756  L
s
P
p
.001  w
.90295  .02381  m
.90295  .02756  L
s
P
p
.001  w
.96358  .02381  m
.96358  .02756  L
s
P
p
.001  w
.9939  .02381  m
.9939  .02756  L
s
P
p
.002  w
0 .02381  m
1 .02381  L
s
P
p
.002  w
.02381  .21429  m
.03006  .21429  L
s
P
[(0.2)] .01131  .21429  1 0 Mshowa
p
.002  w
.02381  .40476  m
.03006  .40476  L
s
P
[(0.4)] .01131  .40476  1 0 Mshowa
p
.002  w
.02381  .59524  m
.03006  .59524  L
s
P
[(0.6)] .01131  .59524  1 0 Mshowa
p
.002  w
.02381  .78571  m
.03006  .78571  L
s
P
[(0.8)] .01131  .78571  1 0 Mshowa
p
.002  w
.02381  .97619  m
.03006  .97619  L
s
P
[(1)] .01131  .97619  1 0 Mshowa
p
.001  w
.02381  .0619  m
.02756  .0619  L
s
P
p
.001  w
.02381  .1  m
.02756  .1  L
s
P
p
.001  w
.02381  .1381  m
.02756  .1381  L
s
P
p
.001  w
.02381  .17619  m
.02756  .17619  L
s
P
p
.001  w
.02381  .25238  m
.02756  .25238  L
s
P
p
.001  w
.02381  .29048  m
.02756  .29048  L
s
P
p
.001  w
.02381  .32857  m
.02756  .32857  L
s
P
p
.001  w
.02381  .36667  m
.02756  .36667  L
s
P
p
.001  w
.02381  .44286  m
.02756  .44286  L
s
P
p
.001  w
.02381  .48095  m
.02756  .48095  L
s
P
p
.001  w
.02381  .51905  m
.02756  .51905  L
s
P
p
.001  w
.02381  .55714  m
.02756  .55714  L
s
P
p
.001  w
.02381  .63333  m
.02756  .63333  L
s
P
p
.001  w
.02381  .67143  m
.02756  .67143  L
s
P
p
.001  w
.02381  .70952  m
.02756  .70952  L
s
P
p
.001  w
.02381  .74762  m
.02756  .74762  L
s
P
p
.001  w
.02381  .82381  m
.02756  .82381  L
s
P
p
.001  w
.02381  .8619  m
.02756  .8619  L
s
P
p
.001  w
.02381  .9  m
.02756  .9  L
s
P
p
.001  w
.02381  .9381  m
.02756  .9381  L
s
P
p
.002  w
.02381  0 m
.02381  1 L
s
P
P
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
p
p
p
.004  w
.02381  .97619  m
.02505  .97619  L
.02629  .97618  L
.02753  .97617  L
.02877  .97616  L
.03001  .97614  L
.03125  .97612  L
.03373  .97606  L
.03621  .97599  L
.03869  .9759  L
.04365  .97568  L
.04861  .97539  L
.05357  .97504  L
.06349  .97415  L
.07341  .973  L
.08333  .9716  L
.10317  .96804  L
.12302  .96347  L
.14286  .95789  L
.18254  .94374  L
.22222  .92565  L
.2619  .90369  L
.30159  .87797  L
.34127  .8486  L
.38095  .81569  L
.42063  .77938  L
.46032  .73985  L
.5  .69724  L
.53968  .65176  L
.57937  .60358  L
.61905  .55292  L
.65873  .5  L
.69841  .44504  L
.7381  .38827  L
.77778  .32994  L
.81746  .2703  L
.85714  .20961  L
.89683  .14812  L
.93651  .0861  L
.97619  .02381  L
s
P
P
p
.008  w
.02678  .14646  Mdot
.39063  .28407  Mdot
.26452  .27152  Mdot
.54732  .55915  Mdot
.32896  .61093  Mdot
.72394  .14469  Mdot
.61399  .46631  Mdot
.58028  .75949  Mdot
.94897  .29787  Mdot
.82773  .29195  Mdot
.87467  .1223  Mdot
.20254  .75279  Mdot
.87169  .95203  Mdot
.7881  .49253  Mdot
.63099  .70431  Mdot
.26459  .90957  Mdot
.32583  .1172  Mdot
.51684  .78869  Mdot
.68804  .62707  Mdot
.91275  .053  Mdot
.71526  .35301  Mdot
.10883  .73724  Mdot
.81678  .25452  Mdot
.88249  .96064  Mdot
.92127  .27868  Mdot
.1182  .49192  Mdot
.3141  .55056  Mdot
.8298  .55854  Mdot
.96445  .45717  Mdot
.33677  .74604  Mdot
.30023  .80628  Mdot
.40021  .71684  Mdot
.56116  .47709  Mdot
.31518  .95579  Mdot
.72057  .24638  Mdot
.40888  .97135  Mdot
.77549  .94389  Mdot
.3145  .50324  Mdot
.4852  .41714  Mdot
.46089  .9209  Mdot
.49694  .93617  Mdot
.14793  .19867  Mdot
.22052  .15369  Mdot
.72391  .45801  Mdot
.63555  .6528  Mdot
.43254  .47841  Mdot
.89117  .43023  Mdot
.04747  .48325  Mdot
.13949  .46253  Mdot
.70916  .9562  Mdot
.63048  .06919  Mdot
.27209  .05911  Mdot
.15735  .10922  Mdot
.14797  .83664  Mdot
.91302  .93172  Mdot
.40024  .40243  Mdot
.30128  .30273  Mdot
.94389  .90022  Mdot
.3863  .84869  Mdot
.92023  .44077  Mdot
.27062  .40997  Mdot
.23488  .46076  Mdot
.61633  .36459  Mdot
.93898  .42546  Mdot
.48279  .27918  Mdot
.81483  .56501  Mdot
.54596  .32366  Mdot
.43839  .18639  Mdot
.2685  .04474  Mdot
.4707  .26236  Mdot
.85839  .17224  Mdot
.52666  .79778  Mdot
.61158  .73846  Mdot
.31559  .36083  Mdot
.97144  .39768  Mdot
.3528  .91156  Mdot
.51246  .1423  Mdot
.51416  .37036  Mdot
.94269  .79484  Mdot
.09958  .20778  Mdot
.698  .77391  Mdot
.60507  .9216  Mdot
.8158  .62548  Mdot
.10222  .14763  Mdot
.22803  .86322  Mdot
.76283  .763  Mdot
.23278  .48935  Mdot
.43384  .82763  Mdot
.69651  .37086  Mdot
.89587  .48108  Mdot
.73001  .55221  Mdot
.8201  .29711  Mdot
.05581  .75449  Mdot
.23884  .3517  Mdot
.2162  .15281  Mdot
.16043  .22787  Mdot
.96436  .26579  Mdot
.37379  .44107  Mdot
.75539  .75263  Mdot
.91614  .58963  Mdot
P
P
% End of Graphics
MathPictureEnd
^*)
