(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  PowerCurve
CALLING SEQUENCE:  PowerCurve[n, mlist, nullp, altp, errormax]
PARAMETERS:
      n - an integer
      mlist - a list of integers
     nullp, altp, errormax - real numbers
SYNOPSIS:
     -  The book defines, given m and n, alpha(p) = Sum[binomial(n, p, k)], k = m, ..., n. 
         The user enters into this program nullp (the null hypthesis p-value) and an altp
         (an alternative hypothesis p, greater than nullp).  The program then defines pmin
         = nullp - Abs[altp - nullp] and pmax = altp + Abs[altp - nullp], and plots alpha(p)
         on the interval [pmin, pmax] for each value m in mlist, with n equal to the
         parameter n.  The program displays all of these graphs together on a single set
         of axes, along with a dotted-line box, whose edges are decided as follows: we
         ultimately want each of the probabilities of a type 1or type 2 error occurring to be
         <=  errormax.  The box the program draws is such that a value of m satisfies this
         requirement if and only if the graph of alpha(p) enters the box from the bottom
         and leaves from the top (see book for more details).
     -  Note:  this program requires the program "Bin[n, p, k]" be initialized.
RETURNED VALUES:
     -  none
LOCATION:
     Folder:  Chapter 3
     File:       "PowerCurve.Chpt3.mat"
;[s]
1:0,1;1349,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[PowerCurve];
PowerCurve[n_, mlist_, nullp_, altp_, errormax_] :=
Block[{pmin = nullp - (Abs[altp - nullp]), 
       pmax = altp + (Abs[altp - nullp]),
       flist = {}
      },
      For[i = 1, i <= Length[mlist], i++,
          flist = Append[flist,
                         Plot[Sum[Bin[n, p, k], 
                                  {k, mlist[[i]], n}]
                             , {p, pmin, pmax},
                             DisplayFunction -> Identity
                             ]
                        ];
         ];   
      Show[Graphics[{Dashing[{0.03, 0.03}],
                     Line[{{nullp, errormax},
                          {altp, errormax}
                         }
                        ]
                   }],
           Graphics[{Dashing[{0.03, 0.03}],
                     Line[{{nullp, 1 - errormax},
                          {altp, 1 - errormax}
                         }
                        ]
                   }],
           Graphics[{Dashing[{0.03, 0.03}],
                     Line[{{nullp, errormax},
                          {nullp, 1 - errormax}
                         }
                        ]
                   }],
           Graphics[{Dashing[{0.03, 0.03}],
                     Line[{{altp, errormax},
                          {altp, 1 - errormax}
                         }
                        ]
                   }],
           flist, DisplayFunction -> $DisplayFunction,
           Axes -> True, PlotRange -> {0, 1}]
     ]
(*
:[font = input; preserveAspect; startGroup]
PowerCurve[100, {69, 73}, .6, .8, .05];
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.611939 1.58937 0 0.618034 [
[(0.4)] .02381 0 0 2 Msboxa
[(0.5)] .18275 0 0 2 Msboxa
[(0.6)] .34168 0 0 2 Msboxa
[(0.7)] .50062 0 0 2 Msboxa
[(0.8)] .65956 0 0 2 Msboxa
[(0.9)] .8185 0 0 2 Msboxa
[(1)] .97743 0 0 2 Msboxa
[(0.2)] .96493 .12361 1 0 Msboxa
[(0.4)] .96493 .24721 1 0 Msboxa
[(0.6)] .96493 .37082 1 0 Msboxa
[(0.8)] .96493 .49443 1 0 Msboxa
[(1)] .96493 .61803 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0.4)] .02381 0 0 2 Mshowa
p
.002 w
.18275 0 m
.18275 .00625 L
s
P
[(0.5)] .18275 0 0 2 Mshowa
p
.002 w
.34168 0 m
.34168 .00625 L
s
P
[(0.6)] .34168 0 0 2 Mshowa
p
.002 w
.50062 0 m
.50062 .00625 L
s
P
[(0.7)] .50062 0 0 2 Mshowa
p
.002 w
.65956 0 m
.65956 .00625 L
s
P
[(0.8)] .65956 0 0 2 Mshowa
p
.002 w
.8185 0 m
.8185 .00625 L
s
P
[(0.9)] .8185 0 0 2 Mshowa
p
.002 w
.97743 0 m
.97743 .00625 L
s
P
[(1)] .97743 0 0 2 Mshowa
p
.001 w
.0556 0 m
.0556 .00375 L
s
P
p
.001 w
.08738 0 m
.08738 .00375 L
s
P
p
.001 w
.11917 0 m
.11917 .00375 L
s
P
p
.001 w
.15096 0 m
.15096 .00375 L
s
P
p
.001 w
.21453 0 m
.21453 .00375 L
s
P
p
.001 w
.24632 0 m
.24632 .00375 L
s
P
p
.001 w
.27811 0 m
.27811 .00375 L
s
P
p
.001 w
.3099 0 m
.3099 .00375 L
s
P
p
.001 w
.37347 0 m
.37347 .00375 L
s
P
p
.001 w
.40526 0 m
.40526 .00375 L
s
P
p
.001 w
.43705 0 m
.43705 .00375 L
s
P
p
.001 w
.46883 0 m
.46883 .00375 L
s
P
p
.001 w
.53241 0 m
.53241 .00375 L
s
P
p
.001 w
.5642 0 m
.5642 .00375 L
s
P
p
.001 w
.59598 0 m
.59598 .00375 L
s
P
p
.001 w
.62777 0 m
.62777 .00375 L
s
P
p
.001 w
.69135 0 m
.69135 .00375 L
s
P
p
.001 w
.72313 0 m
.72313 .00375 L
s
P
p
.001 w
.75492 0 m
.75492 .00375 L
s
P
p
.001 w
.78671 0 m
.78671 .00375 L
s
P
p
.001 w
.85028 0 m
.85028 .00375 L
s
P
p
.001 w
.88207 0 m
.88207 .00375 L
s
P
p
.001 w
.91386 0 m
.91386 .00375 L
s
P
p
.001 w
.94564 0 m
.94564 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
.97743 .12361 m
.98368 .12361 L
s
P
[(0.2)] .96493 .12361 1 0 Mshowa
p
.002 w
.97743 .24721 m
.98368 .24721 L
s
P
[(0.4)] .96493 .24721 1 0 Mshowa
p
.002 w
.97743 .37082 m
.98368 .37082 L
s
P
[(0.6)] .96493 .37082 1 0 Mshowa
p
.002 w
.97743 .49443 m
.98368 .49443 L
s
P
[(0.8)] .96493 .49443 1 0 Mshowa
p
.002 w
.97743 .61803 m
.98368 .61803 L
s
P
[(1)] .96493 .61803 1 0 Mshowa
p
.001 w
.97743 .02472 m
.98118 .02472 L
s
P
p
.001 w
.97743 .04944 m
.98118 .04944 L
s
P
p
.001 w
.97743 .07416 m
.98118 .07416 L
s
P
p
.001 w
.97743 .09889 m
.98118 .09889 L
s
P
p
.001 w
.97743 .14833 m
.98118 .14833 L
s
P
p
.001 w
.97743 .17305 m
.98118 .17305 L
s
P
p
.001 w
.97743 .19777 m
.98118 .19777 L
s
P
p
.001 w
.97743 .22249 m
.98118 .22249 L
s
P
p
.001 w
.97743 .27193 m
.98118 .27193 L
s
P
p
.001 w
.97743 .29666 m
.98118 .29666 L
s
P
p
.001 w
.97743 .32138 m
.98118 .32138 L
s
P
p
.001 w
.97743 .3461 m
.98118 .3461 L
s
P
p
.001 w
.97743 .39554 m
.98118 .39554 L
s
P
p
.001 w
.97743 .42026 m
.98118 .42026 L
s
P
p
.001 w
.97743 .44498 m
.98118 .44498 L
s
P
p
.001 w
.97743 .46971 m
.98118 .46971 L
s
P
p
.001 w
.97743 .51915 m
.98118 .51915 L
s
P
p
.001 w
.97743 .54387 m
.98118 .54387 L
s
P
p
.001 w
.97743 .56859 m
.98118 .56859 L
s
P
p
.001 w
.97743 .59331 m
.98118 .59331 L
s
P
p
.002 w
.97743 0 m
.97743 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
[ .03 .03 ] 0 setdash
.004 w
.34168 .0309 m
.65956 .0309 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.34168 .58713 m
.65956 .58713 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.34168 .0309 m
.34168 .58713 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.65956 .0309 m
.65956 .58713 L
s
P
p
p
.004 w
.02381 0 m
.02629 0 L
.02878 0 L
.03374 0 L
.03623 0 L
.03871 0 L
.04368 0 L
.04864 0 L
.05361 0 L
.05858 0 L
.06354 0 L
.06851 0 L
.07348 0 L
.07844 0 L
.08341 0 L
.08838 0 L
.09334 0 L
.09831 0 L
.10328 0 L
.10824 0 L
.11321 0 L
.11818 0 L
.12315 0 L
.12811 0 L
.13308 0 L
.13805 1e-05 L
.14301 1e-05 L
.14798 1e-05 L
.15295 1e-05 L
.15791 2e-05 L
.16288 2e-05 L
.16785 3e-05 L
.17281 3e-05 L
.17778 4e-05 L
.18275 6e-05 L
.18771 7e-05 L
.19268 9e-05 L
.20261 .00015 L
.20758 .00019 L
.21255 .00023 L
.21751 .00029 L
.22248 .00036 L
.23241 .00055 L
.23738 .00068 L
.24235 .00084 L
.24731 .00102 L
.25228 .00125 L
.26222 .00183 L
.27215 .00266 L
.28208 .00381 L
Mistroke
.29202 .00537 L
.30195 .00748 L
.31188 .01028 L
.32182 .01393 L
.33175 .01865 L
.34168 .02463 L
.36155 .04133 L
.37148 .05251 L
.38142 .06588 L
.40129 .09987 L
.42115 .14407 L
.46089 .25971 L
.50062 .39128 L
.52049 .45206 L
.54036 .50416 L
.56022 .54533 L
.57016 .56162 L
.58009 .57517 L
.59002 .58618 L
.59996 .5949 L
.60989 .60164 L
.61982 .60671 L
.62976 .61042 L
.63472 .61186 L
.63969 .61306 L
.64466 .61406 L
.64962 .61488 L
.65459 .61556 L
.65956 .6161 L
.66452 .61654 L
.66949 .61689 L
.67446 .61716 L
.67943 .61738 L
.68439 .61754 L
.68936 .61767 L
.69433 .61777 L
.69929 .61784 L
.70426 .6179 L
.70923 .61794 L
.71419 .61797 L
.71916 .61799 L
.72164 .618 L
.72413 .618 L
.72661 .61801 L
.72909 .61801 L
.73406 .61802 L
.73654 .61802 L
.73903 .61802 L
.74151 .61803 L
.74399 .61803 L
Mistroke
.74648 .61803 L
.74896 .61803 L
.75393 .61803 L
.75641 .61803 L
.75889 .61803 L
.76138 .61803 L
.76386 .61803 L
.76634 .61803 L
.76883 .61803 L
.77131 .61803 L
.77379 .61803 L
.77628 .61803 L
.77876 .61803 L
.78124 .61803 L
.78373 .61803 L
.78621 .61803 L
.78869 .61803 L
.79118 .61803 L
.79366 .61803 L
.79614 .61803 L
.79863 .61803 L
.80111 .61803 L
.80359 .61803 L
.80608 .61803 L
.80856 .61803 L
.81104 .61803 L
.81353 .61803 L
.81477 .61803 L
.81601 .61803 L
.81725 .61803 L
.8185 .61803 L
.81974 .61803 L
.82098 .61803 L
.82222 .61803 L
.82346 .61803 L
.82595 .61803 L
.82719 .61803 L
.82843 .61803 L
.82967 .61803 L
.83091 .61803 L
.8334 .61803 L
.83464 .61803 L
.83588 .61803 L
.83712 .61803 L
.83836 .61803 L
.8396 .61803 L
.84085 .61803 L
.84209 .61803 L
.84333 .61803 L
.84457 .61803 L
Mistroke
.84581 .61803 L
.84705 .61803 L
.8483 .61803 L
.84954 .61803 L
.85078 .61803 L
.85202 .61803 L
.85326 .61803 L
.8545 .61803 L
.85575 .61803 L
.85699 .61803 L
.85823 .61803 L
.85947 .61803 L
.86071 .61803 L
.86195 .61803 L
.8632 .61803 L
.86444 .61803 L
.86568 .61803 L
.86692 .61803 L
.86816 .61803 L
.8694 .61803 L
.87065 .61803 L
.87189 .61803 L
.87313 .61803 L
.87561 .61803 L
.87685 .61803 L
.8781 .61803 L
.87934 .61803 L
.88058 .61803 L
Mfstroke
.88174 .61803 m
.88058 .61803 L
s
.88199 .61803 m
.88306 .61803 L
s
.88306 .61803 m
0 0 rlineto
.88407 .61803 m
.88306 .61803 L
s
.88449 .61803 m
.88555 .61803 L
s
.88555 .61803 m
.88679 .61803 L
.88803 .61803 L
s
.89004 .61803 m
.88803 .61803 L
s
.89093 .61803 m
.89176 .61803 L
s
.89176 .61803 m
0 0 rlineto
.89202 .61803 m
.89176 .61803 L
s
s
s
s
.89747 .61803 m
.89796 .61803 L
s
.89796 .61803 m
.89921 .61803 L
.90045 .61803 L
s
.9011 .61803 m
.90045 .61803 L
s
s
s
s
s
.90715 .61803 m
.9079 .61803 L
s
.9079 .61803 m
0 0 rlineto
.90835 .61803 m
.9079 .61803 L
s
s
s
.9122 .61803 m
.91286 .61803 L
s
.91286 .61803 m
0 0 rlineto
.91311 .61803 m
.91286 .61803 L
s
s
s
.91697 .61803 m
.91783 .61803 L
s
.91783 .61803 m
0 0 rlineto
.91888 .61803 m
.91783 .61803 L
s
s
s
.92207 .61803 m
.9228 .61803 L
s
.9228 .61803 m
.92404 .61803 L
.92528 .61803 L
.92652 .61803 L
s
.92652 .61803 m
.92652 .61803 L
s
.92796 .61803 m
.92901 .61803 L
s
.92901 .61803 m
.93025 .61803 L
.93149 .61803 L
.93273 .61803 L
s
.93337 .61803 m
.93273 .61803 L
s
.93508 .61803 m
.93521 .61803 L
s
.93521 .61803 m
.93646 .61803 L
.9377 .61803 L
.93894 .61803 L
.94018 .61803 L
.94142 .61803 L
s
.94142 .61803 m
.94142 .61803 L
s
.94284 .61803 m
.94391 .61803 L
s
.94391 .61803 m
0 0 rlineto
.94444 .61803 m
.94391 .61803 L
s
.94581 .61803 m
.94639 .61803 L
s
.94639 .61803 m
0 0 rlineto
.94736 .61803 m
.94639 .61803 L
s
.94778 .61803 m
.94887 .61803 L
s
.94887 .61803 m
.95011 .61803 L
s
.95011 .61803 m
.95011 .61803 L
s
s
s
.95474 .61803 m
.95508 .61803 L
s
.95508 .61803 m
.95757 .61803 L
.95881 .61803 L
.96005 .61803 L
s
.96081 .61803 m
.96005 .61803 L
s
s
.96315 .61803 m
.96377 .61803 L
s
.96377 .61803 m
0 0 rlineto
.96477 .61803 m
.96377 .61803 L
s
.96551 .61803 m
.96626 .61803 L
s
.96626 .61803 m
.9675 .61803 L
.96874 .61803 L
.96998 .61803 L
.97122 .61803 L
.97247 .61803 L
s
.97293 .61803 m
.97247 .61803 L
s
s
s
s
P
P
p
p
.004 w
.02381 0 m
.02629 0 L
.02878 0 L
.03374 0 L
.03623 0 L
.03871 0 L
.04119 0 L
.04368 0 L
.04864 0 L
.05113 0 L
.05361 0 L
.05609 0 L
.05858 0 L
.06106 0 L
.06354 0 L
.06603 0 L
.06851 0 L
.07348 0 L
.07596 0 L
.07844 0 L
.08093 0 L
.08341 0 L
.08838 0 L
.09086 0 L
.09334 0 L
.09831 0 L
.10328 0 L
.10824 0 L
.11321 0 L
.11818 0 L
.12315 0 L
.12811 0 L
.13308 0 L
.13805 0 L
.14301 0 L
.14798 0 L
.15295 0 L
.15791 0 L
.16288 0 L
.16785 0 L
.17281 0 L
.17778 0 L
.18275 0 L
.18771 0 L
.19268 0 L
.19765 0 L
.20261 0 L
.20758 1e-05 L
.21255 1e-05 L
.21751 1e-05 L
Mistroke
.22248 1e-05 L
.22745 2e-05 L
.23241 2e-05 L
.23738 3e-05 L
.24235 4e-05 L
.24731 5e-05 L
.25228 6e-05 L
.25725 8e-05 L
.26222 .0001 L
.26718 .00013 L
.27215 .00016 L
.28208 .00025 L
.28705 .00031 L
.29202 .00039 L
.29698 .00048 L
.30195 .00059 L
.31188 .0009 L
.31685 .0011 L
.32182 .00134 L
.33175 .00196 L
.34168 .00284 L
.35162 .00407 L
.36155 .00574 L
.37148 .008 L
.38142 .01099 L
.39135 .01492 L
.40129 .01999 L
.41122 .02643 L
.42115 .03449 L
.44102 .05653 L
.45095 .07098 L
.46089 .088 L
.50062 .18316 L
.54036 .31318 L
.58009 .44646 L
.59996 .50197 L
.61982 .54566 L
.62976 .56278 L
.63969 .57687 L
.64962 .58815 L
.65956 .59693 L
.66949 .60356 L
.67943 .60841 L
.68439 .61028 L
.68936 .61184 L
.69433 .61313 L
.69929 .61419 L
.70923 .61574 L
.71419 .61629 L
.71916 .61672 L
Mistroke
.72413 .61705 L
.72909 .61731 L
.73406 .61751 L
.73903 .61766 L
.74399 .61776 L
.74896 .61785 L
.75393 .6179 L
.75641 .61793 L
.75889 .61795 L
.76138 .61796 L
.76386 .61797 L
.76634 .61799 L
.76883 .61799 L
.77131 .618 L
.77379 .61801 L
.77628 .61801 L
.77876 .61802 L
.78373 .61802 L
.78621 .61803 L
.78869 .61803 L
.79118 .61803 L
.79366 .61803 L
.79614 .61803 L
.79863 .61803 L
.80111 .61803 L
.80359 .61803 L
.80608 .61803 L
.80856 .61803 L
.81104 .61803 L
.81353 .61803 L
.81601 .61803 L
.8185 .61803 L
.82098 .61803 L
.82346 .61803 L
.82595 .61803 L
.82843 .61803 L
.83091 .61803 L
.8334 .61803 L
.83588 .61803 L
.83712 .61803 L
.83836 .61803 L
.8396 .61803 L
.84085 .61803 L
.84209 .61803 L
.84333 .61803 L
.84457 .61803 L
.84581 .61803 L
.84705 .61803 L
.8483 .61803 L
.84954 .61803 L
Mistroke
.85078 .61803 L
.85202 .61803 L
.85326 .61803 L
.85575 .61803 L
.85699 .61803 L
.85823 .61803 L
.85947 .61803 L
.86071 .61803 L
.86195 .61803 L
.8632 .61803 L
.86444 .61803 L
.86568 .61803 L
.86692 .61803 L
.86816 .61803 L
.8694 .61803 L
.87065 .61803 L
.87189 .61803 L
.87313 .61803 L
.87437 .61803 L
.87561 .61803 L
.87685 .61803 L
.8781 .61803 L
.87934 .61803 L
.88058 .61803 L
.88182 .61803 L
.88306 .61803 L
.8843 .61803 L
.88555 .61803 L
.88679 .61803 L
.88803 .61803 L
.88927 .61803 L
.89051 .61803 L
.89176 .61803 L
.893 .61803 L
.89424 .61803 L
.89548 .61803 L
.89672 .61803 L
.89796 .61803 L
.90045 .61803 L
.90169 .61803 L
.90293 .61803 L
.90541 .61803 L
.90666 .61803 L
.9079 .61803 L
Mfstroke
.90867 .61803 m
.9079 .61803 L
s
s
s
.91181 .61803 m
.91286 .61803 L
s
.91286 .61803 m
0 0 rlineto
.91323 .61803 m
.91286 .61803 L
s
s
s
.91697 .61803 m
.91783 .61803 L
s
.91783 .61803 m
0 0 rlineto
.91893 .61803 m
.91783 .61803 L
s
s
s
.92207 .61803 m
.9228 .61803 L
s
.9228 .61803 m
.92404 .61803 L
.92528 .61803 L
.92652 .61803 L
s
.92652 .61803 m
.92652 .61803 L
s
.92796 .61803 m
.92901 .61803 L
s
.92901 .61803 m
.93025 .61803 L
.93149 .61803 L
.93273 .61803 L
s
.93337 .61803 m
.93273 .61803 L
s
.93508 .61803 m
.93521 .61803 L
s
.93521 .61803 m
.93646 .61803 L
.9377 .61803 L
.93894 .61803 L
.94018 .61803 L
.94142 .61803 L
s
.94142 .61803 m
.94142 .61803 L
s
.94284 .61803 m
.94391 .61803 L
s
.94391 .61803 m
0 0 rlineto
.94444 .61803 m
.94391 .61803 L
s
.94581 .61803 m
.94639 .61803 L
s
.94639 .61803 m
0 0 rlineto
.94736 .61803 m
.94639 .61803 L
s
.94778 .61803 m
.94887 .61803 L
s
.94887 .61803 m
.95011 .61803 L
s
.95011 .61803 m
.95011 .61803 L
s
s
s
.95474 .61803 m
.95508 .61803 L
s
.95508 .61803 m
.95757 .61803 L
.95881 .61803 L
.96005 .61803 L
s
.96081 .61803 m
.96005 .61803 L
s
s
.96315 .61803 m
.96377 .61803 L
s
.96377 .61803 m
0 0 rlineto
.96477 .61803 m
.96377 .61803 L
s
.96551 .61803 m
.96626 .61803 L
s
.96626 .61803 m
.9675 .61803 L
.96874 .61803 L
.96998 .61803 L
.97122 .61803 L
.97247 .61803 L
s
.97293 .61803 m
.97247 .61803 L
s
s
s
s
P
P
P
% End of Graphics
MathPictureEnd

^*)
