(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  Bayes
CALLING SEQUENCE:  Bayes[hlist, prior, elist, conditional]
PARAMETERS:
     hlist , elist - lists of values
     prior - a list of real numbers
     conditional - a matrix of real numbers
SYNOPSIS:
     -  This program takes as its parameters hlist, a list of an experiment's hypotheses
        (i.e., the set of all H_i); prior, a list whose ith entry is the prior probability P(H_i);
        elist, a list of the experiment's evidence events (i.e., the set of all E_i); and
        conditional, a matrix whose ijth entry is the conditional probability P(E_j | H_i). 
        The program returns post, a matrix whose ijth entry is the posterior probability
        P(H_j | E_i).  The program also prints out post with its rows and columns labeled
        by the elements of elist and hlist, respectively.
     -  Note:  this program requires the program "LabelMatrix[M, rowlabels,
         columnlabels]" be initialized.
RETURNED VALUES:
     -  a matrix whose ijth entry is the posterior probability P(H_j | E_i)
LOCATION:
     Folder:  Chapter 4
     File:        "Bayes.Chpt4.mat"
;[s]
9:0,0;360,1;362,0;530,1;532,0;636,1;638,0;980,1;982,0;1101,-1;
2:5,14,10,Helvetica,0,12,0,0,0;4,22,14,Helvetica,32,12,0,0,0;
:[font = text; inactive; preserveAspect]
Here's an example:
;[s]
1:0,1;19,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = input; preserveAspect]
Bayes[{d1, d2, d3},{.322,.214,.464},
      {"++","+-","-+","--"},
      {{.656,.094,.219,.031},
       {.186,.062,.559,.193},
       {.109,.766,.016,.109}}
     ]
:[font = text; inactive; preserveAspect]
Return matrix printed with labels:
;[s]
1:0,1;35,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = print; inactive; preserveAspect]
           d1         d2         d3

++         0.70034    0.13197    0.16769

+-         0.075867   0.033256   0.89088

-+         0.35693    0.60549    0.037577

--         0.065978   0.59973    0.33429
:[font = text; inactive; preserveAspect]
Returned matrix:
;[s]
1:0,1;17,-1;
2:0,13,9,Times,0,12,0,0,0;1,14,10,Helvetica,0,12,0,0,0;
:[font = output; output; inactive; preserveAspect]
MatrixForm[{{0.7003434876596423, 0.1319708764903253, 
    0.1676856358500325}, 
   {0.07586725486264287, 0.03325646681371566, 
    0.890876278323642}, {0.3569302721088435, 
    0.6054927923550374, 0.03757693553611921}, 
   {0.06597750076010946, 0.5997329702433673, 
    0.3342895289965234}}]
;[o]
0.70034    0.13197    0.16769

0.075867   0.033256   0.89088

0.35693    0.60549    0.037577

0.065978   0.59973    0.33429
:[font = input; initialization; preserveAspect]
*)
Clear[Bayes];
Bayes[hlist_, prior_, elist_, conditional_] :=
Block[{probe, row, post = {}},
      For[i = 1, i <= Length[conditional[[1]]], i++,
          probe = Sum[prior[[k]]*conditional[[k]][[i]], 
                      {k, 1, Length[prior]}];
          row = {};
          For[j = 1, j <= Length[prior], j++,
              row = Append[row,
                           N[prior[[j]]*conditional[[j]][[i]]/probe,5]
                          ]
             ];
          post = Append[post, row]
         ];
      Answer = LabelMatrix[post, elist, hlist];
      Print[Answer//MatrixForm];
      Return[MatrixForm[post]]
     ]
(*
:[font = input; preserveAspect; startGroup]
Bayes[{d1, d2, d3},{.322,.214,.464},
      {"++","+-","-+","--"},
      {{.656,.094,.219,.031},
       {.186,.062,.559,.424},
       {.109,.766,.016,.109}}
     ]
:[font = print; inactive; preserveAspect]
           d1         d2         d3

++         0.70034    0.13197    0.16769

+-         0.075867   0.033256   0.89088

-+         0.35693    0.60549    0.037577

--         0.065978   0.59973    0.33429
:[font = output; output; inactive; preserveAspect; endGroup]
MatrixForm[{{0.7003434876596423, 0.1319708764903253, 
 
    0.1676856358500325}, {0.07586725486264287, 
 
    0.03325646681371566, 0.890876278323642}, 
 
   {0.3569302721088435, 0.6054927923550374, 
 
    0.03757693553611921}, 
 
   {0.06597750076010946, 0.5997329702433673, 
 
    0.3342895289965234}}]
;[o]
0.70034    0.13197    0.16769

0.075867   0.033256   0.89088

0.35693    0.60549    0.037577

0.065978   0.59973    0.33429
^*)
