(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  Die
CALLING SEQUENCE:  Die[n, s]
PARAMETERS:
     n, s - integers
SYNOPSIS:
     -  This program simulates the following experiment n times: an s-sided die is
         rolled.  If an odd number turns up, an amount equal to that number is won; if an
         even number turns up, an amount equal to that number is lost.  The program
         displays the frequency and the relative frequency with which each outcome
         occurs, as well as displaying the average gain over the n trials.
RETURNED VALUES:
     -  the average gain over the n trials
LOCATION:
     Folder:  Chapter 6
     File:      "Die.Chpt6.mat"
;[s]
1:0,0;627,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[Die];
Die[n_, s_] :=
Block[{r, olist = Table[0, {j, 1, 6}], alist = {}, 
       avg = 0
      },
      For[i = 1, i <= n, i++,
          r = Random[Integer, {1,s}];
          olist[[r]]++;
          If[EvenQ[r], avg = avg - r,
                       avg = avg + r
            ];
         ];
      alist = Table[{i, olist[[i]], olist[[i]]/n//N},
                    {i, 1, s}
                   ];
      For[j = 1, j <= s, j++,
          If[EvenQ[j],
             alist[[j]] = ReplacePart[alist[[j]],
                                      -alist[[j]][[1]],
                                      1
                                     ]
            ]
         ]; 
      Print["Winning   Frequency  Relative Frequency"];
      Print["  "];
      Print[TableForm[alist, TableSpacing -> {0,10}]        
           ];
      Print["  "];
      avg = avg/n//N;
      Print["Average winnings = ", avg];
      Return[avg]  
     ]
(*
:[font = input; preserveAspect; startGroup]
Die[10000, 6]
:[font = print; inactive; preserveAspect]
Winning   Frequency  Relative Frequency
  
1           1678          0.1678
-2          1631          0.1631
3           1689          0.1689
-4          1616          0.1616
5           1691          0.1691
-6          1695          0.1695
  
Average winnings = -0.4696
:[font = output; output; inactive; preserveAspect; endGroup]
-0.4696
;[o]
-0.4696
^*)
