(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  StockSystem
CALLING SEQUENCE:  StockSystem[n]
PARAMETERS:
     n - an integer
SYNOPSIS:
     -  This program simulates Mr. Ace's playing of the stock market, as described in the
        book, where he must stop after n days.  Without loss of generality, we let the
        book's V = 0.  The program prints out and returns Mr. Ace's net gain after the n
        days, and plots the points (x, f(x)) for x = 0 to n, where x is the number of the day,
        and f(x) is the value of V on day x.  The points are connected with lines:  dotted
        lines indicate time during which Mr. Ace holds stock under his system; unbroken
        lines indicate time during which he does not hold stock.
RETURNED VALUES:
     -  Mr. Ace's net gain
LOCATION:
     Folder:  Chapter 6
     File:       "StockSystem.Chpt6.mat"
;[s]
1:0,0;822,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[StockSystem];
StockSystem[n_, print_] :=
Block[{r, total = 0, tlist = {{0,0}}, linelist = {},
       own = True,
       gain = 0
      },
      For[i = 2, i <= n, i++,
          r = Random[Integer, {0, 1}];
          If[r == 1, total++, total--];
          tlist = Append[tlist, {i - 1, total}];
          t1 = tlist[[i - 1]];
          t2 = tlist[[i]];
          If[(own),
             If[print,
                linelist = Append[linelist,
                               Graphics[{Dashing[{.03, .03}],
                                        Line[{t1, t2}]}
                                       ]
                                 ]
               ];
             If[total == 1,
                gain++;
                own = False
               ],  
             If[print,
                linelist = Append[linelist,
                                  Graphics[Line[{t1, t2}]]
                                 ]
               ];
             If[(!own)&&(total == 0),
                own = True
               ]
            ];
         ];   
      If[total < 0, gain = gain + total];
      Print["Net gain = ", gain];
      If[print, Show[linelist, Axes -> True]];
      Return[gain]
     ]
(*
:[font = input; preserveAspect; startGroup]
StockSystem[20, True];
:[font = print; inactive; preserveAspect]
Net gain = 1
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0501253 0.161866 0.0735755 [
[(2.5)] .14912 .16187 0 2 Msboxa
[(5)] .27444 .16187 0 2 Msboxa
[(7.5)] .39975 .16187 0 2 Msboxa
[(10)] .52506 .16187 0 2 Msboxa
[(12.5)] .65038 .16187 0 2 Msboxa
[(15)] .77569 .16187 0 2 Msboxa
[(17.5)] .901 .16187 0 2 Msboxa
[(-2)] .01131 .01472 1 0 Msboxa
[(2)] .01131 .30902 1 0 Msboxa
[(4)] .01131 .45617 1 0 Msboxa
[(6)] .01131 .60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.14912 .16187 m
.14912 .16812 L
s
P
[(2.5)] .14912 .16187 0 2 Mshowa
p
.002 w
.27444 .16187 m
.27444 .16812 L
s
P
[(5)] .27444 .16187 0 2 Mshowa
p
.002 w
.39975 .16187 m
.39975 .16812 L
s
P
[(7.5)] .39975 .16187 0 2 Mshowa
p
.002 w
.52506 .16187 m
.52506 .16812 L
s
P
[(10)] .52506 .16187 0 2 Mshowa
p
.002 w
.65038 .16187 m
.65038 .16812 L
s
P
[(12.5)] .65038 .16187 0 2 Mshowa
p
.002 w
.77569 .16187 m
.77569 .16812 L
s
P
[(15)] .77569 .16187 0 2 Mshowa
p
.002 w
.901 .16187 m
.901 .16812 L
s
P
[(17.5)] .901 .16187 0 2 Mshowa
p
.001 w
.04887 .16187 m
.04887 .16562 L
s
P
p
.001 w
.07393 .16187 m
.07393 .16562 L
s
P
p
.001 w
.099 .16187 m
.099 .16562 L
s
P
p
.001 w
.12406 .16187 m
.12406 .16562 L
s
P
p
.001 w
.17419 .16187 m
.17419 .16562 L
s
P
p
.001 w
.19925 .16187 m
.19925 .16562 L
s
P
p
.001 w
.22431 .16187 m
.22431 .16562 L
s
P
p
.001 w
.24937 .16187 m
.24937 .16562 L
s
P
p
.001 w
.2995 .16187 m
.2995 .16562 L
s
P
p
.001 w
.32456 .16187 m
.32456 .16562 L
s
P
p
.001 w
.34962 .16187 m
.34962 .16562 L
s
P
p
.001 w
.37469 .16187 m
.37469 .16562 L
s
P
p
.001 w
.42481 .16187 m
.42481 .16562 L
s
P
p
.001 w
.44987 .16187 m
.44987 .16562 L
s
P
p
.001 w
.47494 .16187 m
.47494 .16562 L
s
P
p
.001 w
.5 .16187 m
.5 .16562 L
s
P
p
.001 w
.55013 .16187 m
.55013 .16562 L
s
P
p
.001 w
.57519 .16187 m
.57519 .16562 L
s
P
p
.001 w
.60025 .16187 m
.60025 .16562 L
s
P
p
.001 w
.62531 .16187 m
.62531 .16562 L
s
P
p
.001 w
.67544 .16187 m
.67544 .16562 L
s
P
p
.001 w
.7005 .16187 m
.7005 .16562 L
s
P
p
.001 w
.72556 .16187 m
.72556 .16562 L
s
P
p
.001 w
.75063 .16187 m
.75063 .16562 L
s
P
p
.001 w
.80075 .16187 m
.80075 .16562 L
s
P
p
.001 w
.82581 .16187 m
.82581 .16562 L
s
P
p
.001 w
.85088 .16187 m
.85088 .16562 L
s
P
p
.001 w
.87594 .16187 m
.87594 .16562 L
s
P
p
.001 w
.92607 .16187 m
.92607 .16562 L
s
P
p
.001 w
.95113 .16187 m
.95113 .16562 L
s
P
p
.001 w
.97619 .16187 m
.97619 .16562 L
s
P
p
.002 w
0 .16187 m
1 .16187 L
s
P
p
.002 w
.02381 .01472 m
.03006 .01472 L
s
P
[(-2)] .01131 .01472 1 0 Mshowa
p
.002 w
.02381 .30902 m
.03006 .30902 L
s
P
[(2)] .01131 .30902 1 0 Mshowa
p
.002 w
.02381 .45617 m
.03006 .45617 L
s
P
[(4)] .01131 .45617 1 0 Mshowa
p
.002 w
.02381 .60332 m
.03006 .60332 L
s
P
[(6)] .01131 .60332 1 0 Mshowa
p
.001 w
.02381 .04415 m
.02756 .04415 L
s
P
p
.001 w
.02381 .07358 m
.02756 .07358 L
s
P
p
.001 w
.02381 .10301 m
.02756 .10301 L
s
P
p
.001 w
.02381 .13244 m
.02756 .13244 L
s
P
p
.001 w
.02381 .1913 m
.02756 .1913 L
s
P
p
.001 w
.02381 .22073 m
.02756 .22073 L
s
P
p
.001 w
.02381 .25016 m
.02756 .25016 L
s
P
p
.001 w
.02381 .27959 m
.02756 .27959 L
s
P
p
.001 w
.02381 .33845 m
.02756 .33845 L
s
P
p
.001 w
.02381 .36788 m
.02756 .36788 L
s
P
p
.001 w
.02381 .39731 m
.02756 .39731 L
s
P
p
.001 w
.02381 .42674 m
.02756 .42674 L
s
P
p
.001 w
.02381 .4856 m
.02756 .4856 L
s
P
p
.001 w
.02381 .51503 m
.02756 .51503 L
s
P
p
.001 w
.02381 .54446 m
.02756 .54446 L
s
P
p
.001 w
.02381 .57389 m
.02756 .57389 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
[ .03 .03 ] 0 setdash
.004 w
.02381 .16187 m
.07393 .08829 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.07393 .08829 m
.12406 .01472 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.12406 .01472 m
.17419 .08829 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.17419 .08829 m
.22431 .16187 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.22431 .16187 m
.27444 .08829 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.27444 .08829 m
.32456 .01472 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.32456 .01472 m
.37469 .08829 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.37469 .08829 m
.42481 .01472 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.42481 .01472 m
.47494 .08829 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.47494 .08829 m
.52506 .16187 L
s
P
p
[ .03 .03 ] 0 setdash
.004 w
.52506 .16187 m
.57519 .23544 L
s
P
.004 w
.57519 .23544 m
.62531 .30902 L
s
.62531 .30902 m
.67544 .38259 L
s
.67544 .38259 m
.72556 .45617 L
s
.72556 .45617 m
.77569 .52974 L
s
.77569 .52974 m
.82581 .60332 L
s
.82581 .60332 m
.87594 .52974 L
s
.87594 .52974 m
.92607 .45617 L
s
.92607 .45617 m
.97619 .38259 L
s
P
% End of Graphics
MathPictureEnd

^*)
