(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  DieTest
CALLING SEQUENCE:  DieTest[numbtrials, numrolls, plist]
PARAMETERS:
     numbtrials, numrolls - integers
     plist - a probability list
SYNOPSIS:  
     -  This program performs an experiment in which a die is rolled numrolls times, and
        computes V, as defined in the text.  The die's faces are numbered 1 through 6,
        and the probability of  face i coming up is given by plist[[i]].  If numbtrials = 1, the
        program prints out V, and its corresponding p-value with 5 degrees of freedom .
        If numbtrials > 1, the experiment is carried out numbtrials times, and three graphs
        are output.  The first is an area bargraph of the V values for each experiment. 
        The second is the corresponding chi-square density.  The third overlays the
        chi-square density on the bargraph.  
     -  Note:  this program requires the packages "Statistics`ContinuousDistributions`"
        and "Statistics`HypothesisTests`" be loaded in, and the program
        "Areabargraph[data, xmin, xmax, k]" be initialized.
RETURNED VALUES:  
     -  none
LOCATION:
     Folder:  Chapter 7
     File:       "DieTest.Chpt7.mat"
;[s]
1:0,0;1162,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[DieTest];
DieTest[numbtrials_, numbrolls_, plist_] :=
Block[{distlist = {0,0,0,0,0,0}, chilist = {}, plot1, plot2, v},
	  For[i = 1, i <= 6, i++,
		  For[j = i,j >= 1, j--,
			  distlist[[i]] = distlist[[i]] + plist[[j]]
			 ]
		 ];
	  For[k = 1, k <= numbtrials, k++,
	      Block[{rolllist = {0,0,0,0,0,0}, V},
			 	For[m = 1, m <= numbrolls, m++,
			 	 	Block[{r,roll},
			 	 		  r = Random[];
			 	 		  roll = Which[r < distlist[[1]], 1,
			 	 			           (r < distlist[[2]])&&(r >= distlist[[1]]),2,
			 	 			           (r < distlist[[3]])&&(r >= distlist[[2]]),3,
			 	 			           (r < distlist[[4]])&&(r >= distlist[[3]]),4,
			 	 			           (r < distlist[[5]])&&(r >= distlist[[4]]),5,
			 	 			           r >= distlist[[5]],6
			 	 			          ];
			 	 		  rolllist[[roll]] = rolllist[[roll]]+1
			 	 		]
			 	   ];
			 	V = 0; 
				For[q = 1,q <= 6, q++,
				 	V = (V + ((rolllist[[q]] - numbrolls*plist[[q]])^2)/
				 	    (numbrolls*plist[[q]]))//N
				   ];
			    chilist = Append[chilist, V]
			   ]
		 ];
	  If[numbtrials > 1,
	     plot1 = Areabargraph[chilist, 0, 30, 30];
		 plot2 = Plot[PDF[ChiSquareDistribution[5],x],{x,0,30}];
		 Show[plot1,plot2]
		];
 	  If[numbtrials == 1,
	     v = chilist[[1]];
	     Print["V = ", v];
	     Print[ChiSquarePValue[v, 5]]
	    ];
	 ]
(*
:[font = input; preserveAspect; startGroup]
DieTest[1, 60, {.1,.1,.1,.1,.1,.5}]
:[font = print; inactive; preserveAspect; endGroup]
V = 8.2
OneSidedPValue -> 0.145552
:[font = input; preserveAspect; startGroup]
v=1/6//N;
DieTest[60, 1000, {v,v,v,v,v,v}]
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; startGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 2.20726 [
[(0)] .02381 0 0 2 Msboxa
[(5)] .18254 0 0 2 Msboxa
[(10)] .34127 0 0 2 Msboxa
[(15)] .5 0 0 2 Msboxa
[(20)] .65873 0 0 2 Msboxa
[(25)] .81746 0 0 2 Msboxa
[(30)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.05)] -0.0125 .12508 1 0 Msboxa
[(0.1)] -0.0125 .23544 1 0 Msboxa
[(0.15)] -0.0125 .3458 1 0 Msboxa
[(0.2)] -0.0125 .45617 1 0 Msboxa
[(0.25)] -0.0125 .56653 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.18254 0 m
.18254 .00625 L
s
P
[(5)] .18254 0 0 2 Mshowa
p
.002 w
.34127 0 m
.34127 .00625 L
s
P
[(10)] .34127 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(15)] .5 0 0 2 Mshowa
p
.002 w
.65873 0 m
.65873 .00625 L
s
P
[(20)] .65873 0 0 2 Mshowa
p
.002 w
.81746 0 m
.81746 .00625 L
s
P
[(25)] .81746 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(30)] .97619 0 0 2 Mshowa
p
.001 w
.05556 0 m
.05556 .00375 L
s
P
p
.001 w
.0873 0 m
.0873 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.15079 0 m
.15079 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.24603 0 m
.24603 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.37302 0 m
.37302 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.43651 0 m
.43651 .00375 L
s
P
p
.001 w
.46825 0 m
.46825 .00375 L
s
P
p
.001 w
.53175 0 m
.53175 .00375 L
s
P
p
.001 w
.56349 0 m
.56349 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.62698 0 m
.62698 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75397 0 m
.75397 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.84921 0 m
.84921 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.9127 0 m
.9127 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .12508 m
.00625 .12508 L
s
P
[(0.05)] -0.0125 .12508 1 0 Mshowa
p
.002 w
0 .23544 m
.00625 .23544 L
s
P
[(0.1)] -0.0125 .23544 1 0 Mshowa
p
.002 w
0 .3458 m
.00625 .3458 L
s
P
[(0.15)] -0.0125 .3458 1 0 Mshowa
p
.002 w
0 .45617 m
.00625 .45617 L
s
P
[(0.2)] -0.0125 .45617 1 0 Mshowa
p
.002 w
0 .56653 m
.00625 .56653 L
s
P
[(0.25)] -0.0125 .56653 1 0 Mshowa
p
.001 w
0 .03679 m
.00375 .03679 L
s
P
p
.001 w
0 .05886 m
.00375 .05886 L
s
P
p
.001 w
0 .08093 m
.00375 .08093 L
s
P
p
.001 w
0 .10301 m
.00375 .10301 L
s
P
p
.001 w
0 .14715 m
.00375 .14715 L
s
P
p
.001 w
0 .16922 m
.00375 .16922 L
s
P
p
.001 w
0 .1913 m
.00375 .1913 L
s
P
p
.001 w
0 .21337 m
.00375 .21337 L
s
P
p
.001 w
0 .25751 m
.00375 .25751 L
s
P
p
.001 w
0 .27959 m
.00375 .27959 L
s
P
p
.001 w
0 .30166 m
.00375 .30166 L
s
P
p
.001 w
0 .32373 m
.00375 .32373 L
s
P
p
.001 w
0 .36788 m
.00375 .36788 L
s
P
p
.001 w
0 .38995 m
.00375 .38995 L
s
P
p
.001 w
0 .41202 m
.00375 .41202 L
s
P
p
.001 w
0 .4341 m
.00375 .4341 L
s
P
p
.001 w
0 .47824 m
.00375 .47824 L
s
P
p
.001 w
0 .50031 m
.00375 .50031 L
s
P
p
.001 w
0 .52239 m
.00375 .52239 L
s
P
p
.001 w
0 .54446 m
.00375 .54446 L
s
P
p
.001 w
0 .5886 m
.00375 .5886 L
s
P
p
.001 w
0 .61068 m
.00375 .61068 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.18254 .61178 m
.18254 .61803 L
s
P
p
.002 w
.34127 .61178 m
.34127 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.65873 .61178 m
.65873 .61803 L
s
P
p
.002 w
.81746 .61178 m
.81746 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.05556 .61428 m
.05556 .61803 L
s
P
p
.001 w
.0873 .61428 m
.0873 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.15079 .61428 m
.15079 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.24603 .61428 m
.24603 .61803 L
s
P
p
.001 w
.27778 .61428 m
.27778 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.37302 .61428 m
.37302 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.43651 .61428 m
.43651 .61803 L
s
P
p
.001 w
.46825 .61428 m
.46825 .61803 L
s
P
p
.001 w
.53175 .61428 m
.53175 .61803 L
s
P
p
.001 w
.56349 .61428 m
.56349 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.62698 .61428 m
.62698 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.72222 .61428 m
.72222 .61803 L
s
P
p
.001 w
.75397 .61428 m
.75397 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.84921 .61428 m
.84921 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.9127 .61428 m
.9127 .61803 L
s
P
p
.001 w
.94444 .61428 m
.94444 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .12508 m
1 .12508 L
s
P
p
.002 w
.99375 .23544 m
1 .23544 L
s
P
p
.002 w
.99375 .3458 m
1 .3458 L
s
P
p
.002 w
.99375 .45617 m
1 .45617 L
s
P
p
.002 w
.99375 .56653 m
1 .56653 L
s
P
p
.001 w
.99625 .03679 m
1 .03679 L
s
P
p
.001 w
.99625 .05886 m
1 .05886 L
s
P
p
.001 w
.99625 .08093 m
1 .08093 L
s
P
p
.001 w
.99625 .10301 m
1 .10301 L
s
P
p
.001 w
.99625 .14715 m
1 .14715 L
s
P
p
.001 w
.99625 .16922 m
1 .16922 L
s
P
p
.001 w
.99625 .1913 m
1 .1913 L
s
P
p
.001 w
.99625 .21337 m
1 .21337 L
s
P
p
.001 w
.99625 .25751 m
1 .25751 L
s
P
p
.001 w
.99625 .27959 m
1 .27959 L
s
P
p
.001 w
.99625 .30166 m
1 .30166 L
s
P
p
.001 w
.99625 .32373 m
1 .32373 L
s
P
p
.001 w
.99625 .36788 m
1 .36788 L
s
P
p
.001 w
.99625 .38995 m
1 .38995 L
s
P
p
.001 w
.99625 .41202 m
1 .41202 L
s
P
p
.001 w
.99625 .4341 m
1 .4341 L
s
P
p
.001 w
.99625 .47824 m
1 .47824 L
s
P
p
.001 w
.99625 .50031 m
1 .50031 L
s
P
p
.001 w
.99625 .52239 m
1 .52239 L
s
P
p
.001 w
.99625 .54446 m
1 .54446 L
s
P
p
.001 w
.99625 .5886 m
1 .5886 L
s
P
p
.001 w
.99625 .61068 m
1 .61068 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
0 0 1 r
.02381 .01472 m
.02381 .0515 L
.05556 .0515 L
.05556 .01472 L
F
.05556 .01472 m
.05556 .08829 L
.0873 .08829 L
.0873 .01472 L
F
.0873 .01472 m
.0873 .60332 L
.11905 .60332 L
.11905 .01472 L
F
.11905 .01472 m
.11905 .30902 L
.15079 .30902 L
.15079 .01472 L
F
.15079 .01472 m
.15079 .12508 L
.18254 .12508 L
.18254 .01472 L
F
.18254 .01472 m
.18254 .16187 L
.21429 .16187 L
.21429 .01472 L
F
.21429 .01472 m
.21429 .16187 L
.24603 .16187 L
.24603 .01472 L
F
.24603 .01472 m
.24603 .27223 L
.27778 .27223 L
.27778 .01472 L
F
.27778 .01472 m
.27778 .27223 L
.30952 .27223 L
.30952 .01472 L
F
.30952 .01472 m
.30952 .08829 L
.34127 .08829 L
.34127 .01472 L
F
.34127 .01472 m
.34127 .12508 L
.37302 .12508 L
.37302 .01472 L
F
.37302 .01472 m
.37302 .01472 L
.40476 .01472 L
.40476 .01472 L
F
.40476 .01472 m
.40476 .08829 L
.43651 .08829 L
.43651 .01472 L
F
.43651 .01472 m
.43651 .01472 L
.46825 .01472 L
.46825 .01472 L
F
.46825 .01472 m
.46825 .0515 L
.5 .0515 L
.5 .01472 L
F
.5 .01472 m
.5 .01472 L
.53175 .01472 L
.53175 .01472 L
F
.53175 .01472 m
.53175 .01472 L
.56349 .01472 L
.56349 .01472 L
F
.56349 .01472 m
.56349 .01472 L
.59524 .01472 L
.59524 .01472 L
F
.59524 .01472 m
.59524 .01472 L
.62698 .01472 L
.62698 .01472 L
F
.62698 .01472 m
.62698 .01472 L
.65873 .01472 L
.65873 .01472 L
F
.65873 .01472 m
.65873 .01472 L
.69048 .01472 L
.69048 .01472 L
F
.69048 .01472 m
.69048 .01472 L
.72222 .01472 L
.72222 .01472 L
F
.72222 .01472 m
.72222 .01472 L
.75397 .01472 L
.75397 .01472 L
F
.75397 .01472 m
.75397 .01472 L
.78571 .01472 L
.78571 .01472 L
F
.78571 .01472 m
.78571 .01472 L
.81746 .01472 L
.81746 .01472 L
F
.81746 .01472 m
.81746 .01472 L
.84921 .01472 L
.84921 .01472 L
F
.84921 .01472 m
.84921 .01472 L
.88095 .01472 L
.88095 .01472 L
F
.88095 .01472 m
.88095 .01472 L
.9127 .01472 L
.9127 .01472 L
F
.9127 .01472 m
.9127 .01472 L
.94444 .01472 L
.94444 .01472 L
F
.94444 .01472 m
.94444 .01472 L
.97619 .01472 L
.97619 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .0515 L
s
.05556 .01472 m
.05556 .0515 L
s
.02381 .0515 m
.05556 .0515 L
s
.05556 .01472 m
.05556 .08829 L
s
.0873 .01472 m
.0873 .08829 L
s
.05556 .08829 m
.0873 .08829 L
s
.0873 .01472 m
.0873 .60332 L
s
.11905 .01472 m
.11905 .60332 L
s
.0873 .60332 m
.11905 .60332 L
s
.11905 .01472 m
.11905 .30902 L
s
.15079 .01472 m
.15079 .30902 L
s
.11905 .30902 m
.15079 .30902 L
s
.15079 .01472 m
.15079 .12508 L
s
.18254 .01472 m
.18254 .12508 L
s
.15079 .12508 m
.18254 .12508 L
s
.18254 .01472 m
.18254 .16187 L
s
.21429 .01472 m
.21429 .16187 L
s
.18254 .16187 m
.21429 .16187 L
s
.21429 .01472 m
.21429 .16187 L
s
.24603 .01472 m
.24603 .16187 L
s
.21429 .16187 m
.24603 .16187 L
s
.24603 .01472 m
.24603 .27223 L
s
.27778 .01472 m
.27778 .27223 L
s
.24603 .27223 m
.27778 .27223 L
s
.27778 .01472 m
.27778 .27223 L
s
.30952 .01472 m
.30952 .27223 L
s
.27778 .27223 m
.30952 .27223 L
s
.30952 .01472 m
.30952 .08829 L
s
.34127 .01472 m
.34127 .08829 L
s
.30952 .08829 m
.34127 .08829 L
s
.34127 .01472 m
.34127 .12508 L
s
.37302 .01472 m
.37302 .12508 L
s
.34127 .12508 m
.37302 .12508 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.37302 .01472 m
.40476 .01472 L
s
.40476 .01472 m
.40476 .08829 L
s
.43651 .01472 m
.43651 .08829 L
s
.40476 .08829 m
.43651 .08829 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.43651 .01472 m
.46825 .01472 L
s
.46825 .01472 m
.46825 .0515 L
s
.5 .01472 m
.5 .0515 L
s
.46825 .0515 m
.5 .0515 L
s
.5 .01472 m
.5 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.5 .01472 m
.53175 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.53175 .01472 m
.56349 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.56349 .01472 m
.59524 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.59524 .01472 m
.62698 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.62698 .01472 m
.65873 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.65873 .01472 m
.69048 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.69048 .01472 m
.72222 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.72222 .01472 m
.75397 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.75397 .01472 m
.78571 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.78571 .01472 m
.81746 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.81746 .01472 m
.84921 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.84921 .01472 m
.88095 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.88095 .01472 m
.9127 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.9127 .01472 m
.94444 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.94444 .01472 m
.97619 .01472 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 3.81765 [
[(5)] .18254 .01472 0 2 Msboxa
[(10)] .34127 .01472 0 2 Msboxa
[(15)] .5 .01472 0 2 Msboxa
[(20)] .65873 .01472 0 2 Msboxa
[(25)] .81746 .01472 0 2 Msboxa
[(30)] .97619 .01472 0 2 Msboxa
[(0.025)] .01131 .11016 1 0 Msboxa
[(0.05)] .01131 .2056 1 0 Msboxa
[(0.075)] .01131 .30104 1 0 Msboxa
[(0.1)] .01131 .39648 1 0 Msboxa
[(0.125)] .01131 .49192 1 0 Msboxa
[(0.15)] .01131 .58736 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18254 .01472 m
.18254 .02097 L
s
P
[(5)] .18254 .01472 0 2 Mshowa
p
.002 w
.34127 .01472 m
.34127 .02097 L
s
P
[(10)] .34127 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(15)] .5 .01472 0 2 Mshowa
p
.002 w
.65873 .01472 m
.65873 .02097 L
s
P
[(20)] .65873 .01472 0 2 Mshowa
p
.002 w
.81746 .01472 m
.81746 .02097 L
s
P
[(25)] .81746 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(30)] .97619 .01472 0 2 Mshowa
p
.001 w
.05556 .01472 m
.05556 .01847 L
s
P
p
.001 w
.0873 .01472 m
.0873 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.15079 .01472 m
.15079 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.24603 .01472 m
.24603 .01847 L
s
P
p
.001 w
.27778 .01472 m
.27778 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.37302 .01472 m
.37302 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.43651 .01472 m
.43651 .01847 L
s
P
p
.001 w
.46825 .01472 m
.46825 .01847 L
s
P
p
.001 w
.53175 .01472 m
.53175 .01847 L
s
P
p
.001 w
.56349 .01472 m
.56349 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.62698 .01472 m
.62698 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.72222 .01472 m
.72222 .01847 L
s
P
p
.001 w
.75397 .01472 m
.75397 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.84921 .01472 m
.84921 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.9127 .01472 m
.9127 .01847 L
s
P
p
.001 w
.94444 .01472 m
.94444 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .11016 m
.03006 .11016 L
s
P
[(0.025)] .01131 .11016 1 0 Mshowa
p
.002 w
.02381 .2056 m
.03006 .2056 L
s
P
[(0.05)] .01131 .2056 1 0 Mshowa
p
.002 w
.02381 .30104 m
.03006 .30104 L
s
P
[(0.075)] .01131 .30104 1 0 Mshowa
p
.002 w
.02381 .39648 m
.03006 .39648 L
s
P
[(0.1)] .01131 .39648 1 0 Mshowa
p
.002 w
.02381 .49192 m
.03006 .49192 L
s
P
[(0.125)] .01131 .49192 1 0 Mshowa
p
.002 w
.02381 .58736 m
.03006 .58736 L
s
P
[(0.15)] .01131 .58736 1 0 Mshowa
p
.001 w
.02381 .0338 m
.02756 .0338 L
s
P
p
.001 w
.02381 .05289 m
.02756 .05289 L
s
P
p
.001 w
.02381 .07198 m
.02756 .07198 L
s
P
p
.001 w
.02381 .09107 m
.02756 .09107 L
s
P
p
.001 w
.02381 .12924 m
.02756 .12924 L
s
P
p
.001 w
.02381 .14833 m
.02756 .14833 L
s
P
p
.001 w
.02381 .16742 m
.02756 .16742 L
s
P
p
.001 w
.02381 .18651 m
.02756 .18651 L
s
P
p
.001 w
.02381 .22469 m
.02756 .22469 L
s
P
p
.001 w
.02381 .24377 m
.02756 .24377 L
s
P
p
.001 w
.02381 .26286 m
.02756 .26286 L
s
P
p
.001 w
.02381 .28195 m
.02756 .28195 L
s
P
p
.001 w
.02381 .32013 m
.02756 .32013 L
s
P
p
.001 w
.02381 .33922 m
.02756 .33922 L
s
P
p
.001 w
.02381 .3583 m
.02756 .3583 L
s
P
p
.001 w
.02381 .37739 m
.02756 .37739 L
s
P
p
.001 w
.02381 .41557 m
.02756 .41557 L
s
P
p
.001 w
.02381 .43466 m
.02756 .43466 L
s
P
p
.001 w
.02381 .45375 m
.02756 .45375 L
s
P
p
.001 w
.02381 .47283 m
.02756 .47283 L
s
P
p
.001 w
.02381 .51101 m
.02756 .51101 L
s
P
p
.001 w
.02381 .5301 m
.02756 .5301 L
s
P
p
.001 w
.02381 .54919 m
.02756 .54919 L
s
P
p
.001 w
.02381 .56827 m
.02756 .56827 L
s
P
p
.001 w
.02381 .60645 m
.02756 .60645 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
.004 w
.02381 .01472 m
.04365 .19824 L
.05357 .3031 L
.06349 .39448 L
.07341 .46868 L
.07837 .49909 L
.08333 .52514 L
.08829 .54701 L
.09325 .56489 L
.09821 .57902 L
.10069 .58476 L
.10317 .58966 L
.10565 .59375 L
.10813 .59707 L
.11062 .59965 L
.11186 .60068 L
.1131 .60152 L
.11434 .60221 L
.11558 .60272 L
.11682 .60308 L
.11806 .60327 L
.1193 .60332 L
.12054 .60322 L
.12178 .60297 L
.12302 .60258 L
.12426 .60205 L
.1255 .60139 L
.12798 .59968 L
.13046 .59748 L
.13294 .59482 L
.14286 .58008 L
.15278 .55999 L
.1627 .53595 L
.18254 .48063 L
.22222 .36324 L
.2619 .25994 L
.30159 .18012 L
.32143 .14893 L
.34127 .12289 L
.36111 .10139 L
.38095 .0838 L
.40079 .06953 L
.42063 .05803 L
.44048 .04881 L
.46032 .04146 L
.48016 .03563 L
.5 .03103 L
.51984 .0274 L
.53968 .02456 L
.55952 .02234 L
Mistroke
.57937 .0206 L
.59921 .01926 L
.61905 .01821 L
.63889 .0174 L
.65873 .01678 L
.67857 .01629 L
.69841 .01592 L
.71825 .01564 L
.7381 .01542 L
.75794 .01525 L
.77778 .01512 L
.79762 .01503 L
.81746 .01495 L
.8373 .01489 L
.85714 .01485 L
.87698 .01482 L
.89683 .01479 L
.91667 .01477 L
.93651 .01476 L
.95635 .01475 L
.97619 .01474 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.031746 0.0147151 2.20726 [
[(0)] .02381 0 0 2 Msboxa
[(5)] .18254 0 0 2 Msboxa
[(10)] .34127 0 0 2 Msboxa
[(15)] .5 0 0 2 Msboxa
[(20)] .65873 0 0 2 Msboxa
[(25)] .81746 0 0 2 Msboxa
[(30)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.05)] -0.0125 .12508 1 0 Msboxa
[(0.1)] -0.0125 .23544 1 0 Msboxa
[(0.15)] -0.0125 .3458 1 0 Msboxa
[(0.2)] -0.0125 .45617 1 0 Msboxa
[(0.25)] -0.0125 .56653 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.18254 0 m
.18254 .00625 L
s
P
[(5)] .18254 0 0 2 Mshowa
p
.002 w
.34127 0 m
.34127 .00625 L
s
P
[(10)] .34127 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(15)] .5 0 0 2 Mshowa
p
.002 w
.65873 0 m
.65873 .00625 L
s
P
[(20)] .65873 0 0 2 Mshowa
p
.002 w
.81746 0 m
.81746 .00625 L
s
P
[(25)] .81746 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(30)] .97619 0 0 2 Mshowa
p
.001 w
.05556 0 m
.05556 .00375 L
s
P
p
.001 w
.0873 0 m
.0873 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.15079 0 m
.15079 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.24603 0 m
.24603 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.37302 0 m
.37302 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.43651 0 m
.43651 .00375 L
s
P
p
.001 w
.46825 0 m
.46825 .00375 L
s
P
p
.001 w
.53175 0 m
.53175 .00375 L
s
P
p
.001 w
.56349 0 m
.56349 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.62698 0 m
.62698 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75397 0 m
.75397 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.84921 0 m
.84921 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.9127 0 m
.9127 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .12508 m
.00625 .12508 L
s
P
[(0.05)] -0.0125 .12508 1 0 Mshowa
p
.002 w
0 .23544 m
.00625 .23544 L
s
P
[(0.1)] -0.0125 .23544 1 0 Mshowa
p
.002 w
0 .3458 m
.00625 .3458 L
s
P
[(0.15)] -0.0125 .3458 1 0 Mshowa
p
.002 w
0 .45617 m
.00625 .45617 L
s
P
[(0.2)] -0.0125 .45617 1 0 Mshowa
p
.002 w
0 .56653 m
.00625 .56653 L
s
P
[(0.25)] -0.0125 .56653 1 0 Mshowa
p
.001 w
0 .03679 m
.00375 .03679 L
s
P
p
.001 w
0 .05886 m
.00375 .05886 L
s
P
p
.001 w
0 .08093 m
.00375 .08093 L
s
P
p
.001 w
0 .10301 m
.00375 .10301 L
s
P
p
.001 w
0 .14715 m
.00375 .14715 L
s
P
p
.001 w
0 .16922 m
.00375 .16922 L
s
P
p
.001 w
0 .1913 m
.00375 .1913 L
s
P
p
.001 w
0 .21337 m
.00375 .21337 L
s
P
p
.001 w
0 .25751 m
.00375 .25751 L
s
P
p
.001 w
0 .27959 m
.00375 .27959 L
s
P
p
.001 w
0 .30166 m
.00375 .30166 L
s
P
p
.001 w
0 .32373 m
.00375 .32373 L
s
P
p
.001 w
0 .36788 m
.00375 .36788 L
s
P
p
.001 w
0 .38995 m
.00375 .38995 L
s
P
p
.001 w
0 .41202 m
.00375 .41202 L
s
P
p
.001 w
0 .4341 m
.00375 .4341 L
s
P
p
.001 w
0 .47824 m
.00375 .47824 L
s
P
p
.001 w
0 .50031 m
.00375 .50031 L
s
P
p
.001 w
0 .52239 m
.00375 .52239 L
s
P
p
.001 w
0 .54446 m
.00375 .54446 L
s
P
p
.001 w
0 .5886 m
.00375 .5886 L
s
P
p
.001 w
0 .61068 m
.00375 .61068 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.18254 .61178 m
.18254 .61803 L
s
P
p
.002 w
.34127 .61178 m
.34127 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.65873 .61178 m
.65873 .61803 L
s
P
p
.002 w
.81746 .61178 m
.81746 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.05556 .61428 m
.05556 .61803 L
s
P
p
.001 w
.0873 .61428 m
.0873 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.15079 .61428 m
.15079 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.24603 .61428 m
.24603 .61803 L
s
P
p
.001 w
.27778 .61428 m
.27778 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.37302 .61428 m
.37302 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.43651 .61428 m
.43651 .61803 L
s
P
p
.001 w
.46825 .61428 m
.46825 .61803 L
s
P
p
.001 w
.53175 .61428 m
.53175 .61803 L
s
P
p
.001 w
.56349 .61428 m
.56349 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.62698 .61428 m
.62698 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.72222 .61428 m
.72222 .61803 L
s
P
p
.001 w
.75397 .61428 m
.75397 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.84921 .61428 m
.84921 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.9127 .61428 m
.9127 .61803 L
s
P
p
.001 w
.94444 .61428 m
.94444 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .12508 m
1 .12508 L
s
P
p
.002 w
.99375 .23544 m
1 .23544 L
s
P
p
.002 w
.99375 .3458 m
1 .3458 L
s
P
p
.002 w
.99375 .45617 m
1 .45617 L
s
P
p
.002 w
.99375 .56653 m
1 .56653 L
s
P
p
.001 w
.99625 .03679 m
1 .03679 L
s
P
p
.001 w
.99625 .05886 m
1 .05886 L
s
P
p
.001 w
.99625 .08093 m
1 .08093 L
s
P
p
.001 w
.99625 .10301 m
1 .10301 L
s
P
p
.001 w
.99625 .14715 m
1 .14715 L
s
P
p
.001 w
.99625 .16922 m
1 .16922 L
s
P
p
.001 w
.99625 .1913 m
1 .1913 L
s
P
p
.001 w
.99625 .21337 m
1 .21337 L
s
P
p
.001 w
.99625 .25751 m
1 .25751 L
s
P
p
.001 w
.99625 .27959 m
1 .27959 L
s
P
p
.001 w
.99625 .30166 m
1 .30166 L
s
P
p
.001 w
.99625 .32373 m
1 .32373 L
s
P
p
.001 w
.99625 .36788 m
1 .36788 L
s
P
p
.001 w
.99625 .38995 m
1 .38995 L
s
P
p
.001 w
.99625 .41202 m
1 .41202 L
s
P
p
.001 w
.99625 .4341 m
1 .4341 L
s
P
p
.001 w
.99625 .47824 m
1 .47824 L
s
P
p
.001 w
.99625 .50031 m
1 .50031 L
s
P
p
.001 w
.99625 .52239 m
1 .52239 L
s
P
p
.001 w
.99625 .54446 m
1 .54446 L
s
P
p
.001 w
.99625 .5886 m
1 .5886 L
s
P
p
.001 w
.99625 .61068 m
1 .61068 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
p
0 0 1 r
.02381 .01472 m
.02381 .0515 L
.05556 .0515 L
.05556 .01472 L
F
.05556 .01472 m
.05556 .08829 L
.0873 .08829 L
.0873 .01472 L
F
.0873 .01472 m
.0873 .60332 L
.11905 .60332 L
.11905 .01472 L
F
.11905 .01472 m
.11905 .30902 L
.15079 .30902 L
.15079 .01472 L
F
.15079 .01472 m
.15079 .12508 L
.18254 .12508 L
.18254 .01472 L
F
.18254 .01472 m
.18254 .16187 L
.21429 .16187 L
.21429 .01472 L
F
.21429 .01472 m
.21429 .16187 L
.24603 .16187 L
.24603 .01472 L
F
.24603 .01472 m
.24603 .27223 L
.27778 .27223 L
.27778 .01472 L
F
.27778 .01472 m
.27778 .27223 L
.30952 .27223 L
.30952 .01472 L
F
.30952 .01472 m
.30952 .08829 L
.34127 .08829 L
.34127 .01472 L
F
.34127 .01472 m
.34127 .12508 L
.37302 .12508 L
.37302 .01472 L
F
.37302 .01472 m
.37302 .01472 L
.40476 .01472 L
.40476 .01472 L
F
.40476 .01472 m
.40476 .08829 L
.43651 .08829 L
.43651 .01472 L
F
.43651 .01472 m
.43651 .01472 L
.46825 .01472 L
.46825 .01472 L
F
.46825 .01472 m
.46825 .0515 L
.5 .0515 L
.5 .01472 L
F
.5 .01472 m
.5 .01472 L
.53175 .01472 L
.53175 .01472 L
F
.53175 .01472 m
.53175 .01472 L
.56349 .01472 L
.56349 .01472 L
F
.56349 .01472 m
.56349 .01472 L
.59524 .01472 L
.59524 .01472 L
F
.59524 .01472 m
.59524 .01472 L
.62698 .01472 L
.62698 .01472 L
F
.62698 .01472 m
.62698 .01472 L
.65873 .01472 L
.65873 .01472 L
F
.65873 .01472 m
.65873 .01472 L
.69048 .01472 L
.69048 .01472 L
F
.69048 .01472 m
.69048 .01472 L
.72222 .01472 L
.72222 .01472 L
F
.72222 .01472 m
.72222 .01472 L
.75397 .01472 L
.75397 .01472 L
F
.75397 .01472 m
.75397 .01472 L
.78571 .01472 L
.78571 .01472 L
F
.78571 .01472 m
.78571 .01472 L
.81746 .01472 L
.81746 .01472 L
F
.81746 .01472 m
.81746 .01472 L
.84921 .01472 L
.84921 .01472 L
F
.84921 .01472 m
.84921 .01472 L
.88095 .01472 L
.88095 .01472 L
F
.88095 .01472 m
.88095 .01472 L
.9127 .01472 L
.9127 .01472 L
F
.9127 .01472 m
.9127 .01472 L
.94444 .01472 L
.94444 .01472 L
F
.94444 .01472 m
.94444 .01472 L
.97619 .01472 L
.97619 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .0515 L
s
.05556 .01472 m
.05556 .0515 L
s
.02381 .0515 m
.05556 .0515 L
s
.05556 .01472 m
.05556 .08829 L
s
.0873 .01472 m
.0873 .08829 L
s
.05556 .08829 m
.0873 .08829 L
s
.0873 .01472 m
.0873 .60332 L
s
.11905 .01472 m
.11905 .60332 L
s
.0873 .60332 m
.11905 .60332 L
s
.11905 .01472 m
.11905 .30902 L
s
.15079 .01472 m
.15079 .30902 L
s
.11905 .30902 m
.15079 .30902 L
s
.15079 .01472 m
.15079 .12508 L
s
.18254 .01472 m
.18254 .12508 L
s
.15079 .12508 m
.18254 .12508 L
s
.18254 .01472 m
.18254 .16187 L
s
.21429 .01472 m
.21429 .16187 L
s
.18254 .16187 m
.21429 .16187 L
s
.21429 .01472 m
.21429 .16187 L
s
.24603 .01472 m
.24603 .16187 L
s
.21429 .16187 m
.24603 .16187 L
s
.24603 .01472 m
.24603 .27223 L
s
.27778 .01472 m
.27778 .27223 L
s
.24603 .27223 m
.27778 .27223 L
s
.27778 .01472 m
.27778 .27223 L
s
.30952 .01472 m
.30952 .27223 L
s
.27778 .27223 m
.30952 .27223 L
s
.30952 .01472 m
.30952 .08829 L
s
.34127 .01472 m
.34127 .08829 L
s
.30952 .08829 m
.34127 .08829 L
s
.34127 .01472 m
.34127 .12508 L
s
.37302 .01472 m
.37302 .12508 L
s
.34127 .12508 m
.37302 .12508 L
s
.37302 .01472 m
.37302 .01472 L
s
.40476 .01472 m
.40476 .01472 L
s
.37302 .01472 m
.40476 .01472 L
s
.40476 .01472 m
.40476 .08829 L
s
.43651 .01472 m
.43651 .08829 L
s
.40476 .08829 m
.43651 .08829 L
s
.43651 .01472 m
.43651 .01472 L
s
.46825 .01472 m
.46825 .01472 L
s
.43651 .01472 m
.46825 .01472 L
s
.46825 .01472 m
.46825 .0515 L
s
.5 .01472 m
.5 .0515 L
s
.46825 .0515 m
.5 .0515 L
s
.5 .01472 m
.5 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.5 .01472 m
.53175 .01472 L
s
.53175 .01472 m
.53175 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.53175 .01472 m
.56349 .01472 L
s
.56349 .01472 m
.56349 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.56349 .01472 m
.59524 .01472 L
s
.59524 .01472 m
.59524 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.59524 .01472 m
.62698 .01472 L
s
.62698 .01472 m
.62698 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.62698 .01472 m
.65873 .01472 L
s
.65873 .01472 m
.65873 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.65873 .01472 m
.69048 .01472 L
s
.69048 .01472 m
.69048 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.69048 .01472 m
.72222 .01472 L
s
.72222 .01472 m
.72222 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.72222 .01472 m
.75397 .01472 L
s
.75397 .01472 m
.75397 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.75397 .01472 m
.78571 .01472 L
s
.78571 .01472 m
.78571 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.78571 .01472 m
.81746 .01472 L
s
.81746 .01472 m
.81746 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.81746 .01472 m
.84921 .01472 L
s
.84921 .01472 m
.84921 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.84921 .01472 m
.88095 .01472 L
s
.88095 .01472 m
.88095 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.88095 .01472 m
.9127 .01472 L
s
.9127 .01472 m
.9127 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.9127 .01472 m
.94444 .01472 L
s
.94444 .01472 m
.94444 .01472 L
s
.97619 .01472 m
.97619 .01472 L
s
.94444 .01472 m
.97619 .01472 L
s
P
P
p
p
.004 w
.02381 .01472 m
.04365 .12082 L
.05357 .18145 L
.06349 .23429 L
.07341 .27719 L
.07837 .29477 L
.08333 .30983 L
.08829 .32247 L
.09325 .33281 L
.09821 .34098 L
.10069 .3443 L
.10317 .34713 L
.10565 .3495 L
.10813 .35142 L
.11062 .35291 L
.11186 .3535 L
.1131 .35399 L
.11434 .35439 L
.11558 .35468 L
.11682 .35489 L
.11806 .355 L
.1193 .35503 L
.12054 .35497 L
.12178 .35483 L
.12302 .3546 L
.12426 .3543 L
.1255 .35391 L
.12798 .35293 L
.13046 .35165 L
.13294 .35012 L
.14286 .34159 L
.15278 .32998 L
.1627 .31608 L
.18254 .28409 L
.22222 .21622 L
.2619 .1565 L
.30159 .11035 L
.32143 .09231 L
.34127 .07726 L
.36111 .06483 L
.38095 .05466 L
.40079 .04641 L
.42063 .03976 L
.44048 .03443 L
.46032 .03018 L
.48016 .02681 L
.5 .02415 L
.51984 .02205 L
.53968 .02041 L
.55952 .01912 L
Mistroke
.57937 .01812 L
.59921 .01734 L
.61905 .01674 L
.63889 .01627 L
.65873 .01591 L
.67857 .01563 L
.69841 .01541 L
.71825 .01525 L
.7381 .01512 L
.75794 .01503 L
.77778 .01495 L
.79762 .0149 L
.81746 .01485 L
.8373 .01482 L
.85714 .01479 L
.87698 .01477 L
.89683 .01476 L
.91667 .01475 L
.93651 .01474 L
.95635 .01473 L
.97619 .01473 L
Mfstroke
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

^*)
