(*^

::[	frontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.1";
	macintoshStandardFontEncoding; 
	paletteColors = 128; automaticGrouping; currentKernel; 
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; ;
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; ;
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; ;
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; ;
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; ;
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; ;
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; ;
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; ;
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; ;
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; ;
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; ;
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; ;
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; ;
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; ;
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = leftheader, inactive, L2,  12, "Times"; ;
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; ;
	fontset = leftfooter, inactive, L2,  12, "Times"; ;
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; ;
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
]
:[font = text; inactive; preserveAspect; ]
PROGRAM:  Law
CALLING SEQUENCE:  Law[nmin, nmax, inc, p, e]
PARAMETERS:
     nmin, nmax, inc - integers
     p, e - real numbers
SYNOPSIS:
     -  For n = nmin to nmax, in steps of size inc,  this program computes and displays
         (1)  the exact probability P(|A_n - p| >= e), where A_n is the average outcome of
         n Bernoulli trials with probability p of success, and (2)  the Chebyshev estimate
         p(1-p)/(n(e^2)) for this probability.
     -  Note:  this program requires the function "Bin[n, p, k]" be initialized.
RETURNED VALUES:
     -  a list whose elements are {n, P(|A_n - p| >= e),  Chebyshev estimate
        p(1-p)/(n(2^2))},  for n = nmin to nmax, in steps of size inc
LOCATION:
     Folder:  Chapter 8
     File:        "Law.Chpt8.mat"
;[s]
1:0,0;769,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect; ]
*)
Clear[Law];
Law[nmin_, nmax_, inc_, p_, e_] :=
Block[{mean, lowerbound, upperbound, sum, c,
       nlist = {}, plist = {}, clist = {}, alist = {}
      },
      For[n = nmin, n <= nmax, n = n + inc,
          nlist = Append[nlist, n];
          mean = n*p;
          lowerbound = Floor[Max[0, mean - (n*e)]] + 1;
          upperbound = Floor[Min[n, mean + (n*e)]] - 1;
          sum = 0;
          For[k = lowerbound, k <= upperbound, k++,
              sum = sum + Bin[n, p, k]
             ];
          plist = Append[plist, 1 - sum];
          c = p*(1-p)/(n*(e^2));
          clist = Append[clist, c]
         ];
      alist = Table[{nlist[[i]], plist[[i]], clist[[i]]},
                    {i, 1, Length[nlist]}
                   ];
      Print[" n      P(|A_n - ",p,"| >= ",e,")    Chebyshev"];
      Print["  "];
      Print[TableForm[alist, TableSpacing -> {0,10}]]
	 ]
(*
:[font = input; preserveAspect; startGroup; ]
Law[50, 400, 50, .3, .1]
:[font = print; inactive; preserveAspect; endGroup; ]
 n      P(|A_n - 0.3| >= 0.1)    Chebyshev
  
50           0.163653              0.42
100          0.0374514             0.21
150          0.00955279            0.14
200          0.00256512            0.105
250          0.000711052           0.084
300          0.000201584           0.07
350          0.0000581377          0.06
400          0.0000169989          0.0525
^*)