(*^

::[	frontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.1";
	macintoshStandardFontEncoding; 
	paletteColors = 128; automaticGrouping; currentKernel; 
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; ;
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; ;
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; ;
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; ;
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; ;
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; ;
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; ;
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; ;
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; ;
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; ;
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; ;
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; ;
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; ;
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; ;
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = leftheader, inactive, L2,  12, "Times"; ;
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; ;
	fontset = leftfooter, inactive, L2,  12, "Times"; ;
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; ;
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; ;
]
:[font = text; inactive; preserveAspect; ]
PROGRAM:  LawContinuous
CALLING SEQUENCE:  LawContinuous[nmin, nmax, inc, e]
PARAMETERS:
     nmin, nmax, inc - integers
     e -  a real number
SYNOPSIS:
     -  For n = nmin to nmax, in steps of size inc, this program computes and displays
        (1)  the exact probability P(|S_n/n| >= e), where S_n is a sum of n standard
        normally-distributed random variables, and (2) the Chebyshev estimate 1/n*(e^2)
        for this probability.
     -  Note:  this program requires the program "NormalArea[a, b]" be initialized.
RETURNED VALUES:
     -  a list whose elements are {n, P(|S_n/n| >= e),  Chebyshev estimate 1/n*(e^2)},
        for n = nmin to nmax, in steps of size inc
LOCATION:
     Folder:  Chapter 8
     File:       "LawContinuous.Chpt8.mat"
;[s]
1:0,0;761,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect; ]
*)
Clear[LawContinuous];
LawContinuous[nmin_, nmax_, inc_, e_] :=
Block[{narea, p, c,
       nlist = {}, plist = {}, clist = {}, alist = {}
      },
      For[n = nmin, n <= nmax, n = n + inc,
          nlist = Append[nlist, n];
          p = 1 - NormalArea[-(Sqrt[n]*e), (Sqrt[n]*e)];
          plist = Append[plist, p];
          c = 1/(n*(e^2));
          clist = Append[clist, c]
         ];
      alist = Table[{nlist[[i]], plist[[i]], clist[[i]]},
                    {i, 1, Length[nlist]}
                   ];
      Print[" n         P(|S_n/n| >= ",e,")    Chebyshev"];
      Print["  "];
      Print[TableForm[alist, TableSpacing -> {0,10}]]
     ]
(*
:[font = input; preserveAspect; startGroup; ]
LawContinuous[100, 1000, 100, .1]
:[font = print; inactive; preserveAspect; endGroup; ]
 n         P(|S_n/n| >= 0.1)    Chebyshev
  
100           0.317311            1.
200           0.157299            0.5
300           0.0832645           0.333333
400           0.0455003           0.25
500           0.0253473           0.2
600           0.0143059           0.166667
700           0.00815097          0.142857
800           0.00467773          0.125
900           0.0026998           0.111111
1000          0.0015654           0.1
^*)