(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  CLTBernoulliGlobal
CALLING SEQUENCE:  CLTBernoulliGlobal[n, p, kmin, kmax, half]
PARAMETERS:
     n, kmin, kmax - integers
     p - a real number
     half - a Boolean variable (True or False)
SYNOPSIS:
    -  This program uses the normal approximation to approximate the probability that
       S_n, a sum of n Bernoulli trials with probability p of success for each trial, lies in
       [kmin, kmax].  If half = True, the program includes the 1/2 correction; otherwise, it
       doesn't.  To find the exact value of this probability, use the procedure 
       BinomialProbabilities.
    -  Note:  this program requires the program "NormalArea[a, b]" be initialized.
RETURNED VALUES:
     -  the approximated probability that S_n lies in [kmin, kmax]
LOCATION:
     Folder:  Chapter 9
     File:       "CLTBernoulliGlobal.Chpt9.mat"
;[s]
1:0,0;846,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[CLTBernoulliGlobal];
CLTBernoulliGlobal[n_, p_, kmin_, kmax_, half_] :=
Block[{mu, sigma2, min, max, Answer},
      mu = p;
      sigma2 = p*(1-p);
      min = (kmin - n * mu)/Sqrt[n * sigma2];
      max = (kmax - n * mu)/Sqrt[n * sigma2];
      If[half == False,
         Answer = NormalArea[min, max],
         Answer = NormalArea[min - (.5/Sqrt[n * sigma2]),
                             max + (.5/Sqrt[n * sigma2])
                            ]
        ];
      Return[Answer]
     ]
(*
:[font = input; preserveAspect; startGroup]
CLTBernoulliGlobal[100, .2, 25, 30, False]
:[font = output; output; inactive; preserveAspect; endGroup]
0.0994401083410791
;[o]
0.0994401
:[font = input; preserveAspect; startGroup]
CLTBernoulliGlobal[100, .2, 25, 30, True]
:[font = output; output; inactive; preserveAspect; endGroup]
0.1259620687737963
;[o]
0.125962
:[font = input; preserveAspect; startGroup]
BinomialProbabilities[100, .2, 25, 30, False]
:[font = output; output; inactive; preserveAspect; endGroup]
0.1252938818519471
;[o]
0.1252938819
^*)
