(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = text; inactive; preserveAspect]
PROGRAM:  CLTIndTrialsLocal
CALLING SEQUENCE:  CLTIndTrialsLocal[n, distributionlist, k]
PARAMETERS:
     n, k - integers
     distributionlist - a distribution list
SYNOPSIS:
     -  This program computes and displays the exact calculation of P(S_n = k) and the
         normal approximation of the same, where S_n is a sum of n independent
         variables with common distribution given in distributionlist.
     -  Note:  this program requires the programs "NFoldConvolution[distributionlist, n]",
        "DiscreteMean[distributionlist]", and "DiscreteVariance[distributionlist]" be
        initialized.  The last two of these are all in the file Important Programs; the first
        is in the file DiscreteConvolution.Chpt7.mat.
RETURNED VALUES:
     -  {P(S_n = k), normal approximation P(S_n = k)}
LOCATION:
     Folder:  Chapter 9
     File:       "CLTIndTrialsLocal.Chpt9.mat"
;[s]
1:0,0;890,-1;
1:1,14,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[CLTIndTrialsLocal];
CLTIndTrialsLocal[n_, distributionlist_, k_] :=
Block[{clist, c, mu, sigma2, xk, nxk, normalappx},
      clist = NFoldConvolution[distributionlist,n];
      c = Select[clist, #[[1]]==k&];
      If[c == {}, c = 0,
         c = Flatten[c][[2]]
        ];
      mu = DiscreteMean[distributionlist];
      sigma2 = DiscreteVariance[distributionlist];
      xk = (k - n * mu)/Sqrt[n * sigma2];
      nxk = (1/(Sqrt[2 * Pi])) * (E^((-(xk^2))/2)); 
      normalappx = nxk/Sqrt[n * sigma2]//N;
      Print["Exact P(S_n = k)     Normal Approximation"];
      Print[" "];
      Print["   ",N[c,5], "                ", N[normalappx,5]];
      Return[{c, normalappx}]
     ]
(*
:[font = input; preserveAspect; startGroup]
distlist = Table[{i, .166667}, {i, 1, 6}]
:[font = output; output; inactive; preserveAspect; endGroup]
{{1, 0.166667}, {2, 0.166667}, {3, 0.166667}, 
 
  {4, 0.166667}, {5, 0.166667}, {6, 0.166667}}
;[o]
{{1, 0.166667}, {2, 0.166667}, {3, 0.166667}, 
 
  {4, 0.166667}, {5, 0.166667}, {6, 0.166667}}
:[font = input; preserveAspect; startGroup]
CLTIndTrialsLocal[6, distlist, 21]
:[font = print; inactive; preserveAspect]
Exact P(S_n = k)     Normal Approximation
 
   0.092851                0.095365
:[font = output; output; inactive; preserveAspect; endGroup]
{0.092850908441785, 0.0953653500308694}
;[o]
{0.0928509, 0.0953654}
:[font = input; preserveAspect; startGroup]
CLTIndTrialsLocal[6, distlist, .3]
:[font = print; inactive; preserveAspect]
Exact P(S_n = k)     Normal Approximation
 
                             -7
   0                4.5973 10
:[font = output; output; inactive; preserveAspect; endGroup]
{0, 4.597253472854922*10^-7}
;[o]
              -7
{0, 4.59725 10  }
^*)
