(*^
::[	Information =

	"This is a Mathematica Notebook file.  It contains ASCII text, and can be
	transferred by email, ftp, or other text-file transfer utility.  It should
	be read or edited using a copy of Mathematica or MathReader.  If you 
	received this as email, use your mail application or copy/paste to save 
	everything from the line containing (*^ down to the line containing ^*)
	into a plain text file.  On some systems you may have to give the file a 
	name ending with ".ma" to allow Mathematica to recognize it as a Notebook.
	The line below identifies what version of Mathematica created this file,
	but it can be opened using any other version as well.";

	FrontEndVersion = "Macintosh Mathematica Notebook Front End Version 2.2";

	MacintoshStandardFontEncoding; 
	
	fontset = title, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e8,  24, "Times"; 
	fontset = subtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, bold, e6,  18, "Times"; 
	fontset = subsubtitle, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeTitle, center, M7, italic, e6,  14, "Times"; 
	fontset = section, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, grayBox, M22, bold, a20,  18, "Times"; 
	fontset = subsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, blackBox, M19, bold, a15,  14, "Times"; 
	fontset = subsubsection, inactive, noPageBreakBelow, nohscroll, preserveAspect, groupLikeSection, whiteBox, M18, bold, a12,  12, "Times"; 
	fontset = text, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = smalltext, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = input, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeInput, M42, N23, bold, L-5,  12, "Courier"; 
	fontset = output, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = message, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, R65535, L-5,  12, "Courier"; 
	fontset = print, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, L-5,  12, "Courier"; 
	fontset = info, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeOutput, M42, N23, B65535, L-5,  12, "Courier"; 
	fontset = postscript, PostScript, formatAsPostScript, output, inactive, noPageBreakInGroup, nowordwrap, preserveAspect, groupLikeGraphics, M7, l34, w282, h287,  12, "Courier"; 
	fontset = name, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7, italic,  10, "Geneva"; 
	fontset = header, inactive, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = leftheader, inactive, L2,  12, "Times"; 
	fontset = footer, inactive, noKeepOnOnePage, preserveAspect, center, M7,  12, "Times"; 
	fontset = leftfooter, inactive, L2,  12, "Times"; 
	fontset = help, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  10, "Times"; 
	fontset = clipboard, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = completions, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special1, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special2, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special3, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special4, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	fontset = special5, inactive, nohscroll, noKeepOnOnePage, preserveAspect, M7,  12, "Times"; 
	paletteColors = 128; automaticGrouping; currentKernel; 
]
:[font = input; preserveAspect]
PROGRAM:  Queue
CALLING SEQUENCE:  Queue[lambda, mu, tmax]
PARAMETERS:
     lambda, mu - real numbers
     tmax - an integer
SYNOPSIS:
     -  This program simulates the queue problem described in the book, for times  t = 0
        to tmax, where the interarrival times between successive customers are
        exponentially distributed with parameter lambda, and the service times for
        successive customers are exponentially distributed with parameter mu.   The
        program displays a list plot where the x-axis represents time, and the point f(x)
        represents the number of customers in line at time x.  Points are plotted
        for those values of x where the queue either increases or decreases in size. 
        These points are joined with lines to make viewing  the graph easier.   
        An area bargraph of the distribution of waiting times and a spike graph of the 
        distribution of the queue lengths are also shown.
RETURNED VALUES:
     -  The lists of waiting times and queue lengths
LOCATION:
     Folder:  Chapter 5
     File:       "Queue.Chpt5.mat"

;[s]
1:0,1;1095,-1;
2:0,12,10,Courier,1,12,0,0,0;1,13,10,Helvetica,0,12,0,0,0;
:[font = input; initialization; preserveAspect]
*)
Clear[Queue];
Queue[lambda_, mu_, t_] :=
Block[{queuelength = 0,
       timesubtotal = 0,
       arrivalservicelist = {},
       currentpair = {},
       currenttime = 0,
       currentqueuesize,
       queuelist = {{0, 0}},
       currentserved = 1,
       n,
       i,
       nextpersontoarrive = 2,
       beginendservicetimes = {},
       begin,
       arrivallist = {},
       leavelist = {},
       dummylist = {},
       augmentedarrivallist = {},
       augmentedleavelist = {},
       sortedlist = {},
       graphlist = {},
       waitingtimelist = {},
       queuesizelist = {}
      },
      While[(timesubtotal <= t),
            currentpair = {-(1/lambda)*Log[Random[]],
                           -(1/mu)*Log[Random[]]};
            timesubtotal = timesubtotal +
                           currentpair[[1]];
            currentpair[[1]] := timesubtotal;
            If[(timesubtotal <= t),
               arrivalservicelist =
                 Append[arrivalservicelist,
                        currentpair
                       ];
              ];
           ];
      If[(Length[arrivalservicelist] == 0),
         Return["empty list"];
        ];
      beginendservicetimes = 
        Append[beginendservicetimes, 
                {arrivalservicelist[[1]][[1]],
                 arrivalservicelist[[1]][[1]]+
                 arrivalservicelist[[1]][[2]]
                }
              ];
  (*    Print[arrivalservicelist];   *)
      n = Length[arrivalservicelist];
      For[i = 2, i <= n, i++,
          begin = Max[arrivalservicelist[[i]][[1]],
                       beginendservicetimes[[i-1]][[2]]
                      ];
          beginendservicetimes = 
           Append[beginendservicetimes,
                  {begin,
                   begin + arrivalservicelist[[i]][[2]]
                  }
                 ];
         ];
       arrivallist = Transpose[arrivalservicelist][[1]];
       leavelist = Transpose[beginendservicetimes][[2]];
       dummylist = Table[1, {i, n}];
       augmentedarrivallist = Transpose[{arrivallist, dummylist}];
       dummylist = Table[-1, {i, n}];
       augmentedleavelist = Transpose[{leavelist, dummylist}];
       sortedlist = Sort[Join[augmentedarrivallist,
                              augmentedleavelist
                             ]
                        ];
       graphlist = Append[graphlist, {0, 0}];
       For[i = 1, i <= 2*n, i++,
           graphlist = Append[graphlist,
                              {sortedlist[[i]][[1]],
                               graphlist[[i]][[2]] +
                                sortedlist[[i]][[2]]
                              }
                             ];
          ];
(*       Print[graphlist];        *)
       i = 1;
       If[(graphlist[[2*n+1]][[1]] > t),
          Block[{},
                While[(graphlist[[i]][[1]] <= t),
                      i++
                     ];
                graphlist = Take[graphlist, i-1]
               ]
         ];
       queuesizelist = Append[queuesizelist, 0];
       i = 1;
       currenttime = 1;
       currentqueuesize = 0;
       While[(currenttime <= graphlist[[1]][[1]]),
             queuesizelist = Append[queuesizelist, 0];
             currenttime++
            ];
       While[((i < Length[graphlist]) && (currenttime < t)),
             While[((graphlist[[i]][[1]] <= currenttime) &&
                    (i < Length[graphlist])),
                   i++
                  ];
             queuesizelist = Append[queuesizelist,
                                    graphlist[[i-1]][[2]]
                                   ];
             currenttime++;
             While[(currenttime < graphlist[[i]][[1]]),
                   Block[{},
                    queuesizelist = Append[queuesizelist, 
                                          graphlist[[i-1]][[2]]
                                         ];
                    currenttime++
                        ];
                  ];
            ];
       queuesizelist = Append[queuesizelist,
                              graphlist[[Length[graphlist]]][[2]]
                             ];
       ListPlot[graphlist, PlotJoined -> True];
       For[i = 1, i <= n, i++,
           waitingtimelist = 
             Append[waitingtimelist,
                    beginendservicetimes[[i]][[1]] -
                    arrivalservicelist[[i]][[1]]
                   ];
          ];
      Print["maximum waiting time = ", Max[waitingtimelist]];
      Print["average waiting time = ", 
            N[Apply[Plus, waitingtimelist]/Length[waitingtimelist]]
           ];
      Print["maximum queue size = ", Max[queuesizelist]];
      Print["average queue size = ", 
            N[Apply[Plus, queuesizelist]/Length[queuesizelist]]
           ];
      Print["The next two graphs show the distributions of"];
      Print["queue waiting times and queue lengths."];
      Areabargraph[waitingtimelist, 
                   0, 
                   10*Ceiling[Max[waitingtimelist]/10], 
                   10
                  ];
      Spikegraph[SpikeData[queuesizelist], 
                 0,
                 Max[queuesizelist],
                 True
                ];
      Return[{waitingtimelist, queuesizelist}];
     ]
(*
:[font = input; preserveAspect; startGroup]
Queue[1,1,1000]
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0009525 0.0147151 0.00878513 [
[(200)] .21431 .01472 0 2 Msboxa
[(400)] .40481 .01472 0 2 Msboxa
[(600)] .59531 .01472 0 2 Msboxa
[(800)] .78581 .01472 0 2 Msboxa
[(1000)] .97631 .01472 0 2 Msboxa
[(10)] .01131 .10257 1 0 Msboxa
[(20)] .01131 .19042 1 0 Msboxa
[(30)] .01131 .27827 1 0 Msboxa
[(40)] .01131 .36612 1 0 Msboxa
[(50)] .01131 .45397 1 0 Msboxa
[(60)] .01131 .54182 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21431 .01472 m
.21431 .02097 L
s
P
[(200)] .21431 .01472 0 2 Mshowa
p
.002 w
.40481 .01472 m
.40481 .02097 L
s
P
[(400)] .40481 .01472 0 2 Mshowa
p
.002 w
.59531 .01472 m
.59531 .02097 L
s
P
[(600)] .59531 .01472 0 2 Mshowa
p
.002 w
.78581 .01472 m
.78581 .02097 L
s
P
[(800)] .78581 .01472 0 2 Mshowa
p
.002 w
.97631 .01472 m
.97631 .02097 L
s
P
[(1000)] .97631 .01472 0 2 Mshowa
p
.001 w
.06191 .01472 m
.06191 .01847 L
s
P
p
.001 w
.10001 .01472 m
.10001 .01847 L
s
P
p
.001 w
.13811 .01472 m
.13811 .01847 L
s
P
p
.001 w
.17621 .01472 m
.17621 .01847 L
s
P
p
.001 w
.25241 .01472 m
.25241 .01847 L
s
P
p
.001 w
.29051 .01472 m
.29051 .01847 L
s
P
p
.001 w
.32861 .01472 m
.32861 .01847 L
s
P
p
.001 w
.36671 .01472 m
.36671 .01847 L
s
P
p
.001 w
.44291 .01472 m
.44291 .01847 L
s
P
p
.001 w
.48101 .01472 m
.48101 .01847 L
s
P
p
.001 w
.51911 .01472 m
.51911 .01847 L
s
P
p
.001 w
.55721 .01472 m
.55721 .01847 L
s
P
p
.001 w
.63341 .01472 m
.63341 .01847 L
s
P
p
.001 w
.67151 .01472 m
.67151 .01847 L
s
P
p
.001 w
.70961 .01472 m
.70961 .01847 L
s
P
p
.001 w
.74771 .01472 m
.74771 .01847 L
s
P
p
.001 w
.82391 .01472 m
.82391 .01847 L
s
P
p
.001 w
.86201 .01472 m
.86201 .01847 L
s
P
p
.001 w
.90011 .01472 m
.90011 .01847 L
s
P
p
.001 w
.93821 .01472 m
.93821 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .10257 m
.03006 .10257 L
s
P
[(10)] .01131 .10257 1 0 Mshowa
p
.002 w
.02381 .19042 m
.03006 .19042 L
s
P
[(20)] .01131 .19042 1 0 Mshowa
p
.002 w
.02381 .27827 m
.03006 .27827 L
s
P
[(30)] .01131 .27827 1 0 Mshowa
p
.002 w
.02381 .36612 m
.03006 .36612 L
s
P
[(40)] .01131 .36612 1 0 Mshowa
p
.002 w
.02381 .45397 m
.03006 .45397 L
s
P
[(50)] .01131 .45397 1 0 Mshowa
p
.002 w
.02381 .54182 m
.03006 .54182 L
s
P
[(60)] .01131 .54182 1 0 Mshowa
p
.001 w
.02381 .03229 m
.02756 .03229 L
s
P
p
.001 w
.02381 .04986 m
.02756 .04986 L
s
P
p
.001 w
.02381 .06743 m
.02756 .06743 L
s
P
p
.001 w
.02381 .085 m
.02756 .085 L
s
P
p
.001 w
.02381 .12014 m
.02756 .12014 L
s
P
p
.001 w
.02381 .13771 m
.02756 .13771 L
s
P
p
.001 w
.02381 .15528 m
.02756 .15528 L
s
P
p
.001 w
.02381 .17285 m
.02756 .17285 L
s
P
p
.001 w
.02381 .20799 m
.02756 .20799 L
s
P
p
.001 w
.02381 .22556 m
.02756 .22556 L
s
P
p
.001 w
.02381 .24313 m
.02756 .24313 L
s
P
p
.001 w
.02381 .2607 m
.02756 .2607 L
s
P
p
.001 w
.02381 .29584 m
.02756 .29584 L
s
P
p
.001 w
.02381 .31341 m
.02756 .31341 L
s
P
p
.001 w
.02381 .33098 m
.02756 .33098 L
s
P
p
.001 w
.02381 .34855 m
.02756 .34855 L
s
P
p
.001 w
.02381 .38369 m
.02756 .38369 L
s
P
p
.001 w
.02381 .40126 m
.02756 .40126 L
s
P
p
.001 w
.02381 .41883 m
.02756 .41883 L
s
P
p
.001 w
.02381 .4364 m
.02756 .4364 L
s
P
p
.001 w
.02381 .47154 m
.02756 .47154 L
s
P
p
.001 w
.02381 .48911 m
.02756 .48911 L
s
P
p
.001 w
.02381 .50668 m
.02756 .50668 L
s
P
p
.001 w
.02381 .52425 m
.02756 .52425 L
s
P
p
.001 w
.02381 .55939 m
.02756 .55939 L
s
P
p
.001 w
.02381 .57696 m
.02756 .57696 L
s
P
p
.001 w
.02381 .59453 m
.02756 .59453 L
s
P
p
.001 w
.02381 .6121 m
.02756 .6121 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.02381 .01472 m
.02453 .0235 L
.02479 .03229 L
.0261 .04107 L
.02646 .03229 L
.02734 .0235 L
.0279 .01472 L
.02805 .0235 L
.02818 .01472 L
.02925 .0235 L
.0294 .01472 L
.02946 .0235 L
.02987 .03229 L
.03044 .04107 L
.03174 .04986 L
.03194 .04107 L
.03208 .03229 L
.03226 .0235 L
.03308 .03229 L
.03322 .0235 L
.03429 .03229 L
.03447 .04107 L
.03467 .04986 L
.03705 .04107 L
.03728 .04986 L
.03729 .04107 L
.03742 .03229 L
.03783 .0235 L
.03784 .03229 L
.0379 .04107 L
.03853 .03229 L
.03913 .04107 L
.04083 .03229 L
.04104 .04107 L
.0413 .03229 L
.04149 .04107 L
.042 .04986 L
.04266 .04107 L
.04296 .04986 L
.04325 .04107 L
.04398 .04986 L
.04417 .04107 L
.0445 .03229 L
.04635 .04107 L
.04696 .04986 L
.0482 .05864 L
.04843 .04986 L
.04879 .04107 L
.04895 .04986 L
.04927 .05864 L
Mistroke
.04988 .06743 L
.05015 .05864 L
.05036 .04986 L
.05066 .05864 L
.05085 .04986 L
.05157 .05864 L
.05176 .06743 L
.05192 .05864 L
.05197 .06743 L
.05258 .05864 L
.05272 .06743 L
.0529 .05864 L
.05347 .06743 L
.05416 .05864 L
.05441 .06743 L
.05448 .07621 L
.05584 .06743 L
.05596 .05864 L
.05667 .06743 L
.05668 .05864 L
.05682 .04986 L
.05706 .04107 L
.05738 .04986 L
.0575 .04107 L
.05752 .03229 L
.05829 .04107 L
.05834 .04986 L
.0584 .05864 L
.05894 .06743 L
.06063 .05864 L
.06092 .06743 L
.06105 .05864 L
.06118 .06743 L
.06156 .07621 L
.06165 .06743 L
.06172 .05864 L
.06268 .06743 L
.06297 .05864 L
.06323 .04986 L
.06383 .05864 L
.06414 .04986 L
.06477 .05864 L
.0653 .04986 L
.06594 .04107 L
.0663 .04986 L
.06641 .05864 L
.06657 .04986 L
.0666 .05864 L
.06665 .06743 L
.06668 .05864 L
Mistroke
.06678 .06743 L
.06726 .05864 L
.06742 .04986 L
.06752 .04107 L
.0677 .04986 L
.06798 .05864 L
.06844 .06743 L
.06863 .05864 L
.06866 .04986 L
.07089 .05864 L
.07167 .04986 L
.07201 .05864 L
.07225 .06743 L
.07232 .07621 L
.07284 .085 L
.07317 .07621 L
.07356 .06743 L
.07365 .05864 L
.0755 .04986 L
.07602 .05864 L
.07628 .06743 L
.07637 .05864 L
.07766 .04986 L
.07781 .04107 L
.07858 .04986 L
.07865 .04107 L
.07869 .04986 L
.0787 .04107 L
.07902 .04986 L
.08085 .05864 L
.08086 .04986 L
.08088 .04107 L
.08315 .04986 L
.08355 .04107 L
.0838 .03229 L
.08467 .0235 L
.08481 .01472 L
.08568 .0235 L
.08591 .03229 L
.08697 .0235 L
.08708 .03229 L
.08724 .04107 L
.08756 .04986 L
.0877 .04107 L
.08771 .03229 L
.08776 .04107 L
.08781 .04986 L
.08812 .05864 L
.08818 .04986 L
.08869 .04107 L
Mistroke
.08909 .03229 L
.08979 .0235 L
.09016 .01472 L
.09083 .0235 L
.09165 .01472 L
.09477 .0235 L
.09486 .03229 L
.09487 .0235 L
.09493 .03229 L
.0951 .04107 L
.09694 .04986 L
.09751 .05864 L
.09865 .04986 L
.09867 .05864 L
.09884 .06743 L
.09953 .07621 L
.09965 .085 L
.0999 .09378 L
.10009 .10257 L
.10036 .11135 L
.10045 .12014 L
.10064 .12892 L
.10165 .12014 L
.10191 .11135 L
.10242 .10257 L
.10268 .09378 L
.10271 .085 L
.10313 .09378 L
.1035 .10257 L
.10412 .11135 L
.10435 .10257 L
.10504 .11135 L
.1054 .12014 L
.10544 .11135 L
.1055 .12014 L
.10571 .12892 L
.10578 .12014 L
.1062 .11135 L
.10743 .10257 L
.10765 .11135 L
.10767 .12014 L
.10771 .11135 L
.10858 .12014 L
.10901 .11135 L
.10935 .10257 L
.11002 .09378 L
.11118 .10257 L
.11173 .11135 L
.11174 .12014 L
.11185 .12892 L
Mistroke
.11207 .12014 L
.11236 .11135 L
.11257 .12014 L
.11322 .12892 L
.11346 .13771 L
.11392 .14649 L
.11395 .15528 L
.11423 .14649 L
.11464 .15528 L
.11465 .16406 L
.11479 .15528 L
.11497 .14649 L
.11512 .13771 L
.11676 .12892 L
.11685 .13771 L
.11692 .14649 L
.11727 .13771 L
.11752 .14649 L
.11758 .15528 L
.11799 .16406 L
.11806 .15528 L
.11871 .16406 L
.11913 .15528 L
.11941 .14649 L
.11959 .13771 L
.12004 .12892 L
.12057 .13771 L
.12093 .14649 L
.12154 .15528 L
.12185 .16406 L
.12228 .15528 L
.12298 .14649 L
.12356 .13771 L
.12396 .12892 L
.12433 .12014 L
.12482 .12892 L
.12502 .12014 L
.12513 .12892 L
.12518 .13771 L
.1254 .14649 L
.12625 .15528 L
.12639 .16406 L
.12665 .17285 L
.12722 .16406 L
.12755 .17285 L
.12801 .18163 L
.12835 .19042 L
.13024 .18163 L
.13048 .17285 L
.13063 .18163 L
Mistroke
.13065 .19042 L
.13162 .18163 L
.13168 .17285 L
.13204 .16406 L
.1322 .15528 L
.13356 .16406 L
.13374 .15528 L
.13485 .16406 L
.13486 .15528 L
.13545 .14649 L
.13589 .13771 L
.13703 .14649 L
.13777 .15528 L
.13812 .16406 L
.1386 .17285 L
.1386 .16406 L
.13866 .17285 L
.13921 .16406 L
.14012 .17285 L
.14123 .18163 L
.14186 .19042 L
.14315 .18163 L
.1433 .19042 L
.14341 .18163 L
.14374 .17285 L
.14389 .18163 L
.14394 .17285 L
.14556 .18163 L
.14678 .19042 L
.14717 .18163 L
.14721 .17285 L
.14738 .16406 L
.14779 .15528 L
.14895 .14649 L
.14927 .15528 L
.14947 .16406 L
.15038 .17285 L
.15187 .18163 L
.15254 .17285 L
.15264 .18163 L
.15264 .19042 L
.15391 .18163 L
.15454 .19042 L
.15458 .18163 L
.15524 .19042 L
.15533 .1992 L
.15539 .20799 L
.15567 .21677 L
.156 .20799 L
.15606 .21677 L
Mistroke
.15629 .20799 L
.15645 .21677 L
.1566 .22556 L
.15693 .21677 L
.157 .20799 L
.15771 .1992 L
.15774 .19042 L
.15779 .1992 L
.15816 .19042 L
.15821 .1992 L
.15838 .20799 L
.1588 .21677 L
.15914 .22556 L
.15925 .21677 L
.16027 .20799 L
.16082 .21677 L
.16105 .22556 L
.16143 .21677 L
.16245 .22556 L
.16359 .21677 L
.1638 .20799 L
.16392 .1992 L
.16543 .20799 L
.16597 .21677 L
.16656 .20799 L
.1669 .21677 L
.16722 .22556 L
.16751 .21677 L
.16944 .20799 L
.16953 .21677 L
.16954 .20799 L
.17127 .1992 L
.17198 .20799 L
.17259 .1992 L
.17275 .19042 L
.17284 .18163 L
.1733 .19042 L
.17341 .18163 L
.17362 .17285 L
.1739 .16406 L
.17397 .15528 L
.1741 .16406 L
.17433 .15528 L
.17467 .16406 L
.17489 .15528 L
.17546 .14649 L
.17585 .13771 L
.17596 .14649 L
.17621 .15528 L
.17675 .14649 L
Mistroke
.1776 .13771 L
.17818 .12892 L
.17884 .12014 L
.17884 .11135 L
.17919 .10257 L
.17957 .11135 L
.17988 .12014 L
.18051 .11135 L
.18062 .12014 L
.18076 .11135 L
.1813 .10257 L
.18163 .11135 L
.18191 .12014 L
.18277 .11135 L
.1832 .12014 L
.18358 .12892 L
.18678 .12014 L
.18735 .11135 L
.18779 .10257 L
.1885 .11135 L
.18963 .10257 L
.18985 .11135 L
.1906 .12014 L
.19062 .12892 L
.19097 .13771 L
.19102 .14649 L
.19105 .15528 L
.19173 .16406 L
.19204 .15528 L
.19218 .16406 L
.19246 .15528 L
.19246 .16406 L
.19342 .17285 L
.19483 .16406 L
.19488 .15528 L
.19505 .14649 L
.19593 .15528 L
.19668 .14649 L
.1969 .15528 L
.19708 .16406 L
.19717 .17285 L
.19733 .18163 L
.19794 .17285 L
.19797 .16406 L
.19879 .17285 L
.1989 .18163 L
.19929 .17285 L
.20013 .16406 L
.20023 .17285 L
.20058 .16406 L
Mistroke
.20109 .17285 L
.20154 .18163 L
.20183 .17285 L
.20193 .18163 L
.20241 .17285 L
.20286 .16406 L
.20322 .17285 L
.20359 .16406 L
.20372 .17285 L
.20382 .18163 L
.20397 .17285 L
.20408 .18163 L
.20408 .19042 L
.20417 .1992 L
.20441 .20799 L
.20441 .1992 L
.20509 .19042 L
.20605 .18163 L
.20666 .17285 L
.20837 .18163 L
.20873 .17285 L
.20897 .18163 L
.20944 .19042 L
.20953 .1992 L
.20959 .20799 L
.21 .21677 L
.21083 .20799 L
.21098 .21677 L
.21126 .22556 L
.21151 .21677 L
.21167 .20799 L
.21173 .1992 L
.21175 .20799 L
.21202 .21677 L
.21238 .22556 L
.2124 .23434 L
.21278 .24313 L
.21318 .23434 L
.21357 .24313 L
.21388 .23434 L
.21446 .22556 L
.21461 .21677 L
.21625 .22556 L
.21685 .23434 L
.21741 .22556 L
.21809 .21677 L
.2187 .20799 L
.21893 .21677 L
.21905 .22556 L
.21931 .23434 L
Mistroke
.21964 .22556 L
.22046 .21677 L
.22058 .20799 L
.2211 .1992 L
.22116 .19042 L
.22124 .1992 L
.22213 .19042 L
.22288 .18163 L
.22298 .19042 L
.22307 .18163 L
.22356 .17285 L
.22381 .16406 L
.22391 .17285 L
.22462 .18163 L
.22548 .19042 L
.22569 .1992 L
.22572 .20799 L
.22588 .1992 L
.226 .20799 L
.2268 .21677 L
.22724 .22556 L
.22725 .21677 L
.22754 .20799 L
.22773 .1992 L
.22781 .20799 L
.22788 .1992 L
.22793 .20799 L
.22877 .21677 L
.22909 .22556 L
.22925 .21677 L
.22933 .20799 L
.22945 .1992 L
.23019 .19042 L
.23216 .1992 L
.23288 .19042 L
.23302 .18163 L
.23353 .19042 L
.23396 .1992 L
.23418 .19042 L
.23446 .18163 L
.23475 .19042 L
.23513 .1992 L
.23549 .20799 L
.23683 .21677 L
.23715 .20799 L
.23969 .21677 L
.24003 .22556 L
.24171 .23434 L
.24222 .22556 L
.24292 .23434 L
Mistroke
.24356 .22556 L
.24367 .23434 L
.24503 .24313 L
.24539 .23434 L
.24648 .24313 L
.24696 .25191 L
.24719 .2607 L
.24726 .26948 L
.24945 .27827 L
.24981 .28705 L
.25045 .27827 L
.25185 .26948 L
.25265 .27827 L
.25267 .28705 L
.25279 .29584 L
.25312 .30462 L
.25381 .29584 L
.25394 .30462 L
.25406 .29584 L
.25467 .30462 L
.25618 .31341 L
.25632 .32219 L
.25661 .31341 L
.25671 .30462 L
.25695 .29584 L
.25714 .30462 L
.25721 .31341 L
.25829 .32219 L
.2587 .31341 L
.25902 .30462 L
.25961 .31341 L
.26079 .30462 L
.26086 .31341 L
.26151 .30462 L
.26213 .31341 L
.26302 .32219 L
.26358 .33098 L
.26361 .33976 L
.26591 .34855 L
.26617 .35734 L
.26617 .34855 L
.2669 .33976 L
.26713 .33098 L
.26758 .33976 L
.26817 .33098 L
.2686 .33976 L
.26978 .34855 L
.27237 .33976 L
.27334 .34855 L
.27362 .33976 L
Mistroke
.27576 .33098 L
.27641 .33976 L
.27643 .33098 L
.27648 .32219 L
.27667 .33098 L
.27671 .32219 L
.27691 .33098 L
.27694 .32219 L
.27788 .33098 L
.27805 .32219 L
.27828 .31341 L
.27844 .30462 L
.27932 .31341 L
.2802 .32219 L
.28214 .33098 L
.28258 .33976 L
.28268 .34855 L
.28348 .33976 L
.28386 .34855 L
.28413 .33976 L
.28413 .33098 L
.28433 .33976 L
.2855 .33098 L
.28559 .33976 L
.28562 .33098 L
.2859 .32219 L
.28596 .31341 L
.286 .30462 L
.28612 .31341 L
.28676 .32219 L
.28698 .33098 L
.28781 .32219 L
.28822 .31341 L
.28881 .32219 L
.28918 .31341 L
.28934 .32219 L
.28939 .31341 L
.28961 .32219 L
.29036 .31341 L
.29038 .32219 L
.29151 .31341 L
.29241 .32219 L
.29246 .31341 L
.29299 .32219 L
.29317 .33098 L
.29324 .33976 L
.29378 .34855 L
.29477 .35734 L
.29511 .34855 L
.29581 .33976 L
Mistroke
.29689 .33098 L
.29747 .32219 L
.29752 .33098 L
.29807 .33976 L
.29816 .34855 L
.29818 .35734 L
.29844 .34855 L
.29934 .33976 L
.29966 .33098 L
.29993 .33976 L
.30052 .34855 L
.30318 .33976 L
.30328 .33098 L
.30358 .33976 L
.30358 .34855 L
.30367 .33976 L
.30414 .33098 L
.30507 .33976 L
.3053 .33098 L
.30587 .32219 L
.30607 .31341 L
.30748 .30462 L
.30766 .31341 L
.30808 .32219 L
.3084 .33098 L
.30872 .32219 L
.30886 .31341 L
.30891 .32219 L
.30898 .31341 L
.31071 .32219 L
.31077 .31341 L
.31092 .30462 L
.31108 .31341 L
.31226 .30462 L
.31278 .31341 L
.3134 .32219 L
.31382 .31341 L
.31384 .32219 L
.31425 .31341 L
.31435 .30462 L
.31454 .31341 L
.31497 .32219 L
.31622 .33098 L
.31667 .32219 L
.31676 .33098 L
.3172 .33976 L
.31735 .34855 L
.31902 .33976 L
.31917 .33098 L
.31937 .32219 L
Mistroke
.31937 .31341 L
.31944 .30462 L
.3196 .29584 L
.32051 .30462 L
.32084 .31341 L
.32182 .32219 L
.32211 .31341 L
.3224 .32219 L
.32257 .33098 L
.3226 .32219 L
.32266 .33098 L
.32272 .32219 L
.32275 .31341 L
.32277 .30462 L
.3229 .29584 L
.32301 .28705 L
.32364 .29584 L
.32487 .30462 L
.32704 .29584 L
.32717 .30462 L
.32751 .31341 L
.32824 .32219 L
.3284 .33098 L
.32921 .33976 L
.32939 .33098 L
.33114 .33976 L
.33321 .33098 L
.33365 .33976 L
.33415 .34855 L
.33499 .33976 L
.33554 .34855 L
.33591 .35734 L
.33603 .36612 L
.33665 .35734 L
.3369 .36612 L
.33713 .37491 L
.33747 .38369 L
.33855 .39248 L
.33869 .40126 L
.3388 .41005 L
.33902 .40126 L
.33911 .41005 L
.33929 .41883 L
.33955 .41005 L
.34106 .40126 L
.34118 .41005 L
.34153 .40126 L
.34169 .41005 L
.34242 .41883 L
.34275 .42762 L
Mistroke
.34295 .41883 L
.34324 .41005 L
.3443 .40126 L
.34461 .39248 L
.34547 .40126 L
.34555 .41005 L
.34595 .40126 L
.34628 .39248 L
.34653 .40126 L
.34701 .41005 L
.34767 .41883 L
.348 .42762 L
.34825 .4364 L
.34836 .44519 L
.34857 .4364 L
.34879 .44519 L
.34917 .4364 L
.34993 .44519 L
.3516 .45397 L
.3521 .46276 L
.35376 .45397 L
.3538 .44519 L
.35401 .4364 L
.35416 .44519 L
.35455 .45397 L
.35481 .46276 L
.35504 .45397 L
.35556 .44519 L
.35603 .4364 L
.35736 .42762 L
.35745 .4364 L
.35748 .42762 L
.35874 .4364 L
.35973 .44519 L
.36042 .45397 L
.36115 .46276 L
.3613 .47154 L
.36305 .48033 L
.36321 .47154 L
.36341 .48033 L
.36395 .48911 L
.36449 .4979 L
.36458 .50668 L
.36479 .51547 L
.36483 .50668 L
.36492 .4979 L
.36495 .50668 L
.36532 .4979 L
.36541 .48911 L
.36552 .4979 L
Mistroke
.36575 .48911 L
.36621 .4979 L
.36795 .48911 L
.36889 .4979 L
.36892 .48911 L
.36954 .48033 L
.36981 .47154 L
.37104 .46276 L
.37118 .45397 L
.37233 .46276 L
.37242 .45397 L
.37278 .44519 L
.37376 .4364 L
.37384 .44519 L
.37397 .45397 L
.37459 .46276 L
.37575 .47154 L
.37579 .48033 L
.37668 .48911 L
.37713 .48033 L
.37788 .47154 L
.3785 .48033 L
.37894 .47154 L
.37906 .48033 L
.37955 .48911 L
.37993 .48033 L
.37996 .47154 L
.38013 .46276 L
.3816 .45397 L
.38215 .44519 L
.38217 .45397 L
.38276 .46276 L
.38316 .45397 L
.38434 .44519 L
.38474 .4364 L
.3848 .42762 L
.38524 .41883 L
.3859 .42762 L
.38595 .41883 L
.38694 .42762 L
.38708 .41883 L
.38864 .42762 L
.38883 .4364 L
.38896 .44519 L
.38911 .45397 L
.38912 .44519 L
.38981 .45397 L
.39014 .46276 L
.39015 .45397 L
.39021 .46276 L
Mistroke
.39135 .45397 L
.3923 .46276 L
.39245 .47154 L
.39298 .48033 L
.39316 .48911 L
.39333 .48033 L
.39364 .47154 L
.39387 .46276 L
.39454 .47154 L
.39468 .46276 L
.39495 .47154 L
.39577 .48033 L
.396 .48911 L
.39655 .4979 L
.39671 .48911 L
.39737 .48033 L
.39768 .48911 L
.39783 .4979 L
.39806 .48911 L
.39875 .4979 L
.39903 .50668 L
.39965 .51547 L
.40134 .52425 L
.4015 .51547 L
.40168 .52425 L
.40175 .53304 L
.40314 .52425 L
.40323 .51547 L
.4034 .50668 L
.40384 .4979 L
.40416 .48911 L
.40426 .48033 L
.40432 .47154 L
.40467 .48033 L
.40503 .47154 L
.40523 .46276 L
.40525 .45397 L
.40531 .46276 L
.40631 .45397 L
.40636 .44519 L
.40657 .45397 L
.40663 .46276 L
.40666 .47154 L
.40816 .46276 L
.40891 .47154 L
.40943 .48033 L
.41042 .48911 L
.4113 .48033 L
.41241 .47154 L
.41318 .48033 L
Mistroke
.41326 .47154 L
.41375 .46276 L
.4144 .45397 L
.41479 .46276 L
.41479 .45397 L
.41577 .46276 L
.41709 .47154 L
.4181 .46276 L
.4182 .47154 L
.41826 .46276 L
.41849 .47154 L
.42098 .46276 L
.42146 .47154 L
.42161 .46276 L
.42168 .47154 L
.4237 .46276 L
.42404 .47154 L
.42438 .48033 L
.42466 .47154 L
.42503 .48033 L
.42604 .48911 L
.4268 .4979 L
.42714 .48911 L
.42854 .4979 L
.42992 .48911 L
.43031 .48033 L
.43079 .48911 L
.43088 .4979 L
.43106 .48911 L
.43111 .4979 L
.4328 .50668 L
.43281 .4979 L
.43303 .48911 L
.43309 .4979 L
.43402 .50668 L
.43442 .51547 L
.43479 .52425 L
.43498 .51547 L
.43504 .50668 L
.43659 .51547 L
.43756 .50668 L
.43764 .51547 L
.43798 .52425 L
.43836 .51547 L
.4384 .50668 L
.43966 .51547 L
.44014 .52425 L
.44098 .51547 L
.4411 .50668 L
.44141 .51547 L
Mistroke
.4416 .52425 L
.44386 .53304 L
.44525 .52425 L
.44629 .53304 L
.44661 .54182 L
.44669 .53304 L
.44725 .52425 L
.44743 .53304 L
.4499 .52425 L
.45016 .51547 L
.45022 .50668 L
.45042 .4979 L
.45047 .50668 L
.45056 .4979 L
.45148 .48911 L
.45157 .48033 L
.45172 .48911 L
.45205 .4979 L
.45259 .50668 L
.45267 .4979 L
.45318 .50668 L
.45322 .51547 L
.45444 .52425 L
.45629 .53304 L
.45641 .52425 L
.45755 .51547 L
.45776 .50668 L
.45792 .51547 L
.45804 .50668 L
.45833 .4979 L
.45835 .48911 L
.45856 .48033 L
.46023 .47154 L
.46029 .46276 L
.46051 .47154 L
.46051 .46276 L
.46124 .47154 L
.46165 .48033 L
.46247 .48911 L
.46341 .4979 L
.46373 .50668 L
.46375 .4979 L
.46393 .50668 L
.46446 .4979 L
.46558 .50668 L
.46574 .51547 L
.46584 .52425 L
.46618 .53304 L
.4665 .54182 L
.46693 .55061 L
Mistroke
.46823 .55939 L
.46824 .56818 L
.46842 .57696 L
.46856 .56818 L
.46888 .57696 L
.47021 .56818 L
.47092 .57696 L
.47112 .58575 L
.47118 .59453 L
.47122 .60332 L
.47168 .59453 L
.47248 .58575 L
.47318 .57696 L
.47395 .56818 L
.47426 .57696 L
.47433 .56818 L
.47554 .57696 L
.47557 .56818 L
.47586 .55939 L
.47655 .55061 L
.47662 .55939 L
.47689 .55061 L
.47706 .55939 L
.47964 .56818 L
.48007 .57696 L
.48146 .58575 L
.48222 .57696 L
.48257 .56818 L
.48275 .55939 L
.48346 .55061 L
.48433 .54182 L
.48434 .53304 L
.48438 .52425 L
.48498 .53304 L
.48546 .52425 L
.48583 .51547 L
.48634 .50668 L
.48704 .51547 L
.48788 .50668 L
.488 .4979 L
.48848 .50668 L
.48955 .4979 L
.49015 .50668 L
.49114 .4979 L
.49144 .50668 L
.49209 .4979 L
.49241 .48911 L
.49244 .48033 L
.49276 .47154 L
.49336 .48033 L
Mistroke
.49337 .48911 L
.49357 .4979 L
.49451 .50668 L
.49479 .51547 L
.49509 .52425 L
.49573 .53304 L
.49606 .54182 L
.49663 .53304 L
.49695 .54182 L
.49751 .53304 L
.49763 .54182 L
.49855 .53304 L
.49875 .52425 L
.49907 .53304 L
.50046 .54182 L
.50064 .53304 L
.50071 .52425 L
.50077 .51547 L
.50105 .50668 L
.50158 .4979 L
.50278 .50668 L
.50416 .51547 L
.50505 .50668 L
.50538 .51547 L
.50552 .52425 L
.50552 .51547 L
.50612 .52425 L
.50664 .51547 L
.50715 .50668 L
.50723 .4979 L
.50805 .50668 L
.50855 .4979 L
.51067 .48911 L
.51169 .4979 L
.5125 .50668 L
.51275 .4979 L
.51295 .50668 L
.51301 .51547 L
.51387 .52425 L
.5142 .53304 L
.5144 .52425 L
.51529 .53304 L
.51601 .54182 L
.51608 .53304 L
.51687 .52425 L
.51736 .51547 L
.51821 .50668 L
.51822 .4979 L
.51903 .50668 L
.51951 .51547 L
Mistroke
.52015 .52425 L
.5204 .51547 L
.52086 .52425 L
.52126 .51547 L
.52154 .52425 L
.52287 .51547 L
.5244 .52425 L
.52454 .53304 L
.52466 .52425 L
.5266 .53304 L
.5271 .52425 L
.52736 .53304 L
.52821 .54182 L
.53012 .55061 L
.53015 .54182 L
.53018 .55061 L
.53025 .54182 L
.53039 .53304 L
.53112 .52425 L
.53235 .51547 L
.53245 .52425 L
.53349 .53304 L
.53401 .54182 L
.53415 .55061 L
.53523 .54182 L
.53639 .55061 L
.53643 .54182 L
.53648 .53304 L
.53659 .54182 L
.5366 .53304 L
.53686 .52425 L
.53716 .51547 L
.53752 .50668 L
.53787 .4979 L
.53797 .50668 L
.5381 .4979 L
.5383 .48911 L
.53831 .4979 L
.53855 .50668 L
.53936 .4979 L
.53974 .50668 L
.53995 .4979 L
.54016 .50668 L
.54117 .51547 L
.54117 .50668 L
.54173 .51547 L
.54246 .50668 L
.54352 .4979 L
.54445 .48911 L
.54499 .48033 L
Mistroke
.54541 .47154 L
.54553 .46276 L
.54556 .45397 L
.54595 .46276 L
.54598 .47154 L
.54777 .48033 L
.54782 .47154 L
.54789 .48033 L
.54891 .48911 L
.54933 .4979 L
.54966 .48911 L
.54975 .4979 L
.54989 .50668 L
.54991 .4979 L
.5504 .48911 L
.55085 .4979 L
.55107 .48911 L
.55209 .48033 L
.55234 .48911 L
.55382 .48033 L
.55385 .47154 L
.55435 .46276 L
.55543 .45397 L
.55575 .44519 L
.55612 .45397 L
.55653 .46276 L
.55673 .45397 L
.55718 .44519 L
.55865 .4364 L
.5588 .42762 L
.55927 .41883 L
.56024 .41005 L
.56126 .41883 L
.56149 .41005 L
.56163 .41883 L
.56178 .42762 L
.56199 .4364 L
.56263 .44519 L
.56303 .4364 L
.56418 .42762 L
.56435 .4364 L
.5645 .44519 L
.56465 .4364 L
.56468 .42762 L
.56479 .41883 L
.56524 .41005 L
.56563 .41883 L
.56629 .42762 L
.56649 .41883 L
.56735 .41005 L
Mistroke
.56818 .40126 L
.5684 .39248 L
.56855 .40126 L
.56925 .41005 L
.57004 .41883 L
.57075 .42762 L
.57102 .4364 L
.57113 .42762 L
.57148 .4364 L
.57153 .44519 L
.57174 .4364 L
.57189 .42762 L
.57331 .41883 L
.57365 .42762 L
.57388 .4364 L
.57462 .42762 L
.57522 .4364 L
.57591 .44519 L
.57595 .4364 L
.57618 .44519 L
.57693 .4364 L
.57708 .44519 L
.57737 .4364 L
.57833 .44519 L
.57837 .45397 L
.57859 .46276 L
.57967 .45397 L
.58014 .46276 L
.58109 .45397 L
.58147 .44519 L
.58178 .45397 L
.58227 .44519 L
.58274 .4364 L
.58283 .42762 L
.58309 .41883 L
.58313 .42762 L
.58345 .41883 L
.58411 .41005 L
.5849 .40126 L
.58564 .41005 L
.58639 .41883 L
.58658 .42762 L
.5866 .4364 L
.58674 .42762 L
.58694 .41883 L
.58903 .42762 L
.58955 .4364 L
.5897 .42762 L
.58975 .4364 L
.5902 .44519 L
Mistroke
.59021 .4364 L
.59112 .42762 L
.59293 .41883 L
.59318 .41005 L
.59426 .41883 L
.59453 .41005 L
.59507 .41883 L
.59524 .42762 L
.59685 .4364 L
.59711 .44519 L
.59741 .45397 L
.59747 .46276 L
.59773 .47154 L
.59787 .48033 L
.59853 .47154 L
.59909 .46276 L
.59951 .47154 L
.59973 .46276 L
.60174 .45397 L
.60236 .46276 L
.6027 .45397 L
.60292 .46276 L
.60381 .45397 L
.60492 .44519 L
.60522 .4364 L
.6053 .42762 L
.60581 .41883 L
.60608 .42762 L
.6076 .41883 L
.60805 .42762 L
.60863 .41883 L
.60958 .42762 L
.60964 .4364 L
.61043 .44519 L
.61051 .4364 L
.61074 .42762 L
.61118 .41883 L
.61158 .41005 L
.6119 .41883 L
.61256 .42762 L
.61285 .41883 L
.61331 .42762 L
.61374 .4364 L
.61385 .42762 L
.6139 .41883 L
.61436 .41005 L
.61497 .41883 L
.61548 .42762 L
.61579 .4364 L
.61636 .44519 L
Mistroke
.61686 .45397 L
.61778 .44519 L
.61786 .45397 L
.61826 .46276 L
.61835 .47154 L
.61914 .48033 L
.61997 .48911 L
.61999 .4979 L
.62022 .50668 L
.62056 .51547 L
.62087 .50668 L
.621 .4979 L
.62134 .48911 L
.62163 .48033 L
.62171 .47154 L
.62211 .48033 L
.62213 .48911 L
.62255 .4979 L
.62344 .50668 L
.62385 .4979 L
.62461 .50668 L
.62489 .51547 L
.62515 .50668 L
.62531 .4979 L
.6254 .48911 L
.62552 .48033 L
.62581 .48911 L
.6267 .48033 L
.62684 .47154 L
.62695 .48033 L
.62699 .48911 L
.62806 .4979 L
.62816 .48911 L
.62817 .48033 L
.62874 .47154 L
.62969 .48033 L
.63005 .47154 L
.63015 .48033 L
.63016 .48911 L
.63048 .48033 L
.6306 .48911 L
.63162 .4979 L
.6323 .48911 L
.63296 .4979 L
.63323 .48911 L
.63436 .48033 L
.63508 .47154 L
.6359 .48033 L
.63592 .47154 L
.63655 .48033 L
Mistroke
.63694 .48911 L
.63755 .48033 L
.63812 .47154 L
.63819 .46276 L
.63847 .47154 L
.63873 .46276 L
.6388 .47154 L
.63893 .48033 L
.63955 .48911 L
.63965 .48033 L
.64077 .47154 L
.64083 .48033 L
.64104 .47154 L
.64142 .48033 L
.64187 .48911 L
.64278 .48033 L
.64343 .48911 L
.64372 .48033 L
.64387 .47154 L
.64396 .46276 L
.64435 .47154 L
.64475 .46276 L
.64505 .45397 L
.64517 .44519 L
.64539 .4364 L
.64617 .44519 L
.64629 .45397 L
.64647 .44519 L
.64699 .45397 L
.64731 .44519 L
.64736 .45397 L
.64759 .46276 L
.64781 .47154 L
.64909 .48033 L
.64968 .48911 L
.64999 .4979 L
.65008 .50668 L
.65068 .51547 L
.65129 .52425 L
.65161 .51547 L
.65199 .50668 L
.65215 .4979 L
.6522 .50668 L
.65262 .51547 L
.65272 .52425 L
.65274 .53304 L
.65331 .52425 L
.65331 .51547 L
.6542 .50668 L
.65475 .51547 L
Mistroke
.65477 .50668 L
.65515 .4979 L
.65554 .48911 L
.65566 .48033 L
.65642 .48911 L
.65657 .4979 L
.65668 .48911 L
.657 .4979 L
.65742 .48911 L
.65847 .48033 L
.65869 .47154 L
.6589 .48033 L
.6592 .48911 L
.65938 .48033 L
.65968 .48911 L
.66004 .48033 L
.66072 .47154 L
.66121 .48033 L
.66265 .48911 L
.66287 .48033 L
.66292 .47154 L
.66322 .48033 L
.66372 .47154 L
.66431 .48033 L
.66483 .48911 L
.66495 .48033 L
.6655 .47154 L
.66557 .46276 L
.66637 .47154 L
.66723 .48033 L
.6678 .47154 L
.66827 .48033 L
.66829 .47154 L
.66851 .48033 L
.66943 .47154 L
.67005 .48033 L
.67148 .47154 L
.67169 .46276 L
.67214 .45397 L
.67248 .44519 L
.67284 .4364 L
.67301 .44519 L
.6735 .45397 L
.67366 .46276 L
.67411 .45397 L
.6746 .46276 L
.67496 .45397 L
.6753 .44519 L
.67577 .45397 L
.676 .44519 L
Mistroke
.67647 .4364 L
.67659 .42762 L
.67772 .41883 L
.67798 .41005 L
.6785 .41883 L
.67863 .41005 L
.67882 .41883 L
.67896 .42762 L
.6801 .4364 L
.68051 .42762 L
.68072 .4364 L
.68072 .42762 L
.68132 .4364 L
.68147 .42762 L
.68205 .41883 L
.68239 .42762 L
.68307 .4364 L
.68338 .44519 L
.6838 .45397 L
.68479 .46276 L
.68505 .45397 L
.68522 .44519 L
.68576 .4364 L
.68579 .44519 L
.68694 .45397 L
.68717 .44519 L
.68737 .45397 L
.68752 .44519 L
.6876 .4364 L
.68768 .42762 L
.68816 .4364 L
.68851 .42762 L
.68874 .41883 L
.6892 .42762 L
.68921 .41883 L
.68928 .42762 L
.68949 .4364 L
.69 .44519 L
.69026 .4364 L
.6911 .44519 L
.69124 .45397 L
.69162 .46276 L
.69227 .47154 L
.69282 .46276 L
.69334 .47154 L
.694 .46276 L
.69484 .47154 L
.69519 .48033 L
.6954 .47154 L
.69544 .48033 L
Mistroke
.69571 .47154 L
.69571 .46276 L
.69644 .47154 L
.69659 .48033 L
.69716 .48911 L
.69841 .4979 L
.6988 .48911 L
.69981 .4979 L
.70066 .50668 L
.70122 .51547 L
.70124 .50668 L
.70131 .51547 L
.7027 .52425 L
.70304 .53304 L
.70329 .52425 L
.70361 .53304 L
.70369 .52425 L
.70369 .53304 L
.70474 .52425 L
.70523 .53304 L
.70763 .52425 L
.70763 .51547 L
.70765 .50668 L
.7078 .51547 L
.70798 .50668 L
.70821 .51547 L
.70825 .50668 L
.70827 .4979 L
.70842 .50668 L
.70854 .4979 L
.7086 .48911 L
.70897 .48033 L
.70915 .47154 L
.70925 .48033 L
.71015 .48911 L
.71029 .4979 L
.71098 .50668 L
.71142 .51547 L
.71164 .52425 L
.71325 .51547 L
.71391 .50668 L
.71395 .4979 L
.71405 .50668 L
.71419 .51547 L
.71431 .52425 L
.71453 .53304 L
.7146 .52425 L
.71462 .51547 L
.71484 .50668 L
.71592 .51547 L
Mistroke
.71592 .52425 L
.71612 .53304 L
.71622 .52425 L
.71642 .51547 L
.7166 .52425 L
.71664 .53304 L
.71712 .52425 L
.71726 .51547 L
.71746 .50668 L
.71864 .51547 L
.71972 .52425 L
.72063 .51547 L
.72076 .52425 L
.72085 .51547 L
.72144 .50668 L
.72162 .4979 L
.72211 .50668 L
.72284 .51547 L
.72381 .52425 L
.72419 .53304 L
.72481 .52425 L
.72497 .51547 L
.72613 .52425 L
.72632 .51547 L
.72651 .52425 L
.72679 .51547 L
.72759 .50668 L
.7276 .51547 L
.72954 .50668 L
.73007 .4979 L
.7302 .50668 L
.73116 .51547 L
.73116 .50668 L
.73122 .51547 L
.73176 .50668 L
.73238 .4979 L
.73239 .48911 L
.73274 .48033 L
.73278 .47154 L
.73294 .46276 L
.73325 .45397 L
.73418 .46276 L
.73465 .45397 L
.73465 .46276 L
.73486 .47154 L
.73584 .46276 L
.73674 .47154 L
.73751 .48033 L
.73801 .47154 L
.73824 .48033 L
Mistroke
.73832 .47154 L
.73856 .46276 L
.73935 .47154 L
.73957 .48033 L
.73957 .48911 L
.73987 .4979 L
.74016 .48911 L
.74031 .4979 L
.74054 .50668 L
.74106 .51547 L
.74144 .50668 L
.7427 .51547 L
.74293 .52425 L
.74301 .51547 L
.74355 .50668 L
.74495 .4979 L
.74525 .48911 L
.74589 .48033 L
.74605 .48911 L
.74656 .48033 L
.74708 .48911 L
.74761 .4979 L
.74798 .48911 L
.74887 .48033 L
.74952 .47154 L
.74999 .46276 L
.75101 .47154 L
.75108 .46276 L
.75125 .47154 L
.75208 .46276 L
.75403 .45397 L
.75427 .44519 L
.75437 .4364 L
.7545 .44519 L
.7572 .4364 L
.75742 .44519 L
.7581 .4364 L
.75828 .44519 L
.75866 .4364 L
.75956 .44519 L
.75975 .45397 L
.76039 .44519 L
.76211 .4364 L
.76213 .44519 L
.76251 .4364 L
.76307 .42762 L
.76411 .41883 L
.7652 .42762 L
.76561 .41883 L
.76711 .41005 L
Mistroke
.76792 .40126 L
.76818 .41005 L
.76852 .41883 L
.76904 .41005 L
.76923 .41883 L
.76961 .42762 L
.76995 .4364 L
.76997 .42762 L
.77005 .41883 L
.77023 .41005 L
.77038 .41883 L
.7705 .41005 L
.77079 .41883 L
.7709 .41005 L
.77218 .41883 L
.77307 .42762 L
.77311 .41883 L
.77391 .42762 L
.77503 .4364 L
.77527 .42762 L
.77553 .41883 L
.77563 .41005 L
.77597 .41883 L
.77619 .41005 L
.77692 .40126 L
.77723 .41005 L
.77761 .41883 L
.77783 .42762 L
.77824 .41883 L
.78057 .41005 L
.78162 .40126 L
.78289 .39248 L
.78341 .38369 L
.78389 .37491 L
.78459 .36612 L
.78503 .37491 L
.78525 .36612 L
.78556 .35734 L
.78604 .34855 L
.78729 .35734 L
.78779 .34855 L
.78825 .35734 L
.78903 .36612 L
.78966 .35734 L
.78975 .34855 L
.79098 .35734 L
.79253 .34855 L
.79305 .33976 L
.79328 .33098 L
.79382 .33976 L
Mistroke
.79414 .34855 L
.79442 .35734 L
.79544 .36612 L
.79615 .37491 L
.79652 .38369 L
.79689 .39248 L
.79726 .40126 L
.79777 .41005 L
.79888 .41883 L
.79948 .41005 L
.80072 .41883 L
.80109 .41005 L
.80171 .40126 L
.80208 .39248 L
.80228 .38369 L
.80234 .39248 L
.80458 .40126 L
.80475 .39248 L
.80516 .38369 L
.80523 .37491 L
.80532 .38369 L
.80552 .37491 L
.80564 .36612 L
.8063 .37491 L
.80739 .36612 L
.80833 .37491 L
.80845 .38369 L
.80922 .39248 L
.80967 .38369 L
.81077 .39248 L
.81101 .40126 L
.81143 .39248 L
.81148 .40126 L
.81152 .39248 L
.81195 .38369 L
.81222 .39248 L
.81295 .40126 L
.81337 .39248 L
.81355 .38369 L
.81417 .39248 L
.81511 .40126 L
.81531 .41005 L
.81535 .40126 L
.81698 .39248 L
.81844 .38369 L
.81921 .37491 L
.8193 .38369 L
.81965 .39248 L
.82025 .38369 L
.82145 .37491 L
Mistroke
.82156 .38369 L
.82279 .37491 L
.82287 .38369 L
.82294 .39248 L
.82364 .40126 L
.8247 .41005 L
.82477 .40126 L
.8258 .39248 L
.82648 .38369 L
.82854 .39248 L
.82857 .38369 L
.82868 .39248 L
.82896 .38369 L
.82897 .39248 L
.829 .38369 L
.82965 .39248 L
.82969 .38369 L
.82972 .39248 L
.82997 .38369 L
.83043 .39248 L
.83184 .40126 L
.83286 .41005 L
.83288 .41883 L
.83302 .41005 L
.83374 .41883 L
.83388 .41005 L
.83414 .40126 L
.8344 .41005 L
.83589 .40126 L
.83632 .39248 L
.83651 .38369 L
.83682 .39248 L
.83752 .40126 L
.83836 .39248 L
.83869 .38369 L
.83898 .39248 L
.83926 .40126 L
.83939 .39248 L
.83957 .40126 L
.83966 .39248 L
.83967 .38369 L
.83976 .39248 L
.84109 .40126 L
.84159 .41005 L
.84169 .41883 L
.84215 .42762 L
.84282 .4364 L
.84436 .42762 L
.84441 .41883 L
.84487 .42762 L
Mistroke
.84489 .41883 L
.8457 .42762 L
.84613 .4364 L
.84643 .42762 L
.84721 .41883 L
.84764 .42762 L
.84775 .4364 L
.84776 .42762 L
.84822 .41883 L
.84845 .42762 L
.84904 .41883 L
.84913 .41005 L
.84919 .40126 L
.85091 .41005 L
.85094 .40126 L
.851 .39248 L
.8523 .40126 L
.8528 .39248 L
.85281 .38369 L
.85299 .39248 L
.85338 .38369 L
.8536 .37491 L
.85405 .38369 L
.85418 .39248 L
.85436 .40126 L
.85463 .41005 L
.85548 .41883 L
.85572 .41005 L
.85713 .40126 L
.85749 .41005 L
.85781 .40126 L
.85801 .39248 L
.85853 .38369 L
.85867 .37491 L
.859 .38369 L
.85948 .37491 L
.85957 .36612 L
.86042 .37491 L
.86072 .38369 L
.8608 .37491 L
.86087 .36612 L
.86118 .35734 L
.86252 .36612 L
.8631 .35734 L
.86319 .36612 L
.86356 .35734 L
.86358 .36612 L
.86365 .35734 L
.86529 .36612 L
.86551 .37491 L
Mistroke
.86563 .36612 L
.86654 .37491 L
.86781 .36612 L
.86839 .35734 L
.86971 .36612 L
.86975 .35734 L
.86978 .36612 L
.86986 .37491 L
.87017 .38369 L
.87052 .39248 L
.87179 .38369 L
.87287 .37491 L
.87303 .36612 L
.87391 .35734 L
.87594 .34855 L
.87691 .35734 L
.87721 .34855 L
.8775 .35734 L
.87786 .34855 L
.87815 .35734 L
.87828 .36612 L
.87884 .35734 L
.8793 .36612 L
.87977 .35734 L
.88107 .34855 L
.88124 .33976 L
.88172 .34855 L
.88509 .33976 L
.88541 .33098 L
.88575 .32219 L
.88588 .31341 L
.88704 .30462 L
.88731 .29584 L
.88847 .30462 L
.8905 .29584 L
.89146 .30462 L
.89182 .29584 L
.89219 .28705 L
.89232 .27827 L
.89315 .26948 L
.894 .27827 L
.89595 .28705 L
.89622 .27827 L
.89697 .28705 L
.89708 .27827 L
.89775 .28705 L
.89816 .27827 L
.89848 .26948 L
.89877 .27827 L
.89887 .28705 L
Mistroke
.89904 .29584 L
.89924 .28705 L
.90009 .27827 L
.90042 .26948 L
.90136 .2607 L
.90211 .25191 L
.9023 .2607 L
.90246 .25191 L
.90297 .2607 L
.90298 .25191 L
.90302 .2607 L
.90369 .26948 L
.90378 .27827 L
.9042 .26948 L
.9046 .27827 L
.90479 .26948 L
.90484 .27827 L
.90492 .26948 L
.90639 .2607 L
.90723 .26948 L
.90811 .2607 L
.90826 .26948 L
.90837 .2607 L
.90854 .26948 L
.90864 .2607 L
.90934 .26948 L
.90943 .27827 L
.9103 .28705 L
.91114 .29584 L
.91133 .28705 L
.91191 .29584 L
.91199 .30462 L
.91225 .29584 L
.91257 .30462 L
.91273 .29584 L
.91309 .28705 L
.91324 .29584 L
.91351 .30462 L
.91435 .31341 L
.91517 .32219 L
.91555 .33098 L
.91556 .33976 L
.91581 .34855 L
.91633 .35734 L
.91648 .34855 L
.91731 .35734 L
.91734 .34855 L
.91802 .33976 L
.91862 .33098 L
.91922 .33976 L
Mistroke
.91985 .33098 L
.92001 .33976 L
.92051 .34855 L
.92057 .35734 L
.92074 .36612 L
.92081 .35734 L
.92135 .36612 L
.92144 .35734 L
.9219 .34855 L
.92218 .35734 L
.92234 .36612 L
.92265 .35734 L
.92314 .36612 L
.92403 .35734 L
.92419 .34855 L
.92476 .33976 L
.92495 .33098 L
.92548 .33976 L
.92564 .34855 L
.92594 .35734 L
.92626 .36612 L
.92677 .35734 L
.92743 .36612 L
.92782 .35734 L
.92829 .34855 L
.92947 .35734 L
.93046 .36612 L
.93105 .35734 L
.93166 .36612 L
.93184 .37491 L
.93198 .38369 L
.93201 .39248 L
.93238 .38369 L
.9328 .39248 L
.93291 .40126 L
.93297 .39248 L
.9334 .38369 L
.93342 .39248 L
.93517 .40126 L
.9353 .41005 L
.93544 .41883 L
.9357 .42762 L
.93575 .41883 L
.93634 .42762 L
.93663 .41883 L
.93705 .42762 L
.93741 .4364 L
.93788 .44519 L
.938 .4364 L
.93816 .42762 L
Mistroke
.93821 .4364 L
.93899 .42762 L
.93933 .41883 L
.93987 .42762 L
.94006 .4364 L
.94057 .44519 L
.94096 .45397 L
.94129 .46276 L
.9415 .47154 L
.94154 .48033 L
.94166 .47154 L
.94273 .48033 L
.94343 .48911 L
.94392 .4979 L
.94401 .48911 L
.94405 .4979 L
.94416 .50668 L
.9445 .51547 L
.94706 .52425 L
.9473 .51547 L
.94747 .50668 L
.94815 .4979 L
.94915 .50668 L
.94966 .4979 L
.95001 .50668 L
.95052 .4979 L
.95073 .48911 L
.95088 .4979 L
.95136 .50668 L
.95213 .51547 L
.95242 .50668 L
.95246 .4979 L
.95273 .48911 L
.95321 .4979 L
.95324 .50668 L
.95356 .51547 L
.95402 .50668 L
.95441 .4979 L
.95582 .50668 L
.95599 .51547 L
.95608 .50668 L
.95651 .4979 L
.95688 .50668 L
.95714 .51547 L
.95755 .50668 L
.95834 .51547 L
.95932 .52425 L
.95941 .51547 L
.95944 .52425 L
.95972 .53304 L
Mistroke
.9605 .54182 L
.96131 .55061 L
.96133 .54182 L
.96162 .53304 L
.96202 .54182 L
.96235 .55061 L
.96268 .54182 L
.96323 .53304 L
.96327 .54182 L
.96339 .55061 L
.96341 .55939 L
.96417 .55061 L
.96436 .54182 L
.96541 .55061 L
.96575 .55939 L
.966 .56818 L
.9662 .57696 L
.96643 .56818 L
.96825 .55939 L
.96831 .55061 L
.96895 .54182 L
.96943 .53304 L
.96998 .54182 L
.97037 .53304 L
.9709 .54182 L
.97108 .53304 L
.97141 .54182 L
.9715 .55061 L
.97152 .54182 L
.97162 .55061 L
.97224 .55939 L
.97224 .56818 L
.97283 .57696 L
.97295 .58575 L
.97312 .59453 L
.97336 .58575 L
.97522 .59453 L
.97595 .58575 L
.97619 .57696 L
Mfstroke
% End of Graphics
MathPictureEnd

:[font = print; inactive; preserveAspect]
maximum waiting time = 79.4171
maximum queue size = 67
The next two graphs show the distributions of
queue waiting times and queue lengths.
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; startGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0119048 0.0147151 16.6073 [
[(0)] .02381 0 0 2 Msboxa
[(20)] .2619 0 0 2 Msboxa
[(40)] .5 0 0 2 Msboxa
[(60)] .7381 0 0 2 Msboxa
[(80)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.005)] -0.0125 .09775 1 0 Msboxa
[(0.01)] -0.0125 .18079 1 0 Msboxa
[(0.015)] -0.0125 .26382 1 0 Msboxa
[(0.02)] -0.0125 .34686 1 0 Msboxa
[(0.025)] -0.0125 .4299 1 0 Msboxa
[(0.03)] -0.0125 .51293 1 0 Msboxa
[(0.035)] -0.0125 .59597 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.2619 0 m
.2619 .00625 L
s
P
[(20)] .2619 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(40)] .5 0 0 2 Mshowa
p
.002 w
.7381 0 m
.7381 .00625 L
s
P
[(60)] .7381 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(80)] .97619 0 0 2 Mshowa
p
.001 w
.07143 0 m
.07143 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.35714 0 m
.35714 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.45238 0 m
.45238 .00375 L
s
P
p
.001 w
.54762 0 m
.54762 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.64286 0 m
.64286 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.92857 0 m
.92857 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .09775 m
.00625 .09775 L
s
P
[(0.005)] -0.0125 .09775 1 0 Mshowa
p
.002 w
0 .18079 m
.00625 .18079 L
s
P
[(0.01)] -0.0125 .18079 1 0 Mshowa
p
.002 w
0 .26382 m
.00625 .26382 L
s
P
[(0.015)] -0.0125 .26382 1 0 Mshowa
p
.002 w
0 .34686 m
.00625 .34686 L
s
P
[(0.02)] -0.0125 .34686 1 0 Mshowa
p
.002 w
0 .4299 m
.00625 .4299 L
s
P
[(0.025)] -0.0125 .4299 1 0 Mshowa
p
.002 w
0 .51293 m
.00625 .51293 L
s
P
[(0.03)] -0.0125 .51293 1 0 Mshowa
p
.002 w
0 .59597 m
.00625 .59597 L
s
P
[(0.035)] -0.0125 .59597 1 0 Mshowa
p
.001 w
0 .03132 m
.00375 .03132 L
s
P
p
.001 w
0 .04793 m
.00375 .04793 L
s
P
p
.001 w
0 .06454 m
.00375 .06454 L
s
P
p
.001 w
0 .08114 m
.00375 .08114 L
s
P
p
.001 w
0 .11436 m
.00375 .11436 L
s
P
p
.001 w
0 .13097 m
.00375 .13097 L
s
P
p
.001 w
0 .14757 m
.00375 .14757 L
s
P
p
.001 w
0 .16418 m
.00375 .16418 L
s
P
p
.001 w
0 .1974 m
.00375 .1974 L
s
P
p
.001 w
0 .214 m
.00375 .214 L
s
P
p
.001 w
0 .23061 m
.00375 .23061 L
s
P
p
.001 w
0 .24722 m
.00375 .24722 L
s
P
p
.001 w
0 .28043 m
.00375 .28043 L
s
P
p
.001 w
0 .29704 m
.00375 .29704 L
s
P
p
.001 w
0 .31365 m
.00375 .31365 L
s
P
p
.001 w
0 .33025 m
.00375 .33025 L
s
P
p
.001 w
0 .36347 m
.00375 .36347 L
s
P
p
.001 w
0 .38008 m
.00375 .38008 L
s
P
p
.001 w
0 .39668 m
.00375 .39668 L
s
P
p
.001 w
0 .41329 m
.00375 .41329 L
s
P
p
.001 w
0 .44651 m
.00375 .44651 L
s
P
p
.001 w
0 .46311 m
.00375 .46311 L
s
P
p
.001 w
0 .47972 m
.00375 .47972 L
s
P
p
.001 w
0 .49633 m
.00375 .49633 L
s
P
p
.001 w
0 .52954 m
.00375 .52954 L
s
P
p
.001 w
0 .54615 m
.00375 .54615 L
s
P
p
.001 w
0 .56276 m
.00375 .56276 L
s
P
p
.001 w
0 .57936 m
.00375 .57936 L
s
P
p
.001 w
0 .61258 m
.00375 .61258 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.2619 .61178 m
.2619 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.7381 .61178 m
.7381 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.07143 .61428 m
.07143 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.16667 .61428 m
.16667 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.35714 .61428 m
.35714 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.45238 .61428 m
.45238 .61803 L
s
P
p
.001 w
.54762 .61428 m
.54762 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.64286 .61428 m
.64286 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.83333 .61428 m
.83333 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.92857 .61428 m
.92857 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .09775 m
1 .09775 L
s
P
p
.002 w
.99375 .18079 m
1 .18079 L
s
P
p
.002 w
.99375 .26382 m
1 .26382 L
s
P
p
.002 w
.99375 .34686 m
1 .34686 L
s
P
p
.002 w
.99375 .4299 m
1 .4299 L
s
P
p
.002 w
.99375 .51293 m
1 .51293 L
s
P
p
.002 w
.99375 .59597 m
1 .59597 L
s
P
p
.001 w
.99625 .03132 m
1 .03132 L
s
P
p
.001 w
.99625 .04793 m
1 .04793 L
s
P
p
.001 w
.99625 .06454 m
1 .06454 L
s
P
p
.001 w
.99625 .08114 m
1 .08114 L
s
P
p
.001 w
.99625 .11436 m
1 .11436 L
s
P
p
.001 w
.99625 .13097 m
1 .13097 L
s
P
p
.001 w
.99625 .14757 m
1 .14757 L
s
P
p
.001 w
.99625 .16418 m
1 .16418 L
s
P
p
.001 w
.99625 .1974 m
1 .1974 L
s
P
p
.001 w
.99625 .214 m
1 .214 L
s
P
p
.001 w
.99625 .23061 m
1 .23061 L
s
P
p
.001 w
.99625 .24722 m
1 .24722 L
s
P
p
.001 w
.99625 .28043 m
1 .28043 L
s
P
p
.001 w
.99625 .29704 m
1 .29704 L
s
P
p
.001 w
.99625 .31365 m
1 .31365 L
s
P
p
.001 w
.99625 .33025 m
1 .33025 L
s
P
p
.001 w
.99625 .36347 m
1 .36347 L
s
P
p
.001 w
.99625 .38008 m
1 .38008 L
s
P
p
.001 w
.99625 .39668 m
1 .39668 L
s
P
p
.001 w
.99625 .41329 m
1 .41329 L
s
P
p
.001 w
.99625 .44651 m
1 .44651 L
s
P
p
.001 w
.99625 .46311 m
1 .46311 L
s
P
p
.001 w
.99625 .47972 m
1 .47972 L
s
P
p
.001 w
.99625 .49633 m
1 .49633 L
s
P
p
.001 w
.99625 .52954 m
1 .52954 L
s
P
p
.001 w
.99625 .54615 m
1 .54615 L
s
P
p
.001 w
.99625 .56276 m
1 .56276 L
s
P
p
.001 w
.99625 .57936 m
1 .57936 L
s
P
p
.001 w
.99625 .61258 m
1 .61258 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
0 0 1 r
.02381 .01472 m
.02381 .20828 L
.11905 .20828 L
.11905 .01472 L
F
.11905 .01472 m
.11905 .16285 L
.21429 .16285 L
.21429 .01472 L
F
.21429 .01472 m
.21429 .14705 L
.30952 .14705 L
.30952 .01472 L
F
.30952 .01472 m
.30952 .09767 L
.40476 .09767 L
.40476 .01472 L
F
.40476 .01472 m
.40476 .24384 L
.5 .24384 L
.5 .01472 L
F
.5 .01472 m
.5 .60332 L
.59524 .60332 L
.59524 .01472 L
F
.59524 .01472 m
.59524 .39395 L
.69048 .39395 L
.69048 .01472 L
F
.69048 .01472 m
.69048 .26951 L
.78571 .26951 L
.78571 .01472 L
F
.78571 .01472 m
.78571 .05817 L
.88095 .05817 L
.88095 .01472 L
F
.88095 .01472 m
.88095 .03842 L
.97619 .03842 L
.97619 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .20828 L
s
.11905 .01472 m
.11905 .20828 L
s
.02381 .20828 m
.11905 .20828 L
s
.11905 .01472 m
.11905 .16285 L
s
.21429 .01472 m
.21429 .16285 L
s
.11905 .16285 m
.21429 .16285 L
s
.21429 .01472 m
.21429 .14705 L
s
.30952 .01472 m
.30952 .14705 L
s
.21429 .14705 m
.30952 .14705 L
s
.30952 .01472 m
.30952 .09767 L
s
.40476 .01472 m
.40476 .09767 L
s
.30952 .09767 m
.40476 .09767 L
s
.40476 .01472 m
.40476 .24384 L
s
.5 .01472 m
.5 .24384 L
s
.40476 .24384 m
.5 .24384 L
s
.5 .01472 m
.5 .60332 L
s
.59524 .01472 m
.59524 .60332 L
s
.5 .60332 m
.59524 .60332 L
s
.59524 .01472 m
.59524 .39395 L
s
.69048 .01472 m
.69048 .39395 L
s
.59524 .39395 m
.69048 .39395 L
s
.69048 .01472 m
.69048 .26951 L
s
.78571 .01472 m
.78571 .26951 L
s
.69048 .26951 m
.78571 .26951 L
s
.78571 .01472 m
.78571 .05817 L
s
.88095 .01472 m
.88095 .05817 L
s
.78571 .05817 m
.88095 .05817 L
s
.88095 .01472 m
.88095 .03842 L
s
.97619 .01472 m
.97619 .03842 L
s
.88095 .03842 m
.97619 .03842 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0142146 0.0147151 14.7298 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .16596 0 0 2 Msboxa
[(20)] .3081 0 0 2 Msboxa
[(30)] .45025 0 0 2 Msboxa
[(40)] .5924 0 0 2 Msboxa
[(50)] .73454 0 0 2 Msboxa
[(60)] .87669 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.01)] -0.0125 .16201 1 0 Msboxa
[(0.02)] -0.0125 .30931 1 0 Msboxa
[(0.03)] -0.0125 .45661 1 0 Msboxa
[(0.04)] -0.0125 .60391 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.16596 0 m
.16596 .00625 L
s
P
[(10)] .16596 0 0 2 Mshowa
p
.002 w
.3081 0 m
.3081 .00625 L
s
P
[(20)] .3081 0 0 2 Mshowa
p
.002 w
.45025 0 m
.45025 .00625 L
s
P
[(30)] .45025 0 0 2 Mshowa
p
.002 w
.5924 0 m
.5924 .00625 L
s
P
[(40)] .5924 0 0 2 Mshowa
p
.002 w
.73454 0 m
.73454 .00625 L
s
P
[(50)] .73454 0 0 2 Mshowa
p
.002 w
.87669 0 m
.87669 .00625 L
s
P
[(60)] .87669 0 0 2 Mshowa
p
.001 w
.05224 0 m
.05224 .00375 L
s
P
p
.001 w
.08067 0 m
.08067 .00375 L
s
P
p
.001 w
.1091 0 m
.1091 .00375 L
s
P
p
.001 w
.13753 0 m
.13753 .00375 L
s
P
p
.001 w
.19439 0 m
.19439 .00375 L
s
P
p
.001 w
.22281 0 m
.22281 .00375 L
s
P
p
.001 w
.25124 0 m
.25124 .00375 L
s
P
p
.001 w
.27967 0 m
.27967 .00375 L
s
P
p
.001 w
.33653 0 m
.33653 .00375 L
s
P
p
.001 w
.36496 0 m
.36496 .00375 L
s
P
p
.001 w
.39339 0 m
.39339 .00375 L
s
P
p
.001 w
.42182 0 m
.42182 .00375 L
s
P
p
.001 w
.47868 0 m
.47868 .00375 L
s
P
p
.001 w
.50711 0 m
.50711 .00375 L
s
P
p
.001 w
.53554 0 m
.53554 .00375 L
s
P
p
.001 w
.56397 0 m
.56397 .00375 L
s
P
p
.001 w
.62082 0 m
.62082 .00375 L
s
P
p
.001 w
.64925 0 m
.64925 .00375 L
s
P
p
.001 w
.67768 0 m
.67768 .00375 L
s
P
p
.001 w
.70611 0 m
.70611 .00375 L
s
P
p
.001 w
.76297 0 m
.76297 .00375 L
s
P
p
.001 w
.7914 0 m
.7914 .00375 L
s
P
p
.001 w
.81983 0 m
.81983 .00375 L
s
P
p
.001 w
.84826 0 m
.84826 .00375 L
s
P
p
.001 w
.90512 0 m
.90512 .00375 L
s
P
p
.001 w
.93355 0 m
.93355 .00375 L
s
P
p
.001 w
.96198 0 m
.96198 .00375 L
s
P
p
.001 w
.99041 0 m
.99041 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .16201 m
.00625 .16201 L
s
P
[(0.01)] -0.0125 .16201 1 0 Mshowa
p
.002 w
0 .30931 m
.00625 .30931 L
s
P
[(0.02)] -0.0125 .30931 1 0 Mshowa
p
.002 w
0 .45661 m
.00625 .45661 L
s
P
[(0.03)] -0.0125 .45661 1 0 Mshowa
p
.002 w
0 .60391 m
.00625 .60391 L
s
P
[(0.04)] -0.0125 .60391 1 0 Mshowa
p
.001 w
0 .04417 m
.00375 .04417 L
s
P
p
.001 w
0 .07363 m
.00375 .07363 L
s
P
p
.001 w
0 .10309 m
.00375 .10309 L
s
P
p
.001 w
0 .13255 m
.00375 .13255 L
s
P
p
.001 w
0 .19147 m
.00375 .19147 L
s
P
p
.001 w
0 .22093 m
.00375 .22093 L
s
P
p
.001 w
0 .25039 m
.00375 .25039 L
s
P
p
.001 w
0 .27985 m
.00375 .27985 L
s
P
p
.001 w
0 .33877 m
.00375 .33877 L
s
P
p
.001 w
0 .36823 m
.00375 .36823 L
s
P
p
.001 w
0 .39769 m
.00375 .39769 L
s
P
p
.001 w
0 .42715 m
.00375 .42715 L
s
P
p
.001 w
0 .48607 m
.00375 .48607 L
s
P
p
.001 w
0 .51553 m
.00375 .51553 L
s
P
p
.001 w
0 .54499 m
.00375 .54499 L
s
P
p
.001 w
0 .57445 m
.00375 .57445 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.16596 .61178 m
.16596 .61803 L
s
P
p
.002 w
.3081 .61178 m
.3081 .61803 L
s
P
p
.002 w
.45025 .61178 m
.45025 .61803 L
s
P
p
.002 w
.5924 .61178 m
.5924 .61803 L
s
P
p
.002 w
.73454 .61178 m
.73454 .61803 L
s
P
p
.002 w
.87669 .61178 m
.87669 .61803 L
s
P
p
.001 w
.05224 .61428 m
.05224 .61803 L
s
P
p
.001 w
.08067 .61428 m
.08067 .61803 L
s
P
p
.001 w
.1091 .61428 m
.1091 .61803 L
s
P
p
.001 w
.13753 .61428 m
.13753 .61803 L
s
P
p
.001 w
.19439 .61428 m
.19439 .61803 L
s
P
p
.001 w
.22281 .61428 m
.22281 .61803 L
s
P
p
.001 w
.25124 .61428 m
.25124 .61803 L
s
P
p
.001 w
.27967 .61428 m
.27967 .61803 L
s
P
p
.001 w
.33653 .61428 m
.33653 .61803 L
s
P
p
.001 w
.36496 .61428 m
.36496 .61803 L
s
P
p
.001 w
.39339 .61428 m
.39339 .61803 L
s
P
p
.001 w
.42182 .61428 m
.42182 .61803 L
s
P
p
.001 w
.47868 .61428 m
.47868 .61803 L
s
P
p
.001 w
.50711 .61428 m
.50711 .61803 L
s
P
p
.001 w
.53554 .61428 m
.53554 .61803 L
s
P
p
.001 w
.56397 .61428 m
.56397 .61803 L
s
P
p
.001 w
.62082 .61428 m
.62082 .61803 L
s
P
p
.001 w
.64925 .61428 m
.64925 .61803 L
s
P
p
.001 w
.67768 .61428 m
.67768 .61803 L
s
P
p
.001 w
.70611 .61428 m
.70611 .61803 L
s
P
p
.001 w
.76297 .61428 m
.76297 .61803 L
s
P
p
.001 w
.7914 .61428 m
.7914 .61803 L
s
P
p
.001 w
.81983 .61428 m
.81983 .61803 L
s
P
p
.001 w
.84826 .61428 m
.84826 .61803 L
s
P
p
.001 w
.90512 .61428 m
.90512 .61803 L
s
P
p
.001 w
.93355 .61428 m
.93355 .61803 L
s
P
p
.001 w
.96198 .61428 m
.96198 .61803 L
s
P
p
.001 w
.99041 .61428 m
.99041 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .16201 m
1 .16201 L
s
P
p
.002 w
.99375 .30931 m
1 .30931 L
s
P
p
.002 w
.99375 .45661 m
1 .45661 L
s
P
p
.002 w
.99375 .60391 m
1 .60391 L
s
P
p
.001 w
.99625 .04417 m
1 .04417 L
s
P
p
.001 w
.99625 .07363 m
1 .07363 L
s
P
p
.001 w
.99625 .10309 m
1 .10309 L
s
P
p
.001 w
.99625 .13255 m
1 .13255 L
s
P
p
.001 w
.99625 .19147 m
1 .19147 L
s
P
p
.001 w
.99625 .22093 m
1 .22093 L
s
P
p
.001 w
.99625 .25039 m
1 .25039 L
s
P
p
.001 w
.99625 .27985 m
1 .27985 L
s
P
p
.001 w
.99625 .33877 m
1 .33877 L
s
P
p
.001 w
.99625 .36823 m
1 .36823 L
s
P
p
.001 w
.99625 .39769 m
1 .39769 L
s
P
p
.001 w
.99625 .42715 m
1 .42715 L
s
P
p
.001 w
.99625 .48607 m
1 .48607 L
s
P
p
.001 w
.99625 .51553 m
1 .51553 L
s
P
p
.001 w
.99625 .54499 m
1 .54499 L
s
P
p
.001 w
.99625 .57445 m
1 .57445 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
.004 w
.02381 .10301 m
.02381 .01472 L
s
.03802 .13244 m
.03802 .01472 L
s
.05224 .17658 m
.05224 .01472 L
s
.06645 .26487 m
.06645 .01472 L
s
.08067 .23544 m
.08067 .01472 L
s
.09488 .1913 m
.09488 .01472 L
s
.1091 .13244 m
.1091 .01472 L
s
.12331 .05886 m
.12331 .01472 L
s
.13753 .02943 m
.13753 .01472 L
s
.15174 .04415 m
.15174 .01472 L
s
.16596 .08829 m
.16596 .01472 L
s
.18017 .16187 m
.18017 .01472 L
s
.19439 .07358 m
.19439 .01472 L
s
.2086 .11772 m
.2086 .01472 L
s
.22281 .10301 m
.22281 .01472 L
s
.23703 .13244 m
.23703 .01472 L
s
.25124 .17658 m
.25124 .01472 L
s
.26546 .20601 m
.26546 .01472 L
s
.27967 .22073 m
.27967 .01472 L
s
.29389 .14715 m
.29389 .01472 L
s
.3081 .20601 m
.3081 .01472 L
s
.32232 .14715 m
.32232 .01472 L
s
.33653 .23544 m
.33653 .01472 L
s
.35075 .20601 m
.35075 .01472 L
s
.36496 .10301 m
.36496 .01472 L
s
.37918 .13244 m
.37918 .01472 L
s
.39339 .02943 m
.39339 .01472 L
s
.4076 .02943 m
.4076 .01472 L
s
.42182 .05886 m
.42182 .01472 L
s
.43603 .11772 m
.43603 .01472 L
s
.45025 .20601 m
.45025 .01472 L
s
.46446 .04415 m
.46446 .01472 L
s
.47868 .14715 m
.47868 .01472 L
s
.49289 .22073 m
.49289 .01472 L
s
.50711 .2943 m
.50711 .01472 L
s
.52132 .17658 m
.52132 .01472 L
s
.53554 .25016 m
.53554 .01472 L
s
.54975 .33845 m
.54975 .01472 L
s
.56397 .41202 m
.56397 .01472 L
s
.57818 .33845 m
.57818 .01472 L
s
.5924 .20601 m
.5924 .01472 L
s
.60661 .10301 m
.60661 .01472 L
s
.62082 .22073 m
.62082 .01472 L
s
.63504 .42674 m
.63504 .01472 L
s
.64925 .26487 m
.64925 .01472 L
s
.66347 .42674 m
.66347 .01472 L
s
.67768 .4856 m
.67768 .01472 L
s
.6919 .51503 m
.6919 .01472 L
s
.70611 .41202 m
.70611 .01472 L
s
.72033 .33845 m
.72033 .01472 L
s
.73454 .38259 m
.73454 .01472 L
s
.74876 .54446 m
.74876 .01472 L
s
.76297 .60332 m
.76297 .01472 L
s
.77719 .55917 m
.77719 .01472 L
s
.7914 .50031 m
.7914 .01472 L
s
.80561 .5886 m
.80561 .01472 L
s
.81983 .57389 m
.81983 .01472 L
s
.83404 .57389 m
.83404 .01472 L
s
.84826 .44145 m
.84826 .01472 L
s
.86247 .35316 m
.86247 .01472 L
s
.87669 .1913 m
.87669 .01472 L
s
.8909 .07358 m
.8909 .01472 L
s
.90512 .11772 m
.90512 .01472 L
s
.91933 .13244 m
.91933 .01472 L
s
.93355 .07358 m
.93355 .01472 L
s
.94776 .05886 m
.94776 .01472 L
s
.96198 .04415 m
.96198 .01472 L
s
.97619 .02943 m
.97619 .01472 L
s
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = input; preserveAspect; startGroup]
Queue[1,1.1,10000];
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 9.52492e-05 0.0147151 0.0159082 [
[(2000)] .21431 .01472 0 2 Msboxa
[(4000)] .40481 .01472 0 2 Msboxa
[(6000)] .5953 .01472 0 2 Msboxa
[(8000)] .7858 .01472 0 2 Msboxa
[(10000)] .9763 .01472 0 2 Msboxa
[(5)] .01131 .09426 1 0 Msboxa
[(10)] .01131 .1738 1 0 Msboxa
[(15)] .01131 .25334 1 0 Msboxa
[(20)] .01131 .33288 1 0 Msboxa
[(25)] .01131 .41242 1 0 Msboxa
[(30)] .01131 .49196 1 0 Msboxa
[(35)] .01131 .5715 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.21431 .01472 m
.21431 .02097 L
s
P
[(2000)] .21431 .01472 0 2 Mshowa
p
.002 w
.40481 .01472 m
.40481 .02097 L
s
P
[(4000)] .40481 .01472 0 2 Mshowa
p
.002 w
.5953 .01472 m
.5953 .02097 L
s
P
[(6000)] .5953 .01472 0 2 Mshowa
p
.002 w
.7858 .01472 m
.7858 .02097 L
s
P
[(8000)] .7858 .01472 0 2 Mshowa
p
.002 w
.9763 .01472 m
.9763 .02097 L
s
P
[(10000)] .9763 .01472 0 2 Mshowa
p
.001 w
.06191 .01472 m
.06191 .01847 L
s
P
p
.001 w
.10001 .01472 m
.10001 .01847 L
s
P
p
.001 w
.13811 .01472 m
.13811 .01847 L
s
P
p
.001 w
.17621 .01472 m
.17621 .01847 L
s
P
p
.001 w
.25241 .01472 m
.25241 .01847 L
s
P
p
.001 w
.29051 .01472 m
.29051 .01847 L
s
P
p
.001 w
.32861 .01472 m
.32861 .01847 L
s
P
p
.001 w
.36671 .01472 m
.36671 .01847 L
s
P
p
.001 w
.44291 .01472 m
.44291 .01847 L
s
P
p
.001 w
.48101 .01472 m
.48101 .01847 L
s
P
p
.001 w
.51911 .01472 m
.51911 .01847 L
s
P
p
.001 w
.55721 .01472 m
.55721 .01847 L
s
P
p
.001 w
.6334 .01472 m
.6334 .01847 L
s
P
p
.001 w
.6715 .01472 m
.6715 .01847 L
s
P
p
.001 w
.7096 .01472 m
.7096 .01847 L
s
P
p
.001 w
.7477 .01472 m
.7477 .01847 L
s
P
p
.001 w
.8239 .01472 m
.8239 .01847 L
s
P
p
.001 w
.862 .01472 m
.862 .01847 L
s
P
p
.001 w
.9001 .01472 m
.9001 .01847 L
s
P
p
.001 w
.9382 .01472 m
.9382 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .09426 m
.03006 .09426 L
s
P
[(5)] .01131 .09426 1 0 Mshowa
p
.002 w
.02381 .1738 m
.03006 .1738 L
s
P
[(10)] .01131 .1738 1 0 Mshowa
p
.002 w
.02381 .25334 m
.03006 .25334 L
s
P
[(15)] .01131 .25334 1 0 Mshowa
p
.002 w
.02381 .33288 m
.03006 .33288 L
s
P
[(20)] .01131 .33288 1 0 Mshowa
p
.002 w
.02381 .41242 m
.03006 .41242 L
s
P
[(25)] .01131 .41242 1 0 Mshowa
p
.002 w
.02381 .49196 m
.03006 .49196 L
s
P
[(30)] .01131 .49196 1 0 Mshowa
p
.002 w
.02381 .5715 m
.03006 .5715 L
s
P
[(35)] .01131 .5715 1 0 Mshowa
p
.001 w
.02381 .03062 m
.02756 .03062 L
s
P
p
.001 w
.02381 .04653 m
.02756 .04653 L
s
P
p
.001 w
.02381 .06244 m
.02756 .06244 L
s
P
p
.001 w
.02381 .07835 m
.02756 .07835 L
s
P
p
.001 w
.02381 .11016 m
.02756 .11016 L
s
P
p
.001 w
.02381 .12607 m
.02756 .12607 L
s
P
p
.001 w
.02381 .14198 m
.02756 .14198 L
s
P
p
.001 w
.02381 .15789 m
.02756 .15789 L
s
P
p
.001 w
.02381 .18971 m
.02756 .18971 L
s
P
p
.001 w
.02381 .20561 m
.02756 .20561 L
s
P
p
.001 w
.02381 .22152 m
.02756 .22152 L
s
P
p
.001 w
.02381 .23743 m
.02756 .23743 L
s
P
p
.001 w
.02381 .26925 m
.02756 .26925 L
s
P
p
.001 w
.02381 .28515 m
.02756 .28515 L
s
P
p
.001 w
.02381 .30106 m
.02756 .30106 L
s
P
p
.001 w
.02381 .31697 m
.02756 .31697 L
s
P
p
.001 w
.02381 .34879 m
.02756 .34879 L
s
P
p
.001 w
.02381 .3647 m
.02756 .3647 L
s
P
p
.001 w
.02381 .3806 m
.02756 .3806 L
s
P
p
.001 w
.02381 .39651 m
.02756 .39651 L
s
P
p
.001 w
.02381 .42833 m
.02756 .42833 L
s
P
p
.001 w
.02381 .44424 m
.02756 .44424 L
s
P
p
.001 w
.02381 .46014 m
.02756 .46014 L
s
P
p
.001 w
.02381 .47605 m
.02756 .47605 L
s
P
p
.001 w
.02381 .50787 m
.02756 .50787 L
s
P
p
.001 w
.02381 .52378 m
.02756 .52378 L
s
P
p
.001 w
.02381 .53969 m
.02756 .53969 L
s
P
p
.001 w
.02381 .55559 m
.02756 .55559 L
s
P
p
.001 w
.02381 .58741 m
.02756 .58741 L
s
P
p
.001 w
.02381 .60332 m
.02756 .60332 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.004 w
.02381 .01472 m
.02397 .03062 L
.02399 .01472 L
.02412 .03062 L
.02414 .04653 L
.02417 .03062 L
.02418 .01472 L
.0243 .03062 L
.02433 .01472 L
.02434 .03062 L
.02436 .04653 L
.02438 .03062 L
.02445 .01472 L
.02451 .03062 L
.02451 .01472 L
.02456 .03062 L
.02457 .04653 L
.02465 .03062 L
.02473 .04653 L
.02474 .03062 L
.02475 .04653 L
.02479 .03062 L
.02487 .04653 L
.0249 .03062 L
.02491 .04653 L
.02494 .03062 L
.02499 .01472 L
.02516 .03062 L
.02519 .04653 L
.0252 .06244 L
.02536 .04653 L
.02539 .06244 L
.02541 .04653 L
.02549 .03062 L
.0255 .01472 L
.02559 .03062 L
.02559 .01472 L
.0256 .03062 L
.0256 .01472 L
.02566 .03062 L
.0257 .01472 L
.026 .03062 L
.02604 .01472 L
.0261 .03062 L
.02625 .04653 L
.02638 .03062 L
.02647 .01472 L
.02649 .03062 L
.02655 .04653 L
.02655 .06244 L
Mistroke
.02656 .07835 L
.02657 .06244 L
.02659 .04653 L
.02669 .03062 L
.02678 .04653 L
.02681 .03062 L
.02681 .04653 L
.02681 .06244 L
.02682 .04653 L
.02684 .06244 L
.0269 .04653 L
.02691 .03062 L
.02692 .04653 L
.02694 .06244 L
.02699 .04653 L
.02709 .03062 L
.02711 .01472 L
.02717 .03062 L
.02723 .04653 L
.02729 .03062 L
.02736 .01472 L
.02761 .03062 L
.02762 .04653 L
.02763 .03062 L
.02767 .01472 L
.02799 .03062 L
.02804 .01472 L
.02819 .03062 L
.0282 .04653 L
.02827 .06244 L
.02828 .04653 L
.02828 .06244 L
.02831 .04653 L
.02831 .03062 L
.02832 .04653 L
.02834 .03062 L
.02838 .01472 L
.02839 .03062 L
.0284 .04653 L
.02846 .03062 L
.02848 .01472 L
.02849 .03062 L
.02858 .04653 L
.02863 .03062 L
.02867 .04653 L
.02872 .03062 L
.02875 .04653 L
.02881 .03062 L
.02884 .01472 L
.02885 .03062 L
Mistroke
.02887 .01472 L
.02895 .03062 L
.02903 .04653 L
.02903 .03062 L
.02904 .04653 L
.0291 .06244 L
.02924 .04653 L
.02925 .06244 L
.02932 .04653 L
.02942 .03062 L
.02944 .01472 L
.02957 .03062 L
.02958 .01472 L
.02968 .03062 L
.02973 .04653 L
.02974 .06244 L
.02986 .07835 L
.02994 .09426 L
.02994 .11016 L
.02997 .09426 L
.03001 .07835 L
.03004 .06244 L
.03014 .04653 L
.03014 .03062 L
.03016 .04653 L
.03019 .03062 L
.03023 .04653 L
.03025 .03062 L
.03031 .01472 L
.03038 .03062 L
.03038 .04653 L
.03038 .06244 L
.03039 .07835 L
.03042 .09426 L
.03053 .11016 L
.03056 .12607 L
.03056 .11016 L
.03071 .09426 L
.03082 .07835 L
.03092 .09426 L
.03092 .07835 L
.03101 .09426 L
.03104 .07835 L
.03108 .06244 L
.03112 .04653 L
.03122 .03062 L
.03124 .04653 L
.03126 .03062 L
.03128 .01472 L
.03137 .03062 L
Mistroke
.03142 .04653 L
.03156 .03062 L
.03167 .01472 L
.0317 .03062 L
.0317 .01472 L
.03174 .03062 L
.03192 .01472 L
.03199 .03062 L
.03203 .01472 L
.03203 .03062 L
.03205 .01472 L
.03213 .03062 L
.0322 .01472 L
.03223 .03062 L
.03228 .04653 L
.03238 .03062 L
.03238 .04653 L
.03239 .03062 L
.03241 .01472 L
.03253 .03062 L
.03266 .01472 L
.03266 .03062 L
.03267 .04653 L
.03271 .06244 L
.03272 .07835 L
.03291 .06244 L
.03302 .07835 L
.03304 .09426 L
.03311 .07835 L
.03313 .09426 L
.03313 .07835 L
.03321 .09426 L
.03331 .07835 L
.03336 .06244 L
.03343 .04653 L
.03345 .03062 L
.03345 .01472 L
.03352 .03062 L
.03353 .04653 L
.03355 .03062 L
.03356 .04653 L
.0336 .06244 L
.03367 .07835 L
.03371 .09426 L
.03373 .11016 L
.03373 .09426 L
.03375 .07835 L
.03375 .09426 L
.03376 .07835 L
.03378 .09426 L
Mistroke
.03378 .11016 L
.03378 .09426 L
.0338 .07835 L
.0338 .06244 L
.03383 .04653 L
.03387 .06244 L
.03392 .04653 L
.03393 .06244 L
.03403 .07835 L
.03403 .06244 L
.03407 .07835 L
.03408 .06244 L
.03411 .07835 L
.03412 .09426 L
.03419 .07835 L
.0342 .06244 L
.03428 .07835 L
.03436 .06244 L
.03439 .07835 L
.0345 .09426 L
.03455 .07835 L
.03456 .09426 L
.03461 .11016 L
.03466 .12607 L
.03468 .11016 L
.03476 .09426 L
.03484 .11016 L
.03484 .09426 L
.03492 .07835 L
.03495 .06244 L
.03508 .07835 L
.0351 .09426 L
.03518 .11016 L
.03527 .09426 L
.03534 .07835 L
.03536 .09426 L
.03541 .07835 L
.03544 .09426 L
.03544 .11016 L
.03557 .09426 L
.03562 .07835 L
.03564 .09426 L
.03568 .11016 L
.03573 .12607 L
.03597 .14198 L
.03611 .12607 L
.03618 .11016 L
.03621 .09426 L
.03637 .11016 L
.03637 .12607 L
Mistroke
.03638 .14198 L
.03644 .12607 L
.03653 .11016 L
.03656 .09426 L
.03658 .11016 L
.0366 .09426 L
.03663 .07835 L
.03665 .09426 L
.03665 .11016 L
.03677 .09426 L
.03691 .11016 L
.03691 .12607 L
.03692 .14198 L
.03692 .12607 L
.03702 .14198 L
.03712 .15789 L
.03719 .14198 L
.03723 .12607 L
.03725 .14198 L
.03736 .15789 L
.03746 .1738 L
.03751 .15789 L
.03755 .1738 L
.03765 .15789 L
.0377 .1738 L
.03771 .18971 L
.03776 .1738 L
.03784 .18971 L
.03786 .20561 L
.03793 .18971 L
.03794 .1738 L
.03798 .18971 L
.03799 .20561 L
.038 .22152 L
.03801 .20561 L
.03806 .22152 L
.03809 .23743 L
.03812 .22152 L
.03814 .20561 L
.03825 .22152 L
.03835 .23743 L
.03837 .25334 L
.03837 .23743 L
.03842 .22152 L
.03854 .23743 L
.03855 .25334 L
.03856 .26925 L
.03871 .25334 L
.03872 .23743 L
.03872 .22152 L
Mistroke
.03874 .20561 L
.03877 .18971 L
.0388 .20561 L
.03881 .18971 L
.03883 .1738 L
.03884 .18971 L
.03899 .20561 L
.03899 .18971 L
.03903 .20561 L
.03905 .18971 L
.03906 .20561 L
.03907 .22152 L
.03913 .20561 L
.03913 .22152 L
.03918 .23743 L
.0392 .22152 L
.03921 .23743 L
.03922 .22152 L
.03929 .20561 L
.03929 .22152 L
.03931 .20561 L
.03931 .22152 L
.03938 .23743 L
.03938 .22152 L
.03941 .23743 L
.03942 .25334 L
.03948 .26925 L
.0396 .25334 L
.03962 .26925 L
.03963 .25334 L
.03964 .26925 L
.0397 .25334 L
.0397 .23743 L
.03977 .25334 L
.0398 .23743 L
.03988 .25334 L
.03989 .23743 L
.0399 .22152 L
.03991 .20561 L
.03992 .22152 L
.03997 .23743 L
.04006 .22152 L
.04011 .23743 L
.04013 .25334 L
.04013 .23743 L
.04016 .25334 L
.04022 .23743 L
.0404 .25334 L
.04042 .26925 L
.04047 .28515 L
Mistroke
.04052 .30106 L
.04054 .28515 L
.04055 .30106 L
.04066 .28515 L
.04066 .30106 L
.04074 .31697 L
.04076 .30106 L
.04078 .28515 L
.04078 .30106 L
.0408 .31697 L
.04085 .30106 L
.04087 .31697 L
.04092 .30106 L
.04118 .28515 L
.04123 .26925 L
.0414 .25334 L
.04148 .23743 L
.04152 .22152 L
.04156 .23743 L
.04159 .25334 L
.0416 .26925 L
.0416 .28515 L
.0417 .30106 L
.0418 .31697 L
.04181 .30106 L
.04185 .28515 L
.04185 .30106 L
.04187 .28515 L
.04196 .26925 L
.04197 .25334 L
.04197 .23743 L
.04203 .22152 L
.04204 .20561 L
.04205 .18971 L
.04207 .1738 L
.04212 .15789 L
.04216 .1738 L
.04233 .18971 L
.04237 .1738 L
.04242 .18971 L
.04242 .1738 L
.0425 .15789 L
.04252 .1738 L
.04253 .15789 L
.04253 .1738 L
.04263 .18971 L
.04279 .1738 L
.04279 .18971 L
.04281 .1738 L
.04287 .18971 L
Mistroke
.043 .1738 L
.04301 .18971 L
.0431 .1738 L
.04322 .18971 L
.04323 .1738 L
.04324 .18971 L
.0433 .20561 L
.04332 .22152 L
.04332 .20561 L
.04339 .18971 L
.04341 .1738 L
.04342 .18971 L
.04348 .1738 L
.04349 .18971 L
.04349 .20561 L
.04355 .22152 L
.0436 .23743 L
.0436 .22152 L
.04369 .23743 L
.04386 .25334 L
.04392 .23743 L
.04399 .22152 L
.04399 .20561 L
.04402 .18971 L
.04404 .1738 L
.04406 .18971 L
.04412 .1738 L
.04416 .15789 L
.04416 .14198 L
.0443 .15789 L
.04431 .14198 L
.04443 .15789 L
.04445 .14198 L
.04447 .12607 L
.04448 .11016 L
.04449 .12607 L
.04451 .11016 L
.04457 .09426 L
.04457 .11016 L
.04459 .09426 L
.04461 .07835 L
.04462 .06244 L
.04469 .04653 L
.04471 .06244 L
.04472 .07835 L
.04481 .06244 L
.04485 .07835 L
.04488 .06244 L
.04493 .07835 L
.04498 .09426 L
Mistroke
.04513 .07835 L
.04524 .06244 L
.04526 .07835 L
.04534 .09426 L
.04535 .11016 L
.04535 .09426 L
.04544 .11016 L
.04545 .09426 L
.04548 .11016 L
.0455 .09426 L
.0455 .11016 L
.04552 .09426 L
.04554 .07835 L
.04554 .06244 L
.04554 .04653 L
.0456 .03062 L
.04563 .01472 L
.04563 .03062 L
.04568 .04653 L
.04579 .06244 L
.04589 .04653 L
.0459 .06244 L
.04591 .07835 L
.04592 .06244 L
.04595 .04653 L
.04595 .06244 L
.04596 .07835 L
.04603 .06244 L
.04609 .07835 L
.0461 .06244 L
.0461 .07835 L
.04611 .09426 L
.04612 .07835 L
.04615 .06244 L
.04615 .04653 L
.04618 .03062 L
.04618 .01472 L
.04624 .03062 L
.04639 .01472 L
.04646 .03062 L
.04646 .04653 L
.04652 .06244 L
.04656 .07835 L
.04657 .06244 L
.0467 .07835 L
.04672 .09426 L
.04674 .07835 L
.04678 .06244 L
.04679 .07835 L
.04679 .09426 L
Mistroke
.04687 .07835 L
.04692 .09426 L
.04692 .11016 L
.04698 .09426 L
.047 .07835 L
.04702 .09426 L
.04705 .11016 L
.04706 .09426 L
.04718 .11016 L
.0472 .12607 L
.04721 .11016 L
.04723 .12607 L
.04727 .11016 L
.04734 .09426 L
.04739 .07835 L
.04744 .09426 L
.04751 .07835 L
.04751 .09426 L
.04761 .11016 L
.04761 .12607 L
.04762 .11016 L
.04769 .12607 L
.04773 .14198 L
.0478 .15789 L
.04781 .14198 L
.04785 .12607 L
.04787 .11016 L
.04791 .12607 L
.04794 .14198 L
.04795 .12607 L
.04796 .11016 L
.04797 .09426 L
.048 .07835 L
.04809 .06244 L
.04818 .07835 L
.04819 .09426 L
.04819 .07835 L
.04821 .06244 L
.04828 .07835 L
.0483 .09426 L
.04831 .11016 L
.04839 .12607 L
.04839 .14198 L
.04851 .12607 L
.04856 .11016 L
.04857 .09426 L
.04858 .07835 L
.04875 .06244 L
.04876 .07835 L
.0488 .06244 L
Mistroke
.04891 .07835 L
.04893 .06244 L
.04896 .07835 L
.04896 .06244 L
.04897 .07835 L
.04898 .09426 L
.049 .11016 L
.04901 .12607 L
.04903 .11016 L
.04909 .12607 L
.04913 .11016 L
.04928 .09426 L
.04928 .11016 L
.04934 .12607 L
.04934 .11016 L
.04937 .12607 L
.04942 .14198 L
.04946 .15789 L
.0495 .14198 L
.04951 .12607 L
.04954 .14198 L
.04963 .12607 L
.04978 .14198 L
.04984 .15789 L
.04997 .14198 L
.04999 .15789 L
.05002 .1738 L
.05015 .18971 L
.05017 .1738 L
.05024 .15789 L
.05025 .14198 L
.05026 .15789 L
.05026 .14198 L
.05035 .12607 L
.0504 .11016 L
.05046 .12607 L
.05049 .14198 L
.05054 .12607 L
.05057 .14198 L
.05076 .15789 L
.05078 .1738 L
.05081 .18971 L
.05085 .20561 L
.05089 .18971 L
.05101 .20561 L
.05108 .22152 L
.05114 .20561 L
.05116 .22152 L
.05129 .23743 L
.05136 .22152 L
Mistroke
.05138 .20561 L
.05148 .22152 L
.05162 .20561 L
.05165 .18971 L
.05168 .20561 L
.05169 .18971 L
.05171 .1738 L
.05173 .15789 L
.05178 .1738 L
.0518 .15789 L
.05181 .1738 L
.05192 .15789 L
.05195 .1738 L
.05196 .18971 L
.05202 .20561 L
.05204 .18971 L
.05217 .1738 L
.05219 .18971 L
.05229 .20561 L
.05232 .18971 L
.05233 .20561 L
.05234 .22152 L
.05242 .23743 L
.05244 .25334 L
.05247 .23743 L
.05256 .25334 L
.05256 .23743 L
.05264 .25334 L
.05269 .26925 L
.05276 .25334 L
.0528 .23743 L
.05285 .25334 L
.05285 .23743 L
.05287 .22152 L
.05288 .23743 L
.0529 .22152 L
.05293 .23743 L
.05298 .22152 L
.05298 .23743 L
.05304 .22152 L
.0531 .23743 L
.05311 .25334 L
.0532 .26925 L
.05321 .25334 L
.05327 .26925 L
.05332 .28515 L
.05333 .26925 L
.05334 .25334 L
.05349 .26925 L
.05356 .25334 L
Mistroke
.05361 .23743 L
.05361 .22152 L
.05361 .20561 L
.05364 .22152 L
.05368 .20561 L
.0537 .22152 L
.05386 .20561 L
.05389 .18971 L
.05391 .1738 L
.05403 .15789 L
.05405 .1738 L
.05407 .18971 L
.05408 .1738 L
.05416 .18971 L
.05429 .20561 L
.05449 .18971 L
.05453 .1738 L
.05454 .15789 L
.05454 .1738 L
.05463 .18971 L
.05467 .20561 L
.05467 .22152 L
.05494 .20561 L
.05494 .22152 L
.05494 .20561 L
.05496 .22152 L
.05498 .23743 L
.05512 .25334 L
.05513 .26925 L
.05519 .25334 L
.05522 .26925 L
.05525 .25334 L
.05525 .23743 L
.05527 .22152 L
.05529 .23743 L
.05542 .22152 L
.05547 .20561 L
.05549 .22152 L
.05552 .20561 L
.05557 .18971 L
.05557 .1738 L
.05558 .18971 L
.05561 .20561 L
.05562 .18971 L
.05562 .1738 L
.05564 .18971 L
.05566 .20561 L
.05566 .18971 L
.05567 .1738 L
.0557 .18971 L
Mistroke
.05585 .1738 L
.05585 .15789 L
.05594 .14198 L
.05596 .12607 L
.05598 .11016 L
.0561 .12607 L
.05612 .14198 L
.05613 .12607 L
.05614 .14198 L
.05615 .15789 L
.05623 .14198 L
.05624 .15789 L
.0563 .1738 L
.05637 .15789 L
.0564 .14198 L
.05644 .15789 L
.05652 .14198 L
.05665 .15789 L
.05671 .1738 L
.05674 .15789 L
.0568 .1738 L
.05683 .18971 L
.05684 .1738 L
.05684 .15789 L
.05686 .1738 L
.0569 .18971 L
.0569 .20561 L
.05691 .22152 L
.05691 .23743 L
.05693 .22152 L
.05697 .23743 L
.05697 .22152 L
.05702 .20561 L
.05704 .22152 L
.05704 .20561 L
.05712 .18971 L
.05716 .20561 L
.05719 .18971 L
.05725 .20561 L
.05728 .22152 L
.05728 .23743 L
.05734 .22152 L
.05736 .20561 L
.05737 .18971 L
.0574 .1738 L
.05744 .15789 L
.05747 .14198 L
.05757 .15789 L
.0576 .14198 L
.0577 .15789 L
Mistroke
.05775 .14198 L
.05779 .12607 L
.05781 .14198 L
.05787 .12607 L
.05792 .14198 L
.05799 .12607 L
.058 .11016 L
.058 .12607 L
.0581 .14198 L
.05812 .15789 L
.05813 .1738 L
.05818 .18971 L
.0582 .1738 L
.05825 .18971 L
.05827 .20561 L
.05834 .22152 L
.05837 .23743 L
.0584 .22152 L
.0585 .23743 L
.05855 .22152 L
.05858 .23743 L
.05859 .25334 L
.05863 .23743 L
.05868 .22152 L
.05872 .20561 L
.0588 .18971 L
.05887 .1738 L
.0589 .15789 L
.05896 .1738 L
.05901 .18971 L
.05913 .1738 L
.05919 .18971 L
.0592 .1738 L
.05922 .18971 L
.05928 .20561 L
.05935 .18971 L
.05941 .20561 L
.05943 .18971 L
.05944 .20561 L
.05947 .22152 L
.05947 .23743 L
.05954 .25334 L
.05959 .26925 L
.05964 .28515 L
.05966 .26925 L
.0597 .28515 L
.0597 .30106 L
.05979 .31697 L
.0598 .30106 L
.05984 .28515 L
Mistroke
.05988 .26925 L
.05991 .28515 L
.05993 .30106 L
.06012 .28515 L
.06025 .26925 L
.06026 .28515 L
.06029 .26925 L
.06035 .25334 L
.0604 .23743 L
.06052 .25334 L
.06064 .26925 L
.06071 .25334 L
.0608 .23743 L
.06083 .22152 L
.06089 .23743 L
.06092 .25334 L
.06094 .23743 L
.06098 .25334 L
.061 .23743 L
.06105 .22152 L
.06106 .20561 L
.06111 .18971 L
.06113 .20561 L
.06113 .22152 L
.06115 .20561 L
.06116 .18971 L
.06128 .20561 L
.06132 .18971 L
.06133 .20561 L
.06134 .22152 L
.06137 .23743 L
.06137 .25334 L
.0614 .23743 L
.06141 .25334 L
.06146 .26925 L
.0615 .28515 L
.06152 .30106 L
.06159 .28515 L
.06173 .30106 L
.06178 .31697 L
.06192 .30106 L
.06196 .31697 L
.06199 .30106 L
.06201 .28515 L
.06201 .26925 L
.06205 .28515 L
.0621 .30106 L
.06217 .31697 L
.06219 .33288 L
.0622 .31697 L
Mistroke
.06225 .33288 L
.06238 .31697 L
.06243 .33288 L
.06243 .31697 L
.06244 .33288 L
.06249 .31697 L
.06249 .33288 L
.06253 .31697 L
.06263 .30106 L
.06273 .31697 L
.06275 .30106 L
.06281 .31697 L
.06288 .30106 L
.06288 .31697 L
.063 .33288 L
.06301 .31697 L
.06303 .30106 L
.06309 .28515 L
.06312 .26925 L
.0632 .25334 L
.06324 .23743 L
.06326 .22152 L
.06326 .23743 L
.06329 .25334 L
.06334 .26925 L
.06335 .28515 L
.06342 .26925 L
.06357 .25334 L
.06359 .23743 L
.0636 .22152 L
.06362 .23743 L
.06364 .22152 L
.06365 .23743 L
.06367 .22152 L
.06368 .20561 L
.06382 .18971 L
.06383 .20561 L
.064 .22152 L
.06404 .20561 L
.06405 .18971 L
.06412 .1738 L
.06426 .18971 L
.06429 .20561 L
.06434 .22152 L
.06442 .23743 L
.06447 .22152 L
.06448 .23743 L
.06451 .25334 L
.06451 .26925 L
.06453 .28515 L
Mistroke
.06454 .30106 L
.06458 .28515 L
.06459 .26925 L
.06466 .25334 L
.06467 .23743 L
.06468 .22152 L
.06473 .23743 L
.06476 .25334 L
.06476 .26925 L
.0648 .28515 L
.06482 .26925 L
.06494 .28515 L
.06511 .26925 L
.06511 .25334 L
.06511 .23743 L
.06521 .25334 L
.06523 .26925 L
.06527 .25334 L
.06529 .26925 L
.06533 .25334 L
.0655 .23743 L
.06563 .22152 L
.06564 .23743 L
.06568 .25334 L
.06574 .23743 L
.06576 .22152 L
.06585 .20561 L
.06586 .18971 L
.06586 .20561 L
.06589 .22152 L
.066 .20561 L
.06602 .18971 L
.06616 .1738 L
.06617 .15789 L
.06628 .1738 L
.06643 .15789 L
.06652 .14198 L
.06653 .12607 L
.06661 .14198 L
.0667 .12607 L
.06674 .11016 L
.06682 .09426 L
.06689 .11016 L
.06695 .09426 L
.06699 .11016 L
.067 .09426 L
.067 .11016 L
.06711 .12607 L
.06731 .11016 L
.06734 .09426 L
Mistroke
.06735 .07835 L
.06737 .06244 L
.06739 .07835 L
.06739 .06244 L
.06741 .07835 L
.06746 .06244 L
.06747 .04653 L
.06756 .03062 L
.06768 .01472 L
.06774 .03062 L
.06775 .01472 L
.06791 .03062 L
.06792 .04653 L
.068 .06244 L
.06802 .07835 L
.06811 .09426 L
.06813 .11016 L
.06818 .09426 L
.06826 .07835 L
.06851 .09426 L
.06851 .11016 L
.06854 .12607 L
.06855 .14198 L
.06856 .15789 L
.06857 .1738 L
.0686 .18971 L
.06863 .1738 L
.06867 .15789 L
.06881 .14198 L
.06883 .12607 L
.06891 .11016 L
.06898 .12607 L
.06899 .11016 L
.06905 .09426 L
.06909 .11016 L
.06926 .12607 L
.06926 .14198 L
.0693 .12607 L
.06936 .14198 L
.06937 .15789 L
.06941 .14198 L
.06946 .15789 L
.06959 .14198 L
.06961 .15789 L
.06969 .1738 L
.06972 .15789 L
.06975 .14198 L
.06981 .15789 L
.06986 .1738 L
.06988 .15789 L
Mistroke
.06992 .1738 L
.06997 .18971 L
.07011 .1738 L
.07012 .18971 L
.07021 .20561 L
.07033 .22152 L
.07045 .20561 L
.07058 .18971 L
.07062 .1738 L
.07063 .15789 L
.07066 .1738 L
.07075 .18971 L
.07079 .20561 L
.07084 .18971 L
.07086 .1738 L
.07088 .15789 L
.07092 .14198 L
.07096 .12607 L
.07097 .14198 L
.07097 .12607 L
.07105 .11016 L
.07106 .09426 L
.07113 .11016 L
.07114 .12607 L
.07115 .11016 L
.07119 .12607 L
.07119 .11016 L
.07121 .09426 L
.07124 .07835 L
.07127 .06244 L
.07127 .04653 L
.07129 .03062 L
.07129 .04653 L
.07139 .03062 L
.07151 .01472 L
.07158 .03062 L
.07166 .01472 L
.07177 .03062 L
.07178 .01472 L
.07181 .03062 L
.07182 .04653 L
.07186 .03062 L
.07187 .04653 L
.07192 .03062 L
.07193 .01472 L
.07193 .03062 L
.07194 .04653 L
.07196 .03062 L
.07204 .04653 L
.07207 .06244 L
Mistroke
.07212 .04653 L
.07215 .06244 L
.07231 .07835 L
.07237 .06244 L
.07252 .04653 L
.07254 .06244 L
.07266 .04653 L
.07267 .03062 L
.07267 .01472 L
.07273 .03062 L
.07273 .04653 L
.07279 .03062 L
.0728 .04653 L
.07298 .03062 L
.07299 .01472 L
.07303 .03062 L
.07305 .04653 L
.07307 .03062 L
.07308 .01472 L
.0731 .03062 L
.0731 .01472 L
.07311 .03062 L
.07313 .01472 L
.07323 .03062 L
.07324 .01472 L
.07345 .03062 L
.07347 .04653 L
.07348 .06244 L
.07349 .04653 L
.0735 .06244 L
.07353 .07835 L
.07353 .06244 L
.07355 .07835 L
.07355 .06244 L
.07359 .04653 L
.07367 .06244 L
.07369 .04653 L
.0737 .06244 L
.07374 .04653 L
.07378 .06244 L
.07381 .04653 L
.07382 .03062 L
.07388 .01472 L
.07398 .03062 L
.07404 .04653 L
.07406 .06244 L
.07414 .07835 L
.07433 .06244 L
.07436 .04653 L
.07452 .03062 L
Mistroke
.07459 .04653 L
.07466 .06244 L
.07476 .04653 L
.07478 .06244 L
.07481 .07835 L
.07482 .06244 L
.07489 .07835 L
.07492 .06244 L
.07493 .04653 L
.07496 .06244 L
.07499 .07835 L
.0753 .09426 L
.07535 .11016 L
.07542 .12607 L
.07544 .11016 L
.07544 .12607 L
.07556 .11016 L
.0756 .09426 L
.07569 .11016 L
.0757 .09426 L
.07572 .11016 L
.07577 .12607 L
.07584 .14198 L
.07586 .15789 L
.07589 .14198 L
.076 .12607 L
.07607 .11016 L
.07615 .12607 L
.07624 .11016 L
.07625 .12607 L
.07632 .11016 L
.07636 .12607 L
.07636 .11016 L
.07647 .12607 L
.07651 .14198 L
.07653 .15789 L
.07653 .1738 L
.07656 .18971 L
.07661 .1738 L
.07663 .15789 L
.07672 .1738 L
.07689 .15789 L
.07689 .1738 L
.07693 .18971 L
.07694 .1738 L
.077 .15789 L
.07702 .1738 L
.07706 .18971 L
.07712 .1738 L
.07721 .15789 L
Mistroke
.07722 .14198 L
.07723 .12607 L
.07724 .11016 L
.07729 .09426 L
.07743 .11016 L
.07744 .09426 L
.0775 .07835 L
.07754 .09426 L
.07757 .11016 L
.07759 .09426 L
.07761 .11016 L
.07762 .12607 L
.07766 .14198 L
.07766 .12607 L
.07768 .11016 L
.07768 .09426 L
.07774 .07835 L
.07778 .06244 L
.07782 .07835 L
.07782 .06244 L
.07785 .04653 L
.07788 .03062 L
.07789 .04653 L
.07804 .03062 L
.07808 .01472 L
.0784 .03062 L
.07842 .04653 L
.07843 .03062 L
.07846 .04653 L
.07856 .03062 L
.07863 .04653 L
.07868 .06244 L
.0787 .07835 L
.0787 .06244 L
.07871 .07835 L
.07876 .06244 L
.07885 .07835 L
.07885 .09426 L
.0789 .07835 L
.0789 .06244 L
.07891 .07835 L
.07893 .09426 L
.07895 .07835 L
.07905 .06244 L
.07906 .04653 L
.07911 .03062 L
.07914 .01472 L
.07923 .03062 L
.07923 .01472 L
.07925 .03062 L
Mistroke
.07938 .04653 L
.07945 .03062 L
.07949 .01472 L
.07955 .03062 L
.07956 .01472 L
.0798 .03062 L
.07985 .04653 L
.07992 .03062 L
.07996 .01472 L
.07999 .03062 L
.08003 .04653 L
.08009 .03062 L
.08031 .01472 L
.08041 .03062 L
.08045 .04653 L
.08052 .06244 L
.08053 .07835 L
.08061 .09426 L
.08083 .07835 L
.08092 .09426 L
.08098 .07835 L
.08104 .06244 L
.08107 .07835 L
.08108 .09426 L
.08111 .07835 L
.08116 .06244 L
.08125 .04653 L
.08127 .03062 L
.08128 .04653 L
.08133 .03062 L
.08137 .01472 L
.08139 .03062 L
.08141 .04653 L
.08141 .03062 L
.08145 .04653 L
.08146 .06244 L
.08146 .07835 L
.08152 .06244 L
.08155 .07835 L
.08155 .06244 L
.08166 .04653 L
.08172 .03062 L
.08173 .04653 L
.08174 .06244 L
.08174 .04653 L
.08195 .06244 L
.08197 .04653 L
.08198 .06244 L
.08208 .04653 L
.08211 .03062 L
Mistroke
.08211 .04653 L
.08216 .06244 L
.08216 .07835 L
.08218 .06244 L
.08219 .07835 L
.08231 .06244 L
.08232 .07835 L
.08233 .06244 L
.08233 .07835 L
.0824 .06244 L
.08245 .04653 L
.08246 .06244 L
.08248 .04653 L
.08253 .06244 L
.0826 .04653 L
.08273 .06244 L
.08274 .04653 L
.08279 .06244 L
.08281 .04653 L
.08299 .03062 L
.08314 .01472 L
.08323 .03062 L
.08325 .04653 L
.08327 .06244 L
.0833 .04653 L
.08333 .03062 L
.08345 .04653 L
.08347 .06244 L
.08347 .04653 L
.08348 .03062 L
.0835 .01472 L
.08355 .03062 L
.0836 .04653 L
.08363 .03062 L
.08366 .04653 L
.08377 .06244 L
.08396 .04653 L
.08406 .06244 L
.08412 .04653 L
.08414 .03062 L
.08417 .01472 L
.08421 .03062 L
.08424 .01472 L
.08427 .03062 L
.08433 .01472 L
.08443 .03062 L
.08446 .04653 L
.08454 .06244 L
.08454 .04653 L
.08456 .03062 L
Mistroke
.0846 .04653 L
.08465 .06244 L
.08479 .04653 L
.0848 .03062 L
.08483 .04653 L
.08483 .06244 L
.08487 .07835 L
.0849 .06244 L
.08491 .07835 L
.08496 .06244 L
.08497 .07835 L
.08504 .09426 L
.08506 .07835 L
.08516 .06244 L
.08523 .04653 L
.08527 .03062 L
.08529 .01472 L
.08531 .03062 L
.08543 .04653 L
.08553 .03062 L
.08554 .04653 L
.08555 .06244 L
.08558 .07835 L
.08559 .06244 L
.0857 .07835 L
.0857 .06244 L
.08575 .07835 L
.08577 .06244 L
.08584 .04653 L
.08586 .06244 L
.08586 .07835 L
.08591 .09426 L
.08599 .11016 L
.08602 .09426 L
.08603 .07835 L
.08604 .06244 L
.08608 .04653 L
.08616 .06244 L
.08618 .04653 L
.08626 .06244 L
.08626 .07835 L
.08655 .06244 L
.0866 .04653 L
.08661 .03062 L
.08663 .04653 L
.08691 .06244 L
.08704 .07835 L
.08706 .09426 L
.0871 .11016 L
.08711 .09426 L
Mistroke
.08714 .07835 L
.08718 .09426 L
.0872 .07835 L
.08721 .09426 L
.08723 .11016 L
.08732 .09426 L
.08736 .11016 L
.08739 .09426 L
.0874 .11016 L
.08741 .12607 L
.08744 .14198 L
.08745 .15789 L
.08748 .1738 L
.08749 .15789 L
.08753 .1738 L
.08754 .18971 L
.08754 .20561 L
.08754 .18971 L
.08757 .1738 L
.08761 .18971 L
.08769 .1738 L
.08772 .15789 L
.08773 .1738 L
.08775 .15789 L
.08777 .1738 L
.08778 .15789 L
.08781 .14198 L
.08805 .12607 L
.08811 .14198 L
.08811 .15789 L
.0882 .14198 L
.08822 .12607 L
.08824 .11016 L
.0883 .09426 L
.08831 .11016 L
.08845 .12607 L
.08846 .11016 L
.08847 .09426 L
.08848 .07835 L
.08858 .09426 L
.08864 .07835 L
.08864 .09426 L
.08869 .11016 L
.08874 .12607 L
.08878 .14198 L
.08879 .12607 L
.08886 .11016 L
.08893 .09426 L
.08896 .11016 L
.08901 .09426 L
Mistroke
.08906 .11016 L
.08912 .09426 L
.08913 .11016 L
.08917 .09426 L
.08923 .07835 L
.08923 .09426 L
.08929 .11016 L
.08944 .12607 L
.08947 .11016 L
.08956 .09426 L
.08957 .11016 L
.08957 .12607 L
.0896 .14198 L
.08969 .12607 L
.0897 .14198 L
.08975 .12607 L
.0899 .14198 L
.08993 .15789 L
.08993 .1738 L
.08999 .15789 L
.09003 .1738 L
.0901 .18971 L
.0901 .1738 L
.09015 .15789 L
.09016 .14198 L
.09029 .12607 L
.09034 .11016 L
.09037 .09426 L
.09046 .11016 L
.09047 .12607 L
.09049 .14198 L
.09052 .15789 L
.09054 .1738 L
.09054 .18971 L
.09061 .20561 L
.09063 .22152 L
.09065 .23743 L
.09067 .25334 L
.09068 .23743 L
.09073 .22152 L
.09075 .23743 L
.09076 .22152 L
.09084 .23743 L
.09085 .22152 L
.09093 .23743 L
.09098 .22152 L
.09101 .23743 L
.09106 .25334 L
.09108 .23743 L
.09109 .22152 L
Mistroke
.09109 .23743 L
.09112 .22152 L
.09112 .23743 L
.09114 .25334 L
.09127 .26925 L
.09128 .28515 L
.09131 .26925 L
.09135 .28515 L
.09138 .26925 L
.09143 .25334 L
.09145 .23743 L
.0915 .22152 L
.09158 .23743 L
.09165 .22152 L
.09166 .20561 L
.09168 .18971 L
.09171 .1738 L
.09177 .15789 L
.0918 .14198 L
.09182 .12607 L
.09187 .11016 L
.09189 .12607 L
.09192 .14198 L
.09196 .12607 L
.09196 .14198 L
.09208 .15789 L
.09223 .14198 L
.09228 .12607 L
.09234 .11016 L
.09239 .12607 L
.09243 .11016 L
.09244 .12607 L
.09246 .11016 L
.09251 .09426 L
.09256 .11016 L
.09258 .12607 L
.09289 .14198 L
.09291 .15789 L
.09293 .14198 L
.09296 .15789 L
.09299 .1738 L
.09305 .18971 L
.0932 .1738 L
.0933 .15789 L
.09331 .1738 L
.09332 .18971 L
.09335 .20561 L
.09336 .22152 L
.09343 .20561 L
.09346 .18971 L
Mistroke
.09347 .1738 L
.0935 .15789 L
.09353 .1738 L
.09358 .18971 L
.0936 .1738 L
.09368 .18971 L
.09374 .20561 L
.09377 .18971 L
.09377 .1738 L
.0938 .18971 L
.09381 .20561 L
.09383 .18971 L
.09384 .20561 L
.09391 .18971 L
.09391 .20561 L
.09395 .22152 L
.09397 .20561 L
.09401 .22152 L
.09402 .23743 L
.09406 .22152 L
.09406 .23743 L
.09409 .25334 L
.09421 .23743 L
.09428 .25334 L
.09437 .23743 L
.09438 .25334 L
.09443 .26925 L
.09444 .25334 L
.09445 .26925 L
.09449 .28515 L
.09456 .26925 L
.09457 .25334 L
.09458 .23743 L
.09461 .22152 L
.09462 .20561 L
.09469 .22152 L
.09475 .20561 L
.09481 .18971 L
.09484 .1738 L
.09484 .18971 L
.09491 .20561 L
.09495 .22152 L
.09501 .23743 L
.09501 .25334 L
.09502 .23743 L
.09503 .25334 L
.09505 .26925 L
.09507 .25334 L
.09507 .23743 L
.09511 .25334 L
Mistroke
.09526 .26925 L
.0953 .25334 L
.0953 .26925 L
.09532 .25334 L
.09535 .26925 L
.09541 .28515 L
.09545 .26925 L
.09546 .25334 L
.0955 .26925 L
.09552 .25334 L
.09553 .23743 L
.09562 .22152 L
.09571 .20561 L
.09575 .18971 L
.09578 .20561 L
.09581 .22152 L
.09587 .20561 L
.09587 .22152 L
.0959 .23743 L
.09594 .25334 L
.09594 .26925 L
.09612 .28515 L
.09615 .30106 L
.09616 .28515 L
.09622 .30106 L
.09628 .28515 L
.09628 .26925 L
.09633 .25334 L
.09636 .23743 L
.09639 .22152 L
.0964 .23743 L
.0964 .25334 L
.09643 .26925 L
.09644 .28515 L
.09654 .26925 L
.09656 .25334 L
.09657 .23743 L
.09664 .22152 L
.09676 .20561 L
.09679 .22152 L
.09687 .23743 L
.0969 .22152 L
.097 .23743 L
.09703 .25334 L
.09703 .23743 L
.09704 .22152 L
.09714 .23743 L
.09715 .22152 L
.09718 .23743 L
.09724 .25334 L
Mistroke
.09724 .23743 L
.09729 .22152 L
.09733 .20561 L
.09742 .18971 L
.09743 .1738 L
.09743 .18971 L
.09749 .1738 L
.09751 .18971 L
.09757 .1738 L
.09769 .15789 L
.0977 .1738 L
.09774 .18971 L
.09783 .1738 L
.09788 .18971 L
.09793 .20561 L
.09795 .22152 L
.09804 .23743 L
.09804 .25334 L
.09814 .23743 L
.09824 .22152 L
.09826 .23743 L
.09827 .22152 L
.09827 .20561 L
.09836 .22152 L
.09841 .20561 L
.09842 .22152 L
.09852 .20561 L
.09854 .18971 L
.09856 .20561 L
.09861 .18971 L
.0987 .1738 L
.09877 .18971 L
.09895 .1738 L
.09901 .18971 L
.09909 .20561 L
.09911 .22152 L
.09913 .23743 L
.09918 .22152 L
.09919 .20561 L
.09936 .22152 L
.09945 .23743 L
.09946 .22152 L
.09951 .20561 L
.09962 .18971 L
.09966 .1738 L
.09968 .18971 L
.09979 .20561 L
.09982 .22152 L
.09984 .23743 L
.09989 .22152 L
Mistroke
.09991 .23743 L
.09994 .25334 L
.09998 .23743 L
.10002 .25334 L
.10011 .23743 L
.10011 .22152 L
.10012 .20561 L
.10013 .18971 L
.10015 .1738 L
.10017 .18971 L
.10022 .20561 L
.1003 .22152 L
.10037 .23743 L
.10047 .22152 L
.10049 .20561 L
.10056 .18971 L
.10062 .1738 L
.10064 .15789 L
.10072 .14198 L
.10072 .15789 L
.10079 .14198 L
.10081 .15789 L
.10084 .1738 L
.10088 .18971 L
.10089 .20561 L
.10093 .18971 L
.10099 .1738 L
.10107 .18971 L
.10109 .1738 L
.10114 .15789 L
.10119 .1738 L
.1012 .15789 L
.10123 .1738 L
.10125 .15789 L
.10127 .14198 L
.10146 .12607 L
.10151 .14198 L
.1016 .12607 L
.1017 .11016 L
.1017 .12607 L
.10172 .11016 L
.10173 .09426 L
.10174 .11016 L
.10177 .09426 L
.10179 .11016 L
.10183 .12607 L
.10185 .11016 L
.10197 .12607 L
.10197 .11016 L
.10198 .12607 L
Mistroke
.10198 .11016 L
.10201 .09426 L
.10203 .11016 L
.10203 .12607 L
.10211 .14198 L
.10212 .12607 L
.10215 .14198 L
.10218 .15789 L
.10223 .1738 L
.10227 .18971 L
.10227 .20561 L
.10228 .22152 L
.10237 .23743 L
.10238 .22152 L
.1024 .23743 L
.10247 .25334 L
.10255 .23743 L
.10257 .22152 L
.10258 .20561 L
.10266 .22152 L
.10272 .23743 L
.10276 .25334 L
.10277 .26925 L
.10277 .28515 L
.10283 .26925 L
.10284 .25334 L
.10289 .26925 L
.1029 .25334 L
.10296 .23743 L
.103 .25334 L
.10309 .23743 L
.10311 .25334 L
.10312 .23743 L
.10319 .22152 L
.10321 .23743 L
.10321 .25334 L
.10326 .26925 L
.10326 .25334 L
.10333 .26925 L
.10334 .25334 L
.1034 .26925 L
.10341 .28515 L
.10343 .30106 L
.10345 .28515 L
.1035 .26925 L
.10356 .25334 L
.10362 .23743 L
.10368 .22152 L
.1039 .23743 L
.10392 .25334 L
Mistroke
.10395 .26925 L
.10396 .25334 L
.104 .26925 L
.1041 .28515 L
.10424 .30106 L
.10432 .31697 L
.10434 .30106 L
.10436 .28515 L
.10436 .30106 L
.10437 .31697 L
.10446 .30106 L
.10455 .31697 L
.10455 .30106 L
.10456 .28515 L
.10456 .26925 L
.10461 .25334 L
.10469 .23743 L
.10486 .22152 L
.10486 .23743 L
.10487 .22152 L
.10491 .20561 L
.10493 .18971 L
.10496 .20561 L
.10497 .18971 L
.10497 .1738 L
.10508 .15789 L
.10512 .14198 L
.1052 .12607 L
.10523 .11016 L
.10525 .09426 L
.1053 .11016 L
.10534 .09426 L
.10537 .11016 L
.10538 .09426 L
.10544 .07835 L
.10548 .09426 L
.10549 .11016 L
.10549 .12607 L
.10553 .14198 L
.10559 .15789 L
.1059 .1738 L
.10593 .15789 L
.10595 .1738 L
.10596 .15789 L
.10596 .1738 L
.10602 .18971 L
.10604 .1738 L
.10607 .15789 L
.10608 .1738 L
.10614 .18971 L
Mistroke
.10627 .1738 L
.10641 .18971 L
.10654 .1738 L
.10656 .18971 L
.10656 .1738 L
.10666 .15789 L
.10667 .14198 L
.10667 .12607 L
.10674 .14198 L
.10677 .12607 L
.10683 .11016 L
.10687 .12607 L
.10694 .11016 L
.10694 .12607 L
.10696 .11016 L
.10697 .09426 L
.10697 .11016 L
.10705 .12607 L
.10718 .11016 L
.1072 .09426 L
.10725 .11016 L
.10731 .12607 L
.10736 .14198 L
.1075 .12607 L
.1077 .14198 L
.1077 .12607 L
.10773 .11016 L
.10789 .09426 L
.10792 .07835 L
.10794 .06244 L
.10802 .07835 L
.10802 .09426 L
.10804 .11016 L
.10806 .12607 L
.10806 .11016 L
.10811 .12607 L
.10811 .11016 L
.10818 .09426 L
.10821 .11016 L
.10822 .09426 L
.10823 .11016 L
.10824 .12607 L
.10827 .14198 L
.1083 .12607 L
.10832 .11016 L
.10838 .12607 L
.10841 .11016 L
.10844 .09426 L
.10847 .07835 L
.10852 .06244 L
Mistroke
.10853 .04653 L
.10853 .06244 L
.10855 .04653 L
.10859 .03062 L
.10865 .04653 L
.10873 .03062 L
.10882 .04653 L
.10887 .03062 L
.10892 .01472 L
.10893 .03062 L
.10895 .01472 L
.10904 .03062 L
.10907 .01472 L
.10911 .03062 L
.10913 .04653 L
.10917 .03062 L
.1093 .04653 L
.10931 .06244 L
.10943 .07835 L
.10949 .06244 L
.10951 .04653 L
.10957 .03062 L
.10959 .01472 L
.10964 .03062 L
.10965 .04653 L
.10966 .06244 L
.10967 .04653 L
.10969 .06244 L
.10972 .07835 L
.10981 .09426 L
.10981 .07835 L
.10986 .06244 L
.10987 .04653 L
.10987 .03062 L
.10989 .04653 L
.1099 .06244 L
.10994 .07835 L
.10997 .09426 L
.10999 .11016 L
.11003 .09426 L
.11008 .11016 L
.11011 .12607 L
.11015 .11016 L
.11018 .09426 L
.11019 .11016 L
.11021 .12607 L
.11024 .14198 L
.11032 .12607 L
.11033 .11016 L
.11036 .09426 L
Mistroke
.11036 .07835 L
.11052 .09426 L
.11062 .11016 L
.11067 .12607 L
.11071 .11016 L
.11072 .09426 L
.11074 .11016 L
.11075 .12607 L
.11077 .14198 L
.11079 .12607 L
.11081 .11016 L
.11087 .09426 L
.11091 .07835 L
.11096 .09426 L
.11102 .07835 L
.11103 .06244 L
.11106 .07835 L
.11114 .09426 L
.11115 .11016 L
.11119 .12607 L
.11128 .11016 L
.11136 .12607 L
.11141 .14198 L
.11143 .15789 L
.11143 .1738 L
.11149 .15789 L
.11152 .1738 L
.11152 .18971 L
.11157 .20561 L
.11158 .22152 L
.11159 .20561 L
.1117 .22152 L
.11178 .23743 L
.1118 .22152 L
.11187 .23743 L
.11189 .25334 L
.11191 .23743 L
.11202 .22152 L
.11203 .20561 L
.11204 .22152 L
.1121 .20561 L
.1122 .18971 L
.1122 .20561 L
.11221 .18971 L
.11229 .20561 L
.11243 .22152 L
.11243 .23743 L
.11246 .22152 L
.11247 .20561 L
.11256 .22152 L
Mistroke
.11266 .23743 L
.11274 .25334 L
.11299 .23743 L
.11301 .25334 L
.11301 .23743 L
.11301 .25334 L
.11304 .23743 L
.11305 .25334 L
.11307 .23743 L
.11315 .22152 L
.11319 .23743 L
.11322 .22152 L
.11327 .20561 L
.11327 .22152 L
.11328 .20561 L
.11339 .18971 L
.1136 .1738 L
.11364 .18971 L
.11373 .1738 L
.11386 .15789 L
.11389 .1738 L
.11391 .18971 L
.114 .1738 L
.11407 .15789 L
.11413 .14198 L
.11415 .15789 L
.11416 .14198 L
.11421 .15789 L
.11424 .1738 L
.11435 .15789 L
.11444 .1738 L
.11445 .15789 L
.11448 .1738 L
.11451 .15789 L
.11459 .14198 L
.11467 .15789 L
.11467 .1738 L
.11468 .18971 L
.11472 .1738 L
.11474 .18971 L
.11475 .20561 L
.11482 .22152 L
.11482 .20561 L
.11502 .22152 L
.11511 .23743 L
.11514 .22152 L
.11516 .23743 L
.1152 .25334 L
.11527 .26925 L
.11527 .28515 L
Mistroke
.11536 .26925 L
.11537 .28515 L
.11538 .26925 L
.11541 .25334 L
.11552 .23743 L
.11552 .22152 L
.11567 .20561 L
.11571 .18971 L
.11574 .1738 L
.11583 .18971 L
.11586 .1738 L
.11591 .18971 L
.11593 .1738 L
.11594 .15789 L
.11598 .1738 L
.11601 .15789 L
.11602 .14198 L
.11605 .15789 L
.11607 .14198 L
.1162 .12607 L
.1163 .11016 L
.11641 .09426 L
.11642 .11016 L
.11652 .12607 L
.11656 .14198 L
.11658 .15789 L
.11659 .1738 L
.11661 .15789 L
.11664 .14198 L
.1167 .15789 L
.1167 .1738 L
.11671 .18971 L
.11671 .20561 L
.11672 .18971 L
.11677 .20561 L
.11679 .18971 L
.1168 .1738 L
.11683 .18971 L
.11686 .1738 L
.11691 .15789 L
.11696 .14198 L
.11696 .12607 L
.11706 .11016 L
.11709 .09426 L
.11715 .11016 L
.11722 .12607 L
.11726 .14198 L
.11727 .15789 L
.11728 .1738 L
.1173 .18971 L
Mistroke
.11735 .20561 L
.11736 .22152 L
.11736 .20561 L
.11741 .22152 L
.11741 .20561 L
.11742 .22152 L
.11749 .20561 L
.11764 .22152 L
.11764 .20561 L
.11765 .18971 L
.11774 .20561 L
.11779 .18971 L
.11785 .1738 L
.11789 .15789 L
.1179 .14198 L
.11794 .12607 L
.11798 .11016 L
.11799 .09426 L
.118 .11016 L
.11802 .12607 L
.11804 .11016 L
.1181 .12607 L
.11813 .11016 L
.11828 .09426 L
.11844 .07835 L
.11844 .09426 L
.1185 .11016 L
.11857 .09426 L
.11857 .07835 L
.1186 .06244 L
.11867 .07835 L
.11868 .09426 L
.11869 .07835 L
.11871 .06244 L
.11873 .04653 L
.11879 .06244 L
.1189 .04653 L
.11891 .06244 L
.11892 .04653 L
.11897 .03062 L
.11899 .04653 L
.11903 .03062 L
.11911 .01472 L
.11915 .03062 L
.11924 .01472 L
.11941 .03062 L
.11958 .01472 L
.11961 .03062 L
.11969 .01472 L
.11977 .03062 L
Mistroke
.1198 .04653 L
.11984 .03062 L
.11997 .04653 L
.12012 .06244 L
.12012 .07835 L
.12024 .09426 L
.12027 .07835 L
.12028 .09426 L
.1203 .07835 L
.12041 .06244 L
.12047 .04653 L
.12054 .03062 L
.12054 .01472 L
.12083 .03062 L
.12084 .01472 L
.12097 .03062 L
.12099 .04653 L
.12101 .03062 L
.12105 .01472 L
.12115 .03062 L
.12118 .04653 L
.12118 .06244 L
.12119 .07835 L
.1212 .09426 L
.12122 .07835 L
.12123 .09426 L
.12125 .11016 L
.12132 .12607 L
.12134 .11016 L
.12149 .12607 L
.12157 .14198 L
.12157 .15789 L
.12162 .1738 L
.12164 .18971 L
.12165 .20561 L
.12168 .22152 L
.12178 .20561 L
.12191 .18971 L
.122 .1738 L
.122 .15789 L
.12202 .14198 L
.12208 .12607 L
.1221 .11016 L
.12214 .09426 L
.12227 .07835 L
.12227 .06244 L
.12229 .04653 L
.12232 .03062 L
.12234 .01472 L
.1224 .03062 L
Mistroke
.12241 .04653 L
.12245 .03062 L
.12252 .01472 L
.12253 .03062 L
.12258 .01472 L
.1228 .03062 L
.12282 .04653 L
.12284 .06244 L
.12284 .04653 L
.12293 .06244 L
.12294 .07835 L
.12297 .09426 L
.12312 .11016 L
.12313 .09426 L
.12315 .11016 L
.12315 .09426 L
.12322 .07835 L
.12322 .09426 L
.12325 .11016 L
.12326 .09426 L
.1233 .11016 L
.12332 .09426 L
.12334 .07835 L
.12337 .09426 L
.12337 .07835 L
.12344 .09426 L
.12347 .11016 L
.12352 .12607 L
.12362 .14198 L
.12366 .15789 L
.12371 .1738 L
.12372 .15789 L
.12378 .1738 L
.1238 .18971 L
.1238 .20561 L
.12386 .18971 L
.12391 .1738 L
.12394 .15789 L
.12395 .14198 L
.124 .12607 L
.12403 .14198 L
.12411 .15789 L
.12416 .1738 L
.12416 .18971 L
.12418 .20561 L
.12424 .18971 L
.12428 .20561 L
.12434 .22152 L
.12437 .23743 L
.12438 .25334 L
Mistroke
.12439 .23743 L
.12446 .22152 L
.12449 .20561 L
.12451 .22152 L
.12453 .20561 L
.12453 .18971 L
.12457 .1738 L
.1246 .15789 L
.12477 .1738 L
.12481 .15789 L
.1249 .1738 L
.1249 .18971 L
.12492 .20561 L
.125 .22152 L
.12501 .20561 L
.12502 .22152 L
.12508 .23743 L
.12514 .25334 L
.12514 .26925 L
.12516 .25334 L
.12516 .26925 L
.12522 .25334 L
.1254 .23743 L
.12545 .25334 L
.1255 .23743 L
.1255 .25334 L
.1255 .26925 L
.12554 .25334 L
.12558 .23743 L
.12558 .22152 L
.12561 .20561 L
.12561 .22152 L
.1257 .20561 L
.1257 .18971 L
.12582 .1738 L
.12583 .15789 L
.12604 .14198 L
.12611 .15789 L
.12613 .14198 L
.12614 .12607 L
.12618 .14198 L
.12622 .15789 L
.12627 .1738 L
.12643 .15789 L
.12649 .1738 L
.12654 .15789 L
.12662 .14198 L
.12672 .12607 L
.12673 .14198 L
.12675 .12607 L
Mistroke
.12675 .11016 L
.12678 .09426 L
.12681 .07835 L
.12681 .06244 L
.12686 .04653 L
.12691 .03062 L
.12692 .04653 L
.12695 .03062 L
.127 .01472 L
.12705 .03062 L
.12715 .01472 L
.12729 .03062 L
.12733 .04653 L
.12744 .03062 L
.12754 .04653 L
.12765 .06244 L
.12779 .04653 L
.12786 .03062 L
.12786 .04653 L
.12788 .06244 L
.12795 .07835 L
.12808 .06244 L
.12809 .07835 L
.12812 .06244 L
.12818 .07835 L
.1282 .06244 L
.12822 .04653 L
.12824 .03062 L
.12837 .04653 L
.12842 .03062 L
.1285 .04653 L
.12851 .06244 L
.12856 .04653 L
.12861 .03062 L
.12862 .01472 L
.12868 .03062 L
.12876 .01472 L
.12881 .03062 L
.12882 .01472 L
.12908 .03062 L
.12909 .01472 L
.12909 .03062 L
.1291 .04653 L
.12911 .03062 L
.12922 .01472 L
.12933 .03062 L
.12941 .04653 L
.12942 .03062 L
.12942 .04653 L
.12946 .03062 L
Mistroke
.12951 .01472 L
.12966 .03062 L
.12969 .04653 L
.12971 .06244 L
.12973 .04653 L
.12973 .06244 L
.12977 .07835 L
.12981 .06244 L
.12982 .07835 L
.12982 .06244 L
.12987 .07835 L
.12989 .06244 L
.12991 .07835 L
.12995 .06244 L
.12995 .07835 L
.12999 .06244 L
.13001 .07835 L
.13005 .06244 L
.13006 .04653 L
.13017 .06244 L
.1302 .04653 L
.13021 .06244 L
.13027 .04653 L
.13031 .03062 L
.13032 .01472 L
.13042 .03062 L
.13042 .04653 L
.13055 .06244 L
.13058 .04653 L
.13063 .03062 L
.13071 .04653 L
.13074 .03062 L
.13076 .04653 L
.1308 .06244 L
.13081 .07835 L
.13081 .09426 L
.13091 .11016 L
.13098 .09426 L
.13099 .11016 L
.131 .09426 L
.13107 .07835 L
.13117 .09426 L
.13118 .07835 L
.13119 .09426 L
.13122 .07835 L
.13142 .06244 L
.13149 .07835 L
.13151 .09426 L
.13154 .11016 L
.13159 .12607 L
Mistroke
.13162 .11016 L
.13168 .09426 L
.13176 .11016 L
.13176 .12607 L
.13183 .11016 L
.13192 .09426 L
.13192 .11016 L
.13193 .12607 L
.13194 .14198 L
.13196 .12607 L
.132 .14198 L
.13204 .15789 L
.13206 .1738 L
.13211 .18971 L
.13225 .1738 L
.1323 .15789 L
.13243 .14198 L
.1325 .15789 L
.13251 .1738 L
.13259 .15789 L
.13259 .1738 L
.1326 .15789 L
.13263 .1738 L
.13264 .15789 L
.13266 .14198 L
.1327 .15789 L
.13273 .14198 L
.13277 .15789 L
.13282 .14198 L
.13283 .15789 L
.13287 .1738 L
.13288 .18971 L
.13288 .20561 L
.13293 .18971 L
.13305 .20561 L
.13314 .22152 L
.13329 .20561 L
.13332 .22152 L
.13333 .20561 L
.13333 .18971 L
.13339 .20561 L
.13342 .22152 L
.13344 .23743 L
.13357 .25334 L
.13357 .23743 L
.13359 .22152 L
.1336 .20561 L
.13362 .18971 L
.13369 .20561 L
.13371 .18971 L
Mistroke
.13371 .20561 L
.13376 .22152 L
.13378 .23743 L
.13383 .25334 L
.13387 .26925 L
.13401 .28515 L
.13406 .26925 L
.13407 .28515 L
.13408 .26925 L
.1341 .28515 L
.13411 .26925 L
.13412 .28515 L
.13413 .30106 L
.13416 .28515 L
.13419 .30106 L
.13419 .28515 L
.1342 .26925 L
.13423 .28515 L
.13423 .26925 L
.13424 .25334 L
.13425 .23743 L
.13425 .22152 L
.13426 .23743 L
.13445 .22152 L
.13449 .20561 L
.13451 .22152 L
.13452 .23743 L
.13459 .25334 L
.13471 .23743 L
.13472 .25334 L
.13473 .23743 L
.13481 .22152 L
.13486 .23743 L
.13489 .25334 L
.13495 .26925 L
.13496 .25334 L
.13496 .26925 L
.13499 .25334 L
.13501 .26925 L
.1351 .28515 L
.13511 .26925 L
.13511 .28515 L
.13515 .30106 L
.13516 .31697 L
.13519 .33288 L
.13529 .34879 L
.13535 .3647 L
.13538 .34879 L
.13547 .33288 L
.13557 .34879 L
Mistroke
.13559 .3647 L
.13564 .3806 L
.13565 .39651 L
.13566 .3806 L
.13573 .3647 L
.136 .3806 L
.13607 .39651 L
.1362 .3806 L
.13622 .3647 L
.13622 .34879 L
.13627 .3647 L
.13629 .3806 L
.13641 .39651 L
.13648 .3806 L
.13654 .3647 L
.13655 .34879 L
.13657 .33288 L
.13661 .31697 L
.13663 .30106 L
.13672 .31697 L
.13672 .33288 L
.13675 .31697 L
.13679 .33288 L
.13679 .31697 L
.1368 .33288 L
.13681 .31697 L
.13683 .33288 L
.13685 .31697 L
.13697 .33288 L
.13699 .34879 L
.13714 .3647 L
.13719 .34879 L
.13722 .33288 L
.13722 .31697 L
.13723 .33288 L
.13736 .31697 L
.13746 .33288 L
.13751 .34879 L
.13753 .3647 L
.13757 .34879 L
.13759 .3647 L
.1376 .3806 L
.13765 .3647 L
.13771 .34879 L
.13775 .33288 L
.13788 .31697 L
.13797 .33288 L
.13819 .31697 L
.13828 .30106 L
.1383 .31697 L
Mistroke
.13836 .30106 L
.13841 .31697 L
.13843 .33288 L
.13844 .31697 L
.13848 .30106 L
.13851 .31697 L
.13856 .30106 L
.13856 .31697 L
.13862 .30106 L
.13872 .28515 L
.13881 .30106 L
.13888 .31697 L
.13894 .30106 L
.13894 .31697 L
.13895 .30106 L
.13898 .31697 L
.13898 .33288 L
.139 .34879 L
.13901 .3647 L
.13903 .34879 L
.13903 .3647 L
.13907 .34879 L
.13907 .3647 L
.13915 .34879 L
.13927 .33288 L
.13927 .31697 L
.13928 .30106 L
.13938 .28515 L
.13945 .26925 L
.13946 .25334 L
.13961 .23743 L
.13964 .22152 L
.13972 .23743 L
.13973 .22152 L
.13983 .20561 L
.13986 .18971 L
.13987 .1738 L
.13989 .18971 L
.13994 .1738 L
.13994 .15789 L
.13997 .1738 L
.13999 .15789 L
.14003 .14198 L
.14019 .15789 L
.1402 .1738 L
.14023 .15789 L
.14024 .1738 L
.14025 .15789 L
.14025 .14198 L
.14038 .15789 L
Mistroke
.14042 .1738 L
.14049 .15789 L
.14051 .1738 L
.14053 .15789 L
.14054 .1738 L
.14056 .15789 L
.14057 .14198 L
.14059 .12607 L
.14059 .14198 L
.14066 .12607 L
.14067 .11016 L
.14069 .09426 L
.14081 .11016 L
.14081 .09426 L
.14084 .07835 L
.14086 .09426 L
.14086 .11016 L
.1409 .09426 L
.14092 .07835 L
.141 .06244 L
.14102 .07835 L
.14104 .09426 L
.14114 .07835 L
.14117 .09426 L
.14118 .07835 L
.14127 .06244 L
.14129 .04653 L
.14129 .03062 L
.1413 .01472 L
.14132 .03062 L
.14153 .01472 L
.14164 .03062 L
.14167 .01472 L
.14169 .03062 L
.14174 .04653 L
.14175 .06244 L
.14178 .04653 L
.14191 .03062 L
.14196 .01472 L
.14209 .03062 L
.1421 .01472 L
.14212 .03062 L
.1422 .04653 L
.14222 .03062 L
.14222 .04653 L
.14235 .03062 L
.14235 .01472 L
.14236 .03062 L
.14236 .04653 L
.14236 .06244 L
Mistroke
.14239 .07835 L
.14239 .09426 L
.14244 .07835 L
.14254 .09426 L
.14266 .11016 L
.14266 .09426 L
.14273 .07835 L
.14273 .06244 L
.14275 .07835 L
.14276 .06244 L
.1428 .04653 L
.14285 .03062 L
.14287 .04653 L
.14291 .06244 L
.14292 .07835 L
.14294 .09426 L
.14299 .11016 L
.143 .12607 L
.14304 .14198 L
.14306 .12607 L
.14309 .11016 L
.14312 .09426 L
.14318 .07835 L
.14321 .06244 L
.14325 .07835 L
.14328 .09426 L
.14329 .11016 L
.14338 .12607 L
.14343 .11016 L
.14344 .12607 L
.14346 .11016 L
.1435 .09426 L
.14353 .07835 L
.14354 .06244 L
.14366 .07835 L
.14367 .09426 L
.1438 .11016 L
.14381 .09426 L
.14389 .07835 L
.1439 .06244 L
.14392 .04653 L
.14407 .03062 L
.14418 .01472 L
.1442 .03062 L
.14424 .04653 L
.14427 .03062 L
.14441 .01472 L
.14443 .03062 L
.14446 .01472 L
.14495 .03062 L
Mistroke
.145 .01472 L
.14532 .03062 L
.14543 .04653 L
.14561 .03062 L
.14564 .04653 L
.14564 .03062 L
.14564 .01472 L
.14564 .03062 L
.14569 .04653 L
.14571 .06244 L
.14574 .07835 L
.14575 .06244 L
.1458 .07835 L
.14583 .09426 L
.14584 .11016 L
.14589 .12607 L
.1459 .14198 L
.14596 .15789 L
.146 .1738 L
.14603 .15789 L
.14609 .1738 L
.14609 .15789 L
.1461 .14198 L
.14612 .15789 L
.14614 .1738 L
.14615 .18971 L
.14621 .1738 L
.14628 .15789 L
.14634 .1738 L
.14646 .18971 L
.14649 .1738 L
.14652 .15789 L
.14654 .1738 L
.14657 .15789 L
.14661 .14198 L
.14662 .12607 L
.14664 .14198 L
.14665 .12607 L
.14666 .14198 L
.1467 .12607 L
.14673 .11016 L
.14674 .12607 L
.14684 .14198 L
.14686 .15789 L
.14687 .1738 L
.14699 .15789 L
.14701 .14198 L
.14703 .12607 L
.14708 .14198 L
.14712 .12607 L
Mistroke
.14716 .11016 L
.1472 .09426 L
.14734 .11016 L
.14736 .09426 L
.14736 .07835 L
.14747 .09426 L
.14748 .07835 L
.14748 .09426 L
.14748 .11016 L
.14755 .12607 L
.14759 .11016 L
.1476 .12607 L
.14763 .11016 L
.14764 .12607 L
.14767 .11016 L
.14771 .09426 L
.14773 .07835 L
.14774 .06244 L
.1478 .07835 L
.1478 .06244 L
.14792 .07835 L
.14796 .06244 L
.14797 .04653 L
.14801 .06244 L
.1481 .07835 L
.14822 .09426 L
.1483 .07835 L
.14831 .06244 L
.14833 .07835 L
.14834 .06244 L
.14838 .04653 L
.14861 .03062 L
.14861 .01472 L
.14868 .03062 L
.14875 .01472 L
.14877 .03062 L
.14893 .01472 L
.14903 .03062 L
.14904 .04653 L
.14908 .03062 L
.14911 .01472 L
.14912 .03062 L
.14919 .01472 L
.14925 .03062 L
.14926 .01472 L
.14937 .03062 L
.14938 .04653 L
.14939 .06244 L
.14944 .07835 L
.14945 .06244 L
Mistroke
.14949 .07835 L
.14961 .09426 L
.14967 .11016 L
.14968 .12607 L
.14974 .14198 L
.15005 .12607 L
.15009 .11016 L
.15017 .09426 L
.15022 .07835 L
.15029 .09426 L
.15029 .07835 L
.15047 .06244 L
.15056 .07835 L
.15058 .09426 L
.1506 .07835 L
.15061 .09426 L
.15063 .11016 L
.15064 .12607 L
.15065 .11016 L
.15071 .09426 L
.15079 .11016 L
.1509 .09426 L
.1509 .11016 L
.15091 .12607 L
.15093 .11016 L
.15094 .12607 L
.15096 .11016 L
.151 .09426 L
.1512 .11016 L
.15123 .09426 L
.15135 .07835 L
.15136 .09426 L
.15141 .07835 L
.15142 .06244 L
.15151 .04653 L
.15155 .03062 L
.15157 .01472 L
.15162 .03062 L
.15182 .04653 L
.15183 .03062 L
.15186 .01472 L
.15193 .03062 L
.152 .01472 L
.15203 .03062 L
.15203 .01472 L
.15209 .03062 L
.15212 .01472 L
.15217 .03062 L
.15218 .01472 L
.15229 .03062 L
Mistroke
.15234 .01472 L
.15247 .03062 L
.15254 .01472 L
.15257 .03062 L
.15261 .01472 L
.15265 .03062 L
.15277 .04653 L
.15287 .03062 L
.1529 .04653 L
.15304 .06244 L
.15315 .04653 L
.15324 .06244 L
.15325 .07835 L
.15327 .09426 L
.15328 .07835 L
.15328 .06244 L
.15334 .04653 L
.15336 .06244 L
.15339 .04653 L
.15345 .03062 L
.15346 .04653 L
.15348 .03062 L
.15352 .01472 L
.15369 .03062 L
.15383 .01472 L
.15384 .03062 L
.15387 .04653 L
.1539 .06244 L
.15398 .07835 L
.154 .06244 L
.15404 .07835 L
.15405 .06244 L
.15419 .07835 L
.15426 .06244 L
.15428 .07835 L
.15432 .06244 L
.15434 .04653 L
.15439 .03062 L
.1544 .04653 L
.15444 .06244 L
.15446 .07835 L
.15449 .06244 L
.15458 .07835 L
.1546 .09426 L
.15474 .07835 L
.15476 .06244 L
.15486 .04653 L
.15488 .06244 L
.15501 .04653 L
.15512 .06244 L
Mistroke
.15519 .04653 L
.15524 .06244 L
.15528 .07835 L
.15531 .09426 L
.15538 .11016 L
.15549 .12607 L
.15557 .11016 L
.15562 .09426 L
.15562 .07835 L
.15565 .09426 L
.15568 .11016 L
.1558 .12607 L
.15587 .11016 L
.15588 .12607 L
.15595 .14198 L
.15603 .15789 L
.15609 .14198 L
.15612 .15789 L
.15615 .14198 L
.15617 .12607 L
.15624 .11016 L
.15624 .09426 L
.15632 .11016 L
.15635 .12607 L
.15643 .11016 L
.15644 .12607 L
.15645 .11016 L
.15645 .09426 L
.15647 .07835 L
.15654 .06244 L
.15655 .04653 L
.15656 .06244 L
.15664 .04653 L
.15666 .03062 L
.15667 .01472 L
.15688 .03062 L
.15709 .04653 L
.15719 .06244 L
.15721 .07835 L
.15721 .06244 L
.15722 .07835 L
.15728 .06244 L
.15733 .07835 L
.1574 .09426 L
.15741 .11016 L
.1575 .12607 L
.15762 .11016 L
.15766 .12607 L
.15766 .14198 L
.15767 .15789 L
Mistroke
.15768 .1738 L
.1577 .18971 L
.15771 .1738 L
.15775 .18971 L
.15775 .20561 L
.15778 .22152 L
.15782 .23743 L
.15785 .22152 L
.15794 .23743 L
.15795 .22152 L
.15798 .23743 L
.15799 .25334 L
.15803 .23743 L
.15804 .22152 L
.15805 .23743 L
.15806 .25334 L
.1581 .23743 L
.15811 .25334 L
.15811 .26925 L
.15813 .28515 L
.15815 .26925 L
.15818 .25334 L
.15822 .23743 L
.15822 .25334 L
.15824 .26925 L
.15825 .25334 L
.15829 .26925 L
.15838 .25334 L
.15842 .23743 L
.15843 .25334 L
.15843 .23743 L
.1585 .22152 L
.15853 .23743 L
.15855 .22152 L
.15859 .23743 L
.15868 .25334 L
.15877 .23743 L
.15881 .22152 L
.15886 .20561 L
.15904 .22152 L
.15909 .20561 L
.15911 .18971 L
.15911 .20561 L
.15918 .18971 L
.15919 .20561 L
.15926 .22152 L
.15931 .23743 L
.15933 .22152 L
.15947 .20561 L
.1595 .22152 L
Mistroke
.15952 .20561 L
.15953 .22152 L
.15959 .23743 L
.15962 .22152 L
.15965 .23743 L
.15981 .25334 L
.15981 .26925 L
.15983 .28515 L
.15983 .30106 L
.15987 .28515 L
.15989 .26925 L
.15989 .25334 L
.15995 .26925 L
.16001 .28515 L
.16003 .30106 L
.16003 .28515 L
.16003 .30106 L
.16007 .31697 L
.16011 .30106 L
.16022 .31697 L
.16029 .30106 L
.16034 .28515 L
.16037 .26925 L
.16042 .28515 L
.16045 .30106 L
.16046 .31697 L
.16047 .30106 L
.16049 .31697 L
.16052 .30106 L
.16054 .28515 L
.16066 .30106 L
.16068 .28515 L
.1607 .30106 L
.16071 .28515 L
.16071 .30106 L
.16079 .28515 L
.16081 .26925 L
.16088 .28515 L
.16096 .26925 L
.16104 .25334 L
.16112 .26925 L
.16127 .28515 L
.1613 .26925 L
.16131 .25334 L
.16135 .26925 L
.16135 .28515 L
.16141 .26925 L
.16146 .25334 L
.16147 .26925 L
.16148 .25334 L
Mistroke
.16151 .23743 L
.16155 .22152 L
.16156 .20561 L
.16158 .22152 L
.16168 .23743 L
.16169 .22152 L
.16173 .23743 L
.16183 .22152 L
.16188 .23743 L
.16189 .25334 L
.162 .26925 L
.16203 .28515 L
.16211 .26925 L
.16213 .25334 L
.16213 .23743 L
.16213 .22152 L
.16217 .20561 L
.16217 .22152 L
.16223 .23743 L
.16225 .22152 L
.16225 .23743 L
.16226 .22152 L
.16229 .20561 L
.16232 .22152 L
.16238 .23743 L
.16241 .22152 L
.16244 .20561 L
.16253 .22152 L
.1627 .23743 L
.16273 .22152 L
.16275 .23743 L
.16275 .25334 L
.16278 .26925 L
.16279 .25334 L
.16279 .23743 L
.16282 .25334 L
.16282 .23743 L
.16333 .22152 L
.16335 .20561 L
.16345 .18971 L
.16353 .1738 L
.16354 .18971 L
.1636 .1738 L
.16362 .18971 L
.16363 .1738 L
.16369 .18971 L
.16374 .20561 L
.16374 .22152 L
.16377 .20561 L
.16377 .18971 L
Mistroke
.16392 .1738 L
.16398 .15789 L
.16401 .1738 L
.16403 .18971 L
.16404 .20561 L
.16412 .18971 L
.16415 .1738 L
.1642 .18971 L
.16421 .20561 L
.16428 .22152 L
.16429 .20561 L
.16441 .22152 L
.16448 .23743 L
.16449 .25334 L
.1645 .26925 L
.16462 .28515 L
.16462 .30106 L
.16468 .28515 L
.16469 .26925 L
.16473 .25334 L
.16477 .26925 L
.16481 .25334 L
.16482 .23743 L
.16493 .25334 L
.16497 .23743 L
.16498 .22152 L
.16498 .20561 L
.16504 .22152 L
.16504 .20561 L
.16506 .18971 L
.16509 .1738 L
.16513 .15789 L
.16516 .14198 L
.16519 .12607 L
.16545 .11016 L
.16547 .12607 L
.16553 .11016 L
.16555 .12607 L
.16561 .14198 L
.16574 .12607 L
.16579 .14198 L
.16586 .12607 L
.16604 .11016 L
.16607 .12607 L
.16616 .11016 L
.16619 .12607 L
.1662 .11016 L
.16627 .09426 L
.16628 .07835 L
.16629 .06244 L
Mistroke
.16642 .04653 L
.16644 .06244 L
.16666 .04653 L
.16677 .06244 L
.1668 .04653 L
.16684 .03062 L
.167 .04653 L
.16702 .06244 L
.16703 .07835 L
.16704 .06244 L
.1671 .07835 L
.16711 .09426 L
.16712 .07835 L
.16712 .06244 L
.16727 .04653 L
.16733 .06244 L
.16736 .04653 L
.16739 .03062 L
.16743 .04653 L
.16743 .06244 L
.16747 .04653 L
.16748 .03062 L
.16755 .04653 L
.16759 .06244 L
.16763 .04653 L
.16764 .03062 L
.16765 .01472 L
.16774 .03062 L
.16779 .04653 L
.1679 .03062 L
.16791 .01472 L
.16798 .03062 L
.168 .04653 L
.16801 .03062 L
.16802 .01472 L
.16814 .03062 L
.16819 .01472 L
.16826 .03062 L
.1683 .01472 L
.16835 .03062 L
.16837 .01472 L
.16851 .03062 L
.16865 .01472 L
.16882 .03062 L
.16883 .01472 L
.16896 .03062 L
.16899 .04653 L
.16904 .06244 L
.1691 .07835 L
.1691 .09426 L
Mistroke
.16919 .11016 L
.16932 .09426 L
.16937 .11016 L
.16953 .09426 L
.16954 .11016 L
.16956 .12607 L
.16958 .14198 L
.16962 .15789 L
.16964 .1738 L
.16973 .18971 L
.16985 .1738 L
.16985 .15789 L
.17003 .14198 L
.17014 .15789 L
.17015 .1738 L
.17017 .15789 L
.17023 .1738 L
.17024 .18971 L
.17031 .1738 L
.17034 .15789 L
.17039 .14198 L
.1704 .12607 L
.17048 .11016 L
.17048 .09426 L
.17053 .11016 L
.17055 .12607 L
.17056 .11016 L
.17057 .12607 L
.17057 .14198 L
.17058 .12607 L
.17066 .11016 L
.17067 .09426 L
.1708 .07835 L
.17083 .06244 L
.17083 .07835 L
.17096 .09426 L
.17107 .11016 L
.17109 .12607 L
.17109 .11016 L
.17121 .12607 L
.17146 .11016 L
.17153 .09426 L
.17163 .11016 L
.17165 .12607 L
.17168 .11016 L
.17186 .12607 L
.17189 .14198 L
.17198 .12607 L
.17199 .14198 L
.172 .15789 L
Mistroke
.17208 .1738 L
.17209 .18971 L
.1721 .1738 L
.17214 .15789 L
.17222 .14198 L
.17227 .15789 L
.17233 .1738 L
.17233 .15789 L
.17239 .14198 L
.17244 .15789 L
.17257 .1738 L
.17269 .18971 L
.17276 .1738 L
.17277 .18971 L
.17278 .1738 L
.17278 .15789 L
.1728 .14198 L
.17285 .12607 L
.17289 .11016 L
.17293 .12607 L
.17295 .11016 L
.17297 .12607 L
.17299 .14198 L
.17302 .15789 L
.17303 .14198 L
.17304 .12607 L
.1731 .14198 L
.17311 .15789 L
.17324 .1738 L
.17333 .18971 L
.17334 .20561 L
.17342 .18971 L
.17347 .1738 L
.17353 .18971 L
.17353 .1738 L
.17357 .18971 L
.17358 .1738 L
.1736 .18971 L
.17362 .1738 L
.17366 .15789 L
.17368 .1738 L
.17368 .15789 L
.17389 .14198 L
.17395 .15789 L
.17399 .1738 L
.17404 .15789 L
.17408 .14198 L
.1741 .15789 L
.17411 .14198 L
.17413 .12607 L
Mistroke
.17416 .11016 L
.17425 .12607 L
.17431 .11016 L
.17434 .12607 L
.17434 .14198 L
.17435 .15789 L
.17443 .14198 L
.17448 .12607 L
.17452 .11016 L
.17467 .12607 L
.17469 .14198 L
.17478 .15789 L
.17496 .1738 L
.17497 .18971 L
.17506 .1738 L
.17509 .15789 L
.1751 .14198 L
.17514 .12607 L
.17521 .14198 L
.17525 .12607 L
.17526 .11016 L
.17531 .09426 L
.17532 .11016 L
.17534 .12607 L
.1755 .11016 L
.17557 .12607 L
.17558 .11016 L
.1756 .09426 L
.17562 .07835 L
.17566 .09426 L
.17572 .07835 L
.17575 .06244 L
.1758 .04653 L
.17582 .03062 L
.17582 .01472 L
.17586 .03062 L
.17591 .01472 L
.17595 .03062 L
.17615 .01472 L
.17618 .03062 L
.17618 .01472 L
.17623 .03062 L
.17624 .01472 L
.17627 .03062 L
.17631 .01472 L
.17635 .03062 L
.17638 .04653 L
.17649 .06244 L
.17656 .07835 L
.17657 .06244 L
Mistroke
.17658 .04653 L
.1766 .03062 L
.17662 .04653 L
.17671 .06244 L
.17676 .04653 L
.17688 .03062 L
.17689 .04653 L
.17698 .03062 L
.17703 .04653 L
.17706 .06244 L
.17709 .04653 L
.17711 .03062 L
.17724 .04653 L
.17725 .03062 L
.17727 .01472 L
.17739 .03062 L
.17746 .04653 L
.17748 .06244 L
.17751 .04653 L
.17752 .06244 L
.17759 .07835 L
.17768 .06244 L
.17773 .07835 L
.17774 .09426 L
.17775 .11016 L
.17778 .12607 L
.17782 .14198 L
.17784 .12607 L
.17797 .11016 L
.17805 .09426 L
.17818 .11016 L
.17825 .12607 L
.17826 .11016 L
.17827 .12607 L
.17844 .11016 L
.17846 .09426 L
.17848 .07835 L
.17864 .09426 L
.17891 .07835 L
.17895 .06244 L
.17903 .07835 L
.17908 .06244 L
.17914 .07835 L
.17916 .06244 L
.1792 .07835 L
.17937 .06244 L
.17941 .07835 L
.17946 .09426 L
.1795 .07835 L
.17952 .06244 L
Mistroke
.17953 .04653 L
.17956 .03062 L
.17958 .01472 L
.17959 .03062 L
.1796 .01472 L
.17961 .03062 L
.17962 .01472 L
.17966 .03062 L
.17966 .01472 L
.17967 .03062 L
.17978 .01472 L
.17986 .03062 L
.17989 .01472 L
.18056 .03062 L
.18057 .01472 L
.18076 .03062 L
.18076 .04653 L
.18078 .06244 L
.1808 .04653 L
.18083 .03062 L
.18085 .01472 L
.18086 .03062 L
.18087 .01472 L
.1809 .03062 L
.18092 .04653 L
.18099 .06244 L
.18099 .07835 L
.18101 .09426 L
.18117 .07835 L
.18118 .09426 L
.18122 .11016 L
.18134 .09426 L
.18139 .11016 L
.18144 .12607 L
.18156 .11016 L
.1816 .12607 L
.18163 .14198 L
.18165 .15789 L
.1817 .14198 L
.18188 .12607 L
.18189 .14198 L
.18189 .12607 L
.1819 .14198 L
.18194 .15789 L
.18194 .1738 L
.18196 .18971 L
.18197 .1738 L
.18197 .15789 L
.18199 .1738 L
.182 .15789 L
Mistroke
.18211 .14198 L
.18212 .12607 L
.18218 .14198 L
.1822 .12607 L
.1822 .11016 L
.18223 .12607 L
.18228 .14198 L
.18232 .12607 L
.18233 .11016 L
.18237 .12607 L
.18239 .14198 L
.18243 .15789 L
.18246 .1738 L
.18249 .18971 L
.18259 .1738 L
.18262 .15789 L
.18273 .1738 L
.18275 .18971 L
.18279 .1738 L
.18287 .18971 L
.18289 .1738 L
.18304 .15789 L
.18309 .14198 L
.1831 .12607 L
.18314 .11016 L
.18315 .12607 L
.1832 .11016 L
.18323 .09426 L
.18335 .11016 L
.18336 .09426 L
.18337 .07835 L
.18343 .09426 L
.18348 .11016 L
.18351 .09426 L
.18368 .07835 L
.18373 .09426 L
.18376 .11016 L
.18385 .12607 L
.18395 .11016 L
.18397 .09426 L
.18398 .07835 L
.1841 .06244 L
.1841 .04653 L
.18414 .03062 L
.1842 .01472 L
.1844 .03062 L
.1844 .01472 L
.18443 .03062 L
.18444 .04653 L
.18445 .06244 L
Mistroke
.18449 .07835 L
.18451 .09426 L
.18456 .07835 L
.18457 .09426 L
.18467 .11016 L
.18467 .12607 L
.18478 .11016 L
.18479 .12607 L
.18492 .14198 L
.18493 .15789 L
.18504 .14198 L
.18505 .12607 L
.18506 .14198 L
.18523 .15789 L
.18533 .1738 L
.18545 .18971 L
.18548 .20561 L
.18555 .18971 L
.18556 .20561 L
.18574 .22152 L
.18575 .20561 L
.18593 .18971 L
.18594 .20561 L
.18595 .18971 L
.18611 .1738 L
.18612 .18971 L
.18614 .20561 L
.18615 .22152 L
.18615 .23743 L
.18619 .25334 L
.18621 .26925 L
.18625 .25334 L
.18628 .23743 L
.18633 .25334 L
.18639 .26925 L
.1864 .25334 L
.18644 .26925 L
.18647 .25334 L
.18662 .23743 L
.1867 .22152 L
.18678 .23743 L
.18681 .22152 L
.18685 .23743 L
.18686 .25334 L
.18689 .23743 L
.18697 .25334 L
.18706 .23743 L
.18717 .22152 L
.18721 .23743 L
.18727 .22152 L
Mistroke
.18729 .23743 L
.18745 .22152 L
.18751 .23743 L
.18754 .25334 L
.18765 .23743 L
.18765 .25334 L
.18772 .23743 L
.18772 .25334 L
.18773 .23743 L
.18774 .25334 L
.18776 .26925 L
.18778 .28515 L
.18787 .30106 L
.18789 .31697 L
.18814 .33288 L
.18816 .34879 L
.18821 .3647 L
.18824 .3806 L
.18826 .39651 L
.18827 .3806 L
.1883 .3647 L
.18835 .34879 L
.18835 .3647 L
.18843 .34879 L
.18844 .3647 L
.18849 .3806 L
.18856 .39651 L
.18856 .3806 L
.18858 .39651 L
.18868 .3806 L
.18869 .3647 L
.1887 .34879 L
.18871 .33288 L
.18873 .31697 L
.18878 .33288 L
.18879 .34879 L
.18882 .33288 L
.18882 .31697 L
.1889 .30106 L
.189 .28515 L
.18902 .26925 L
.18903 .25334 L
.18908 .26925 L
.18908 .25334 L
.18911 .23743 L
.18916 .22152 L
.18918 .20561 L
.1892 .18971 L
.18921 .1738 L
.18924 .18971 L
Mistroke
.18928 .1738 L
.18929 .15789 L
.18933 .1738 L
.1894 .18971 L
.18945 .20561 L
.18955 .18971 L
.18959 .1738 L
.18966 .18971 L
.1897 .1738 L
.18973 .15789 L
.18976 .14198 L
.18983 .15789 L
.18989 .1738 L
.18993 .18971 L
.18996 .20561 L
.19002 .22152 L
.19005 .23743 L
.19011 .25334 L
.19017 .26925 L
.19033 .25334 L
.19038 .26925 L
.19052 .25334 L
.19064 .23743 L
.19065 .25334 L
.1907 .26925 L
.19071 .28515 L
.19074 .26925 L
.1908 .28515 L
.19083 .26925 L
.19084 .25334 L
.19088 .26925 L
.19091 .28515 L
.19093 .26925 L
.19094 .28515 L
.19094 .26925 L
.19097 .25334 L
.19102 .23743 L
.19112 .25334 L
.19112 .26925 L
.19116 .28515 L
.19124 .30106 L
.19125 .28515 L
.19127 .26925 L
.1913 .28515 L
.1914 .30106 L
.1914 .31697 L
.19148 .33288 L
.1915 .31697 L
.19153 .33288 L
.19153 .31697 L
Mistroke
.19155 .30106 L
.19163 .28515 L
.19169 .26925 L
.19175 .25334 L
.19193 .23743 L
.19197 .22152 L
.19205 .20561 L
.19205 .22152 L
.19207 .23743 L
.19219 .25334 L
.19222 .26925 L
.19228 .25334 L
.19234 .26925 L
.19239 .25334 L
.19251 .23743 L
.19258 .25334 L
.1926 .26925 L
.19264 .25334 L
.19266 .26925 L
.19269 .25334 L
.19273 .26925 L
.19277 .25334 L
.19278 .26925 L
.19296 .25334 L
.19297 .23743 L
.19301 .22152 L
.19303 .20561 L
.19303 .18971 L
.1931 .20561 L
.1931 .22152 L
.19311 .20561 L
.19311 .18971 L
.19331 .1738 L
.19334 .15789 L
.19335 .14198 L
.19343 .15789 L
.1935 .14198 L
.19357 .12607 L
.19363 .14198 L
.19366 .15789 L
.19374 .1738 L
.1938 .15789 L
.19382 .1738 L
.19386 .15789 L
.19392 .1738 L
.19393 .15789 L
.19396 .14198 L
.19397 .15789 L
.19399 .1738 L
.19402 .15789 L
Mistroke
.19412 .14198 L
.19417 .15789 L
.19418 .14198 L
.19432 .15789 L
.19432 .14198 L
.19433 .12607 L
.19442 .11016 L
.19446 .09426 L
.19446 .07835 L
.19451 .06244 L
.19452 .07835 L
.19459 .06244 L
.19466 .07835 L
.19475 .06244 L
.19478 .04653 L
.19481 .03062 L
.19489 .04653 L
.1949 .03062 L
.19507 .01472 L
.19512 .03062 L
.19522 .04653 L
.19526 .06244 L
.19527 .07835 L
.19528 .06244 L
.19537 .07835 L
.19539 .06244 L
.19541 .04653 L
.19545 .03062 L
.19546 .01472 L
.19551 .03062 L
.19551 .01472 L
.19556 .03062 L
.19561 .01472 L
.1958 .03062 L
.19582 .01472 L
.19589 .03062 L
.1959 .04653 L
.1959 .03062 L
.19608 .04653 L
.19609 .06244 L
.1961 .04653 L
.19615 .03062 L
.19615 .01472 L
.19635 .03062 L
.19641 .04653 L
.19644 .03062 L
.19647 .01472 L
.19651 .03062 L
.19654 .04653 L
.19656 .03062 L
Mistroke
.19675 .01472 L
.1969 .03062 L
.19695 .01472 L
.19699 .03062 L
.19706 .04653 L
.19716 .03062 L
.19716 .04653 L
.19739 .03062 L
.1974 .04653 L
.19749 .03062 L
.19749 .04653 L
.1975 .06244 L
.19756 .07835 L
.19757 .09426 L
.19758 .11016 L
.19763 .09426 L
.19764 .11016 L
.19775 .12607 L
.19776 .11016 L
.1978 .09426 L
.19783 .11016 L
.19784 .12607 L
.19792 .11016 L
.19803 .09426 L
.19808 .07835 L
.1981 .06244 L
.19817 .04653 L
.19822 .06244 L
.19828 .07835 L
.19829 .09426 L
.19834 .07835 L
.19845 .06244 L
.19846 .07835 L
.19846 .09426 L
.1985 .11016 L
.19867 .09426 L
.19868 .07835 L
.19869 .06244 L
.1987 .07835 L
.19871 .06244 L
.19873 .07835 L
.19878 .09426 L
.19884 .07835 L
.19888 .09426 L
.1989 .07835 L
.1989 .06244 L
.19891 .04653 L
.19904 .06244 L
.19905 .04653 L
.19911 .03062 L
Mistroke
.19912 .04653 L
.19929 .06244 L
.1993 .07835 L
.19935 .06244 L
.19945 .07835 L
.19947 .09426 L
.1995 .07835 L
.1995 .06244 L
.19962 .07835 L
.19964 .06244 L
.19983 .07835 L
.19984 .06244 L
.19991 .04653 L
.19992 .03062 L
.19992 .01472 L
.20005 .03062 L
.20006 .01472 L
.20013 .03062 L
.20021 .04653 L
.20042 .03062 L
.20044 .04653 L
.20044 .03062 L
.20049 .01472 L
.20056 .03062 L
.2006 .01472 L
.20061 .03062 L
.20069 .01472 L
.2008 .03062 L
.20084 .04653 L
.20084 .03062 L
.20085 .04653 L
.20085 .06244 L
.20089 .07835 L
.20091 .09426 L
.20096 .11016 L
.20099 .09426 L
.20104 .07835 L
.20105 .09426 L
.20107 .07835 L
.2011 .06244 L
.20112 .04653 L
.20115 .03062 L
.20118 .01472 L
.20124 .03062 L
.20135 .04653 L
.20136 .06244 L
.2014 .07835 L
.20143 .09426 L
.20143 .11016 L
.20145 .12607 L
Mistroke
.20147 .11016 L
.20164 .09426 L
.20171 .07835 L
.20174 .06244 L
.20175 .07835 L
.20176 .06244 L
.20181 .04653 L
.20193 .06244 L
.20196 .04653 L
.20197 .03062 L
.20203 .01472 L
.20208 .03062 L
.20214 .04653 L
.20216 .06244 L
.20224 .07835 L
.20225 .06244 L
.20228 .04653 L
.2023 .06244 L
.20235 .04653 L
.20236 .06244 L
.20237 .07835 L
.20239 .09426 L
.20239 .07835 L
.20241 .09426 L
.20251 .07835 L
.20264 .06244 L
.20269 .04653 L
.20276 .03062 L
.20277 .01472 L
.20292 .03062 L
.20294 .04653 L
.20295 .06244 L
.203 .07835 L
.20302 .06244 L
.20311 .07835 L
.20314 .09426 L
.20315 .11016 L
.20328 .12607 L
.20339 .14198 L
.2034 .12607 L
.20342 .11016 L
.20343 .09426 L
.20347 .11016 L
.20354 .12607 L
.20359 .14198 L
.2036 .12607 L
.20366 .14198 L
.20367 .12607 L
.20369 .14198 L
.20373 .15789 L
Mistroke
.20373 .14198 L
.20389 .12607 L
.20391 .14198 L
.204 .12607 L
.20402 .14198 L
.20404 .12607 L
.20406 .11016 L
.20408 .09426 L
.20411 .11016 L
.20414 .09426 L
.20417 .07835 L
.20419 .09426 L
.2042 .07835 L
.20422 .06244 L
.20427 .04653 L
.20434 .03062 L
.20439 .04653 L
.20459 .06244 L
.20462 .07835 L
.20466 .06244 L
.20467 .07835 L
.20477 .06244 L
.2048 .04653 L
.20484 .03062 L
.20484 .01472 L
.20486 .03062 L
.20487 .01472 L
.20505 .03062 L
.20512 .01472 L
.20514 .03062 L
.2052 .04653 L
.20532 .03062 L
.20534 .04653 L
.20534 .03062 L
.20546 .01472 L
.2055 .03062 L
.20552 .04653 L
.20555 .06244 L
.20558 .07835 L
.20562 .06244 L
.20562 .07835 L
.20564 .06244 L
.20576 .04653 L
.20582 .03062 L
.20588 .01472 L
.20597 .03062 L
.20598 .01472 L
.20645 .03062 L
.20646 .04653 L
.20648 .06244 L
Mistroke
.2065 .04653 L
.20654 .06244 L
.20664 .07835 L
.20677 .09426 L
.20677 .07835 L
.20693 .09426 L
.20698 .07835 L
.20698 .06244 L
.20701 .07835 L
.20709 .06244 L
.20709 .07835 L
.20712 .06244 L
.20713 .07835 L
.20715 .09426 L
.20719 .11016 L
.20721 .12607 L
.20723 .14198 L
.20724 .15789 L
.20736 .1738 L
.2074 .15789 L
.20742 .14198 L
.20742 .15789 L
.20743 .14198 L
.20753 .12607 L
.20763 .11016 L
.2077 .09426 L
.20772 .07835 L
.2078 .06244 L
.20784 .04653 L
.20785 .06244 L
.20791 .04653 L
.20795 .06244 L
.20799 .04653 L
.20799 .06244 L
.208 .07835 L
.20801 .09426 L
.20801 .07835 L
.2081 .06244 L
.20811 .04653 L
.20816 .03062 L
.2082 .04653 L
.20822 .03062 L
.20833 .04653 L
.20834 .03062 L
.20843 .04653 L
.2085 .06244 L
.20853 .04653 L
.20859 .06244 L
.2086 .04653 L
.20862 .03062 L
Mistroke
.20865 .01472 L
.20873 .03062 L
.20875 .04653 L
.20884 .03062 L
.20889 .04653 L
.20892 .03062 L
.20897 .04653 L
.20898 .03062 L
.20902 .04653 L
.20908 .06244 L
.20912 .07835 L
.20921 .09426 L
.20925 .07835 L
.20929 .06244 L
.20929 .07835 L
.20935 .06244 L
.2096 .07835 L
.2096 .06244 L
.2096 .07835 L
.20964 .09426 L
.20968 .11016 L
.2097 .12607 L
.20971 .11016 L
.20972 .09426 L
.20973 .07835 L
.20977 .09426 L
.20986 .11016 L
.20987 .09426 L
.20987 .11016 L
.20989 .12607 L
.21005 .14198 L
.21012 .15789 L
.21015 .1738 L
.21015 .15789 L
.21016 .14198 L
.2102 .12607 L
.21022 .14198 L
.21024 .15789 L
.21026 .1738 L
.21027 .15789 L
.21031 .14198 L
.21033 .12607 L
.21045 .14198 L
.21045 .15789 L
.2105 .1738 L
.21053 .15789 L
.21054 .1738 L
.21056 .15789 L
.21056 .1738 L
.21057 .15789 L
Mistroke
.21059 .14198 L
.21059 .15789 L
.21064 .1738 L
.21077 .18971 L
.21079 .20561 L
.21081 .22152 L
.21101 .20561 L
.21105 .18971 L
.21106 .1738 L
.21109 .15789 L
.21116 .1738 L
.21116 .18971 L
.21117 .20561 L
.21117 .22152 L
.21119 .20561 L
.2113 .22152 L
.21131 .20561 L
.21133 .18971 L
.2114 .20561 L
.21141 .18971 L
.21145 .1738 L
.21147 .18971 L
.21148 .1738 L
.2115 .15789 L
.21152 .14198 L
.21152 .15789 L
.21153 .1738 L
.21154 .15789 L
.21163 .1738 L
.21168 .15789 L
.2117 .14198 L
.21175 .12607 L
.21181 .11016 L
.21193 .09426 L
.21195 .07835 L
.21197 .06244 L
.21201 .07835 L
.21206 .09426 L
.21206 .11016 L
.21211 .12607 L
.21213 .11016 L
.21228 .09426 L
.21234 .11016 L
.21237 .09426 L
.21238 .11016 L
.2124 .12607 L
.21246 .11016 L
.21252 .09426 L
.21252 .11016 L
.21262 .12607 L
Mistroke
.21266 .14198 L
.21267 .12607 L
.2127 .11016 L
.21273 .12607 L
.21274 .11016 L
.21284 .12607 L
.21288 .11016 L
.21291 .12607 L
.21294 .14198 L
.21296 .12607 L
.21301 .14198 L
.21303 .12607 L
.21308 .11016 L
.21319 .12607 L
.2132 .11016 L
.21328 .09426 L
.21328 .11016 L
.21329 .09426 L
.21335 .11016 L
.2134 .12607 L
.21354 .14198 L
.21363 .12607 L
.2137 .14198 L
.21371 .12607 L
.21372 .11016 L
.21375 .12607 L
.21375 .11016 L
.21379 .12607 L
.21389 .11016 L
.21392 .12607 L
.21396 .11016 L
.21398 .09426 L
.21406 .11016 L
.21412 .12607 L
.21415 .14198 L
.2142 .12607 L
.21424 .14198 L
.21433 .12607 L
.21434 .11016 L
.21435 .12607 L
.21436 .11016 L
.21436 .12607 L
.21437 .11016 L
.21438 .12607 L
.21439 .11016 L
.21443 .12607 L
.21445 .11016 L
.21445 .09426 L
.21447 .07835 L
.21447 .09426 L
Mistroke
.21449 .07835 L
.21459 .06244 L
.21459 .04653 L
.21472 .03062 L
.21475 .01472 L
.21477 .03062 L
.21477 .04653 L
.2148 .06244 L
.21483 .07835 L
.21484 .06244 L
.21485 .04653 L
.2149 .03062 L
.21496 .04653 L
.21496 .06244 L
.21497 .07835 L
.21501 .09426 L
.21512 .07835 L
.21536 .09426 L
.21538 .07835 L
.21538 .09426 L
.21547 .11016 L
.21557 .09426 L
.21562 .11016 L
.21569 .09426 L
.21571 .11016 L
.21579 .09426 L
.21579 .07835 L
.21583 .09426 L
.21589 .11016 L
.21589 .09426 L
.21592 .07835 L
.21594 .09426 L
.21596 .07835 L
.21605 .09426 L
.21607 .07835 L
.2161 .09426 L
.2161 .07835 L
.21612 .06244 L
.21617 .04653 L
.21618 .06244 L
.21618 .07835 L
.2162 .06244 L
.21626 .04653 L
.21627 .06244 L
.21633 .04653 L
.21645 .06244 L
.21645 .07835 L
.21645 .09426 L
.21648 .07835 L
.2165 .09426 L
Mistroke
.21653 .11016 L
.21654 .09426 L
.21655 .07835 L
.21657 .06244 L
.2167 .04653 L
.21676 .03062 L
.21681 .01472 L
.21681 .03062 L
.21684 .01472 L
.21704 .03062 L
.21704 .01472 L
.21707 .03062 L
.21714 .04653 L
.21724 .06244 L
.21731 .07835 L
.21732 .09426 L
.21736 .07835 L
.21742 .09426 L
.21742 .11016 L
.21743 .09426 L
.21747 .07835 L
.21751 .09426 L
.21758 .07835 L
.21762 .09426 L
.21766 .11016 L
.21778 .12607 L
.21781 .11016 L
.21783 .12607 L
.21788 .11016 L
.21789 .12607 L
.21799 .11016 L
.21808 .12607 L
.21812 .11016 L
.21815 .09426 L
.21818 .07835 L
.21824 .09426 L
.21828 .11016 L
.21841 .12607 L
.21846 .11016 L
.21849 .09426 L
.21852 .11016 L
.21863 .12607 L
.21864 .14198 L
.21895 .12607 L
.21906 .11016 L
.21914 .09426 L
.21914 .07835 L
.21918 .09426 L
.21923 .07835 L
.21928 .06244 L
Mistroke
.21934 .07835 L
.21936 .09426 L
.21942 .11016 L
.21951 .09426 L
.21956 .11016 L
.21961 .09426 L
.21964 .11016 L
.21971 .09426 L
.21975 .07835 L
.21987 .06244 L
.21988 .04653 L
.21997 .06244 L
.21999 .07835 L
.22 .06244 L
.22002 .07835 L
.22003 .06244 L
.22005 .04653 L
.22008 .03062 L
.22008 .04653 L
.22015 .03062 L
.22016 .04653 L
.22021 .06244 L
.22029 .07835 L
.22031 .06244 L
.22038 .07835 L
.22039 .06244 L
.2204 .04653 L
.22041 .06244 L
.22043 .07835 L
.2205 .09426 L
.22058 .11016 L
.2206 .09426 L
.22066 .11016 L
.22071 .12607 L
.22074 .11016 L
.22074 .12607 L
.22075 .11016 L
.22087 .09426 L
.22091 .07835 L
.22094 .09426 L
.22096 .07835 L
.22098 .06244 L
.22099 .04653 L
.22108 .06244 L
.22109 .04653 L
.22112 .03062 L
.22113 .01472 L
.22114 .03062 L
.22115 .01472 L
.22116 .03062 L
Mistroke
.22118 .01472 L
.22134 .03062 L
.22137 .01472 L
.22159 .03062 L
.2216 .01472 L
.2217 .03062 L
.22175 .04653 L
.22176 .06244 L
.22177 .04653 L
.22186 .03062 L
.22187 .01472 L
.22195 .03062 L
.222 .01472 L
.22206 .03062 L
.22207 .01472 L
.22214 .03062 L
.22225 .01472 L
.2223 .03062 L
.22244 .04653 L
.22244 .03062 L
.22248 .04653 L
.22252 .03062 L
.22255 .04653 L
.22262 .06244 L
.22263 .04653 L
.22268 .03062 L
.22272 .04653 L
.22272 .03062 L
.22277 .01472 L
.2229 .03062 L
.22292 .04653 L
.22306 .06244 L
.22306 .04653 L
.2231 .06244 L
.22311 .07835 L
.22318 .06244 L
.22326 .07835 L
.22328 .06244 L
.22329 .07835 L
.22329 .09426 L
.22332 .07835 L
.22341 .06244 L
.22349 .04653 L
.22351 .06244 L
.22357 .07835 L
.22362 .09426 L
.22365 .07835 L
.22381 .09426 L
.22388 .11016 L
.22396 .09426 L
Mistroke
.22398 .07835 L
.22399 .09426 L
.22404 .07835 L
.22412 .09426 L
.22416 .07835 L
.22416 .09426 L
.22417 .07835 L
.22427 .09426 L
.22434 .11016 L
.22436 .09426 L
.22439 .11016 L
.22441 .09426 L
.22442 .07835 L
.22443 .06244 L
.22446 .07835 L
.2245 .06244 L
.22453 .07835 L
.22453 .09426 L
.22454 .11016 L
.22455 .09426 L
.22456 .11016 L
.22464 .12607 L
.22465 .11016 L
.22471 .12607 L
.22471 .11016 L
.22478 .09426 L
.22487 .11016 L
.22489 .12607 L
.22491 .14198 L
.225 .15789 L
.22507 .14198 L
.22513 .15789 L
.22515 .1738 L
.22517 .18971 L
.22518 .20561 L
.22519 .22152 L
.2252 .20561 L
.22535 .18971 L
.22541 .20561 L
.22549 .22152 L
.22554 .23743 L
.22556 .22152 L
.2256 .20561 L
.22566 .22152 L
.22568 .23743 L
.22571 .22152 L
.22575 .20561 L
.22577 .22152 L
.22577 .20561 L
.22585 .22152 L
Mistroke
.22595 .20561 L
.22601 .18971 L
.22603 .20561 L
.22605 .18971 L
.22609 .20561 L
.22617 .22152 L
.22622 .23743 L
.22628 .25334 L
.22634 .26925 L
.22636 .25334 L
.2264 .23743 L
.22642 .22152 L
.22649 .20561 L
.22652 .18971 L
.22654 .1738 L
.22657 .18971 L
.22658 .20561 L
.2266 .22152 L
.22661 .20561 L
.22676 .18971 L
.2268 .1738 L
.22681 .18971 L
.22689 .20561 L
.22693 .22152 L
.22706 .23743 L
.22707 .22152 L
.22723 .20561 L
.22724 .22152 L
.22726 .23743 L
.22731 .22152 L
.22732 .23743 L
.22743 .25334 L
.2275 .23743 L
.22751 .22152 L
.22762 .20561 L
.2277 .18971 L
.22775 .1738 L
.22779 .15789 L
.22785 .1738 L
.22798 .15789 L
.22799 .1738 L
.22806 .15789 L
.22812 .14198 L
.2282 .15789 L
.22821 .14198 L
.22829 .15789 L
.22829 .1738 L
.22829 .18971 L
.22831 .1738 L
.22831 .15789 L
Mistroke
.2284 .1738 L
.22843 .18971 L
.22845 .1738 L
.22859 .18971 L
.22861 .20561 L
.22863 .18971 L
.22864 .1738 L
.22865 .18971 L
.22867 .1738 L
.2287 .18971 L
.22875 .20561 L
.22876 .18971 L
.22885 .20561 L
.22892 .22152 L
.22892 .23743 L
.22893 .22152 L
.22899 .23743 L
.22899 .25334 L
.22905 .23743 L
.22908 .22152 L
.2291 .20561 L
.22914 .22152 L
.22919 .20561 L
.22926 .18971 L
.22929 .20561 L
.22933 .18971 L
.22946 .1738 L
.22956 .15789 L
.2296 .1738 L
.22966 .15789 L
.22971 .1738 L
.22971 .15789 L
.22971 .14198 L
.22978 .12607 L
.2298 .14198 L
.22981 .12607 L
.22982 .14198 L
.22984 .12607 L
.22984 .11016 L
.22985 .12607 L
.22993 .14198 L
.22994 .12607 L
.22999 .11016 L
.23 .09426 L
.23006 .11016 L
.23011 .09426 L
.23013 .11016 L
.23015 .09426 L
.23015 .07835 L
.23016 .09426 L
Mistroke
.23021 .11016 L
.23027 .12607 L
.23037 .14198 L
.23044 .15789 L
.23051 .14198 L
.23072 .15789 L
.23084 .14198 L
.23088 .12607 L
.23097 .14198 L
.23099 .12607 L
.231 .11016 L
.23109 .12607 L
.23109 .11016 L
.23115 .09426 L
.23117 .07835 L
.2312 .09426 L
.23121 .07835 L
.23121 .09426 L
.23127 .07835 L
.23147 .09426 L
.23157 .11016 L
.23165 .09426 L
.23167 .11016 L
.2317 .12607 L
.2317 .11016 L
.2317 .09426 L
.23171 .11016 L
.23176 .09426 L
.23181 .11016 L
.23183 .09426 L
.2319 .11016 L
.23196 .09426 L
.23201 .11016 L
.23201 .09426 L
.23202 .07835 L
.23212 .09426 L
.23229 .07835 L
.23244 .09426 L
.23244 .11016 L
.23254 .09426 L
.2326 .11016 L
.2326 .12607 L
.23261 .11016 L
.23262 .12607 L
.23267 .11016 L
.23267 .12607 L
.23274 .11016 L
.23275 .09426 L
.23282 .07835 L
.23288 .06244 L
Mistroke
.23288 .04653 L
.23289 .06244 L
.23292 .07835 L
.23296 .09426 L
.233 .07835 L
.23306 .09426 L
.23308 .07835 L
.23314 .09426 L
.23316 .07835 L
.23324 .06244 L
.23334 .04653 L
.23334 .03062 L
.23336 .01472 L
.23342 .03062 L
.23348 .01472 L
.23352 .03062 L
.23354 .01472 L
.23379 .03062 L
.23396 .04653 L
.23399 .03062 L
.23409 .01472 L
.23415 .03062 L
.23426 .04653 L
.23432 .06244 L
.23435 .04653 L
.23446 .06244 L
.23448 .07835 L
.23454 .09426 L
.23456 .07835 L
.2346 .06244 L
.23461 .07835 L
.23463 .06244 L
.23473 .04653 L
.23482 .03062 L
.23482 .04653 L
.2349 .06244 L
.23491 .04653 L
.23493 .06244 L
.23496 .04653 L
.23497 .03062 L
.235 .01472 L
.23503 .03062 L
.23505 .01472 L
.23508 .03062 L
.23516 .01472 L
.23522 .03062 L
.23526 .01472 L
.23534 .03062 L
.23538 .04653 L
.23544 .03062 L
Mistroke
.23544 .01472 L
.23566 .03062 L
.23568 .04653 L
.2357 .03062 L
.23574 .04653 L
.23574 .03062 L
.23584 .04653 L
.23586 .03062 L
.23591 .04653 L
.23592 .06244 L
.23596 .07835 L
.23597 .06244 L
.236 .04653 L
.23601 .06244 L
.23606 .04653 L
.23607 .03062 L
.23609 .01472 L
.23624 .03062 L
.2363 .01472 L
.23634 .03062 L
.23636 .04653 L
.2364 .06244 L
.23642 .07835 L
.23644 .09426 L
.23652 .07835 L
.23658 .09426 L
.23665 .11016 L
.23666 .09426 L
.23668 .11016 L
.23674 .12607 L
.23681 .11016 L
.23686 .09426 L
.23692 .07835 L
.23695 .09426 L
.23695 .11016 L
.23701 .09426 L
.23715 .07835 L
.23719 .06244 L
.23722 .04653 L
.23724 .03062 L
.23725 .01472 L
.23739 .03062 L
.23743 .04653 L
.23751 .03062 L
.23753 .01472 L
.23759 .03062 L
.23759 .04653 L
.23767 .06244 L
.23785 .04653 L
.23786 .06244 L
Mistroke
.23789 .04653 L
.23795 .03062 L
.23802 .04653 L
.23806 .06244 L
.23812 .04653 L
.23814 .06244 L
.23829 .04653 L
.23829 .03062 L
.23835 .04653 L
.23836 .03062 L
.23846 .04653 L
.23849 .03062 L
.23852 .01472 L
.23865 .03062 L
.23876 .04653 L
.23877 .03062 L
.23883 .01472 L
.23883 .03062 L
.2389 .01472 L
.23904 .03062 L
.2391 .04653 L
.23911 .03062 L
.23913 .01472 L
.23914 .03062 L
.23914 .01472 L
.23922 .03062 L
.23926 .01472 L
.23929 .03062 L
.23931 .01472 L
.23932 .03062 L
.23935 .01472 L
.23957 .03062 L
.23962 .04653 L
.23964 .06244 L
.23966 .04653 L
.23971 .06244 L
.23973 .04653 L
.23977 .03062 L
.23978 .04653 L
.23978 .06244 L
.23989 .07835 L
.2399 .06244 L
.23996 .07835 L
.24 .09426 L
.24008 .07835 L
.2401 .06244 L
.24014 .04653 L
.24024 .06244 L
.24042 .07835 L
.2405 .06244 L
Mistroke
.24052 .07835 L
.24053 .06244 L
.24061 .04653 L
.24063 .03062 L
.24066 .01472 L
.24075 .03062 L
.24078 .04653 L
.24081 .03062 L
.24089 .04653 L
.24094 .03062 L
.24095 .01472 L
.24103 .03062 L
.24103 .01472 L
.24104 .03062 L
.24107 .01472 L
.24119 .03062 L
.24125 .04653 L
.24128 .06244 L
.24129 .07835 L
.24133 .09426 L
.24133 .07835 L
.24136 .09426 L
.24146 .11016 L
.24151 .12607 L
.24153 .11016 L
.24155 .12607 L
.24167 .14198 L
.24167 .12607 L
.24175 .11016 L
.24175 .12607 L
.24177 .11016 L
.24182 .09426 L
.24184 .11016 L
.24199 .12607 L
.24201 .14198 L
.24201 .12607 L
.24208 .14198 L
.24227 .12607 L
.24228 .11016 L
.24243 .09426 L
.24244 .07835 L
.24252 .06244 L
.24255 .04653 L
.24264 .06244 L
.24265 .04653 L
.24266 .06244 L
.24271 .04653 L
.24272 .03062 L
.24275 .01472 L
.24278 .03062 L
Mistroke
.24286 .04653 L
.24288 .03062 L
.2429 .04653 L
.24292 .03062 L
.24292 .04653 L
.24302 .06244 L
.24303 .04653 L
.24306 .03062 L
.24311 .04653 L
.24311 .06244 L
.24324 .04653 L
.24326 .03062 L
.24326 .04653 L
.24328 .03062 L
.24351 .01472 L
.24353 .03062 L
.24355 .04653 L
.2436 .03062 L
.24365 .01472 L
.24382 .03062 L
.24382 .04653 L
.24384 .06244 L
.24387 .04653 L
.24389 .03062 L
.2439 .04653 L
.24403 .03062 L
.2441 .04653 L
.24413 .06244 L
.24415 .07835 L
.24417 .06244 L
.24418 .04653 L
.24423 .03062 L
.24425 .04653 L
.24426 .03062 L
.24427 .04653 L
.24428 .03062 L
.24444 .04653 L
.24447 .06244 L
.24455 .04653 L
.24456 .06244 L
.24459 .04653 L
.24459 .06244 L
.24463 .04653 L
.24468 .06244 L
.24469 .07835 L
.24471 .09426 L
.24473 .11016 L
.24482 .09426 L
.24497 .11016 L
.24503 .09426 L
Mistroke
.24514 .07835 L
.24514 .06244 L
.2453 .07835 L
.24533 .09426 L
.24537 .07835 L
.24547 .09426 L
.24553 .11016 L
.24559 .12607 L
.24578 .14198 L
.2458 .15789 L
.24582 .1738 L
.24583 .18971 L
.24584 .20561 L
.24593 .18971 L
.24598 .1738 L
.24604 .18971 L
.24606 .20561 L
.24611 .18971 L
.24613 .1738 L
.24627 .15789 L
.24628 .1738 L
.24642 .15789 L
.24647 .14198 L
.24649 .15789 L
.24651 .1738 L
.24656 .18971 L
.24666 .20561 L
.24669 .18971 L
.24674 .20561 L
.24675 .18971 L
.24677 .1738 L
.2468 .18971 L
.24682 .1738 L
.24683 .18971 L
.24685 .1738 L
.24688 .18971 L
.2469 .1738 L
.2469 .18971 L
.24696 .20561 L
.24697 .22152 L
.24705 .23743 L
.24707 .25334 L
.24707 .23743 L
.24712 .25334 L
.24716 .23743 L
.24724 .25334 L
.24727 .23743 L
.24741 .25334 L
.24742 .26925 L
.24742 .25334 L
Mistroke
.24747 .26925 L
.24761 .28515 L
.24761 .30106 L
.24761 .28515 L
.24766 .26925 L
.24769 .28515 L
.24777 .30106 L
.24783 .31697 L
.24795 .30106 L
.24813 .28515 L
.24822 .30106 L
.24826 .28515 L
.24826 .30106 L
.24831 .28515 L
.24833 .30106 L
.24836 .28515 L
.24836 .26925 L
.24843 .28515 L
.24844 .26925 L
.24848 .25334 L
.24854 .26925 L
.24861 .28515 L
.24865 .30106 L
.24869 .28515 L
.24876 .26925 L
.24876 .25334 L
.24877 .23743 L
.24877 .22152 L
.24878 .23743 L
.2488 .22152 L
.24881 .23743 L
.24883 .22152 L
.24883 .23743 L
.24895 .25334 L
.24896 .23743 L
.24907 .25334 L
.24912 .23743 L
.24919 .25334 L
.24924 .26925 L
.24925 .25334 L
.24926 .26925 L
.24927 .25334 L
.24932 .23743 L
.24935 .22152 L
.24939 .23743 L
.24945 .25334 L
.24947 .26925 L
.24949 .28515 L
.24955 .30106 L
.24956 .28515 L
Mistroke
.24959 .26925 L
.24973 .25334 L
.24976 .23743 L
.24977 .25334 L
.2498 .26925 L
.24982 .28515 L
.24983 .26925 L
.2499 .28515 L
.24996 .30106 L
.24998 .31697 L
.25001 .33288 L
.25005 .31697 L
.25006 .33288 L
.25018 .31697 L
.25019 .30106 L
.25021 .31697 L
.25024 .33288 L
.25033 .34879 L
.25046 .3647 L
.25058 .3806 L
.25064 .39651 L
.25071 .41242 L
.25078 .39651 L
.25095 .3806 L
.25097 .39651 L
.25097 .41242 L
.25103 .39651 L
.2511 .3806 L
.25111 .39651 L
.25119 .3806 L
.25122 .3647 L
.25125 .3806 L
.25129 .39651 L
.25139 .3806 L
.25139 .3647 L
.25142 .34879 L
.25143 .33288 L
.25149 .31697 L
.2515 .30106 L
.25156 .28515 L
.25157 .26925 L
.25165 .28515 L
.25166 .30106 L
.2517 .31697 L
.25175 .33288 L
.25181 .31697 L
.25184 .33288 L
.25189 .31697 L
.25192 .30106 L
.25195 .28515 L
Mistroke
.252 .26925 L
.25203 .25334 L
.25204 .23743 L
.25206 .22152 L
.25209 .23743 L
.2521 .25334 L
.25214 .23743 L
.25215 .22152 L
.25216 .20561 L
.2524 .18971 L
.25242 .1738 L
.25245 .15789 L
.25256 .1738 L
.25257 .18971 L
.25259 .20561 L
.25262 .22152 L
.25266 .20561 L
.25283 .22152 L
.25286 .23743 L
.25299 .25334 L
.25312 .23743 L
.25318 .22152 L
.25326 .23743 L
.25329 .22152 L
.2533 .23743 L
.25332 .22152 L
.25334 .23743 L
.25339 .25334 L
.2534 .23743 L
.25342 .25334 L
.25347 .26925 L
.25349 .28515 L
.25351 .26925 L
.25351 .28515 L
.25356 .26925 L
.25364 .25334 L
.25371 .23743 L
.25374 .25334 L
.25376 .23743 L
.25378 .22152 L
.25378 .23743 L
.25384 .22152 L
.25386 .20561 L
.25386 .18971 L
.25387 .20561 L
.25392 .18971 L
.25395 .20561 L
.25402 .18971 L
.25406 .20561 L
.25408 .22152 L
Mistroke
.25413 .23743 L
.25423 .22152 L
.25428 .23743 L
.25429 .25334 L
.25433 .26925 L
.25449 .25334 L
.25454 .23743 L
.25457 .22152 L
.25464 .23743 L
.25466 .25334 L
.25466 .26925 L
.2548 .25334 L
.25483 .26925 L
.25489 .28515 L
.25492 .30106 L
.25502 .28515 L
.25505 .30106 L
.25505 .31697 L
.2551 .33288 L
.25513 .31697 L
.25513 .33288 L
.25516 .34879 L
.25517 .33288 L
.25523 .31697 L
.25528 .30106 L
.25528 .28515 L
.25536 .30106 L
.25539 .28515 L
.2554 .26925 L
.2554 .28515 L
.25552 .30106 L
.25552 .28515 L
.25555 .30106 L
.25561 .28515 L
.25566 .26925 L
.25576 .28515 L
.25577 .26925 L
.25583 .25334 L
.25583 .23743 L
.25584 .22152 L
.2559 .20561 L
.25593 .22152 L
.25601 .20561 L
.25602 .22152 L
.25603 .23743 L
.25607 .22152 L
.25611 .23743 L
.25622 .25334 L
.25625 .26925 L
.2563 .28515 L
Mistroke
.25636 .30106 L
.25637 .31697 L
.25645 .30106 L
.25649 .28515 L
.25649 .30106 L
.25651 .28515 L
.25663 .26925 L
.25669 .28515 L
.25676 .26925 L
.25677 .25334 L
.25679 .23743 L
.2568 .22152 L
.25681 .20561 L
.25686 .22152 L
.25686 .23743 L
.25688 .22152 L
.25688 .23743 L
.25693 .22152 L
.25694 .20561 L
.25699 .18971 L
.25708 .1738 L
.25711 .15789 L
.2573 .1738 L
.25732 .15789 L
.25737 .14198 L
.25739 .15789 L
.25743 .1738 L
.25746 .18971 L
.25756 .1738 L
.25758 .15789 L
.25768 .1738 L
.25774 .15789 L
.25774 .14198 L
.25778 .12607 L
.25785 .14198 L
.25785 .12607 L
.25788 .11016 L
.25789 .09426 L
.25797 .07835 L
.25799 .09426 L
.25801 .11016 L
.25814 .09426 L
.25824 .07835 L
.25824 .09426 L
.25827 .11016 L
.25828 .09426 L
.25843 .07835 L
.25845 .06244 L
.25846 .07835 L
.25847 .09426 L
Mistroke
.25867 .11016 L
.25873 .12607 L
.25877 .11016 L
.25878 .09426 L
.25881 .11016 L
.25883 .12607 L
.25887 .11016 L
.25893 .12607 L
.25894 .11016 L
.25897 .12607 L
.25898 .11016 L
.25903 .09426 L
.25916 .07835 L
.25917 .09426 L
.2592 .11016 L
.25923 .09426 L
.25924 .07835 L
.25926 .06244 L
.25929 .04653 L
.25929 .03062 L
.25932 .01472 L
.25949 .03062 L
.25972 .01472 L
.25984 .03062 L
.25985 .04653 L
.25992 .03062 L
.25997 .01472 L
.26006 .03062 L
.26008 .01472 L
.26008 .03062 L
.26013 .04653 L
.26023 .06244 L
.26026 .07835 L
.26039 .06244 L
.26044 .04653 L
.26048 .03062 L
.26052 .01472 L
.26086 .03062 L
.26088 .01472 L
.26105 .03062 L
.26106 .01472 L
.26106 .03062 L
.26108 .01472 L
.26115 .03062 L
.26117 .04653 L
.26126 .06244 L
.26127 .07835 L
.2613 .06244 L
.26132 .04653 L
.26134 .03062 L
Mistroke
.2614 .04653 L
.2615 .03062 L
.2616 .04653 L
.26163 .06244 L
.26166 .07835 L
.26167 .09426 L
.26169 .11016 L
.26172 .12607 L
.26172 .14198 L
.26182 .15789 L
.26182 .14198 L
.26199 .12607 L
.26206 .11016 L
.26206 .12607 L
.26211 .11016 L
.26212 .09426 L
.26215 .07835 L
.26216 .06244 L
.26217 .04653 L
.26219 .03062 L
.26238 .01472 L
.2626 .03062 L
.2626 .01472 L
.26277 .03062 L
.26277 .01472 L
.2628 .03062 L
.2628 .01472 L
.2631 .03062 L
.26312 .01472 L
.26336 .03062 L
.26342 .01472 L
.26349 .03062 L
.26361 .01472 L
.26367 .03062 L
.2637 .01472 L
.26374 .03062 L
.26379 .01472 L
.26383 .03062 L
.26386 .01472 L
.26388 .03062 L
.26392 .01472 L
.26428 .03062 L
.26428 .01472 L
.26434 .03062 L
.2644 .01472 L
.26477 .03062 L
.26477 .01472 L
.26487 .03062 L
.26492 .01472 L
.265 .03062 L
Mistroke
.265 .01472 L
.26512 .03062 L
.26514 .01472 L
.26527 .03062 L
.26533 .01472 L
.26564 .03062 L
.2657 .01472 L
.26593 .03062 L
.26594 .01472 L
.26599 .03062 L
.26603 .04653 L
.26603 .06244 L
.26607 .07835 L
.26614 .09426 L
.26619 .11016 L
.26637 .12607 L
.26647 .14198 L
.26648 .15789 L
.26654 .14198 L
.26666 .15789 L
.26667 .1738 L
.2667 .15789 L
.26678 .14198 L
.26688 .15789 L
.26691 .14198 L
.26693 .12607 L
.267 .14198 L
.26703 .12607 L
.26707 .14198 L
.26715 .12607 L
.26718 .14198 L
.2672 .15789 L
.26721 .1738 L
.26726 .15789 L
.26733 .14198 L
.26735 .12607 L
.26735 .11016 L
.26736 .09426 L
.26737 .07835 L
.26738 .09426 L
.26739 .07835 L
.26741 .09426 L
.26743 .11016 L
.26744 .09426 L
.26744 .11016 L
.26748 .12607 L
.26749 .11016 L
.26752 .09426 L
.26764 .07835 L
.2677 .06244 L
Mistroke
.26771 .04653 L
.26782 .06244 L
.26788 .07835 L
.26791 .09426 L
.26806 .07835 L
.26815 .09426 L
.26821 .07835 L
.26824 .09426 L
.26836 .11016 L
.26842 .12607 L
.26843 .11016 L
.26855 .09426 L
.26863 .11016 L
.26866 .12607 L
.26872 .11016 L
.26877 .12607 L
.26878 .14198 L
.26878 .12607 L
.26882 .14198 L
.26883 .15789 L
.26883 .14198 L
.26883 .12607 L
.26885 .11016 L
.26888 .09426 L
.26897 .07835 L
.269 .06244 L
.26903 .07835 L
.26909 .06244 L
.26914 .04653 L
.2692 .06244 L
.26926 .04653 L
.26936 .03062 L
.26952 .04653 L
.26954 .06244 L
.26955 .04653 L
.26957 .03062 L
.26957 .04653 L
.26962 .03062 L
.26963 .01472 L
.2697 .03062 L
.26972 .01472 L
.26974 .03062 L
.26981 .04653 L
.2699 .03062 L
.26991 .04653 L
.26996 .06244 L
.26999 .04653 L
.27 .06244 L
.27003 .07835 L
.27006 .06244 L
Mistroke
.27009 .07835 L
.27015 .09426 L
.27021 .11016 L
.27024 .12607 L
.27026 .14198 L
.27033 .15789 L
.27033 .14198 L
.27035 .12607 L
.27037 .11016 L
.27042 .09426 L
.27046 .07835 L
.27049 .06244 L
.27053 .07835 L
.27066 .06244 L
.27068 .04653 L
.27076 .03062 L
.27079 .01472 L
.27096 .03062 L
.27098 .04653 L
.27106 .06244 L
.27124 .04653 L
.27127 .06244 L
.2713 .07835 L
.27135 .06244 L
.27135 .04653 L
.27136 .06244 L
.27142 .04653 L
.27152 .06244 L
.27157 .04653 L
.27157 .03062 L
.27163 .01472 L
.27182 .03062 L
.2719 .04653 L
.27194 .03062 L
.27202 .04653 L
.27202 .03062 L
.27203 .04653 L
.2721 .03062 L
.2721 .01472 L
.2722 .03062 L
.27221 .04653 L
.27223 .03062 L
.27223 .01472 L
.2723 .03062 L
.27237 .01472 L
.27237 .03062 L
.27238 .01472 L
.2725 .03062 L
.27253 .04653 L
.27256 .06244 L
Mistroke
.27261 .07835 L
.27265 .09426 L
.27277 .07835 L
.2728 .06244 L
.27283 .07835 L
.27293 .09426 L
.27299 .07835 L
.27306 .09426 L
.27312 .07835 L
.27313 .06244 L
.27314 .04653 L
.27321 .06244 L
.27321 .04653 L
.27322 .03062 L
.27325 .01472 L
.27331 .03062 L
.27332 .01472 L
.27333 .03062 L
.27335 .04653 L
.2734 .06244 L
.27345 .04653 L
.2736 .06244 L
.27362 .07835 L
.27367 .09426 L
.27382 .07835 L
.27383 .09426 L
.27392 .11016 L
.27394 .12607 L
.27396 .11016 L
.27407 .09426 L
.2741 .11016 L
.27416 .12607 L
.27417 .14198 L
.2742 .15789 L
.2742 .1738 L
.27428 .15789 L
.27436 .1738 L
.27438 .18971 L
.27448 .20561 L
.27453 .18971 L
.2746 .20561 L
.27466 .18971 L
.27478 .20561 L
.27479 .22152 L
.27479 .20561 L
.27482 .18971 L
.27489 .20561 L
.27491 .18971 L
.27492 .20561 L
.27495 .22152 L
Mistroke
.27496 .23743 L
.27523 .22152 L
.27531 .20561 L
.27534 .18971 L
.27542 .1738 L
.27547 .15789 L
.27555 .1738 L
.27556 .18971 L
.27558 .20561 L
.27566 .18971 L
.27572 .1738 L
.27589 .18971 L
.27596 .20561 L
.27599 .22152 L
.276 .20561 L
.27609 .22152 L
.2761 .20561 L
.27611 .22152 L
.27612 .20561 L
.27617 .18971 L
.27623 .1738 L
.27629 .15789 L
.27651 .14198 L
.27653 .12607 L
.27656 .11016 L
.27672 .09426 L
.27675 .11016 L
.27677 .09426 L
.2768 .07835 L
.27685 .06244 L
.27694 .04653 L
.27695 .06244 L
.27697 .04653 L
.27699 .03062 L
.27708 .04653 L
.27711 .03062 L
.27722 .04653 L
.27723 .03062 L
.27735 .04653 L
.27737 .03062 L
.27743 .01472 L
.27745 .03062 L
.27751 .01472 L
.27753 .03062 L
.27762 .01472 L
.27764 .03062 L
.27765 .04653 L
.27765 .03062 L
.27768 .01472 L
.2777 .03062 L
Mistroke
.27775 .04653 L
.27778 .06244 L
.27779 .04653 L
.27783 .06244 L
.27787 .07835 L
.27789 .06244 L
.27793 .04653 L
.27797 .06244 L
.27799 .04653 L
.27807 .06244 L
.27808 .04653 L
.27819 .03062 L
.27828 .04653 L
.27835 .03062 L
.27837 .01472 L
.27868 .03062 L
.27871 .01472 L
.27871 .03062 L
.27875 .04653 L
.27878 .06244 L
.27879 .04653 L
.27881 .03062 L
.27883 .01472 L
.27897 .03062 L
.27904 .01472 L
.27916 .03062 L
.27924 .01472 L
.27925 .03062 L
.27927 .01472 L
.27931 .03062 L
.27933 .01472 L
.27934 .03062 L
.27939 .01472 L
.2795 .03062 L
.27955 .01472 L
.27958 .03062 L
.27967 .01472 L
.27983 .03062 L
.27985 .01472 L
.27992 .03062 L
.27996 .01472 L
.28001 .03062 L
.28005 .04653 L
.28008 .06244 L
.28009 .04653 L
.2801 .03062 L
.28014 .04653 L
.28014 .03062 L
.2802 .04653 L
.28022 .03062 L
Mistroke
.28034 .01472 L
.28037 .03062 L
.28037 .04653 L
.28041 .03062 L
.28045 .04653 L
.28047 .06244 L
.28047 .07835 L
.2805 .09426 L
.2805 .07835 L
.28055 .09426 L
.28065 .11016 L
.28067 .12607 L
.2807 .14198 L
.28077 .12607 L
.28079 .11016 L
.28081 .12607 L
.28082 .11016 L
.28083 .09426 L
.28098 .11016 L
.28117 .09426 L
.28117 .11016 L
.28122 .09426 L
.28134 .11016 L
.28137 .12607 L
.28139 .11016 L
.2814 .09426 L
.28143 .07835 L
.28146 .06244 L
.28147 .07835 L
.2815 .09426 L
.28154 .11016 L
.28163 .09426 L
.2817 .11016 L
.28173 .09426 L
.28183 .11016 L
.28192 .09426 L
.28195 .11016 L
.28197 .09426 L
.282 .11016 L
.28201 .12607 L
.28205 .11016 L
.28209 .09426 L
.28209 .11016 L
.28211 .12607 L
.28217 .11016 L
.28225 .12607 L
.28239 .11016 L
.28247 .12607 L
.28248 .14198 L
.28251 .12607 L
Mistroke
.28259 .14198 L
.28266 .12607 L
.28271 .14198 L
.28272 .12607 L
.28277 .11016 L
.28286 .09426 L
.28289 .11016 L
.283 .09426 L
.28311 .07835 L
.28315 .06244 L
.28316 .04653 L
.28323 .06244 L
.28325 .07835 L
.28332 .09426 L
.28333 .11016 L
.2835 .09426 L
.28356 .07835 L
.28356 .06244 L
.2836 .07835 L
.28369 .06244 L
.28372 .04653 L
.28375 .03062 L
.28387 .01472 L
.28395 .03062 L
.28397 .04653 L
.28398 .06244 L
.28398 .07835 L
.28403 .09426 L
.28405 .07835 L
.28407 .09426 L
.28415 .11016 L
.28419 .12607 L
.28424 .14198 L
.28431 .12607 L
.28442 .14198 L
.28444 .15789 L
.28462 .14198 L
.28467 .15789 L
.2847 .14198 L
.2847 .15789 L
.28482 .1738 L
.28484 .18971 L
.28485 .1738 L
.28494 .15789 L
.28495 .1738 L
.28497 .15789 L
.28504 .14198 L
.2851 .15789 L
.28511 .14198 L
.28514 .15789 L
Mistroke
.28514 .14198 L
.28516 .12607 L
.28517 .14198 L
.28524 .12607 L
.2853 .11016 L
.28539 .09426 L
.28542 .11016 L
.28546 .09426 L
.28546 .07835 L
.28557 .06244 L
.28562 .04653 L
.28563 .06244 L
.28564 .07835 L
.28567 .06244 L
.28573 .07835 L
.28575 .09426 L
.2858 .11016 L
.28584 .09426 L
.28585 .11016 L
.28587 .12607 L
.28601 .11016 L
.28602 .12607 L
.28606 .14198 L
.28608 .12607 L
.28613 .14198 L
.28613 .15789 L
.28617 .14198 L
.28621 .15789 L
.28623 .1738 L
.28629 .18971 L
.28637 .20561 L
.2864 .22152 L
.28642 .23743 L
.28649 .22152 L
.2865 .20561 L
.28654 .18971 L
.2866 .20561 L
.2866 .22152 L
.2866 .23743 L
.2866 .22152 L
.28664 .20561 L
.28671 .22152 L
.28678 .20561 L
.28679 .22152 L
.28687 .23743 L
.28687 .25334 L
.28691 .26925 L
.28699 .28515 L
.287 .26925 L
.28704 .25334 L
Mistroke
.28705 .23743 L
.28711 .22152 L
.28715 .23743 L
.28718 .22152 L
.28718 .23743 L
.28727 .25334 L
.28732 .26925 L
.28735 .25334 L
.28741 .26925 L
.28742 .25334 L
.28745 .26925 L
.28755 .25334 L
.28757 .23743 L
.28759 .22152 L
.28771 .23743 L
.28776 .22152 L
.28781 .20561 L
.28787 .22152 L
.28791 .23743 L
.28804 .22152 L
.28805 .20561 L
.28806 .22152 L
.28822 .20561 L
.28829 .18971 L
.28833 .1738 L
.28842 .15789 L
.28843 .1738 L
.28846 .18971 L
.28848 .20561 L
.28856 .18971 L
.28876 .1738 L
.28884 .15789 L
.28893 .14198 L
.28899 .15789 L
.28905 .14198 L
.28907 .15789 L
.28907 .14198 L
.28915 .15789 L
.28922 .14198 L
.28923 .12607 L
.28942 .14198 L
.28945 .15789 L
.28945 .1738 L
.28949 .18971 L
.28949 .1738 L
.28958 .15789 L
.2896 .1738 L
.28966 .15789 L
.28968 .1738 L
.28979 .18971 L
Mistroke
.28983 .20561 L
.28989 .18971 L
.2899 .20561 L
.28993 .22152 L
.29004 .20561 L
.29004 .18971 L
.29006 .1738 L
.2901 .15789 L
.29016 .14198 L
.29017 .12607 L
.29027 .11016 L
.29028 .12607 L
.29041 .14198 L
.29042 .15789 L
.2905 .1738 L
.2905 .18971 L
.29052 .20561 L
.29056 .22152 L
.29065 .23743 L
.29071 .22152 L
.29075 .23743 L
.29078 .25334 L
.2908 .26925 L
.29081 .25334 L
.29086 .23743 L
.29086 .22152 L
.29092 .20561 L
.29094 .18971 L
.29099 .1738 L
.291 .15789 L
.291 .14198 L
.29104 .15789 L
.29106 .1738 L
.29108 .15789 L
.29108 .1738 L
.2911 .18971 L
.29118 .20561 L
.2912 .22152 L
.29125 .23743 L
.29128 .22152 L
.2914 .23743 L
.29151 .22152 L
.29156 .23743 L
.29157 .25334 L
.29165 .26925 L
.29171 .25334 L
.29173 .23743 L
.2918 .22152 L
.29181 .20561 L
.29181 .18971 L
Mistroke
.29193 .20561 L
.29197 .18971 L
.29203 .20561 L
.29206 .18971 L
.29217 .20561 L
.2922 .18971 L
.29223 .20561 L
.29228 .18971 L
.29229 .1738 L
.29231 .18971 L
.2924 .1738 L
.29242 .15789 L
.29252 .1738 L
.29256 .15789 L
.29256 .14198 L
.29258 .15789 L
.29259 .14198 L
.29264 .15789 L
.29274 .1738 L
.29282 .15789 L
.29284 .1738 L
.29284 .15789 L
.29285 .14198 L
.29292 .15789 L
.29292 .14198 L
.29293 .15789 L
.29295 .14198 L
.29301 .15789 L
.29307 .1738 L
.2932 .15789 L
.29321 .14198 L
.29324 .12607 L
.29325 .14198 L
.2934 .12607 L
.29345 .11016 L
.29359 .09426 L
.29361 .07835 L
.29362 .09426 L
.29365 .11016 L
.29366 .12607 L
.29378 .11016 L
.29381 .12607 L
.2939 .14198 L
.29391 .15789 L
.29425 .14198 L
.29429 .15789 L
.29437 .1738 L
.29437 .15789 L
.29443 .14198 L
.29448 .12607 L
Mistroke
.29454 .11016 L
.29458 .09426 L
.29458 .11016 L
.29461 .09426 L
.29467 .07835 L
.29481 .06244 L
.29491 .04653 L
.29491 .06244 L
.29497 .07835 L
.29498 .09426 L
.295 .07835 L
.29504 .09426 L
.29516 .07835 L
.29524 .06244 L
.29525 .07835 L
.29525 .06244 L
.29527 .04653 L
.29529 .06244 L
.2953 .07835 L
.29535 .06244 L
.29542 .07835 L
.29544 .06244 L
.29547 .04653 L
.29551 .03062 L
.29564 .01472 L
.29577 .03062 L
.29585 .01472 L
.2959 .03062 L
.29591 .01472 L
.29595 .03062 L
.29613 .04653 L
.29619 .06244 L
.29624 .07835 L
.29627 .09426 L
.29629 .07835 L
.29631 .06244 L
.29635 .04653 L
.29637 .03062 L
.29638 .01472 L
.29659 .03062 L
.29665 .04653 L
.29666 .03062 L
.29672 .01472 L
.29674 .03062 L
.29676 .01472 L
.29677 .03062 L
.29679 .01472 L
.29698 .03062 L
.29702 .04653 L
.29704 .06244 L
Mistroke
.29704 .04653 L
.2971 .03062 L
.29715 .01472 L
.29731 .03062 L
.29734 .04653 L
.29738 .03062 L
.2974 .01472 L
.29741 .03062 L
.29743 .01472 L
.2976 .03062 L
.29761 .01472 L
.29762 .03062 L
.29762 .01472 L
.29785 .03062 L
.29792 .01472 L
.29799 .03062 L
.29803 .04653 L
.29805 .03062 L
.29808 .01472 L
.29809 .03062 L
.29812 .01472 L
.29814 .03062 L
.29815 .04653 L
.29818 .06244 L
.2982 .07835 L
.29831 .06244 L
.29843 .04653 L
.29849 .03062 L
.2985 .01472 L
.29855 .03062 L
.29858 .01472 L
.29866 .03062 L
.29867 .04653 L
.29873 .06244 L
.29875 .07835 L
.29886 .09426 L
.29908 .11016 L
.2991 .12607 L
.29911 .11016 L
.29913 .09426 L
.29917 .11016 L
.29918 .12607 L
.2992 .14198 L
.29946 .15789 L
.29948 .1738 L
.29951 .15789 L
.29951 .1738 L
.29953 .18971 L
.29959 .1738 L
.29965 .15789 L
Mistroke
.29967 .14198 L
.29968 .15789 L
.29969 .14198 L
.29974 .12607 L
.29979 .11016 L
.29996 .12607 L
.29998 .14198 L
.29998 .15789 L
.30004 .14198 L
.30006 .12607 L
.30017 .11016 L
.30019 .09426 L
.3002 .11016 L
.30026 .09426 L
.30028 .11016 L
.30029 .09426 L
.30043 .11016 L
.30047 .12607 L
.30062 .11016 L
.30066 .12607 L
.30067 .14198 L
.30073 .12607 L
.30076 .14198 L
.30084 .12607 L
.30091 .11016 L
.30094 .09426 L
.30095 .07835 L
.301 .06244 L
.30101 .07835 L
.30116 .09426 L
.30117 .07835 L
.30127 .06244 L
.30135 .04653 L
.30136 .03062 L
.3014 .01472 L
.30154 .03062 L
.30155 .01472 L
.30165 .03062 L
.30174 .01472 L
.30191 .03062 L
.30196 .01472 L
.30205 .03062 L
.30207 .01472 L
.3021 .03062 L
.30211 .01472 L
.30244 .03062 L
.30245 .01472 L
.30245 .03062 L
.30246 .04653 L
.30255 .03062 L
Mistroke
.30257 .01472 L
.30289 .03062 L
.30289 .01472 L
.30296 .03062 L
.30296 .04653 L
.30303 .03062 L
.30308 .04653 L
.30309 .06244 L
.30309 .07835 L
.30311 .09426 L
.30313 .11016 L
.30322 .09426 L
.30323 .07835 L
.30327 .09426 L
.3033 .11016 L
.30335 .09426 L
.30341 .11016 L
.30341 .09426 L
.30343 .11016 L
.30345 .09426 L
.30349 .07835 L
.30351 .06244 L
.30355 .07835 L
.30355 .06244 L
.30363 .04653 L
.30364 .03062 L
.30365 .04653 L
.30371 .03062 L
.30375 .04653 L
.3038 .03062 L
.3039 .01472 L
.30409 .03062 L
.30414 .01472 L
.30417 .03062 L
.30441 .01472 L
.30444 .03062 L
.30449 .04653 L
.3046 .06244 L
.30468 .04653 L
.30471 .06244 L
.30475 .07835 L
.30476 .06244 L
.30483 .04653 L
.30487 .03062 L
.30489 .01472 L
.30511 .03062 L
.30513 .04653 L
.30516 .06244 L
.30523 .04653 L
.30523 .06244 L
Mistroke
.30524 .04653 L
.30525 .03062 L
.3053 .01472 L
.30533 .03062 L
.30539 .01472 L
.30541 .03062 L
.30542 .04653 L
.30551 .06244 L
.30561 .07835 L
.30578 .06244 L
.30585 .04653 L
.30585 .03062 L
.30589 .04653 L
.30614 .03062 L
.3062 .01472 L
.30626 .03062 L
.30634 .04653 L
.30634 .06244 L
.30635 .04653 L
.30637 .03062 L
.30638 .04653 L
.3065 .06244 L
.30654 .04653 L
.30656 .03062 L
.30665 .04653 L
.30665 .03062 L
.30666 .04653 L
.30668 .06244 L
.30668 .07835 L
.30677 .09426 L
.30679 .07835 L
.3068 .06244 L
.30681 .07835 L
.30691 .09426 L
.30694 .07835 L
.30696 .09426 L
.30697 .11016 L
.30701 .09426 L
.30702 .11016 L
.30713 .09426 L
.30715 .11016 L
.30722 .09426 L
.30724 .07835 L
.30726 .09426 L
.30762 .11016 L
.3077 .12607 L
.30771 .11016 L
.30784 .12607 L
.30791 .14198 L
.30793 .15789 L
Mistroke
.30795 .1738 L
.30802 .18971 L
.30811 .1738 L
.30812 .15789 L
.30815 .1738 L
.30821 .18971 L
.30825 .20561 L
.30825 .18971 L
.30831 .1738 L
.30837 .18971 L
.30847 .20561 L
.30859 .22152 L
.3086 .23743 L
.30871 .22152 L
.30874 .20561 L
.30876 .18971 L
.30888 .1738 L
.30891 .18971 L
.30893 .1738 L
.30895 .15789 L
.30896 .14198 L
.30898 .12607 L
.30899 .14198 L
.309 .12607 L
.30913 .14198 L
.30918 .15789 L
.30921 .1738 L
.30932 .18971 L
.30945 .20561 L
.30948 .18971 L
.30949 .20561 L
.3095 .22152 L
.30953 .20561 L
.30959 .18971 L
.30961 .20561 L
.30964 .22152 L
.30964 .20561 L
.30966 .18971 L
.30969 .1738 L
.30973 .18971 L
.30973 .1738 L
.30977 .18971 L
.30977 .20561 L
.30986 .22152 L
.30987 .20561 L
.3099 .18971 L
.30994 .20561 L
.30998 .18971 L
.30999 .20561 L
.31 .18971 L
Mistroke
.31004 .1738 L
.31006 .15789 L
.31021 .1738 L
.31031 .18971 L
.31038 .20561 L
.31045 .18971 L
.31046 .20561 L
.31054 .18971 L
.31061 .1738 L
.31066 .18971 L
.31066 .1738 L
.31069 .18971 L
.3107 .1738 L
.3107 .15789 L
.31072 .1738 L
.31076 .15789 L
.31088 .14198 L
.31093 .15789 L
.31096 .1738 L
.31099 .18971 L
.31109 .1738 L
.3111 .18971 L
.31117 .1738 L
.31123 .15789 L
.31127 .14198 L
.31133 .12607 L
.31135 .14198 L
.31146 .12607 L
.31149 .14198 L
.31153 .15789 L
.31155 .1738 L
.31168 .18971 L
.31172 .20561 L
.31173 .18971 L
.31176 .1738 L
.31178 .18971 L
.31179 .20561 L
.31185 .18971 L
.31187 .20561 L
.31188 .18971 L
.31189 .1738 L
.31195 .15789 L
.31197 .14198 L
.31202 .15789 L
.31205 .1738 L
.31206 .18971 L
.31211 .20561 L
.31215 .22152 L
.31215 .23743 L
.31217 .25334 L
Mistroke
.3122 .26925 L
.31223 .25334 L
.31234 .23743 L
.31236 .25334 L
.3124 .23743 L
.31242 .22152 L
.31252 .23743 L
.31255 .22152 L
.31257 .20561 L
.31263 .18971 L
.31266 .20561 L
.31269 .22152 L
.31271 .20561 L
.31273 .18971 L
.31278 .1738 L
.31289 .15789 L
.31291 .14198 L
.31303 .12607 L
.3131 .11016 L
.31311 .12607 L
.31312 .11016 L
.31317 .09426 L
.31321 .07835 L
.31323 .06244 L
.31335 .07835 L
.31349 .06244 L
.31355 .07835 L
.31356 .06244 L
.31363 .07835 L
.31367 .06244 L
.31368 .04653 L
.31368 .03062 L
.3137 .04653 L
.31377 .06244 L
.31381 .07835 L
.31383 .06244 L
.31383 .07835 L
.31386 .06244 L
.31388 .04653 L
.31389 .03062 L
.31392 .04653 L
.31396 .06244 L
.31407 .04653 L
.31413 .06244 L
.31414 .07835 L
.31416 .06244 L
.31428 .04653 L
.31431 .06244 L
.31434 .07835 L
.31438 .06244 L
Mistroke
.3144 .04653 L
.31464 .06244 L
.3147 .04653 L
.31471 .03062 L
.31474 .04653 L
.31479 .06244 L
.31481 .07835 L
.31481 .09426 L
.31481 .11016 L
.31486 .12607 L
.31494 .11016 L
.31497 .12607 L
.31497 .11016 L
.31506 .12607 L
.31506 .11016 L
.31507 .09426 L
.31513 .11016 L
.31514 .09426 L
.31515 .07835 L
.31526 .09426 L
.3153 .11016 L
.31536 .09426 L
.31541 .07835 L
.31543 .06244 L
.31545 .07835 L
.31545 .06244 L
.31548 .04653 L
.31549 .03062 L
.31552 .01472 L
.31556 .03062 L
.3156 .04653 L
.31567 .06244 L
.31571 .07835 L
.31571 .06244 L
.31577 .07835 L
.31581 .06244 L
.31595 .04653 L
.31596 .03062 L
.31604 .01472 L
.31605 .03062 L
.31607 .01472 L
.3162 .03062 L
.31622 .01472 L
.31624 .03062 L
.31627 .04653 L
.31636 .06244 L
.31659 .07835 L
.31664 .06244 L
.31675 .07835 L
.31678 .09426 L
Mistroke
.31684 .11016 L
.31694 .09426 L
.31697 .11016 L
.31698 .12607 L
.31701 .14198 L
.31702 .15789 L
.31706 .14198 L
.31708 .15789 L
.31722 .14198 L
.31723 .15789 L
.31725 .1738 L
.31727 .15789 L
.31727 .14198 L
.31727 .15789 L
.31731 .1738 L
.31734 .18971 L
.31735 .20561 L
.3174 .18971 L
.31742 .1738 L
.31751 .15789 L
.31757 .1738 L
.31759 .15789 L
.3176 .1738 L
.31764 .15789 L
.31768 .14198 L
.31774 .12607 L
.31776 .14198 L
.31777 .15789 L
.31778 .14198 L
.31787 .15789 L
.31789 .14198 L
.31796 .15789 L
.31796 .14198 L
.31799 .12607 L
.31806 .11016 L
.31813 .09426 L
.31816 .07835 L
.31817 .09426 L
.31821 .11016 L
.31833 .09426 L
.31833 .11016 L
.31834 .12607 L
.31838 .14198 L
.31846 .12607 L
.3185 .11016 L
.31855 .09426 L
.31866 .11016 L
.31873 .12607 L
.31875 .11016 L
.31875 .09426 L
Mistroke
.31877 .07835 L
.31882 .09426 L
.31882 .07835 L
.31893 .09426 L
.319 .11016 L
.319 .12607 L
.31901 .11016 L
.3192 .09426 L
.31924 .07835 L
.31931 .06244 L
.31931 .07835 L
.31933 .09426 L
.31937 .07835 L
.31941 .09426 L
.31946 .11016 L
.31949 .09426 L
.31951 .07835 L
.31954 .06244 L
.31954 .07835 L
.31955 .09426 L
.31957 .07835 L
.3196 .06244 L
.31961 .04653 L
.31964 .06244 L
.31971 .07835 L
.31971 .09426 L
.31979 .07835 L
.31981 .06244 L
.31988 .07835 L
.31994 .09426 L
.3201 .11016 L
.32017 .12607 L
.32022 .11016 L
.32028 .12607 L
.32036 .11016 L
.32041 .09426 L
.32044 .07835 L
.32051 .09426 L
.32054 .11016 L
.32055 .09426 L
.32056 .07835 L
.32058 .09426 L
.3206 .07835 L
.32061 .09426 L
.32072 .11016 L
.32078 .09426 L
.32079 .07835 L
.32085 .09426 L
.32094 .07835 L
.32095 .06244 L
Mistroke
.32096 .07835 L
.32104 .06244 L
.32106 .04653 L
.3212 .06244 L
.32122 .04653 L
.32122 .06244 L
.32123 .07835 L
.32133 .06244 L
.32135 .07835 L
.3214 .09426 L
.3214 .07835 L
.3214 .06244 L
.32145 .04653 L
.32154 .03062 L
.32154 .04653 L
.32156 .06244 L
.32161 .04653 L
.32162 .06244 L
.32169 .04653 L
.32181 .06244 L
.32181 .04653 L
.32186 .03062 L
.32187 .01472 L
.32194 .03062 L
.32195 .04653 L
.32196 .06244 L
.32197 .04653 L
.32198 .06244 L
.322 .04653 L
.32207 .03062 L
.32217 .01472 L
.32217 .03062 L
.32218 .04653 L
.3222 .06244 L
.32224 .04653 L
.32226 .03062 L
.32231 .04653 L
.32235 .06244 L
.32243 .07835 L
.3225 .06244 L
.32259 .04653 L
.32263 .03062 L
.32267 .04653 L
.32278 .06244 L
.3228 .07835 L
.32283 .06244 L
.32288 .07835 L
.32289 .09426 L
.32293 .11016 L
.32296 .12607 L
Mistroke
.32298 .14198 L
.32299 .15789 L
.32302 .14198 L
.32307 .15789 L
.32316 .14198 L
.32319 .15789 L
.32319 .1738 L
.32325 .15789 L
.32332 .14198 L
.32332 .12607 L
.32333 .14198 L
.32337 .15789 L
.32346 .1738 L
.3235 .15789 L
.32355 .14198 L
.32361 .15789 L
.32364 .14198 L
.32367 .15789 L
.32371 .14198 L
.32373 .15789 L
.32376 .1738 L
.32378 .18971 L
.32379 .20561 L
.32389 .22152 L
.32395 .23743 L
.32404 .25334 L
.32414 .23743 L
.32414 .25334 L
.32416 .23743 L
.32417 .22152 L
.32417 .23743 L
.32418 .25334 L
.3242 .23743 L
.32423 .22152 L
.32424 .23743 L
.32433 .25334 L
.32433 .26925 L
.32433 .25334 L
.32437 .26925 L
.32445 .25334 L
.32454 .26925 L
.32454 .25334 L
.32456 .26925 L
.32458 .28515 L
.3247 .30106 L
.32472 .28515 L
.32474 .26925 L
.32476 .25334 L
.32478 .26925 L
.32479 .28515 L
Mistroke
.32483 .30106 L
.32484 .28515 L
.32487 .26925 L
.32491 .25334 L
.32492 .23743 L
.32493 .22152 L
.3251 .20561 L
.32514 .18971 L
.32515 .1738 L
.32516 .18971 L
.32527 .1738 L
.32529 .15789 L
.32534 .1738 L
.32537 .15789 L
.32537 .14198 L
.32539 .15789 L
.32556 .1738 L
.32556 .18971 L
.32556 .20561 L
.32565 .18971 L
.32575 .20561 L
.32578 .18971 L
.32585 .1738 L
.32591 .18971 L
.32592 .20561 L
.32594 .18971 L
.32594 .20561 L
.32595 .22152 L
.32599 .20561 L
.32612 .18971 L
.32613 .1738 L
.32616 .18971 L
.32617 .20561 L
.32617 .22152 L
.32622 .20561 L
.32626 .18971 L
.3263 .20561 L
.32631 .18971 L
.32632 .20561 L
.32644 .22152 L
.32644 .20561 L
.32646 .22152 L
.32648 .20561 L
.32663 .22152 L
.32663 .20561 L
.32667 .22152 L
.32671 .20561 L
.32674 .18971 L
.32679 .20561 L
.3268 .22152 L
Mistroke
.32689 .23743 L
.32693 .25334 L
.32699 .26925 L
.32702 .28515 L
.32714 .30106 L
.32715 .31697 L
.32715 .33288 L
.32732 .31697 L
.32735 .33288 L
.32738 .34879 L
.32744 .3647 L
.32745 .34879 L
.32748 .33288 L
.32751 .34879 L
.32754 .3647 L
.32758 .34879 L
.32765 .33288 L
.32768 .31697 L
.3277 .30106 L
.32777 .28515 L
.32778 .30106 L
.32788 .28515 L
.328 .26925 L
.32801 .25334 L
.32807 .23743 L
.32808 .22152 L
.32819 .20561 L
.32826 .22152 L
.32832 .23743 L
.32837 .22152 L
.32838 .20561 L
.32841 .18971 L
.32844 .20561 L
.32851 .18971 L
.32853 .1738 L
.32854 .15789 L
.32856 .1738 L
.32859 .15789 L
.32863 .14198 L
.32866 .15789 L
.32867 .14198 L
.32876 .15789 L
.32886 .14198 L
.32888 .12607 L
.3289 .11016 L
.3289 .12607 L
.32893 .11016 L
.32895 .09426 L
.32895 .07835 L
.32896 .09426 L
Mistroke
.329 .11016 L
.329 .09426 L
.32917 .07835 L
.3292 .06244 L
.32925 .04653 L
.32928 .06244 L
.32951 .04653 L
.32952 .03062 L
.32953 .01472 L
.32983 .03062 L
.32983 .04653 L
.32983 .06244 L
.32991 .07835 L
.32994 .09426 L
.32999 .07835 L
.33013 .09426 L
.33018 .07835 L
.33023 .09426 L
.33024 .07835 L
.33025 .09426 L
.33036 .07835 L
.33041 .06244 L
.33044 .07835 L
.33044 .06244 L
.33053 .04653 L
.33056 .06244 L
.33064 .07835 L
.33076 .06244 L
.33078 .07835 L
.33078 .06244 L
.33086 .07835 L
.33099 .09426 L
.33107 .11016 L
.33109 .12607 L
.3311 .11016 L
.33111 .09426 L
.33112 .11016 L
.33116 .12607 L
.33126 .14198 L
.33128 .15789 L
.33132 .14198 L
.33135 .12607 L
.33136 .11016 L
.33142 .12607 L
.33147 .14198 L
.33149 .12607 L
.3315 .14198 L
.33152 .12607 L
.33155 .11016 L
.33156 .09426 L
Mistroke
.33159 .11016 L
.33165 .09426 L
.33166 .07835 L
.33169 .09426 L
.3317 .07835 L
.33172 .06244 L
.33174 .04653 L
.33177 .03062 L
.33191 .04653 L
.33191 .06244 L
.33203 .07835 L
.33204 .06244 L
.33206 .04653 L
.33208 .03062 L
.33217 .04653 L
.33222 .06244 L
.33224 .07835 L
.33227 .09426 L
.33227 .07835 L
.3323 .09426 L
.33245 .07835 L
.33249 .09426 L
.33251 .11016 L
.33253 .12607 L
.33259 .14198 L
.33262 .12607 L
.33263 .14198 L
.33264 .12607 L
.33268 .14198 L
.33276 .12607 L
.33277 .14198 L
.33287 .15789 L
.33289 .1738 L
.3329 .15789 L
.33296 .1738 L
.33298 .15789 L
.33305 .14198 L
.33309 .12607 L
.33316 .11016 L
.33318 .09426 L
.3332 .11016 L
.33322 .12607 L
.33323 .14198 L
.33323 .12607 L
.33323 .14198 L
.33326 .12607 L
.33333 .11016 L
.33338 .09426 L
.3334 .11016 L
.33341 .09426 L
Mistroke
.3335 .11016 L
.33352 .09426 L
.33356 .11016 L
.33358 .09426 L
.33359 .11016 L
.33359 .09426 L
.3338 .11016 L
.33388 .12607 L
.33394 .11016 L
.334 .12607 L
.334 .14198 L
.33405 .12607 L
.33409 .11016 L
.33415 .12607 L
.33415 .11016 L
.33431 .12607 L
.33444 .14198 L
.33456 .15789 L
.33478 .1738 L
.33479 .18971 L
.33483 .1738 L
.33484 .18971 L
.33485 .1738 L
.3349 .15789 L
.33501 .14198 L
.33503 .12607 L
.33503 .11016 L
.33507 .12607 L
.33511 .11016 L
.33513 .12607 L
.33517 .14198 L
.33532 .15789 L
.33535 .14198 L
.33536 .15789 L
.33536 .1738 L
.33542 .18971 L
.33544 .1738 L
.33545 .18971 L
.33546 .1738 L
.33548 .15789 L
.33559 .1738 L
.33561 .15789 L
.33563 .14198 L
.33564 .15789 L
.3357 .14198 L
.33574 .15789 L
.33583 .14198 L
.33599 .12607 L
.33608 .11016 L
.33613 .12607 L
Mistroke
.33623 .11016 L
.33626 .12607 L
.33632 .14198 L
.33637 .15789 L
.33649 .1738 L
.33649 .18971 L
.33661 .20561 L
.33669 .22152 L
.33674 .23743 L
.3369 .25334 L
.3369 .26925 L
.33692 .28515 L
.33692 .30106 L
.33693 .28515 L
.33697 .30106 L
.33705 .31697 L
.33706 .33288 L
.33713 .31697 L
.33717 .30106 L
.33725 .31697 L
.33726 .30106 L
.33727 .28515 L
.33747 .26925 L
.33751 .28515 L
.33753 .30106 L
.33757 .31697 L
.33765 .30106 L
.33769 .28515 L
.3377 .26925 L
.33771 .28515 L
.33775 .26925 L
.33778 .28515 L
.33781 .26925 L
.3379 .25334 L
.33791 .26925 L
.33795 .28515 L
.33796 .26925 L
.33806 .28515 L
.33808 .26925 L
.33809 .25334 L
.3381 .23743 L
.3381 .22152 L
.33812 .20561 L
.33813 .18971 L
.33831 .1738 L
.33832 .15789 L
.33836 .14198 L
.33841 .15789 L
.33842 .1738 L
.33843 .15789 L
Mistroke
.33854 .14198 L
.33855 .12607 L
.33874 .14198 L
.33876 .15789 L
.33877 .1738 L
.33877 .18971 L
.33888 .20561 L
.33891 .22152 L
.33892 .20561 L
.33892 .22152 L
.339 .23743 L
.33913 .25334 L
.33916 .23743 L
.33935 .22152 L
.33935 .23743 L
.33949 .25334 L
.33958 .23743 L
.33964 .25334 L
.33968 .23743 L
.3398 .25334 L
.33982 .23743 L
.33988 .25334 L
.33996 .23743 L
.34002 .25334 L
.34009 .26925 L
.34009 .25334 L
.3401 .26925 L
.34012 .28515 L
.34014 .26925 L
.34016 .25334 L
.34026 .23743 L
.34028 .22152 L
.34038 .20561 L
.3404 .18971 L
.34049 .20561 L
.34054 .18971 L
.34057 .1738 L
.34058 .15789 L
.34059 .1738 L
.34062 .18971 L
.34065 .1738 L
.34068 .15789 L
.34075 .1738 L
.34079 .15789 L
.34082 .1738 L
.34099 .15789 L
.34105 .14198 L
.34107 .12607 L
.3411 .11016 L
.34111 .12607 L
Mistroke
.34117 .11016 L
.34117 .09426 L
.34122 .11016 L
.34127 .12607 L
.34129 .11016 L
.34141 .09426 L
.34149 .07835 L
.3415 .09426 L
.34151 .07835 L
.34155 .06244 L
.34161 .04653 L
.34165 .03062 L
.34166 .01472 L
.34168 .03062 L
.3417 .01472 L
.34184 .03062 L
.34193 .04653 L
.34195 .03062 L
.34204 .01472 L
.3421 .03062 L
.3422 .01472 L
.34241 .03062 L
.34249 .04653 L
.34251 .06244 L
.34252 .07835 L
.34255 .09426 L
.3426 .07835 L
.3426 .09426 L
.34279 .11016 L
.34283 .09426 L
.34286 .07835 L
.34286 .09426 L
.34286 .11016 L
.34296 .09426 L
.34298 .11016 L
.34302 .12607 L
.34322 .11016 L
.34322 .12607 L
.34324 .11016 L
.34327 .12607 L
.3433 .14198 L
.3433 .12607 L
.34332 .11016 L
.34333 .12607 L
.34334 .14198 L
.34336 .12607 L
.34341 .11016 L
.34352 .09426 L
.34366 .07835 L
.3438 .06244 L
Mistroke
.3438 .07835 L
.34393 .09426 L
.34395 .11016 L
.34397 .12607 L
.34398 .14198 L
.34398 .12607 L
.34405 .11016 L
.34405 .12607 L
.34407 .11016 L
.34415 .09426 L
.34418 .11016 L
.34428 .12607 L
.34431 .14198 L
.34436 .15789 L
.34437 .1738 L
.34439 .18971 L
.3444 .20561 L
.34442 .18971 L
.34443 .1738 L
.34446 .18971 L
.34456 .1738 L
.34467 .15789 L
.3447 .14198 L
.3447 .12607 L
.34473 .14198 L
.34476 .15789 L
.34476 .14198 L
.34478 .12607 L
.34486 .11016 L
.34492 .12607 L
.34496 .11016 L
.34501 .09426 L
.34502 .07835 L
.34504 .09426 L
.34505 .11016 L
.34506 .12607 L
.34507 .11016 L
.34507 .09426 L
.34518 .07835 L
.34521 .06244 L
.34521 .07835 L
.34526 .06244 L
.34528 .04653 L
.34532 .06244 L
.34545 .07835 L
.34551 .09426 L
.34552 .07835 L
.34552 .06244 L
.34556 .04653 L
.3456 .03062 L
Mistroke
.34561 .04653 L
.3458 .03062 L
.34582 .01472 L
.34612 .03062 L
.34617 .01472 L
.34624 .03062 L
.34627 .01472 L
.34637 .03062 L
.34648 .01472 L
.34659 .03062 L
.34659 .04653 L
.34675 .06244 L
.34689 .04653 L
.34692 .03062 L
.34703 .01472 L
.34706 .03062 L
.34706 .04653 L
.34709 .06244 L
.3471 .04653 L
.34712 .06244 L
.3472 .04653 L
.3472 .03062 L
.34724 .01472 L
.34728 .03062 L
.34729 .01472 L
.34737 .03062 L
.34737 .01472 L
.34753 .03062 L
.34763 .01472 L
.34773 .03062 L
.34774 .04653 L
.34788 .03062 L
.34814 .04653 L
.34815 .06244 L
.34817 .07835 L
.34817 .09426 L
.34819 .11016 L
.34822 .09426 L
.34835 .11016 L
.34839 .09426 L
.34849 .07835 L
.3485 .06244 L
.34853 .04653 L
.34858 .06244 L
.34858 .04653 L
.34861 .03062 L
.34862 .01472 L
.34899 .03062 L
.34901 .01472 L
.34903 .03062 L
Mistroke
.34903 .01472 L
.34905 .03062 L
.3491 .04653 L
.3491 .03062 L
.34911 .04653 L
.34912 .03062 L
.34917 .04653 L
.34917 .06244 L
.34918 .04653 L
.3492 .06244 L
.34922 .04653 L
.34936 .03062 L
.34938 .01472 L
.34963 .03062 L
.34963 .04653 L
.34966 .06244 L
.34967 .07835 L
.34969 .06244 L
.34969 .07835 L
.34981 .06244 L
.34983 .04653 L
.34987 .06244 L
.34988 .07835 L
.34993 .06244 L
.34993 .07835 L
.34993 .06244 L
.35002 .04653 L
.35009 .03062 L
.35013 .01472 L
.35018 .03062 L
.35019 .01472 L
.35052 .03062 L
.35053 .01472 L
.35071 .03062 L
.35074 .01472 L
.35083 .03062 L
.35099 .01472 L
.35103 .03062 L
.35112 .04653 L
.35115 .03062 L
.35116 .01472 L
.35123 .03062 L
.3513 .04653 L
.35131 .03062 L
.35135 .01472 L
.35136 .03062 L
.35143 .01472 L
.35145 .03062 L
.35151 .04653 L
.35153 .06244 L
Mistroke
.35158 .04653 L
.3516 .06244 L
.35162 .07835 L
.35172 .09426 L
.35179 .11016 L
.35194 .12607 L
.35197 .11016 L
.352 .09426 L
.35215 .11016 L
.35216 .12607 L
.35221 .14198 L
.35223 .12607 L
.35226 .11016 L
.3523 .12607 L
.35235 .11016 L
.3524 .09426 L
.35245 .11016 L
.35246 .12607 L
.35255 .14198 L
.35261 .12607 L
.35265 .14198 L
.35265 .12607 L
.35268 .11016 L
.35269 .09426 L
.35269 .11016 L
.35269 .12607 L
.35282 .11016 L
.35284 .09426 L
.35285 .11016 L
.35288 .12607 L
.35298 .11016 L
.35313 .12607 L
.35314 .14198 L
.35317 .12607 L
.35321 .14198 L
.35328 .15789 L
.35335 .14198 L
.35341 .15789 L
.35343 .14198 L
.35345 .15789 L
.35345 .14198 L
.35346 .12607 L
.35346 .14198 L
.3535 .12607 L
.35358 .14198 L
.35361 .12607 L
.35373 .14198 L
.35385 .15789 L
.35392 .14198 L
.35404 .12607 L
Mistroke
.35406 .11016 L
.35412 .09426 L
.35416 .07835 L
.35422 .09426 L
.35424 .07835 L
.35428 .09426 L
.35429 .11016 L
.3543 .09426 L
.35431 .07835 L
.35433 .09426 L
.35434 .07835 L
.3544 .09426 L
.35451 .07835 L
.35451 .06244 L
.35453 .04653 L
.35453 .03062 L
.35456 .04653 L
.35457 .03062 L
.35471 .04653 L
.35473 .03062 L
.35477 .04653 L
.35488 .06244 L
.35492 .04653 L
.35498 .03062 L
.355 .01472 L
.35501 .03062 L
.3552 .04653 L
.35521 .06244 L
.35526 .04653 L
.35529 .03062 L
.35538 .01472 L
.35541 .03062 L
.35545 .01472 L
.35549 .03062 L
.35558 .01472 L
.35566 .03062 L
.35569 .01472 L
.35569 .03062 L
.35572 .04653 L
.35577 .03062 L
.35578 .04653 L
.35584 .06244 L
.35595 .04653 L
.35607 .03062 L
.35635 .04653 L
.3565 .03062 L
.35652 .04653 L
.35653 .03062 L
.35654 .04653 L
.35664 .03062 L
Mistroke
.35668 .01472 L
.35687 .03062 L
.35688 .04653 L
.35689 .06244 L
.35692 .04653 L
.35698 .06244 L
.357 .07835 L
.35703 .06244 L
.35703 .04653 L
.35704 .03062 L
.35704 .04653 L
.35718 .03062 L
.35723 .01472 L
.35736 .03062 L
.35754 .04653 L
.35757 .03062 L
.3576 .04653 L
.35768 .03062 L
.35779 .04653 L
.35789 .06244 L
.3579 .04653 L
.35795 .03062 L
.35797 .01472 L
.35799 .03062 L
.358 .01472 L
.3581 .03062 L
.35816 .04653 L
.35822 .03062 L
.35824 .04653 L
.35826 .03062 L
.35836 .01472 L
.35844 .03062 L
.35847 .01472 L
.35848 .03062 L
.35856 .04653 L
.35861 .06244 L
.35868 .04653 L
.35873 .06244 L
.35883 .04653 L
.35894 .06244 L
.35912 .07835 L
.35915 .09426 L
.35917 .11016 L
.35918 .09426 L
.35919 .07835 L
.35919 .06244 L
.35925 .07835 L
.35929 .06244 L
.35938 .07835 L
.35946 .06244 L
Mistroke
.35953 .04653 L
.35954 .03062 L
.35957 .01472 L
.35972 .03062 L
.35976 .01472 L
.35992 .03062 L
.36001 .04653 L
.36005 .06244 L
.36008 .07835 L
.36014 .06244 L
.36016 .07835 L
.36021 .09426 L
.36021 .07835 L
.36022 .06244 L
.36029 .04653 L
.36029 .03062 L
.36034 .04653 L
.36034 .03062 L
.36035 .04653 L
.36038 .03062 L
.36043 .04653 L
.36047 .03062 L
.3605 .04653 L
.3606 .03062 L
.36065 .04653 L
.36066 .03062 L
.36073 .01472 L
.36073 .03062 L
.36074 .01472 L
.36095 .03062 L
.36104 .01472 L
.36124 .03062 L
.36131 .01472 L
.36132 .03062 L
.36139 .01472 L
.36144 .03062 L
.36144 .01472 L
.36188 .03062 L
.36192 .04653 L
.36194 .03062 L
.36194 .04653 L
.36197 .06244 L
.36201 .04653 L
.36202 .03062 L
.36208 .04653 L
.36218 .06244 L
.36225 .04653 L
.36229 .03062 L
.36234 .01472 L
.36242 .03062 L
Mistroke
.36242 .04653 L
.36242 .06244 L
.36244 .07835 L
.36249 .09426 L
.36254 .11016 L
.36255 .09426 L
.36259 .07835 L
.3626 .09426 L
.3626 .07835 L
.36261 .09426 L
.36263 .11016 L
.36273 .09426 L
.36281 .07835 L
.36285 .09426 L
.36291 .11016 L
.36293 .09426 L
.36294 .11016 L
.36295 .09426 L
.36296 .07835 L
.36302 .09426 L
.36304 .11016 L
.36312 .12607 L
.36313 .14198 L
.36314 .15789 L
.36324 .1738 L
.36336 .18971 L
.36342 .1738 L
.36343 .18971 L
.36345 .1738 L
.3635 .18971 L
.36354 .1738 L
.36359 .18971 L
.36359 .20561 L
.36363 .22152 L
.36369 .23743 L
.3637 .22152 L
.36371 .23743 L
.36387 .22152 L
.3639 .23743 L
.36391 .25334 L
.36393 .23743 L
.36403 .25334 L
.36404 .23743 L
.3641 .25334 L
.36416 .23743 L
.36416 .22152 L
.3645 .20561 L
.3646 .22152 L
.3646 .23743 L
.36466 .25334 L
Mistroke
.36471 .26925 L
.36476 .28515 L
.36477 .30106 L
.36477 .31697 L
.36479 .30106 L
.36492 .28515 L
.36494 .30106 L
.36495 .31697 L
.36506 .33288 L
.36512 .34879 L
.36514 .3647 L
.36519 .3806 L
.36521 .39651 L
.36521 .3806 L
.36527 .3647 L
.36531 .34879 L
.3654 .33288 L
.36545 .31697 L
.36547 .30106 L
.36558 .31697 L
.36559 .30106 L
.36563 .28515 L
.36572 .30106 L
.36573 .28515 L
.36578 .26925 L
.36579 .28515 L
.36588 .26925 L
.36592 .28515 L
.36598 .26925 L
.36598 .28515 L
.36609 .26925 L
.36611 .25334 L
.36615 .23743 L
.36621 .22152 L
.36622 .23743 L
.36626 .25334 L
.36628 .26925 L
.36646 .25334 L
.36649 .26925 L
.3665 .28515 L
.3665 .26925 L
.36652 .25334 L
.36655 .26925 L
.36675 .25334 L
.36679 .26925 L
.36681 .25334 L
.36684 .26925 L
.36686 .28515 L
.36687 .26925 L
.36703 .25334 L
Mistroke
.36712 .26925 L
.36717 .28515 L
.36717 .26925 L
.36718 .25334 L
.36722 .26925 L
.36728 .25334 L
.36729 .26925 L
.3673 .28515 L
.36733 .30106 L
.36735 .31697 L
.36737 .33288 L
.36738 .31697 L
.36739 .30106 L
.3675 .31697 L
.36752 .30106 L
.36754 .31697 L
.36757 .33288 L
.36759 .34879 L
.36763 .3647 L
.36766 .34879 L
.36773 .33288 L
.36775 .34879 L
.36791 .33288 L
.36792 .31697 L
.36796 .30106 L
.36798 .28515 L
.36801 .30106 L
.36804 .31697 L
.36805 .30106 L
.36806 .28515 L
.36821 .30106 L
.36828 .28515 L
.36832 .26925 L
.36845 .25334 L
.36854 .23743 L
.36854 .25334 L
.36864 .26925 L
.36877 .28515 L
.36881 .26925 L
.36882 .25334 L
.36883 .23743 L
.36883 .22152 L
.36893 .20561 L
.36898 .22152 L
.36904 .23743 L
.3691 .22152 L
.36911 .20561 L
.36913 .22152 L
.36916 .23743 L
.36919 .25334 L
Mistroke
.36925 .23743 L
.36926 .22152 L
.36928 .23743 L
.36931 .22152 L
.36931 .23743 L
.36935 .25334 L
.36935 .23743 L
.36941 .25334 L
.36946 .26925 L
.36948 .25334 L
.36954 .23743 L
.36961 .25334 L
.36964 .23743 L
.36968 .22152 L
.36971 .23743 L
.36978 .22152 L
.36988 .20561 L
.36994 .22152 L
.36996 .23743 L
.37 .25334 L
.37002 .23743 L
.37009 .22152 L
.37009 .20561 L
.37014 .18971 L
.37017 .20561 L
.37018 .22152 L
.3702 .23743 L
.37022 .22152 L
.37022 .20561 L
.37036 .22152 L
.37037 .20561 L
.37044 .18971 L
.37045 .1738 L
.37047 .15789 L
.37052 .14198 L
.37056 .15789 L
.37059 .14198 L
.3706 .15789 L
.37066 .1738 L
.37068 .15789 L
.37074 .1738 L
.37089 .15789 L
.37092 .1738 L
.37098 .15789 L
.37102 .1738 L
.37104 .15789 L
.37105 .14198 L
.3711 .12607 L
.37112 .11016 L
.37113 .12607 L
Mistroke
.37117 .14198 L
.37134 .12607 L
.37135 .11016 L
.37136 .12607 L
.37138 .14198 L
.37145 .12607 L
.37148 .14198 L
.37153 .15789 L
.37155 .14198 L
.37157 .12607 L
.37157 .11016 L
.3716 .09426 L
.37164 .07835 L
.37166 .09426 L
.37167 .11016 L
.3717 .12607 L
.37176 .14198 L
.37177 .12607 L
.37181 .11016 L
.37181 .12607 L
.37184 .11016 L
.37185 .09426 L
.37189 .07835 L
.372 .09426 L
.37212 .11016 L
.3722 .12607 L
.37232 .11016 L
.37237 .12607 L
.37242 .14198 L
.37242 .12607 L
.37244 .14198 L
.37246 .12607 L
.37251 .11016 L
.37255 .09426 L
.37256 .07835 L
.37274 .09426 L
.3728 .11016 L
.37282 .09426 L
.37287 .07835 L
.37295 .06244 L
.37296 .04653 L
.37302 .03062 L
.37304 .04653 L
.37306 .06244 L
.37311 .07835 L
.37313 .06244 L
.37319 .04653 L
.37319 .03062 L
.37321 .01472 L
.37325 .03062 L
Mistroke
.37332 .01472 L
.37333 .03062 L
.37333 .04653 L
.37334 .06244 L
.37336 .07835 L
.37346 .09426 L
.37351 .07835 L
.37355 .06244 L
.37378 .04653 L
.37391 .06244 L
.37402 .07835 L
.37403 .06244 L
.37406 .04653 L
.37409 .06244 L
.37423 .04653 L
.37424 .06244 L
.37428 .07835 L
.37432 .09426 L
.37437 .07835 L
.37438 .06244 L
.3744 .07835 L
.37441 .06244 L
.37442 .04653 L
.37443 .03062 L
.37451 .01472 L
.37455 .03062 L
.37457 .01472 L
.37462 .03062 L
.37465 .01472 L
.37477 .03062 L
.37479 .01472 L
.3748 .03062 L
.37481 .04653 L
.37483 .03062 L
.37485 .04653 L
.3749 .06244 L
.37506 .07835 L
.37511 .06244 L
.37515 .07835 L
.37516 .06244 L
.37518 .04653 L
.37521 .03062 L
.37521 .04653 L
.37524 .06244 L
.37541 .04653 L
.37543 .03062 L
.37543 .04653 L
.3755 .06244 L
.37554 .07835 L
.37558 .06244 L
Mistroke
.37565 .04653 L
.37565 .06244 L
.37566 .07835 L
.37574 .06244 L
.37574 .07835 L
.37577 .06244 L
.37581 .04653 L
.37585 .06244 L
.37587 .07835 L
.37608 .09426 L
.37615 .11016 L
.37621 .12607 L
.37624 .14198 L
.37632 .15789 L
.3764 .14198 L
.37645 .12607 L
.37647 .14198 L
.37649 .15789 L
.3765 .1738 L
.37652 .15789 L
.37652 .1738 L
.37654 .15789 L
.37657 .14198 L
.37659 .15789 L
.3766 .14198 L
.37661 .12607 L
.37666 .14198 L
.37668 .12607 L
.37669 .14198 L
.37675 .12607 L
.37679 .14198 L
.37692 .12607 L
.37692 .14198 L
.37694 .15789 L
.37694 .14198 L
.377 .12607 L
.377 .14198 L
.37703 .12607 L
.37703 .11016 L
.3771 .12607 L
.37714 .11016 L
.37721 .12607 L
.37726 .14198 L
.37728 .12607 L
.37733 .11016 L
.37734 .12607 L
.37737 .14198 L
.37738 .15789 L
.37739 .14198 L
.37742 .12607 L
Mistroke
.37749 .14198 L
.37764 .15789 L
.37765 .1738 L
.37765 .18971 L
.37769 .1738 L
.37782 .15789 L
.37783 .1738 L
.37783 .15789 L
.3779 .14198 L
.37791 .15789 L
.37793 .1738 L
.37798 .15789 L
.378 .14198 L
.37807 .12607 L
.37814 .11016 L
.37816 .12607 L
.37826 .11016 L
.37827 .09426 L
.37829 .07835 L
.3783 .09426 L
.37834 .11016 L
.37842 .12607 L
.37843 .11016 L
.37844 .12607 L
.37846 .11016 L
.37846 .09426 L
.37848 .07835 L
.37854 .06244 L
.37862 .04653 L
.37864 .06244 L
.37864 .04653 L
.37865 .03062 L
.37869 .04653 L
.37874 .03062 L
.37878 .01472 L
.37886 .03062 L
.3789 .04653 L
.37892 .03062 L
.37893 .01472 L
.37926 .03062 L
.37937 .01472 L
.37941 .03062 L
.37954 .01472 L
.37955 .03062 L
.37966 .01472 L
.37976 .03062 L
.37983 .01472 L
.38019 .03062 L
.38022 .01472 L
.38028 .03062 L
Mistroke
.38033 .04653 L
.38037 .06244 L
.38045 .07835 L
.38052 .06244 L
.38052 .04653 L
.38069 .03062 L
.38071 .04653 L
.38074 .03062 L
.3808 .01472 L
.38083 .03062 L
.38091 .04653 L
.38102 .03062 L
.38105 .04653 L
.38106 .03062 L
.38108 .01472 L
.38119 .03062 L
.38128 .01472 L
.38154 .03062 L
.38159 .01472 L
.38175 .03062 L
.38175 .01472 L
.38216 .03062 L
.38218 .01472 L
.38219 .03062 L
.3822 .01472 L
.38227 .03062 L
.38229 .01472 L
.38256 .03062 L
.38256 .04653 L
.38256 .06244 L
.38259 .04653 L
.38259 .06244 L
.38265 .07835 L
.38273 .09426 L
.38273 .07835 L
.38283 .09426 L
.38285 .07835 L
.38291 .09426 L
.38306 .11016 L
.38307 .09426 L
.38311 .07835 L
.38314 .09426 L
.38321 .11016 L
.38321 .12607 L
.38324 .11016 L
.38328 .12607 L
.38328 .14198 L
.38334 .12607 L
.38335 .14198 L
.38338 .12607 L
Mistroke
.38346 .11016 L
.38347 .12607 L
.38347 .11016 L
.38347 .12607 L
.38349 .14198 L
.38352 .12607 L
.38354 .14198 L
.38362 .15789 L
.38371 .1738 L
.38371 .18971 L
.38373 .20561 L
.38375 .18971 L
.38376 .1738 L
.38378 .15789 L
.38382 .14198 L
.38384 .12607 L
.38385 .11016 L
.3839 .09426 L
.38393 .07835 L
.38395 .06244 L
.38406 .04653 L
.38406 .03062 L
.38409 .01472 L
.38425 .03062 L
.38426 .01472 L
.38434 .03062 L
.38434 .01472 L
.38484 .03062 L
.38485 .04653 L
.38488 .06244 L
.38489 .07835 L
.3849 .09426 L
.38499 .11016 L
.38506 .12607 L
.38506 .14198 L
.38512 .12607 L
.38513 .14198 L
.38522 .12607 L
.38533 .14198 L
.38534 .12607 L
.3854 .14198 L
.38542 .12607 L
.38543 .14198 L
.38546 .12607 L
.38548 .11016 L
.3855 .09426 L
.38551 .11016 L
.38553 .12607 L
.38555 .14198 L
.38557 .12607 L
Mistroke
.38557 .14198 L
.38558 .15789 L
.38559 .14198 L
.38561 .12607 L
.38562 .11016 L
.38564 .09426 L
.38565 .07835 L
.38566 .09426 L
.38571 .07835 L
.38575 .09426 L
.38575 .07835 L
.38583 .09426 L
.38583 .11016 L
.38592 .09426 L
.38593 .07835 L
.38594 .09426 L
.386 .07835 L
.38602 .09426 L
.38607 .11016 L
.38607 .12607 L
.38609 .14198 L
.38619 .12607 L
.38619 .11016 L
.38624 .12607 L
.38624 .14198 L
.3863 .12607 L
.38635 .14198 L
.3864 .15789 L
.38641 .1738 L
.38644 .15789 L
.38652 .14198 L
.38661 .12607 L
.38661 .14198 L
.38662 .15789 L
.38664 .1738 L
.38666 .15789 L
.38667 .14198 L
.38668 .12607 L
.3867 .14198 L
.38671 .12607 L
.38671 .11016 L
.38682 .09426 L
.38683 .07835 L
.38685 .09426 L
.38691 .11016 L
.38691 .09426 L
.38696 .07835 L
.387 .09426 L
.3871 .11016 L
.38712 .09426 L
Mistroke
.38718 .11016 L
.38727 .09426 L
.38729 .07835 L
.38733 .06244 L
.38733 .04653 L
.38736 .03062 L
.38748 .01472 L
.38752 .03062 L
.38753 .04653 L
.38754 .03062 L
.38755 .01472 L
.38773 .03062 L
.38774 .01472 L
.38776 .03062 L
.38781 .01472 L
.38794 .03062 L
.38795 .04653 L
.38799 .06244 L
.38802 .07835 L
.38805 .06244 L
.38813 .04653 L
.38828 .06244 L
.38832 .04653 L
.38836 .03062 L
.38838 .04653 L
.38842 .06244 L
.38842 .07835 L
.38843 .06244 L
.38846 .07835 L
.38846 .06244 L
.38849 .04653 L
.38857 .03062 L
.38871 .04653 L
.38876 .06244 L
.38886 .07835 L
.38893 .06244 L
.38894 .07835 L
.389 .06244 L
.38902 .07835 L
.38905 .09426 L
.38908 .11016 L
.38911 .12607 L
.38916 .11016 L
.38917 .09426 L
.38918 .07835 L
.3892 .09426 L
.3892 .11016 L
.38924 .09426 L
.38927 .07835 L
.38928 .09426 L
Mistroke
.38928 .07835 L
.38938 .06244 L
.38939 .07835 L
.38948 .09426 L
.38951 .11016 L
.38952 .09426 L
.38957 .07835 L
.38959 .06244 L
.38964 .04653 L
.38973 .03062 L
.38982 .01472 L
.38982 .03062 L
.38989 .01472 L
.38993 .03062 L
.38997 .04653 L
.38998 .03062 L
.38999 .01472 L
.39003 .03062 L
.39004 .04653 L
.39006 .03062 L
.39006 .04653 L
.39012 .06244 L
.39014 .07835 L
.39027 .06244 L
.39034 .04653 L
.39035 .03062 L
.39036 .01472 L
.39044 .03062 L
.3905 .04653 L
.39054 .06244 L
.39056 .07835 L
.39061 .09426 L
.39067 .07835 L
.39069 .09426 L
.39077 .07835 L
.39079 .06244 L
.3908 .04653 L
.3909 .03062 L
.39097 .01472 L
.39109 .03062 L
.39111 .04653 L
.39119 .03062 L
.39122 .01472 L
.39131 .03062 L
.39143 .01472 L
.39156 .03062 L
.39161 .04653 L
.39168 .03062 L
.39175 .04653 L
.39176 .03062 L
Mistroke
.3918 .04653 L
.39184 .06244 L
.39185 .07835 L
.39185 .06244 L
.39185 .07835 L
.39195 .06244 L
.39197 .07835 L
.39204 .09426 L
.39216 .11016 L
.39221 .12607 L
.39223 .11016 L
.39228 .09426 L
.39238 .11016 L
.39245 .12607 L
.39249 .11016 L
.3925 .12607 L
.3926 .11016 L
.39262 .12607 L
.39263 .14198 L
.39264 .12607 L
.39264 .11016 L
.39265 .09426 L
.39268 .11016 L
.39268 .09426 L
.39271 .07835 L
.39282 .06244 L
.39292 .04653 L
.39292 .03062 L
.39294 .04653 L
.39298 .06244 L
.393 .07835 L
.39303 .06244 L
.39311 .04653 L
.39317 .06244 L
.39324 .07835 L
.39326 .06244 L
.39329 .07835 L
.3934 .09426 L
.39343 .07835 L
.39348 .06244 L
.39362 .04653 L
.39365 .06244 L
.39367 .04653 L
.39367 .06244 L
.39369 .07835 L
.39372 .09426 L
.39372 .07835 L
.39373 .06244 L
.39386 .07835 L
.39387 .06244 L
Mistroke
.39389 .07835 L
.39391 .06244 L
.39395 .07835 L
.39395 .09426 L
.39404 .11016 L
.39404 .09426 L
.39411 .11016 L
.39413 .12607 L
.39414 .11016 L
.39416 .09426 L
.39431 .11016 L
.39432 .09426 L
.39434 .11016 L
.39436 .09426 L
.3944 .07835 L
.39443 .09426 L
.39444 .11016 L
.39447 .09426 L
.39449 .11016 L
.39452 .12607 L
.39454 .14198 L
.39471 .15789 L
.39472 .1738 L
.39475 .18971 L
.39479 .1738 L
.3948 .15789 L
.39483 .1738 L
.39483 .18971 L
.39496 .20561 L
.39498 .18971 L
.39501 .1738 L
.39506 .15789 L
.3951 .1738 L
.39511 .18971 L
.39512 .1738 L
.39523 .18971 L
.39527 .1738 L
.3953 .15789 L
.39534 .1738 L
.3954 .18971 L
.39547 .20561 L
.39556 .22152 L
.39557 .20561 L
.39561 .22152 L
.39566 .23743 L
.39584 .22152 L
.39584 .23743 L
.39588 .25334 L
.39589 .26925 L
.39591 .25334 L
Mistroke
.39596 .23743 L
.39597 .25334 L
.39597 .26925 L
.39603 .25334 L
.39607 .23743 L
.39614 .25334 L
.39618 .26925 L
.39618 .25334 L
.39619 .23743 L
.39621 .22152 L
.39623 .23743 L
.39629 .22152 L
.39634 .20561 L
.39637 .18971 L
.39638 .20561 L
.39643 .18971 L
.39647 .1738 L
.39653 .18971 L
.39657 .20561 L
.39662 .22152 L
.39667 .20561 L
.39669 .22152 L
.3967 .23743 L
.39675 .25334 L
.39682 .26925 L
.39686 .28515 L
.39692 .26925 L
.39695 .25334 L
.39698 .26925 L
.39698 .28515 L
.39702 .30106 L
.39702 .28515 L
.39704 .30106 L
.3971 .28515 L
.39712 .30106 L
.39716 .28515 L
.3972 .26925 L
.39729 .28515 L
.3973 .30106 L
.39734 .31697 L
.39734 .33288 L
.39738 .31697 L
.39759 .33288 L
.39762 .31697 L
.39766 .33288 L
.39769 .31697 L
.39774 .33288 L
.39775 .31697 L
.39777 .30106 L
.39784 .28515 L
Mistroke
.39786 .26925 L
.39789 .25334 L
.3979 .26925 L
.39797 .28515 L
.39799 .26925 L
.39803 .28515 L
.39807 .30106 L
.39808 .28515 L
.3981 .26925 L
.39813 .25334 L
.39816 .23743 L
.3982 .22152 L
.39832 .20561 L
.39835 .22152 L
.39842 .23743 L
.39851 .22152 L
.39858 .23743 L
.39858 .22152 L
.3986 .23743 L
.39862 .22152 L
.39865 .20561 L
.39865 .18971 L
.39874 .20561 L
.39875 .18971 L
.39876 .20561 L
.39879 .18971 L
.39879 .20561 L
.39884 .18971 L
.39885 .1738 L
.39887 .15789 L
.3989 .1738 L
.39896 .18971 L
.39897 .20561 L
.39898 .18971 L
.39903 .1738 L
.39919 .15789 L
.3993 .1738 L
.39934 .15789 L
.39941 .14198 L
.39947 .15789 L
.39947 .1738 L
.39947 .15789 L
.39951 .1738 L
.39953 .15789 L
.39953 .1738 L
.39955 .18971 L
.3996 .20561 L
.3997 .18971 L
.3997 .1738 L
.39975 .15789 L
Mistroke
.3999 .1738 L
.39991 .18971 L
.39994 .20561 L
.40006 .22152 L
.40007 .23743 L
.4002 .25334 L
.40023 .23743 L
.40023 .25334 L
.40025 .23743 L
.40028 .22152 L
.40035 .23743 L
.40043 .22152 L
.40048 .20561 L
.40071 .22152 L
.40078 .23743 L
.4009 .22152 L
.40093 .23743 L
.40094 .25334 L
.40109 .23743 L
.40111 .25334 L
.40115 .23743 L
.40119 .22152 L
.40128 .20561 L
.40131 .18971 L
.40133 .1738 L
.40137 .15789 L
.40137 .14198 L
.40138 .12607 L
.40138 .14198 L
.40139 .12607 L
.40146 .14198 L
.40148 .15789 L
.40148 .14198 L
.4015 .12607 L
.40153 .14198 L
.4016 .15789 L
.40161 .1738 L
.40162 .15789 L
.40173 .14198 L
.40176 .12607 L
.40177 .14198 L
.40177 .12607 L
.40177 .11016 L
.40178 .12607 L
.40181 .14198 L
.40185 .15789 L
.40187 .1738 L
.40193 .18971 L
.40194 .1738 L
.40196 .18971 L
Mistroke
.40204 .1738 L
.4022 .15789 L
.40221 .1738 L
.40222 .18971 L
.40228 .1738 L
.40229 .18971 L
.40235 .20561 L
.40238 .18971 L
.4024 .20561 L
.40252 .22152 L
.40255 .23743 L
.4026 .25334 L
.40264 .23743 L
.4027 .22152 L
.40272 .20561 L
.40286 .18971 L
.40302 .1738 L
.40305 .18971 L
.40307 .20561 L
.40313 .18971 L
.40314 .20561 L
.40329 .18971 L
.40343 .20561 L
.40346 .18971 L
.40348 .1738 L
.40348 .15789 L
.40351 .1738 L
.40355 .15789 L
.40358 .14198 L
.40367 .12607 L
.40377 .14198 L
.40378 .15789 L
.40382 .14198 L
.40383 .15789 L
.40387 .14198 L
.40387 .12607 L
.40393 .14198 L
.40395 .12607 L
.40398 .11016 L
.40405 .12607 L
.40409 .14198 L
.40409 .12607 L
.40413 .14198 L
.40415 .12607 L
.40417 .14198 L
.40418 .15789 L
.40422 .14198 L
.40427 .12607 L
.40434 .14198 L
.40436 .15789 L
Mistroke
.40439 .1738 L
.40441 .18971 L
.40443 .20561 L
.40458 .22152 L
.40465 .20561 L
.40466 .18971 L
.40466 .20561 L
.40467 .22152 L
.40469 .23743 L
.4047 .22152 L
.40473 .20561 L
.40482 .22152 L
.40494 .20561 L
.40497 .18971 L
.40501 .1738 L
.40506 .18971 L
.40515 .20561 L
.40516 .22152 L
.40522 .23743 L
.4054 .25334 L
.40542 .26925 L
.40544 .25334 L
.40552 .23743 L
.40553 .25334 L
.40558 .26925 L
.40559 .25334 L
.40559 .26925 L
.40559 .25334 L
.4056 .23743 L
.4056 .22152 L
.40563 .23743 L
.40581 .25334 L
.40591 .26925 L
.40592 .25334 L
.40601 .23743 L
.40611 .22152 L
.40617 .23743 L
.40617 .25334 L
.40623 .23743 L
.40627 .22152 L
.40632 .20561 L
.40634 .22152 L
.40636 .20561 L
.40642 .22152 L
.40652 .20561 L
.40667 .18971 L
.40679 .20561 L
.40683 .18971 L
.40683 .20561 L
.40687 .22152 L
Mistroke
.40694 .20561 L
.40708 .18971 L
.40716 .20561 L
.40718 .22152 L
.4072 .20561 L
.40721 .18971 L
.40722 .1738 L
.40726 .15789 L
.40727 .1738 L
.40731 .18971 L
.40737 .1738 L
.40762 .15789 L
.40765 .14198 L
.40765 .15789 L
.40766 .14198 L
.40771 .15789 L
.40772 .14198 L
.40775 .12607 L
.40789 .11016 L
.40794 .09426 L
.40795 .07835 L
.40798 .06244 L
.40801 .07835 L
.40809 .09426 L
.40814 .11016 L
.40822 .12607 L
.40823 .14198 L
.40826 .15789 L
.40827 .1738 L
.40827 .18971 L
.40828 .1738 L
.40833 .18971 L
.40846 .20561 L
.40852 .22152 L
.40853 .20561 L
.40855 .18971 L
.40855 .1738 L
.40855 .18971 L
.40863 .20561 L
.40875 .22152 L
.40875 .20561 L
.40876 .22152 L
.40877 .23743 L
.40879 .25334 L
.40895 .26925 L
.40895 .28515 L
.40897 .26925 L
.40901 .25334 L
.40908 .26925 L
.4091 .25334 L
Mistroke
.40917 .26925 L
.40917 .28515 L
.40918 .26925 L
.40918 .28515 L
.4092 .26925 L
.40926 .25334 L
.4093 .26925 L
.40938 .28515 L
.40946 .26925 L
.40953 .25334 L
.40978 .23743 L
.4098 .25334 L
.40982 .23743 L
.40986 .25334 L
.41006 .26925 L
.41006 .25334 L
.4101 .26925 L
.4101 .28515 L
.41011 .26925 L
.41011 .25334 L
.41011 .23743 L
.41013 .25334 L
.41015 .23743 L
.41017 .25334 L
.41021 .23743 L
.41022 .22152 L
.41025 .23743 L
.41029 .25334 L
.41036 .26925 L
.41045 .28515 L
.41046 .26925 L
.41048 .25334 L
.41053 .23743 L
.41056 .22152 L
.41056 .20561 L
.4106 .18971 L
.41067 .20561 L
.4107 .18971 L
.41074 .1738 L
.41077 .18971 L
.41082 .1738 L
.41083 .18971 L
.41097 .20561 L
.41098 .22152 L
.4111 .23743 L
.41115 .22152 L
.41116 .20561 L
.41132 .18971 L
.41134 .1738 L
.4114 .18971 L
Mistroke
.41142 .1738 L
.41144 .18971 L
.41149 .20561 L
.41149 .22152 L
.41159 .20561 L
.41161 .18971 L
.41168 .20561 L
.41173 .22152 L
.41174 .20561 L
.41195 .18971 L
.41196 .1738 L
.41203 .15789 L
.41207 .1738 L
.41209 .15789 L
.41217 .14198 L
.41219 .15789 L
.4122 .14198 L
.41226 .15789 L
.41232 .14198 L
.41233 .12607 L
.41235 .11016 L
.41236 .09426 L
.41258 .07835 L
.41259 .09426 L
.41263 .07835 L
.41263 .09426 L
.41263 .07835 L
.41266 .06244 L
.41266 .07835 L
.41271 .09426 L
.41271 .07835 L
.41286 .06244 L
.41296 .07835 L
.41296 .09426 L
.41303 .07835 L
.41309 .06244 L
.4131 .04653 L
.41316 .03062 L
.4132 .04653 L
.41321 .06244 L
.41329 .07835 L
.4133 .09426 L
.41335 .07835 L
.41338 .06244 L
.41346 .07835 L
.41357 .09426 L
.41367 .07835 L
.41374 .09426 L
.41378 .11016 L
.41386 .12607 L
Mistroke
.41386 .11016 L
.41413 .09426 L
.41419 .11016 L
.41421 .09426 L
.41427 .07835 L
.41429 .09426 L
.4144 .07835 L
.41449 .06244 L
.41451 .04653 L
.41459 .03062 L
.41459 .04653 L
.41471 .03062 L
.41471 .04653 L
.41481 .03062 L
.41486 .01472 L
.41488 .03062 L
.41489 .04653 L
.41499 .03062 L
.41499 .04653 L
.41504 .06244 L
.41506 .04653 L
.41519 .03062 L
.41543 .04653 L
.41545 .03062 L
.41548 .01472 L
.4155 .03062 L
.41552 .01472 L
.4156 .03062 L
.41568 .01472 L
.41593 .03062 L
.41603 .04653 L
.41607 .06244 L
.41618 .04653 L
.41618 .03062 L
.41619 .04653 L
.4162 .03062 L
.41624 .01472 L
.41629 .03062 L
.41641 .01472 L
.4165 .03062 L
.41656 .04653 L
.41658 .03062 L
.41659 .04653 L
.4166 .03062 L
.4166 .04653 L
.41663 .06244 L
.41671 .07835 L
.41673 .06244 L
.41676 .04653 L
.4168 .06244 L
Mistroke
.41682 .04653 L
.41683 .03062 L
.41689 .04653 L
.41704 .03062 L
.41706 .01472 L
.41716 .03062 L
.41719 .04653 L
.41721 .06244 L
.41731 .07835 L
.41735 .09426 L
.41736 .07835 L
.41736 .09426 L
.41737 .11016 L
.41738 .12607 L
.41755 .14198 L
.4176 .12607 L
.41761 .14198 L
.41764 .15789 L
.41767 .14198 L
.41769 .12607 L
.41769 .11016 L
.41785 .12607 L
.41788 .14198 L
.41796 .12607 L
.41798 .14198 L
.41798 .12607 L
.41799 .14198 L
.41799 .15789 L
.41808 .14198 L
.4181 .15789 L
.41819 .14198 L
.41827 .12607 L
.41827 .14198 L
.41837 .15789 L
.4184 .14198 L
.41846 .12607 L
.4185 .14198 L
.41865 .15789 L
.41865 .14198 L
.41868 .15789 L
.41871 .14198 L
.41874 .12607 L
.41876 .14198 L
.41878 .12607 L
.4188 .14198 L
.41881 .12607 L
.41884 .14198 L
.41885 .12607 L
.41886 .11016 L
.41896 .12607 L
Mistroke
.41896 .11016 L
.41899 .12607 L
.419 .11016 L
.41901 .09426 L
.41908 .07835 L
.41911 .09426 L
.41918 .07835 L
.41919 .09426 L
.41927 .07835 L
.41929 .06244 L
.41933 .04653 L
.4194 .06244 L
.41946 .04653 L
.41947 .03062 L
.41951 .01472 L
.41967 .03062 L
.41967 .01472 L
.41968 .03062 L
.41969 .04653 L
.41978 .03062 L
.41987 .01472 L
.41988 .03062 L
.41996 .01472 L
.41997 .03062 L
.41997 .01472 L
.42003 .03062 L
.42006 .04653 L
.42021 .06244 L
.42021 .07835 L
.42021 .09426 L
.42027 .11016 L
.42029 .12607 L
.42029 .11016 L
.42033 .09426 L
.42035 .11016 L
.42036 .12607 L
.4204 .14198 L
.42042 .15789 L
.42048 .14198 L
.42048 .12607 L
.42048 .11016 L
.42056 .12607 L
.42067 .14198 L
.42074 .15789 L
.42077 .14198 L
.42085 .12607 L
.42096 .14198 L
.42103 .15789 L
.42112 .14198 L
.4212 .15789 L
Mistroke
.42121 .1738 L
.42131 .18971 L
.42133 .1738 L
.42136 .15789 L
.42139 .1738 L
.42139 .15789 L
.42141 .14198 L
.42145 .12607 L
.42148 .14198 L
.4215 .15789 L
.42156 .1738 L
.4216 .15789 L
.42161 .1738 L
.42167 .15789 L
.42174 .1738 L
.4218 .15789 L
.42186 .14198 L
.42201 .15789 L
.42201 .14198 L
.42218 .15789 L
.42222 .14198 L
.42224 .15789 L
.42224 .1738 L
.42228 .18971 L
.42232 .20561 L
.42239 .18971 L
.42239 .1738 L
.42246 .15789 L
.42247 .1738 L
.42257 .15789 L
.42259 .1738 L
.4226 .15789 L
.42264 .14198 L
.42267 .15789 L
.4227 .14198 L
.42271 .15789 L
.42272 .1738 L
.4228 .18971 L
.42282 .20561 L
.42284 .18971 L
.42294 .20561 L
.42295 .18971 L
.42298 .1738 L
.42307 .18971 L
.42319 .20561 L
.4232 .18971 L
.42324 .1738 L
.42324 .18971 L
.42324 .1738 L
.42328 .15789 L
Mistroke
.42328 .1738 L
.42334 .15789 L
.42337 .1738 L
.42343 .15789 L
.42345 .14198 L
.42347 .15789 L
.42348 .14198 L
.42348 .15789 L
.42352 .1738 L
.42357 .15789 L
.42363 .14198 L
.42374 .15789 L
.42389 .14198 L
.42389 .15789 L
.42391 .14198 L
.42391 .12607 L
.424 .14198 L
.42401 .15789 L
.42409 .14198 L
.42427 .15789 L
.42432 .1738 L
.42438 .15789 L
.42439 .1738 L
.42439 .18971 L
.42445 .1738 L
.4245 .15789 L
.42463 .1738 L
.42467 .18971 L
.42469 .1738 L
.42472 .15789 L
.4248 .14198 L
.42487 .12607 L
.42488 .14198 L
.42488 .15789 L
.42488 .14198 L
.42497 .12607 L
.42516 .11016 L
.42524 .09426 L
.42525 .07835 L
.42531 .09426 L
.42533 .11016 L
.42534 .09426 L
.42536 .11016 L
.42538 .12607 L
.42539 .11016 L
.42541 .09426 L
.42542 .11016 L
.42549 .09426 L
.42555 .11016 L
.42571 .09426 L
Mistroke
.42571 .07835 L
.42571 .09426 L
.42575 .07835 L
.42584 .09426 L
.42595 .07835 L
.42605 .06244 L
.42605 .04653 L
.42606 .03062 L
.42606 .04653 L
.4261 .06244 L
.42611 .07835 L
.42615 .09426 L
.42615 .11016 L
.42616 .12607 L
.42629 .14198 L
.42629 .15789 L
.42634 .1738 L
.42637 .18971 L
.42645 .20561 L
.42649 .18971 L
.42652 .20561 L
.42654 .18971 L
.4266 .1738 L
.42662 .18971 L
.42663 .1738 L
.42664 .18971 L
.42674 .20561 L
.42682 .18971 L
.42685 .1738 L
.42691 .18971 L
.427 .20561 L
.42704 .18971 L
.42711 .20561 L
.4273 .22152 L
.42742 .23743 L
.42748 .25334 L
.42753 .26925 L
.42762 .25334 L
.42777 .26925 L
.42797 .25334 L
.42798 .26925 L
.428 .25334 L
.42801 .26925 L
.42813 .28515 L
.42822 .30106 L
.42829 .28515 L
.42832 .26925 L
.42844 .28515 L
.42863 .26925 L
.42877 .25334 L
Mistroke
.42882 .23743 L
.42889 .22152 L
.42897 .20561 L
.42899 .18971 L
.42904 .20561 L
.42906 .22152 L
.42907 .23743 L
.42909 .22152 L
.42911 .20561 L
.42914 .22152 L
.42922 .20561 L
.42924 .22152 L
.42925 .23743 L
.42937 .25334 L
.42939 .26925 L
.42943 .25334 L
.42946 .26925 L
.42951 .28515 L
.42955 .26925 L
.42965 .25334 L
.42971 .26925 L
.42978 .25334 L
.42979 .26925 L
.42997 .25334 L
.42998 .26925 L
.43 .25334 L
.43003 .26925 L
.43004 .25334 L
.43015 .23743 L
.43016 .25334 L
.43016 .23743 L
.43016 .22152 L
.43034 .23743 L
.43035 .25334 L
.43036 .23743 L
.43039 .22152 L
.43049 .23743 L
.43053 .25334 L
.43062 .26925 L
.43082 .28515 L
.43082 .26925 L
.43083 .28515 L
.43083 .30106 L
.43089 .28515 L
.43091 .30106 L
.43093 .28515 L
.43093 .30106 L
.43095 .31697 L
.431 .33288 L
.43104 .34879 L
Mistroke
.43105 .33288 L
.43107 .34879 L
.4311 .33288 L
.43115 .31697 L
.43115 .33288 L
.43116 .31697 L
.43128 .30106 L
.43141 .31697 L
.43158 .30106 L
.43169 .28515 L
.4317 .26925 L
.43174 .25334 L
.43175 .23743 L
.43186 .25334 L
.43187 .26925 L
.43193 .25334 L
.43205 .23743 L
.43206 .25334 L
.43206 .26925 L
.43206 .25334 L
.43209 .26925 L
.4321 .25334 L
.43219 .23743 L
.43221 .22152 L
.43233 .23743 L
.43233 .25334 L
.43241 .26925 L
.43242 .25334 L
.43244 .23743 L
.43246 .22152 L
.43248 .20561 L
.43253 .22152 L
.43256 .23743 L
.43257 .25334 L
.4326 .26925 L
.43261 .25334 L
.43262 .26925 L
.43262 .25334 L
.43265 .26925 L
.43268 .28515 L
.4327 .30106 L
.4327 .31697 L
.43273 .33288 L
.43282 .31697 L
.43286 .30106 L
.43297 .31697 L
.433 .30106 L
.433 .28515 L
.43302 .26925 L
.4331 .28515 L
Mistroke
.43312 .30106 L
.43315 .28515 L
.43318 .26925 L
.4332 .28515 L
.4332 .30106 L
.43322 .31697 L
.43324 .30106 L
.43325 .28515 L
.43328 .26925 L
.43331 .25334 L
.43333 .23743 L
.43337 .22152 L
.43343 .23743 L
.43352 .22152 L
.4336 .20561 L
.43373 .18971 L
.43378 .1738 L
.43393 .18971 L
.43401 .20561 L
.43417 .22152 L
.43425 .23743 L
.43426 .22152 L
.43428 .20561 L
.43432 .22152 L
.43434 .20561 L
.43435 .18971 L
.43436 .1738 L
.43442 .18971 L
.43453 .1738 L
.43457 .18971 L
.43463 .20561 L
.43465 .22152 L
.43471 .23743 L
.43471 .25334 L
.43478 .26925 L
.43479 .28515 L
.43479 .26925 L
.43485 .25334 L
.43486 .23743 L
.43505 .22152 L
.43509 .20561 L
.43511 .22152 L
.43514 .23743 L
.43514 .22152 L
.43517 .20561 L
.43518 .22152 L
.4352 .20561 L
.43529 .22152 L
.43537 .20561 L
.43539 .18971 L
Mistroke
.43542 .20561 L
.4355 .18971 L
.43552 .1738 L
.43565 .15789 L
.43565 .1738 L
.43568 .18971 L
.43579 .20561 L
.43579 .18971 L
.43588 .1738 L
.43596 .18971 L
.43606 .20561 L
.43608 .18971 L
.43609 .20561 L
.43611 .18971 L
.43617 .1738 L
.43618 .18971 L
.43622 .20561 L
.43627 .22152 L
.43648 .20561 L
.4365 .18971 L
.43651 .1738 L
.43652 .15789 L
.43653 .1738 L
.43656 .15789 L
.43665 .1738 L
.43667 .18971 L
.4367 .1738 L
.43678 .15789 L
.43682 .1738 L
.43707 .18971 L
.43709 .20561 L
.43709 .22152 L
.43716 .23743 L
.43721 .22152 L
.43731 .23743 L
.43751 .25334 L
.43756 .23743 L
.43757 .22152 L
.43757 .23743 L
.43763 .25334 L
.43766 .23743 L
.43771 .25334 L
.43775 .23743 L
.43784 .25334 L
.43785 .23743 L
.43788 .25334 L
.4379 .23743 L
.43798 .22152 L
.43802 .20561 L
.43804 .18971 L
Mistroke
.43812 .1738 L
.43816 .18971 L
.43819 .1738 L
.43821 .18971 L
.43827 .1738 L
.43835 .15789 L
.43837 .1738 L
.43841 .18971 L
.43841 .1738 L
.43844 .18971 L
.43852 .20561 L
.43857 .22152 L
.43858 .23743 L
.43863 .22152 L
.43881 .20561 L
.43884 .18971 L
.43888 .20561 L
.43888 .18971 L
.43895 .20561 L
.43897 .18971 L
.43898 .20561 L
.43898 .18971 L
.43899 .20561 L
.43902 .22152 L
.43903 .20561 L
.43908 .18971 L
.43915 .20561 L
.43921 .22152 L
.43926 .20561 L
.43926 .22152 L
.43928 .23743 L
.43943 .22152 L
.43946 .20561 L
.43947 .22152 L
.43949 .20561 L
.43953 .18971 L
.43959 .1738 L
.43959 .18971 L
.4396 .1738 L
.4396 .15789 L
.43966 .14198 L
.43975 .15789 L
.43989 .1738 L
.43992 .18971 L
.44 .1738 L
.44 .18971 L
.44 .1738 L
.44001 .18971 L
.44005 .20561 L
.44006 .18971 L
Mistroke
.44008 .1738 L
.44009 .18971 L
.44017 .1738 L
.44026 .18971 L
.44038 .1738 L
.44042 .15789 L
.44049 .14198 L
.4406 .15789 L
.44064 .14198 L
.44069 .12607 L
.44071 .14198 L
.44072 .15789 L
.44083 .14198 L
.44102 .15789 L
.44105 .1738 L
.44105 .15789 L
.44107 .1738 L
.44121 .15789 L
.44138 .14198 L
.44141 .12607 L
.44151 .11016 L
.44155 .12607 L
.4416 .11016 L
.44164 .12607 L
.44173 .11016 L
.44177 .09426 L
.44179 .07835 L
.44184 .09426 L
.44185 .07835 L
.44188 .09426 L
.44194 .11016 L
.44198 .09426 L
.44201 .11016 L
.44208 .12607 L
.44209 .11016 L
.44226 .12607 L
.44226 .11016 L
.44231 .12607 L
.44245 .11016 L
.44251 .12607 L
.44252 .14198 L
.44264 .15789 L
.44265 .1738 L
.44265 .18971 L
.44268 .20561 L
.44279 .22152 L
.44294 .23743 L
.44295 .22152 L
.44296 .23743 L
.44299 .25334 L
Mistroke
.44302 .23743 L
.44302 .25334 L
.44305 .23743 L
.44321 .25334 L
.44326 .26925 L
.44328 .25334 L
.44335 .23743 L
.44339 .25334 L
.44342 .23743 L
.44346 .22152 L
.44346 .20561 L
.44352 .22152 L
.44353 .20561 L
.44357 .18971 L
.44361 .20561 L
.44367 .18971 L
.44372 .20561 L
.44373 .18971 L
.44376 .20561 L
.44376 .22152 L
.44383 .20561 L
.44384 .22152 L
.44402 .20561 L
.44402 .22152 L
.44405 .23743 L
.44406 .22152 L
.44413 .23743 L
.44418 .25334 L
.44419 .26925 L
.4443 .28515 L
.44434 .30106 L
.44435 .31697 L
.44437 .30106 L
.44444 .31697 L
.44452 .30106 L
.44456 .28515 L
.44458 .30106 L
.44462 .28515 L
.44465 .26925 L
.44467 .28515 L
.4447 .30106 L
.44483 .31697 L
.44488 .30106 L
.44513 .31697 L
.44515 .33288 L
.44521 .31697 L
.44522 .33288 L
.44524 .31697 L
.44524 .33288 L
.4453 .31697 L
Mistroke
.44537 .30106 L
.44542 .31697 L
.44545 .30106 L
.44546 .28515 L
.44555 .26925 L
.44556 .28515 L
.44559 .26925 L
.44562 .25334 L
.4457 .26925 L
.44572 .28515 L
.4458 .26925 L
.44601 .25334 L
.44617 .26925 L
.44625 .28515 L
.44628 .26925 L
.44639 .28515 L
.44651 .26925 L
.44653 .28515 L
.44662 .26925 L
.44667 .25334 L
.44668 .23743 L
.44669 .25334 L
.44676 .26925 L
.44679 .28515 L
.44683 .26925 L
.44685 .28515 L
.4469 .30106 L
.447 .31697 L
.4471 .33288 L
.44717 .34879 L
.44717 .33288 L
.44719 .31697 L
.44727 .33288 L
.44727 .31697 L
.4475 .30106 L
.44759 .31697 L
.44762 .30106 L
.44762 .28515 L
.44775 .26925 L
.44776 .25334 L
.44777 .23743 L
.44781 .25334 L
.44783 .26925 L
.44784 .28515 L
.44786 .26925 L
.44794 .28515 L
.44807 .26925 L
.4481 .28515 L
.44812 .30106 L
.44817 .31697 L
Mistroke
.44823 .30106 L
.44825 .31697 L
.44838 .33288 L
.44839 .34879 L
.44839 .3647 L
.4484 .3806 L
.44842 .39651 L
.44847 .3806 L
.44856 .3647 L
.44859 .34879 L
.44865 .3647 L
.44866 .3806 L
.44869 .39651 L
.44871 .3806 L
.44872 .39651 L
.44872 .41242 L
.44878 .39651 L
.44889 .3806 L
.44891 .39651 L
.44898 .41242 L
.44899 .42833 L
.44903 .41242 L
.44905 .42833 L
.44905 .44424 L
.44909 .46014 L
.44912 .44424 L
.44922 .42833 L
.44929 .44424 L
.44934 .46014 L
.44949 .47605 L
.44951 .49196 L
.44958 .50787 L
.44959 .52378 L
.44959 .50787 L
.44969 .52378 L
.44973 .50787 L
.44974 .49196 L
.44978 .50787 L
.44985 .52378 L
.44987 .53969 L
.44992 .52378 L
.44994 .53969 L
.44997 .52378 L
.45004 .50787 L
.4501 .52378 L
.45016 .50787 L
.45019 .52378 L
.45024 .53969 L
.4504 .55559 L
.45043 .5715 L
Mistroke
.45046 .58741 L
.45048 .60332 L
.45049 .58741 L
.45049 .5715 L
.45051 .55559 L
.45055 .53969 L
.45057 .55559 L
.45061 .53969 L
.45065 .55559 L
.45065 .53969 L
.45066 .55559 L
.45071 .5715 L
.45075 .55559 L
.45078 .53969 L
.45079 .55559 L
.45088 .5715 L
.45093 .55559 L
.45106 .53969 L
.45108 .52378 L
.45109 .50787 L
.45112 .49196 L
.45112 .47605 L
.45113 .46014 L
.45121 .47605 L
.45121 .46014 L
.45123 .47605 L
.45124 .49196 L
.4513 .47605 L
.45132 .46014 L
.45152 .47605 L
.45155 .46014 L
.4517 .47605 L
.45185 .49196 L
.45187 .50787 L
.4519 .52378 L
.45192 .53969 L
.45197 .52378 L
.45198 .50787 L
.452 .49196 L
.45208 .50787 L
.45216 .49196 L
.45216 .50787 L
.45218 .49196 L
.45219 .50787 L
.45224 .49196 L
.45226 .47605 L
.45228 .49196 L
.45228 .50787 L
.45231 .49196 L
.45234 .50787 L
Mistroke
.45235 .52378 L
.45238 .50787 L
.45244 .52378 L
.45247 .53969 L
.45252 .55559 L
.45252 .53969 L
.45253 .55559 L
.45255 .5715 L
.45256 .55559 L
.45258 .5715 L
.45268 .58741 L
.45268 .60332 L
Mfstroke
.45269 .61803 m
.45268 .60332 L
s
.45269 .61803 m
.45274 .60332 L
s
.45274 .60332 m
.45277 .58741 L
.4529 .5715 L
.45291 .55559 L
.45297 .5715 L
.45306 .58741 L
.45316 .5715 L
.45322 .58741 L
.45323 .60332 L
s
.45329 .61803 m
.45323 .60332 L
s
.4533 .61803 m
.45337 .60332 L
s
.45337 .60332 m
0 0 rlineto
.4534 .61803 m
.45337 .60332 L
s
.4534 .61803 m
.45341 .60332 L
s
.45341 .60332 m
0 0 rlineto
.45344 .61803 m
.45341 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.45453 .61803 m
.45454 .60332 L
s
.45454 .60332 m
0 0 rlineto
.45455 .61803 m
.45454 .60332 L
s
s
s
s
s
s
s
.45476 .61803 m
.45486 .60332 L
s
.45486 .60332 m
.45489 .58741 L
.45491 .5715 L
.45514 .55559 L
.45522 .53969 L
.45525 .55559 L
.45527 .53969 L
.45529 .55559 L
.45532 .53969 L
.45539 .55559 L
.45542 .5715 L
.45543 .55559 L
.45545 .53969 L
.45546 .52378 L
.45548 .50787 L
.45551 .49196 L
.45556 .50787 L
.45558 .49196 L
.45558 .47605 L
.45561 .46014 L
.45562 .44424 L
.45572 .46014 L
.45574 .44424 L
.45576 .46014 L
.45582 .44424 L
.45586 .42833 L
.45594 .44424 L
.45594 .46014 L
.45605 .47605 L
.45608 .46014 L
.45609 .44424 L
.45622 .46014 L
.45623 .44424 L
.45625 .46014 L
.4564 .44424 L
.45642 .46014 L
.45646 .44424 L
.45649 .42833 L
.45655 .41242 L
.45655 .39651 L
.45659 .3806 L
.45662 .3647 L
.45665 .3806 L
.45668 .39651 L
.45673 .3806 L
.45678 .39651 L
.45683 .41242 L
.45701 .42833 L
.45702 .44424 L
.45702 .46014 L
Mistroke
.45703 .44424 L
.45703 .46014 L
.45707 .47605 L
.45709 .49196 L
.4571 .50787 L
.45715 .52378 L
.45717 .53969 L
.45717 .52378 L
.45719 .53969 L
.45726 .55559 L
.45736 .53969 L
.4574 .55559 L
.4575 .5715 L
.45761 .58741 L
.45771 .60332 L
Mfstroke
.4578 .61803 m
.45771 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.45872 .61803 m
.45873 .60332 L
s
.45873 .60332 m
0 0 rlineto
.45878 .61803 m
.45873 .60332 L
s
.45879 .61803 m
.45879 .60332 L
s
.45879 .60332 m
0 0 rlineto
.45882 .61803 m
.45879 .60332 L
s
.45883 .61803 m
.45887 .60332 L
s
.45887 .60332 m
0 0 rlineto
.45893 .61803 m
.45887 .60332 L
s
s
s
s
s
.4591 .61803 m
.45911 .60332 L
s
.45911 .60332 m
0 0 rlineto
.45913 .61803 m
.45911 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.48157 .61803 m
.48162 .60332 L
s
.48162 .60332 m
.48172 .58741 L
.48173 .5715 L
.48173 .55559 L
.48179 .5715 L
.48181 .58741 L
.48183 .60332 L
.48187 .58741 L
.48198 .5715 L
.48206 .55559 L
.48207 .53969 L
.48208 .52378 L
.48208 .50787 L
.4821 .52378 L
.48233 .53969 L
.4824 .55559 L
.48241 .5715 L
.48244 .58741 L
.48251 .60332 L
.48253 .58741 L
.48269 .5715 L
.48276 .55559 L
.48278 .53969 L
.48282 .52378 L
.48283 .50787 L
.48286 .52378 L
.4829 .53969 L
.48291 .52378 L
.48296 .50787 L
.48299 .52378 L
.48303 .53969 L
.48308 .55559 L
.48311 .5715 L
.48317 .58741 L
.4832 .60332 L
.48326 .58741 L
.48329 .5715 L
.48349 .58741 L
.4835 .5715 L
.48351 .58741 L
.48353 .5715 L
.48362 .58741 L
.48374 .60332 L
.48374 .58741 L
.48379 .5715 L
.48383 .55559 L
.48385 .5715 L
.48385 .55559 L
.48389 .5715 L
.4839 .58741 L
Mistroke
.48421 .5715 L
.48422 .55559 L
.48424 .5715 L
.48426 .55559 L
.48435 .5715 L
.48436 .55559 L
.4844 .53969 L
.48444 .52378 L
.48449 .53969 L
.4845 .52378 L
.48451 .50787 L
.48451 .52378 L
.48457 .53969 L
.48458 .52378 L
.4846 .53969 L
.48463 .55559 L
.48469 .53969 L
.48471 .52378 L
.48472 .53969 L
.48476 .52378 L
.48478 .50787 L
.48479 .52378 L
.48481 .50787 L
.48497 .49196 L
.48502 .50787 L
.48504 .52378 L
.48507 .50787 L
.48512 .49196 L
.48515 .47605 L
.48521 .49196 L
.48523 .50787 L
.48525 .52378 L
.4853 .53969 L
.48537 .52378 L
.48539 .50787 L
.48543 .49196 L
.4855 .47605 L
.48551 .46014 L
.48552 .44424 L
.48559 .46014 L
.48572 .44424 L
.48585 .46014 L
.48585 .44424 L
.48586 .42833 L
.48587 .41242 L
.48596 .39651 L
.48596 .41242 L
.48607 .42833 L
.48608 .44424 L
.48609 .42833 L
Mistroke
.4861 .44424 L
.48612 .46014 L
.4862 .44424 L
.48626 .42833 L
.48631 .41242 L
.48649 .42833 L
.48653 .44424 L
.48657 .42833 L
.4866 .41242 L
.48667 .42833 L
.4867 .44424 L
.48674 .46014 L
.48675 .44424 L
.48677 .46014 L
.48679 .44424 L
.4868 .42833 L
.48682 .44424 L
.48683 .42833 L
.4869 .44424 L
.48703 .46014 L
.48705 .44424 L
.48708 .46014 L
.48715 .44424 L
.48716 .42833 L
.48717 .44424 L
.4872 .46014 L
.48729 .47605 L
.48742 .46014 L
.48749 .47605 L
.48751 .46014 L
.48758 .44424 L
.48766 .46014 L
.48767 .44424 L
.4877 .42833 L
.48776 .44424 L
.48782 .46014 L
.48786 .44424 L
.48787 .46014 L
.48787 .47605 L
.48805 .49196 L
.48807 .47605 L
.48808 .49196 L
.48813 .50787 L
.48821 .49196 L
.48825 .50787 L
.48827 .52378 L
.48828 .53969 L
.48829 .52378 L
.48831 .53969 L
.48834 .55559 L
Mistroke
.48843 .5715 L
.48848 .55559 L
.48858 .5715 L
.48861 .58741 L
.48869 .5715 L
.48874 .58741 L
.48878 .60332 L
.48881 .58741 L
.48884 .60332 L
.48909 .58741 L
.4891 .5715 L
.48915 .55559 L
.4892 .53969 L
.48921 .52378 L
.48926 .53969 L
.48929 .52378 L
.48931 .50787 L
.48938 .52378 L
.48945 .50787 L
.48953 .49196 L
.48956 .50787 L
.48964 .52378 L
.48973 .53969 L
.48975 .52378 L
.48976 .53969 L
.48985 .52378 L
.48987 .50787 L
.48999 .49196 L
.48999 .47605 L
.49003 .46014 L
.49011 .47605 L
.49011 .46014 L
.49013 .44424 L
.49017 .46014 L
.49031 .47605 L
.49044 .49196 L
.49049 .50787 L
.49053 .52378 L
.49057 .53969 L
.49064 .52378 L
.49064 .50787 L
.49066 .49196 L
.49067 .50787 L
.4907 .49196 L
.49073 .47605 L
.49074 .49196 L
.49074 .50787 L
.49082 .49196 L
.49083 .47605 L
.49104 .46014 L
Mistroke
.49105 .44424 L
.49106 .46014 L
.49112 .44424 L
.49117 .42833 L
.49118 .44424 L
.49121 .42833 L
.49127 .41242 L
.4913 .39651 L
.49133 .3806 L
.49162 .3647 L
.49164 .3806 L
.49166 .39651 L
.49169 .41242 L
.49174 .42833 L
.49193 .44424 L
.49194 .46014 L
.49196 .44424 L
.49199 .42833 L
.492 .44424 L
.49207 .46014 L
.49217 .44424 L
.49221 .42833 L
.49231 .44424 L
.49235 .42833 L
.49237 .44424 L
.4925 .42833 L
.49254 .41242 L
.4926 .39651 L
.49266 .41242 L
.49278 .39651 L
.49279 .3806 L
.4928 .39651 L
.49287 .3806 L
.49289 .3647 L
.49297 .34879 L
.4931 .3647 L
.49315 .34879 L
.49318 .3647 L
.49328 .34879 L
.4933 .3647 L
.49331 .3806 L
.49333 .3647 L
.49351 .3806 L
.49361 .3647 L
.4937 .34879 L
.49379 .33288 L
.4938 .31697 L
.49381 .33288 L
.49386 .34879 L
.49392 .3647 L
Mistroke
.49392 .34879 L
.49393 .33288 L
.49394 .31697 L
.49398 .33288 L
.4941 .31697 L
.49416 .30106 L
.49425 .31697 L
.49433 .33288 L
.49435 .34879 L
.49443 .3647 L
.49447 .34879 L
.49452 .3647 L
.49459 .34879 L
.49465 .33288 L
.49471 .34879 L
.49478 .3647 L
.49478 .34879 L
.49494 .33288 L
.49496 .31697 L
.49505 .30106 L
.4951 .28515 L
.49519 .26925 L
.4952 .28515 L
.49521 .26925 L
.49527 .28515 L
.49535 .26925 L
.49536 .28515 L
.49537 .30106 L
.49537 .31697 L
.49539 .33288 L
.49546 .34879 L
.49547 .3647 L
.49548 .34879 L
.49563 .33288 L
.49563 .31697 L
.49566 .30106 L
.49568 .28515 L
.49573 .30106 L
.49574 .28515 L
.49575 .26925 L
.49578 .28515 L
.49579 .30106 L
.49591 .28515 L
.49599 .26925 L
.49599 .28515 L
.496 .30106 L
.49601 .28515 L
.49604 .30106 L
.49604 .28515 L
.49609 .26925 L
Mistroke
.49611 .28515 L
.49613 .30106 L
.49616 .28515 L
.49619 .30106 L
.49619 .31697 L
.49624 .30106 L
.49631 .28515 L
.49633 .26925 L
.49637 .25334 L
.49642 .26925 L
.49642 .28515 L
.49649 .26925 L
.49652 .25334 L
.49674 .23743 L
.49678 .25334 L
.49683 .23743 L
.49687 .25334 L
.49694 .23743 L
.49698 .22152 L
.49701 .20561 L
.49709 .22152 L
.49714 .20561 L
.49721 .22152 L
.49724 .20561 L
.49727 .18971 L
.49732 .1738 L
.49737 .18971 L
.49742 .20561 L
.49745 .22152 L
.49748 .23743 L
.49752 .22152 L
.49762 .20561 L
.49766 .22152 L
.49768 .23743 L
.4977 .22152 L
.49783 .20561 L
.49796 .22152 L
.49797 .23743 L
.49808 .22152 L
.49809 .20561 L
.49817 .18971 L
.49829 .1738 L
.49831 .18971 L
.49838 .20561 L
.49839 .22152 L
.49844 .20561 L
.49845 .18971 L
.49853 .1738 L
.49853 .18971 L
.49856 .20561 L
Mistroke
.4986 .18971 L
.49861 .20561 L
.49871 .18971 L
.49891 .1738 L
.49892 .18971 L
.49892 .1738 L
.49893 .15789 L
.49894 .1738 L
.49894 .15789 L
.49895 .1738 L
.49895 .15789 L
.49895 .1738 L
.49897 .18971 L
.49902 .1738 L
.49905 .15789 L
.49915 .14198 L
.49918 .12607 L
.49918 .14198 L
.49919 .12607 L
.4992 .14198 L
.49925 .15789 L
.49926 .1738 L
.49928 .15789 L
.49933 .14198 L
.49934 .15789 L
.49945 .14198 L
.49949 .12607 L
.49953 .14198 L
.49955 .15789 L
.49957 .14198 L
.49959 .12607 L
.49966 .11016 L
.49976 .09426 L
.49976 .11016 L
.49976 .12607 L
.49978 .11016 L
.49991 .12607 L
.50004 .11016 L
.5003 .12607 L
.50039 .14198 L
.5004 .15789 L
.50046 .1738 L
.50048 .15789 L
.50058 .1738 L
.50062 .18971 L
.50063 .20561 L
.50063 .18971 L
.50067 .1738 L
.50069 .18971 L
.50072 .1738 L
Mistroke
.50079 .15789 L
.5008 .14198 L
.50093 .15789 L
.50101 .1738 L
.50106 .15789 L
.50123 .1738 L
.50125 .15789 L
.5013 .14198 L
.50132 .12607 L
.50133 .11016 L
.50136 .09426 L
.50138 .07835 L
.50138 .09426 L
.50143 .07835 L
.50157 .06244 L
.50158 .04653 L
.5016 .03062 L
.50162 .04653 L
.50164 .06244 L
.5018 .07835 L
.50186 .06244 L
.50189 .04653 L
.50189 .03062 L
.50192 .04653 L
.50194 .06244 L
.50198 .07835 L
.50209 .06244 L
.50223 .04653 L
.50235 .03062 L
.50241 .01472 L
.50245 .03062 L
.50253 .01472 L
.50267 .03062 L
.50267 .01472 L
.50267 .03062 L
.50271 .04653 L
.50273 .06244 L
.50279 .07835 L
.50282 .06244 L
.50282 .04653 L
.50282 .06244 L
.50286 .07835 L
.5029 .06244 L
.5029 .04653 L
.50292 .06244 L
.50293 .04653 L
.50293 .03062 L
.50298 .01472 L
.50301 .03062 L
.50303 .01472 L
Mistroke
.50305 .03062 L
.50307 .04653 L
.50311 .06244 L
.50314 .04653 L
.50315 .06244 L
.50318 .07835 L
.50318 .09426 L
.50319 .11016 L
.50324 .09426 L
.50324 .07835 L
.50326 .09426 L
.50333 .07835 L
.50335 .06244 L
.50342 .07835 L
.50344 .09426 L
.50344 .07835 L
.50348 .09426 L
.50352 .07835 L
.50357 .09426 L
.50357 .11016 L
.5036 .09426 L
.50361 .11016 L
.50363 .09426 L
.50371 .07835 L
.50373 .09426 L
.50373 .11016 L
.50379 .12607 L
.50393 .11016 L
.50397 .09426 L
.50399 .07835 L
.50409 .06244 L
.50411 .07835 L
.50411 .06244 L
.50412 .04653 L
.50412 .03062 L
.50416 .04653 L
.50416 .03062 L
.50421 .01472 L
.50421 .03062 L
.50429 .04653 L
.50432 .06244 L
.50434 .07835 L
.50435 .06244 L
.50436 .04653 L
.50438 .03062 L
.5044 .01472 L
.50444 .03062 L
.50446 .04653 L
.5045 .06244 L
.50455 .07835 L
Mistroke
.50459 .09426 L
.50462 .07835 L
.50481 .06244 L
.50483 .04653 L
.50492 .03062 L
.50494 .01472 L
.50511 .03062 L
.50514 .04653 L
.50518 .03062 L
.50523 .04653 L
.50532 .03062 L
.50534 .01472 L
.50546 .03062 L
.50546 .04653 L
.50557 .06244 L
.50573 .07835 L
.50573 .09426 L
.50583 .11016 L
.50592 .09426 L
.50593 .07835 L
.50595 .09426 L
.50597 .11016 L
.50602 .12607 L
.50604 .14198 L
.50605 .15789 L
.50606 .14198 L
.50613 .15789 L
.50615 .1738 L
.50623 .18971 L
.50626 .1738 L
.50629 .18971 L
.50642 .20561 L
.50645 .18971 L
.50645 .1738 L
.50648 .18971 L
.50649 .20561 L
.50656 .18971 L
.5066 .1738 L
.50663 .18971 L
.50666 .1738 L
.50679 .15789 L
.50685 .1738 L
.50689 .18971 L
.5069 .1738 L
.50698 .15789 L
.50701 .1738 L
.50704 .18971 L
.50705 .20561 L
.50706 .22152 L
.50709 .20561 L
Mistroke
.50714 .22152 L
.50716 .20561 L
.50723 .22152 L
.50739 .23743 L
.50741 .25334 L
.50745 .23743 L
.50753 .25334 L
.50754 .23743 L
.50754 .22152 L
.50757 .23743 L
.50762 .22152 L
.50766 .20561 L
.50769 .18971 L
.50773 .20561 L
.50773 .22152 L
.50774 .23743 L
.50785 .22152 L
.50788 .23743 L
.50791 .22152 L
.50792 .20561 L
.50811 .18971 L
.50815 .1738 L
.5082 .15789 L
.50824 .14198 L
.50831 .15789 L
.50837 .14198 L
.5084 .12607 L
.50841 .14198 L
.50842 .12607 L
.50846 .14198 L
.50846 .15789 L
.50856 .1738 L
.50875 .18971 L
.50876 .1738 L
.50895 .15789 L
.50896 .14198 L
.50899 .15789 L
.50901 .14198 L
.50901 .12607 L
.50905 .14198 L
.50906 .15789 L
.50907 .14198 L
.50912 .15789 L
.50916 .14198 L
.50917 .12607 L
.50919 .11016 L
.50924 .09426 L
.50941 .07835 L
.50943 .06244 L
.50962 .04653 L
Mistroke
.50965 .03062 L
.5097 .04653 L
.50977 .03062 L
.50982 .04653 L
.50982 .06244 L
.50983 .07835 L
.50991 .09426 L
.50991 .11016 L
.51 .09426 L
.51011 .07835 L
.51016 .06244 L
.51017 .04653 L
.51019 .06244 L
.5102 .04653 L
.51021 .06244 L
.51022 .07835 L
.51033 .09426 L
.51039 .07835 L
.51058 .06244 L
.51058 .07835 L
.51058 .06244 L
.51061 .07835 L
.51068 .06244 L
.51069 .04653 L
.51073 .03062 L
.51077 .01472 L
.51087 .03062 L
.51091 .01472 L
.51094 .03062 L
.51103 .01472 L
.51118 .03062 L
.51124 .04653 L
.51128 .06244 L
.51133 .07835 L
.51138 .09426 L
.5114 .11016 L
.51145 .12607 L
.51152 .14198 L
.51155 .12607 L
.51157 .14198 L
.51161 .15789 L
.51162 .14198 L
.51168 .15789 L
.51172 .14198 L
.51182 .12607 L
.51183 .14198 L
.51191 .15789 L
.51195 .1738 L
.51197 .15789 L
.51197 .1738 L
Mistroke
.51206 .15789 L
.51207 .14198 L
.51213 .12607 L
.51225 .14198 L
.51229 .12607 L
.5123 .11016 L
.51234 .09426 L
.5124 .07835 L
.51241 .09426 L
.51245 .07835 L
.51253 .09426 L
.51259 .11016 L
.51261 .12607 L
.51261 .14198 L
.51263 .12607 L
.51275 .11016 L
.51277 .09426 L
.51281 .11016 L
.51288 .12607 L
.51289 .14198 L
.51298 .12607 L
.51306 .11016 L
.51314 .12607 L
.51318 .11016 L
.51319 .09426 L
.51327 .11016 L
.51339 .12607 L
.51343 .11016 L
.51354 .12607 L
.51367 .11016 L
.51374 .09426 L
.51375 .11016 L
.51376 .12607 L
.51379 .11016 L
.5138 .09426 L
.51381 .11016 L
.51388 .09426 L
.51392 .07835 L
.51396 .06244 L
.51401 .04653 L
.51403 .06244 L
.51408 .07835 L
.51408 .09426 L
.51416 .07835 L
.51425 .06244 L
.51431 .07835 L
.51438 .06244 L
.51449 .04653 L
.51456 .06244 L
.51465 .04653 L
Mistroke
.51467 .03062 L
.51471 .01472 L
.51492 .03062 L
.51493 .01472 L
.51494 .03062 L
.51497 .04653 L
.51502 .06244 L
.51506 .04653 L
.51506 .06244 L
.5151 .07835 L
.5152 .06244 L
.51523 .04653 L
.51527 .03062 L
.51534 .01472 L
.51539 .03062 L
.51544 .04653 L
.5155 .03062 L
.51552 .04653 L
.51556 .06244 L
.51562 .04653 L
.51566 .06244 L
.51571 .07835 L
.51581 .09426 L
.51585 .11016 L
.51589 .12607 L
.51599 .11016 L
.51611 .12607 L
.5162 .11016 L
.51633 .09426 L
.5164 .07835 L
.51649 .06244 L
.51653 .07835 L
.51661 .09426 L
.51662 .11016 L
.51664 .09426 L
.51664 .11016 L
.5167 .12607 L
.51681 .11016 L
.51686 .09426 L
.51686 .11016 L
.51692 .09426 L
.51706 .11016 L
.5171 .12607 L
.51712 .14198 L
.51713 .15789 L
.51716 .14198 L
.51729 .12607 L
.51731 .14198 L
.51731 .12607 L
.51732 .14198 L
Mistroke
.51745 .12607 L
.51748 .11016 L
.51748 .09426 L
.51751 .11016 L
.51759 .12607 L
.51759 .11016 L
.51763 .09426 L
.51776 .11016 L
.5178 .12607 L
.51783 .11016 L
.51784 .12607 L
.51789 .11016 L
.51792 .12607 L
.51794 .11016 L
.51794 .09426 L
.51798 .11016 L
.518 .12607 L
.518 .11016 L
.51803 .09426 L
.51803 .11016 L
.51804 .12607 L
.51806 .11016 L
.51809 .12607 L
.51811 .11016 L
.51811 .09426 L
.51816 .07835 L
.51819 .06244 L
.51819 .04653 L
.51824 .03062 L
.5183 .01472 L
.51848 .03062 L
.51855 .04653 L
.5186 .06244 L
.51872 .07835 L
.51872 .09426 L
.51877 .11016 L
.5188 .09426 L
.51883 .11016 L
.51886 .09426 L
.51892 .07835 L
.51895 .06244 L
.51896 .04653 L
.51906 .06244 L
.51909 .07835 L
.51912 .06244 L
.51913 .04653 L
.51918 .03062 L
.5192 .04653 L
.51921 .06244 L
.51924 .07835 L
Mistroke
.51925 .09426 L
.51934 .07835 L
.51938 .06244 L
.51939 .07835 L
.51943 .06244 L
.5195 .07835 L
.51951 .09426 L
.5196 .07835 L
.51961 .09426 L
.51965 .07835 L
.51969 .06244 L
.51972 .07835 L
.51974 .09426 L
.51988 .11016 L
.51999 .09426 L
.52 .07835 L
.52014 .06244 L
.52014 .07835 L
.52015 .09426 L
.52017 .07835 L
.52026 .06244 L
.52033 .07835 L
.52041 .06244 L
.52048 .07835 L
.52056 .06244 L
.5206 .07835 L
.52061 .09426 L
.52061 .07835 L
.52061 .09426 L
.52065 .07835 L
.52073 .06244 L
.52097 .04653 L
.52099 .03062 L
.52104 .04653 L
.52108 .06244 L
.52112 .07835 L
.52113 .09426 L
.5212 .11016 L
.52123 .12607 L
.52128 .14198 L
.52129 .12607 L
.5213 .11016 L
.52132 .09426 L
.52133 .11016 L
.52142 .12607 L
.52149 .11016 L
.52153 .12607 L
.52156 .11016 L
.52156 .09426 L
.52161 .11016 L
Mistroke
.52167 .09426 L
.52171 .11016 L
.52174 .09426 L
.52178 .07835 L
.5218 .09426 L
.52183 .11016 L
.52187 .12607 L
.52188 .14198 L
.52202 .15789 L
.5222 .14198 L
.52224 .15789 L
.52224 .14198 L
.52228 .15789 L
.52235 .1738 L
.52237 .15789 L
.52242 .14198 L
.52246 .15789 L
.52251 .14198 L
.52253 .12607 L
.52264 .14198 L
.52265 .15789 L
.52266 .14198 L
.52267 .15789 L
.52274 .1738 L
.52277 .15789 L
.52289 .14198 L
.52289 .12607 L
.5229 .11016 L
.52294 .12607 L
.52297 .14198 L
.523 .12607 L
.52302 .11016 L
.52305 .09426 L
.5231 .07835 L
.5231 .09426 L
.52316 .11016 L
.52328 .09426 L
.52334 .11016 L
.52336 .12607 L
.52339 .14198 L
.5234 .12607 L
.52345 .14198 L
.52349 .12607 L
.52352 .14198 L
.52356 .15789 L
.52359 .1738 L
.52375 .18971 L
.5238 .20561 L
.52388 .22152 L
.52388 .20561 L
Mistroke
.52399 .22152 L
.524 .23743 L
.52409 .22152 L
.52412 .20561 L
.52417 .22152 L
.52432 .20561 L
.52432 .18971 L
.52435 .1738 L
.52442 .18971 L
.52449 .20561 L
.52455 .22152 L
.52455 .23743 L
.52455 .22152 L
.52457 .23743 L
.52468 .25334 L
.52472 .26925 L
.52475 .28515 L
.52477 .26925 L
.52483 .25334 L
.52484 .23743 L
.52489 .25334 L
.52496 .23743 L
.52498 .25334 L
.525 .23743 L
.52508 .25334 L
.52512 .23743 L
.52518 .22152 L
.52523 .23743 L
.52524 .22152 L
.52532 .20561 L
.52535 .22152 L
.52537 .20561 L
.52539 .22152 L
.52541 .20561 L
.52542 .22152 L
.52545 .23743 L
.52546 .25334 L
.52548 .23743 L
.52553 .22152 L
.52553 .20561 L
.52554 .22152 L
.52558 .20561 L
.52561 .18971 L
.52561 .1738 L
.52567 .15789 L
.52569 .1738 L
.52572 .18971 L
.52572 .20561 L
.52573 .18971 L
.52573 .1738 L
Mistroke
.52583 .18971 L
.52587 .20561 L
.52594 .18971 L
.52602 .1738 L
.52607 .18971 L
.52608 .1738 L
.52609 .15789 L
.5261 .14198 L
.5261 .12607 L
.52617 .14198 L
.52619 .12607 L
.52626 .14198 L
.5263 .15789 L
.52632 .14198 L
.52634 .15789 L
.52637 .1738 L
.52641 .15789 L
.52644 .14198 L
.52645 .12607 L
.52648 .11016 L
.5265 .09426 L
.5265 .11016 L
.52656 .12607 L
.5266 .11016 L
.52662 .12607 L
.52668 .14198 L
.5267 .12607 L
.52679 .11016 L
.52683 .12607 L
.52684 .14198 L
.52687 .12607 L
.52695 .11016 L
.52709 .12607 L
.52714 .14198 L
.52718 .15789 L
.52718 .1738 L
.52718 .18971 L
.52721 .1738 L
.52733 .18971 L
.52736 .20561 L
.52736 .18971 L
.52739 .20561 L
.52739 .18971 L
.52746 .1738 L
.52748 .15789 L
.52751 .14198 L
.52754 .15789 L
.52774 .1738 L
.52808 .18971 L
.52812 .1738 L
Mistroke
.52819 .15789 L
.52822 .14198 L
.52824 .15789 L
.52825 .1738 L
.52829 .18971 L
.52841 .20561 L
.52844 .18971 L
.52845 .20561 L
.52855 .18971 L
.52857 .20561 L
.52858 .18971 L
.52865 .20561 L
.52871 .18971 L
.52871 .20561 L
.52874 .22152 L
.52877 .20561 L
.52882 .18971 L
.52885 .20561 L
.52889 .22152 L
.52901 .23743 L
.52908 .25334 L
.52912 .23743 L
.52915 .22152 L
.52919 .23743 L
.5292 .25334 L
.52925 .23743 L
.52928 .22152 L
.52929 .20561 L
.52948 .22152 L
.52951 .20561 L
.52953 .18971 L
.52955 .1738 L
.52964 .18971 L
.52967 .20561 L
.52969 .22152 L
.52976 .20561 L
.52981 .18971 L
.52983 .20561 L
.52983 .22152 L
.52984 .23743 L
.52985 .22152 L
.52995 .23743 L
.52999 .25334 L
.53001 .26925 L
.53012 .28515 L
.53017 .26925 L
.53022 .25334 L
.53034 .23743 L
.53045 .22152 L
.53051 .20561 L
Mistroke
.53058 .18971 L
.53061 .20561 L
.53066 .18971 L
.53069 .1738 L
.53073 .15789 L
.53074 .1738 L
.53076 .18971 L
.53078 .1738 L
.53083 .18971 L
.53105 .1738 L
.53105 .15789 L
.53108 .1738 L
.53121 .18971 L
.53139 .1738 L
.53143 .18971 L
.53146 .1738 L
.53149 .15789 L
.53154 .1738 L
.53156 .18971 L
.5316 .20561 L
.5316 .22152 L
.53166 .20561 L
.5317 .22152 L
.53171 .23743 L
.53178 .22152 L
.53181 .20561 L
.53183 .18971 L
.53191 .20561 L
.53206 .18971 L
.53214 .20561 L
.53218 .22152 L
.5322 .20561 L
.53226 .18971 L
.53244 .1738 L
.53249 .15789 L
.53255 .1738 L
.53265 .18971 L
.53266 .20561 L
.53268 .18971 L
.53286 .1738 L
.53295 .15789 L
.53295 .14198 L
.53298 .15789 L
.53313 .14198 L
.53316 .15789 L
.53325 .14198 L
.53326 .15789 L
.53334 .14198 L
.53339 .15789 L
.53339 .1738 L
Mistroke
.53349 .15789 L
.5335 .1738 L
.53351 .18971 L
.53365 .20561 L
.53366 .18971 L
.53369 .1738 L
.53379 .18971 L
.53393 .20561 L
.53395 .22152 L
.53406 .23743 L
.53408 .25334 L
.53412 .23743 L
.53426 .25334 L
.53429 .23743 L
.5343 .22152 L
.53433 .23743 L
.53434 .25334 L
.5344 .26925 L
.53446 .28515 L
.5345 .30106 L
.53461 .31697 L
.53465 .30106 L
.53469 .31697 L
.53471 .30106 L
.5349 .31697 L
.53496 .33288 L
.53498 .34879 L
.535 .33288 L
.53501 .34879 L
.53505 .3647 L
.53508 .34879 L
.5351 .33288 L
.53518 .34879 L
.53521 .3647 L
.53523 .3806 L
.53531 .3647 L
.53536 .34879 L
.53536 .33288 L
.53537 .31697 L
.53538 .30106 L
.53539 .31697 L
.5354 .30106 L
.53564 .31697 L
.53565 .33288 L
.53567 .31697 L
.53569 .30106 L
.53569 .31697 L
.53572 .33288 L
.53575 .31697 L
.53578 .30106 L
Mistroke
.53596 .31697 L
.53596 .33288 L
.53597 .31697 L
.53598 .30106 L
.53606 .31697 L
.53617 .33288 L
.53636 .31697 L
.5364 .33288 L
.53644 .31697 L
.53646 .33288 L
.53656 .34879 L
.53666 .3647 L
.53668 .34879 L
.53675 .33288 L
.53678 .34879 L
.53685 .3647 L
.53689 .3806 L
.53692 .39651 L
.53693 .3806 L
.53697 .3647 L
.53698 .3806 L
.537 .39651 L
.53716 .41242 L
.53719 .39651 L
.53719 .3806 L
.53723 .39651 L
.53724 .3806 L
.53737 .3647 L
.53744 .34879 L
.53744 .3647 L
.53745 .3806 L
.53748 .39651 L
.53753 .41242 L
.53754 .39651 L
.5376 .41242 L
.53761 .39651 L
.53762 .3806 L
.5377 .3647 L
.53776 .34879 L
.53787 .3647 L
.53788 .34879 L
.53788 .3647 L
.5379 .34879 L
.53799 .3647 L
.53805 .34879 L
.53806 .33288 L
.5381 .34879 L
.5381 .33288 L
.53814 .31697 L
.53815 .33288 L
Mistroke
.5383 .31697 L
.53836 .33288 L
.5384 .31697 L
.53843 .30106 L
.53852 .28515 L
.53859 .30106 L
.53861 .28515 L
.53862 .26925 L
.53885 .25334 L
.539 .26925 L
.53905 .25334 L
.53906 .23743 L
.53918 .25334 L
.53918 .23743 L
.53929 .22152 L
.53931 .23743 L
.53933 .22152 L
.53936 .23743 L
.53938 .25334 L
.53944 .26925 L
.53945 .28515 L
.53953 .26925 L
.53959 .28515 L
.53962 .26925 L
.53964 .28515 L
.53968 .30106 L
.53971 .28515 L
.53971 .26925 L
.53975 .28515 L
.5398 .30106 L
.53988 .31697 L
.53996 .33288 L
.53997 .31697 L
.54011 .33288 L
.54013 .34879 L
.54019 .33288 L
.54019 .31697 L
.54019 .30106 L
.54021 .31697 L
.54033 .33288 L
.5404 .34879 L
.5404 .33288 L
.54043 .31697 L
.54045 .30106 L
.54067 .31697 L
.54067 .30106 L
.54068 .31697 L
.5407 .30106 L
.54073 .28515 L
.54076 .30106 L
Mistroke
.54082 .28515 L
.54084 .26925 L
.54084 .28515 L
.54086 .30106 L
.54087 .31697 L
.54095 .33288 L
.54095 .31697 L
.54098 .33288 L
.54098 .31697 L
.54103 .33288 L
.54108 .31697 L
.54111 .30106 L
.54113 .31697 L
.54124 .33288 L
.54124 .31697 L
.54124 .30106 L
.54126 .31697 L
.54132 .30106 L
.54133 .28515 L
.54136 .26925 L
.54138 .28515 L
.5414 .30106 L
.54141 .31697 L
.54148 .33288 L
.54151 .31697 L
.54161 .30106 L
.54169 .28515 L
.54177 .30106 L
.54184 .31697 L
.54188 .33288 L
.54191 .34879 L
.54195 .33288 L
.54198 .31697 L
.542 .30106 L
.54221 .31697 L
.5423 .33288 L
.54233 .34879 L
.54238 .3647 L
.54246 .3806 L
.54249 .39651 L
.54255 .41242 L
.54268 .42833 L
.54272 .41242 L
.54274 .42833 L
.54276 .44424 L
.54278 .46014 L
.54278 .44424 L
.54311 .46014 L
.54312 .47605 L
.54316 .46014 L
Mistroke
.54317 .47605 L
.54335 .46014 L
.54337 .47605 L
.54355 .46014 L
.54363 .44424 L
.54363 .42833 L
.54373 .44424 L
.54377 .46014 L
.54384 .44424 L
.54388 .46014 L
.5439 .44424 L
.54408 .46014 L
.54417 .44424 L
.54419 .42833 L
.54429 .41242 L
.54431 .39651 L
.54433 .3806 L
.54435 .3647 L
.54435 .3806 L
.54438 .3647 L
.5444 .3806 L
.54441 .3647 L
.54452 .3806 L
.54453 .3647 L
.54455 .34879 L
.54455 .3647 L
.54468 .3806 L
.54469 .39651 L
.5447 .3806 L
.54473 .39651 L
.54476 .41242 L
.54481 .42833 L
.54482 .41242 L
.545 .39651 L
.54507 .41242 L
.54507 .39651 L
.54509 .3806 L
.54513 .3647 L
.54518 .3806 L
.54519 .39651 L
.54532 .41242 L
.54542 .42833 L
.54542 .44424 L
.54547 .46014 L
.54549 .44424 L
.5455 .46014 L
.5455 .44424 L
.54553 .46014 L
.5456 .44424 L
.54576 .42833 L
Mistroke
.54582 .44424 L
.546 .42833 L
.54608 .41242 L
.54609 .39651 L
.54627 .3806 L
.54629 .3647 L
.5463 .3806 L
.54632 .3647 L
.54633 .34879 L
.54638 .3647 L
.54639 .3806 L
.54659 .3647 L
.54659 .3806 L
.54659 .39651 L
.54659 .3806 L
.54661 .39651 L
.54665 .41242 L
.54666 .42833 L
.54673 .41242 L
.54678 .39651 L
.54704 .3806 L
.54705 .39651 L
.54709 .3806 L
.54713 .3647 L
.54717 .34879 L
.5472 .3647 L
.54722 .34879 L
.54723 .33288 L
.54725 .31697 L
.54725 .30106 L
.54727 .28515 L
.54732 .30106 L
.54749 .31697 L
.54762 .33288 L
.54765 .34879 L
.54776 .3647 L
.54777 .34879 L
.54781 .3647 L
.54782 .34879 L
.5479 .33288 L
.54792 .34879 L
.54794 .3647 L
.54795 .34879 L
.54797 .33288 L
.54798 .31697 L
.54798 .33288 L
.548 .34879 L
.54804 .3647 L
.54808 .3806 L
.54813 .3647 L
Mistroke
.54817 .3806 L
.54822 .3647 L
.54824 .3806 L
.54832 .3647 L
.54838 .34879 L
.54843 .3647 L
.54846 .3806 L
.54847 .3647 L
.54848 .3806 L
.5485 .3647 L
.54859 .34879 L
.54871 .3647 L
.54875 .34879 L
.54876 .33288 L
.54877 .34879 L
.5488 .33288 L
.54888 .34879 L
.5489 .3647 L
.54897 .3806 L
.54898 .3647 L
.54901 .34879 L
.54902 .33288 L
.5491 .31697 L
.54912 .33288 L
.54914 .34879 L
.54914 .33288 L
.54916 .31697 L
.54916 .33288 L
.54926 .34879 L
.54926 .33288 L
.5493 .34879 L
.54934 .3647 L
.54936 .3806 L
.54941 .39651 L
.54945 .3806 L
.54945 .3647 L
.54946 .34879 L
.54946 .33288 L
.54952 .34879 L
.54954 .33288 L
.54956 .31697 L
.5496 .30106 L
.5496 .28515 L
.54966 .30106 L
.54971 .28515 L
.54973 .30106 L
.54975 .31697 L
.54983 .30106 L
.54987 .31697 L
.54988 .33288 L
Mistroke
.5499 .31697 L
.5499 .30106 L
.54994 .31697 L
.55 .33288 L
.55 .31697 L
.55002 .33288 L
.55002 .34879 L
.55003 .3647 L
.55012 .3806 L
.55016 .39651 L
.55025 .3806 L
.55034 .39651 L
.55035 .3806 L
.55053 .39651 L
.55056 .3806 L
.55057 .3647 L
.55062 .3806 L
.55063 .39651 L
.5507 .3806 L
.5507 .39651 L
.5508 .3806 L
.5508 .39651 L
.55081 .41242 L
.55088 .42833 L
.55088 .44424 L
.5509 .42833 L
.55094 .44424 L
.55098 .46014 L
.55099 .47605 L
.55106 .49196 L
.55109 .50787 L
.55119 .49196 L
.55134 .50787 L
.55134 .52378 L
.55139 .53969 L
.55145 .55559 L
.55148 .5715 L
.55149 .55559 L
.55153 .53969 L
.55175 .55559 L
.55179 .5715 L
.5518 .55559 L
.55185 .5715 L
.5519 .55559 L
.5519 .53969 L
.55191 .52378 L
.55192 .50787 L
.55212 .52378 L
.55217 .53969 L
.55222 .55559 L
Mistroke
.55223 .5715 L
.55226 .55559 L
.55229 .53969 L
.5523 .55559 L
.5523 .5715 L
.55231 .58741 L
.55232 .5715 L
.5524 .58741 L
.55241 .5715 L
.55244 .55559 L
.55254 .53969 L
.55254 .55559 L
.55265 .5715 L
.55271 .58741 L
.55273 .60332 L
.55277 .58741 L
.5528 .60332 L
.55288 .58741 L
.5529 .5715 L
.55297 .58741 L
.55298 .60332 L
.55301 .58741 L
.55303 .5715 L
.55309 .58741 L
.55311 .5715 L
.55313 .55559 L
.55316 .53969 L
.55318 .55559 L
.55327 .5715 L
.55334 .58741 L
.55334 .60332 L
.5534 .58741 L
.55348 .60332 L
.55349 .58741 L
.55351 .60332 L
Mfstroke
.55355 .61803 m
.55351 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
.55415 .61803 m
.55417 .60332 L
s
.55417 .60332 m
0 0 rlineto
.55426 .61803 m
.55417 .60332 L
s
s
s
.55444 .61803 m
.55444 .60332 L
s
.55444 .60332 m
.55454 .58741 L
.55455 .5715 L
.55455 .55559 L
.5546 .53969 L
.55461 .52378 L
.55464 .53969 L
.55473 .52378 L
.55481 .53969 L
.55487 .52378 L
.5549 .50787 L
.5549 .52378 L
.55492 .50787 L
.55493 .49196 L
.55496 .47605 L
.55497 .46014 L
.55497 .47605 L
.55504 .46014 L
.55504 .44424 L
.55504 .46014 L
.55512 .44424 L
.55517 .46014 L
.55519 .44424 L
.55519 .46014 L
.55519 .47605 L
.55525 .46014 L
.55529 .47605 L
.55539 .46014 L
.5555 .44424 L
.55552 .46014 L
.55556 .44424 L
.55562 .42833 L
.55563 .44424 L
.55566 .42833 L
.55567 .44424 L
.55568 .42833 L
.55572 .41242 L
.55579 .42833 L
.5558 .41242 L
.55583 .39651 L
.55584 .3806 L
.55585 .39651 L
.55586 .41242 L
.55596 .39651 L
.55603 .3806 L
.55621 .39651 L
.55629 .3806 L
.55629 .39651 L
.55632 .41242 L
.55636 .42833 L
Mistroke
.55638 .44424 L
.55644 .42833 L
.55649 .41242 L
.5565 .42833 L
.55653 .41242 L
.55653 .39651 L
.55654 .41242 L
.55654 .42833 L
.55654 .41242 L
.55666 .39651 L
.55672 .3806 L
.55677 .3647 L
.55682 .34879 L
.55692 .33288 L
.5571 .31697 L
.55722 .30106 L
.55722 .28515 L
.55725 .26925 L
.55736 .25334 L
.55738 .23743 L
.55746 .22152 L
.55751 .23743 L
.55751 .22152 L
.55752 .20561 L
.55752 .18971 L
.55754 .20561 L
.55761 .22152 L
.55763 .23743 L
.55764 .22152 L
.55767 .20561 L
.5577 .22152 L
.5578 .23743 L
.55783 .25334 L
.55783 .23743 L
.55786 .25334 L
.55786 .26925 L
.55791 .25334 L
.55795 .26925 L
.55805 .25334 L
.55807 .26925 L
.55808 .25334 L
.55808 .23743 L
.55809 .22152 L
.55815 .20561 L
.55815 .22152 L
.55823 .20561 L
.55827 .18971 L
.55827 .20561 L
.5583 .22152 L
.55832 .23743 L
Mistroke
.55833 .25334 L
.55836 .23743 L
.55844 .22152 L
.55844 .23743 L
.55847 .22152 L
.5585 .23743 L
.55855 .25334 L
.55856 .26925 L
.55859 .25334 L
.5586 .26925 L
.55868 .28515 L
.55872 .26925 L
.55878 .28515 L
.55897 .26925 L
.55902 .25334 L
.55915 .26925 L
.55919 .25334 L
.55924 .23743 L
.55928 .22152 L
.5594 .20561 L
.55941 .22152 L
.55941 .20561 L
.55942 .18971 L
.55947 .1738 L
.55952 .18971 L
.55961 .1738 L
.55964 .18971 L
.55972 .1738 L
.55972 .15789 L
.55974 .1738 L
.55974 .18971 L
.55976 .20561 L
.55985 .18971 L
.55986 .20561 L
.55986 .22152 L
.55989 .23743 L
.55991 .22152 L
.55995 .23743 L
.56005 .25334 L
.56011 .26925 L
.56012 .25334 L
.56013 .23743 L
.5602 .22152 L
.56023 .23743 L
.56024 .22152 L
.56029 .20561 L
.56032 .18971 L
.56038 .20561 L
.56073 .18971 L
.56073 .20561 L
Mistroke
.56075 .22152 L
.56078 .20561 L
.56081 .18971 L
.56086 .1738 L
.56092 .15789 L
.56102 .1738 L
.56112 .15789 L
.56121 .14198 L
.56133 .12607 L
.56133 .11016 L
.56137 .09426 L
.56142 .11016 L
.56146 .12607 L
.56146 .11016 L
.56147 .09426 L
.56156 .07835 L
.56164 .06244 L
.56168 .04653 L
.5617 .03062 L
.56174 .04653 L
.56174 .06244 L
.5618 .07835 L
.56185 .09426 L
.56187 .07835 L
.5619 .06244 L
.56192 .04653 L
.56198 .03062 L
.562 .01472 L
.56214 .03062 L
.56216 .01472 L
.56226 .03062 L
.56228 .04653 L
.56232 .03062 L
.56233 .01472 L
.56241 .03062 L
.56257 .01472 L
.56277 .03062 L
.56282 .01472 L
.56292 .03062 L
.56298 .01472 L
.56337 .03062 L
.5634 .01472 L
.56344 .03062 L
.56344 .04653 L
.5635 .06244 L
.56352 .04653 L
.56353 .03062 L
.56357 .01472 L
.56359 .03062 L
.56359 .04653 L
Mistroke
.56365 .03062 L
.56367 .01472 L
.56369 .03062 L
.56372 .01472 L
.56373 .03062 L
.56379 .04653 L
.56384 .03062 L
.56386 .01472 L
.56387 .03062 L
.56394 .04653 L
.56405 .03062 L
.56408 .04653 L
.56415 .06244 L
.56418 .07835 L
.5642 .06244 L
.56424 .04653 L
.56424 .06244 L
.56431 .04653 L
.56441 .06244 L
.56443 .04653 L
.56449 .03062 L
.56454 .01472 L
.56461 .03062 L
.56461 .01472 L
.56475 .03062 L
.56477 .01472 L
.56478 .03062 L
.56483 .04653 L
.56487 .03062 L
.56492 .01472 L
.56497 .03062 L
.56501 .01472 L
.56516 .03062 L
.56519 .04653 L
.56519 .06244 L
.56523 .04653 L
.5653 .03062 L
.56532 .01472 L
.56533 .03062 L
.56533 .01472 L
.56547 .03062 L
.56551 .04653 L
.56552 .03062 L
.56558 .01472 L
.56584 .03062 L
.56584 .01472 L
.56588 .03062 L
.56591 .04653 L
.56592 .06244 L
.56595 .04653 L
Mistroke
.56606 .06244 L
.5661 .07835 L
.56612 .06244 L
.56628 .04653 L
.56633 .06244 L
.56633 .04653 L
.56634 .06244 L
.56639 .04653 L
.56651 .06244 L
.56654 .04653 L
.56655 .06244 L
.56656 .07835 L
.56657 .09426 L
.56657 .11016 L
.56668 .12607 L
.56676 .11016 L
.56685 .09426 L
.56688 .11016 L
.56696 .12607 L
.56697 .14198 L
.56698 .15789 L
.56701 .1738 L
.56701 .18971 L
.56705 .1738 L
.56706 .18971 L
.56707 .1738 L
.56712 .15789 L
.56714 .14198 L
.56716 .15789 L
.5672 .1738 L
.56728 .18971 L
.56731 .20561 L
.56732 .18971 L
.56736 .1738 L
.56736 .15789 L
.56753 .1738 L
.56756 .15789 L
.56757 .1738 L
.56761 .18971 L
.56763 .1738 L
.56764 .15789 L
.56764 .1738 L
.56767 .18971 L
.56767 .20561 L
.56769 .22152 L
.56773 .20561 L
.56778 .18971 L
.5678 .20561 L
.56786 .22152 L
.56789 .20561 L
Mistroke
.5679 .22152 L
.56791 .20561 L
.56795 .18971 L
.56795 .1738 L
.568 .15789 L
.56811 .14198 L
.56816 .12607 L
.56816 .14198 L
.56817 .15789 L
.56817 .1738 L
.56829 .18971 L
.56831 .1738 L
.56839 .18971 L
.56845 .20561 L
.56848 .18971 L
.56851 .20561 L
.56855 .22152 L
.56858 .23743 L
.56859 .22152 L
.56861 .20561 L
.56865 .18971 L
.5687 .20561 L
.56871 .18971 L
.56871 .1738 L
.56873 .15789 L
.56873 .14198 L
.56884 .15789 L
.56884 .14198 L
.56888 .12607 L
.56889 .14198 L
.56891 .12607 L
.56897 .11016 L
.56902 .09426 L
.56906 .11016 L
.56909 .12607 L
.56914 .11016 L
.56916 .09426 L
.56922 .07835 L
.56924 .09426 L
.56933 .07835 L
.56933 .09426 L
.56934 .11016 L
.56936 .12607 L
.56937 .11016 L
.56944 .09426 L
.56946 .11016 L
.56947 .09426 L
.56961 .11016 L
.56963 .09426 L
.56963 .07835 L
Mistroke
.56966 .09426 L
.56967 .11016 L
.5697 .09426 L
.56975 .07835 L
.56976 .09426 L
.56976 .07835 L
.56987 .09426 L
.56987 .07835 L
.57002 .09426 L
.57007 .11016 L
.57007 .09426 L
.5701 .07835 L
.57012 .06244 L
.5703 .04653 L
.57039 .03062 L
.57045 .04653 L
.57046 .03062 L
.5706 .01472 L
.5706 .03062 L
.57067 .01472 L
.57079 .03062 L
.57081 .01472 L
.57088 .03062 L
.57088 .01472 L
.5709 .03062 L
.57091 .01472 L
.57107 .03062 L
.57111 .01472 L
.57123 .03062 L
.57126 .01472 L
.57137 .03062 L
.57137 .01472 L
.57139 .03062 L
.57139 .04653 L
.57139 .03062 L
.57141 .01472 L
.57145 .03062 L
.5715 .01472 L
.57155 .03062 L
.5716 .04653 L
.57163 .03062 L
.57172 .01472 L
.57178 .03062 L
.57179 .01472 L
.57187 .03062 L
.57189 .04653 L
.57191 .03062 L
.57191 .01472 L
.57194 .03062 L
.57196 .01472 L
Mistroke
.57199 .03062 L
.57207 .04653 L
.57209 .03062 L
.57216 .04653 L
.57221 .06244 L
.57229 .07835 L
.57239 .06244 L
.57248 .04653 L
.57258 .06244 L
.57268 .04653 L
.57272 .03062 L
.57278 .01472 L
.57283 .03062 L
.57289 .04653 L
.5729 .06244 L
.57296 .04653 L
.57311 .03062 L
.57315 .04653 L
.57322 .03062 L
.57327 .01472 L
.57333 .03062 L
.5734 .04653 L
.57342 .03062 L
.57345 .01472 L
.57346 .03062 L
.57378 .04653 L
.57382 .03062 L
.57384 .01472 L
.57395 .03062 L
.57399 .01472 L
.57403 .03062 L
.57406 .04653 L
.57407 .03062 L
.57416 .04653 L
.57419 .06244 L
.57421 .07835 L
.57423 .09426 L
.57425 .11016 L
.5743 .12607 L
.57433 .11016 L
.57441 .12607 L
.57452 .11016 L
.57453 .09426 L
.57454 .07835 L
.57459 .06244 L
.57467 .07835 L
.57467 .06244 L
.57479 .07835 L
.5748 .09426 L
.57481 .07835 L
Mistroke
.57481 .09426 L
.57485 .07835 L
.57499 .06244 L
.575 .04653 L
.57501 .06244 L
.57505 .04653 L
.57507 .06244 L
.57515 .07835 L
.57518 .06244 L
.57519 .07835 L
.57523 .09426 L
.57524 .07835 L
.57524 .09426 L
.57542 .07835 L
.57546 .06244 L
.57551 .07835 L
.57557 .09426 L
.57557 .11016 L
.57561 .09426 L
.5757 .11016 L
.57578 .09426 L
.5758 .07835 L
.5758 .06244 L
.57591 .07835 L
.57596 .06244 L
.57599 .04653 L
.576 .06244 L
.576 .07835 L
.57602 .09426 L
.57608 .11016 L
.5761 .09426 L
.57625 .07835 L
.57626 .09426 L
.57627 .11016 L
.57639 .12607 L
.57641 .14198 L
.57644 .15789 L
.57646 .1738 L
.57651 .15789 L
.57653 .1738 L
.57655 .15789 L
.57655 .14198 L
.57655 .12607 L
.57656 .14198 L
.57658 .12607 L
.57659 .11016 L
.5766 .09426 L
.5766 .07835 L
.57662 .06244 L
.57677 .04653 L
Mistroke
.57678 .06244 L
.57681 .07835 L
.57683 .06244 L
.57683 .04653 L
.57689 .03062 L
.57693 .04653 L
.57699 .03062 L
.57704 .01472 L
.5771 .03062 L
.5772 .01472 L
.5773 .03062 L
.57732 .01472 L
.57742 .03062 L
.57744 .04653 L
.57749 .03062 L
.5775 .01472 L
.57752 .03062 L
.57757 .01472 L
.57771 .03062 L
.57776 .04653 L
.5778 .06244 L
.57781 .07835 L
.57787 .09426 L
.578 .07835 L
.57808 .09426 L
.57809 .07835 L
.57815 .06244 L
.57819 .07835 L
.5782 .09426 L
.57823 .07835 L
.57836 .09426 L
.5784 .11016 L
.57851 .12607 L
.57861 .11016 L
.57865 .12607 L
.5788 .14198 L
.57884 .15789 L
.57885 .14198 L
.57891 .15789 L
.57892 .14198 L
.57893 .15789 L
.57893 .1738 L
.57895 .15789 L
.57897 .1738 L
.57899 .15789 L
.57901 .1738 L
.57903 .18971 L
.5791 .1738 L
.57911 .18971 L
.57912 .1738 L
Mistroke
.57914 .15789 L
.57917 .14198 L
.57926 .12607 L
.57932 .14198 L
.57937 .12607 L
.57938 .11016 L
.5795 .09426 L
.5795 .07835 L
.57952 .09426 L
.57952 .07835 L
.57953 .09426 L
.57954 .11016 L
.57968 .09426 L
.57968 .11016 L
.57976 .12607 L
.57984 .11016 L
.57985 .09426 L
.57985 .11016 L
.57992 .12607 L
.57993 .11016 L
.57996 .12607 L
.57997 .14198 L
.57998 .15789 L
.58007 .1738 L
.58009 .18971 L
.58009 .1738 L
.58014 .15789 L
.58015 .14198 L
.58021 .15789 L
.58022 .1738 L
.58025 .15789 L
.58026 .14198 L
.58032 .15789 L
.58035 .1738 L
.58036 .18971 L
.58046 .1738 L
.58047 .18971 L
.58047 .1738 L
.58055 .18971 L
.58058 .1738 L
.5806 .18971 L
.5806 .1738 L
.58065 .18971 L
.58068 .20561 L
.58077 .18971 L
.58078 .1738 L
.58081 .15789 L
.58084 .14198 L
.58085 .15789 L
.58086 .1738 L
Mistroke
.58087 .18971 L
.58087 .20561 L
.58093 .22152 L
.58099 .20561 L
.581 .18971 L
.58102 .1738 L
.58105 .18971 L
.58109 .20561 L
.5811 .22152 L
.58124 .23743 L
.58126 .22152 L
.58129 .20561 L
.58135 .22152 L
.58139 .23743 L
.58144 .25334 L
.58146 .23743 L
.58151 .25334 L
.58153 .23743 L
.58155 .25334 L
.5816 .26925 L
.58162 .25334 L
.58163 .26925 L
.58172 .25334 L
.58178 .23743 L
.58184 .22152 L
.58186 .20561 L
.58195 .18971 L
.58195 .1738 L
.58196 .18971 L
.58201 .1738 L
.58202 .15789 L
.58204 .14198 L
.58204 .15789 L
.58207 .14198 L
.58213 .15789 L
.58215 .14198 L
.58221 .15789 L
.58225 .14198 L
.58237 .15789 L
.58245 .14198 L
.58247 .12607 L
.58251 .11016 L
.58251 .09426 L
.58256 .11016 L
.58262 .12607 L
.58264 .11016 L
.58268 .12607 L
.58286 .11016 L
.5829 .09426 L
.58294 .11016 L
Mistroke
.58296 .12607 L
.58303 .14198 L
.58303 .12607 L
.58304 .11016 L
.5831 .09426 L
.58316 .07835 L
.58322 .09426 L
.5833 .11016 L
.58332 .09426 L
.58333 .11016 L
.5834 .09426 L
.58349 .07835 L
.5835 .06244 L
.5836 .04653 L
.5836 .06244 L
.58364 .04653 L
.58373 .06244 L
.58374 .07835 L
.58376 .06244 L
.58376 .04653 L
.58394 .06244 L
.58403 .04653 L
.58404 .06244 L
.58409 .07835 L
.58422 .09426 L
.58424 .11016 L
.58426 .12607 L
.58431 .14198 L
.58435 .12607 L
.58441 .11016 L
.58441 .12607 L
.58442 .14198 L
.58446 .12607 L
.58454 .14198 L
.58454 .12607 L
.58458 .14198 L
.58467 .15789 L
.58472 .1738 L
.58473 .15789 L
.58499 .1738 L
.58499 .15789 L
.585 .1738 L
.58502 .18971 L
.5851 .1738 L
.58513 .15789 L
.58517 .14198 L
.58519 .15789 L
.58524 .14198 L
.58526 .12607 L
.58534 .11016 L
Mistroke
.58537 .09426 L
.58538 .07835 L
.58551 .06244 L
.58558 .04653 L
.5856 .06244 L
.58566 .07835 L
.58569 .09426 L
.58574 .11016 L
.58577 .09426 L
.58583 .11016 L
.58584 .12607 L
.58585 .11016 L
.58586 .09426 L
.58589 .07835 L
.58605 .06244 L
.58617 .04653 L
.58621 .06244 L
.58625 .04653 L
.58627 .03062 L
.5863 .01472 L
.58631 .03062 L
.58631 .04653 L
.5864 .06244 L
.58657 .07835 L
.58671 .09426 L
.58677 .07835 L
.58685 .06244 L
.58689 .07835 L
.5869 .06244 L
.58692 .07835 L
.58699 .09426 L
.587 .07835 L
.58716 .06244 L
.58719 .07835 L
.58722 .06244 L
.58729 .04653 L
.58738 .03062 L
.58747 .04653 L
.58751 .03062 L
.58752 .01472 L
.58761 .03062 L
.5877 .01472 L
.58795 .03062 L
.58796 .04653 L
.58806 .03062 L
.58815 .01472 L
.58822 .03062 L
.58823 .01472 L
.58829 .03062 L
.5883 .04653 L
Mistroke
.58831 .03062 L
.58836 .01472 L
.58844 .03062 L
.58846 .04653 L
.58847 .03062 L
.58853 .04653 L
.58864 .06244 L
.58873 .07835 L
.58877 .06244 L
.58887 .07835 L
.58891 .06244 L
.58894 .04653 L
.58895 .03062 L
.58897 .01472 L
.58904 .03062 L
.58909 .01472 L
.58919 .03062 L
.58925 .01472 L
.58931 .03062 L
.58944 .01472 L
.5895 .03062 L
.58952 .04653 L
.58953 .03062 L
.58961 .01472 L
.58966 .03062 L
.58971 .04653 L
.58977 .06244 L
.58981 .04653 L
.58983 .03062 L
.59 .01472 L
.59002 .03062 L
.59007 .01472 L
.59018 .03062 L
.59021 .04653 L
.59022 .06244 L
.59025 .04653 L
.59028 .06244 L
.5903 .04653 L
.59031 .06244 L
.59034 .04653 L
.59034 .03062 L
.59045 .04653 L
.5905 .06244 L
.59052 .04653 L
.59054 .03062 L
.59058 .04653 L
.59061 .03062 L
.59068 .04653 L
.5907 .06244 L
.5907 .04653 L
Mistroke
.59071 .06244 L
.59074 .07835 L
.59077 .09426 L
.59082 .07835 L
.59086 .06244 L
.59104 .04653 L
.59106 .06244 L
.59109 .07835 L
.59115 .09426 L
.59115 .11016 L
.59126 .12607 L
.59135 .14198 L
.59136 .15789 L
.59137 .14198 L
.5914 .12607 L
.59147 .11016 L
.59172 .09426 L
.59179 .07835 L
.59179 .06244 L
.59183 .04653 L
.59184 .06244 L
.59189 .04653 L
.59198 .03062 L
.59207 .04653 L
.59211 .03062 L
.59214 .01472 L
.59228 .03062 L
.59238 .04653 L
.59246 .06244 L
.59248 .04653 L
.59251 .03062 L
.59257 .04653 L
.59259 .03062 L
.59261 .04653 L
.59264 .06244 L
.59268 .07835 L
.5927 .06244 L
.59275 .07835 L
.59279 .06244 L
.5928 .04653 L
.59287 .06244 L
.59288 .04653 L
.59292 .06244 L
.59303 .04653 L
.59304 .03062 L
.59305 .04653 L
.59305 .03062 L
.59309 .01472 L
.59311 .03062 L
.59329 .04653 L
Mistroke
.59331 .03062 L
.59336 .01472 L
.59348 .03062 L
.59351 .04653 L
.59353 .06244 L
.59356 .04653 L
.59372 .03062 L
.59375 .04653 L
.59392 .03062 L
.59393 .01472 L
.59408 .03062 L
.59416 .04653 L
.5942 .03062 L
.59422 .04653 L
.59428 .03062 L
.59439 .04653 L
.5944 .06244 L
.59441 .07835 L
.59448 .09426 L
.59451 .11016 L
.59451 .09426 L
.59457 .07835 L
.59461 .09426 L
.59461 .11016 L
.59467 .12607 L
.59468 .14198 L
.5947 .12607 L
.59472 .11016 L
.59475 .12607 L
.59483 .14198 L
.59483 .15789 L
.59491 .14198 L
.59495 .15789 L
.59496 .1738 L
.59502 .15789 L
.59504 .14198 L
.59505 .15789 L
.59511 .1738 L
.59515 .18971 L
.59523 .1738 L
.59527 .15789 L
.59532 .1738 L
.59536 .18971 L
.59538 .1738 L
.5954 .18971 L
.59542 .20561 L
.59547 .18971 L
.59548 .1738 L
.59558 .15789 L
.59561 .1738 L
Mistroke
.59568 .15789 L
.59571 .1738 L
.59587 .18971 L
.59588 .1738 L
.59595 .15789 L
.59595 .14198 L
.5961 .15789 L
.5961 .14198 L
.59621 .12607 L
.59626 .14198 L
.59629 .15789 L
.59633 .1738 L
.59646 .15789 L
.5965 .14198 L
.59652 .12607 L
.59662 .14198 L
.59663 .12607 L
.59664 .11016 L
.59664 .09426 L
.59668 .07835 L
.59669 .09426 L
.5967 .07835 L
.59678 .09426 L
.5968 .11016 L
.59685 .12607 L
.59685 .11016 L
.59687 .09426 L
.59687 .07835 L
.59688 .09426 L
.59692 .07835 L
.59692 .06244 L
.59693 .04653 L
.59704 .06244 L
.59709 .04653 L
.5971 .06244 L
.59713 .04653 L
.59726 .03062 L
.59729 .01472 L
.59733 .03062 L
.59738 .01472 L
.59742 .03062 L
.59744 .01472 L
.59752 .03062 L
.59755 .04653 L
.59759 .03062 L
.59765 .04653 L
.59781 .06244 L
.59782 .07835 L
.59787 .06244 L
.59793 .07835 L
Mistroke
.59794 .06244 L
.59801 .04653 L
.59801 .06244 L
.59806 .07835 L
.59807 .06244 L
.59812 .04653 L
.5982 .06244 L
.5982 .07835 L
.59822 .06244 L
.59823 .04653 L
.59837 .06244 L
.59841 .04653 L
.59842 .06244 L
.59844 .07835 L
.59845 .09426 L
.59852 .11016 L
.59856 .12607 L
.59858 .11016 L
.59863 .12607 L
.59863 .11016 L
.59871 .12607 L
.59875 .11016 L
.59895 .09426 L
.59901 .11016 L
.59903 .12607 L
.59905 .14198 L
.59906 .15789 L
.59908 .14198 L
.59911 .15789 L
.59911 .14198 L
.59914 .12607 L
.59924 .14198 L
.59926 .15789 L
.59929 .14198 L
.59936 .15789 L
.59942 .14198 L
.59944 .12607 L
.59945 .14198 L
.59949 .15789 L
.5995 .1738 L
.59953 .15789 L
.59956 .14198 L
.59965 .15789 L
.59966 .1738 L
.59969 .15789 L
.59976 .1738 L
.59984 .15789 L
.59985 .14198 L
.59999 .15789 L
.60006 .1738 L
Mistroke
.60007 .15789 L
.6001 .14198 L
.60013 .15789 L
.60017 .14198 L
.60018 .12607 L
.60027 .14198 L
.6003 .12607 L
.60031 .14198 L
.60032 .15789 L
.60033 .14198 L
.60041 .12607 L
.60047 .14198 L
.60048 .12607 L
.60052 .11016 L
.60059 .12607 L
.60066 .11016 L
.6007 .12607 L
.60071 .11016 L
.60083 .09426 L
.60091 .07835 L
.60096 .06244 L
.60096 .07835 L
.60105 .09426 L
.60108 .11016 L
.60118 .12607 L
.6013 .11016 L
.60133 .12607 L
.60134 .14198 L
.60134 .15789 L
.60135 .14198 L
.60137 .12607 L
.60139 .11016 L
.60147 .09426 L
.60148 .11016 L
.60155 .09426 L
.60158 .07835 L
.6017 .09426 L
.60172 .07835 L
.60186 .06244 L
.60186 .04653 L
.60189 .03062 L
.60196 .01472 L
.60214 .03062 L
.60216 .04653 L
.60216 .03062 L
.60218 .01472 L
.60219 .03062 L
.60219 .01472 L
.60222 .03062 L
.60233 .04653 L
Mistroke
.60248 .03062 L
.60253 .01472 L
.60263 .03062 L
.60263 .04653 L
.60265 .06244 L
.60266 .04653 L
.60268 .03062 L
.60275 .01472 L
.60285 .03062 L
.60287 .04653 L
.60288 .06244 L
.60288 .04653 L
.60291 .06244 L
.60292 .07835 L
.60294 .09426 L
.60294 .07835 L
.60295 .06244 L
.60311 .07835 L
.60316 .06244 L
.6033 .07835 L
.60332 .09426 L
.60332 .07835 L
.60344 .06244 L
.60355 .07835 L
.60357 .09426 L
.60358 .07835 L
.60369 .09426 L
.60372 .11016 L
.60372 .09426 L
.60377 .07835 L
.60379 .09426 L
.6038 .11016 L
.60382 .09426 L
.60383 .11016 L
.60384 .09426 L
.60403 .07835 L
.60424 .06244 L
.60425 .07835 L
.60427 .09426 L
.60429 .07835 L
.60429 .09426 L
.60432 .11016 L
.60432 .12607 L
.60437 .14198 L
.60443 .12607 L
.60449 .11016 L
.6046 .12607 L
.60469 .14198 L
.60477 .12607 L
.6048 .14198 L
Mistroke
.60481 .15789 L
.60489 .14198 L
.60489 .15789 L
.6049 .14198 L
.60505 .15789 L
.60513 .1738 L
.60514 .15789 L
.60523 .1738 L
.60527 .15789 L
.60529 .1738 L
.60533 .15789 L
.60533 .1738 L
.60538 .18971 L
.6054 .1738 L
.60547 .15789 L
.60556 .14198 L
.60558 .12607 L
.60573 .11016 L
.60578 .12607 L
.60583 .11016 L
.60585 .12607 L
.60589 .14198 L
.606 .12607 L
.60605 .14198 L
.60608 .15789 L
.6061 .1738 L
.60616 .18971 L
.60626 .20561 L
.6063 .18971 L
.6064 .1738 L
.6064 .15789 L
.60642 .1738 L
.60644 .18971 L
.6065 .20561 L
.60662 .18971 L
.60666 .20561 L
.60669 .18971 L
.60672 .20561 L
.60673 .18971 L
.60676 .20561 L
.60677 .22152 L
.60684 .23743 L
.607 .22152 L
.60702 .23743 L
.60704 .25334 L
.60709 .26925 L
.60712 .25334 L
.60718 .26925 L
.60724 .25334 L
.60727 .26925 L
Mistroke
.60731 .28515 L
.60733 .30106 L
.6074 .31697 L
.60747 .30106 L
.60748 .28515 L
.60748 .26925 L
.60749 .25334 L
.60752 .26925 L
.60753 .25334 L
.60753 .23743 L
.60754 .25334 L
.60759 .23743 L
.60763 .25334 L
.60765 .23743 L
.60765 .22152 L
.60772 .20561 L
.60775 .22152 L
.60776 .20561 L
.60788 .22152 L
.6079 .20561 L
.60793 .22152 L
.60794 .20561 L
.60797 .22152 L
.60806 .20561 L
.60809 .18971 L
.60816 .20561 L
.60818 .18971 L
.60829 .20561 L
.60836 .22152 L
.60843 .20561 L
.60844 .22152 L
.60851 .20561 L
.60857 .18971 L
.60858 .1738 L
.60863 .15789 L
.6087 .14198 L
.60871 .12607 L
.60877 .14198 L
.60883 .12607 L
.60894 .11016 L
.60896 .12607 L
.6091 .14198 L
.60913 .15789 L
.60913 .1738 L
.6092 .18971 L
.60929 .20561 L
.60931 .22152 L
.60943 .23743 L
.60949 .25334 L
.60949 .23743 L
Mistroke
.60951 .25334 L
.60954 .23743 L
.60957 .22152 L
.60963 .20561 L
.60969 .22152 L
.60972 .23743 L
.60974 .22152 L
.61004 .20561 L
.61012 .18971 L
.61017 .20561 L
.61019 .18971 L
.6102 .1738 L
.61023 .18971 L
.61025 .1738 L
.61028 .15789 L
.61036 .1738 L
.61039 .15789 L
.61041 .1738 L
.61043 .15789 L
.61044 .1738 L
.61046 .15789 L
.61046 .14198 L
.61062 .15789 L
.61063 .1738 L
.61063 .15789 L
.61064 .1738 L
.61066 .15789 L
.61073 .1738 L
.61084 .15789 L
.61093 .14198 L
.61094 .15789 L
.61097 .14198 L
.61104 .12607 L
.61107 .14198 L
.61117 .15789 L
.61124 .14198 L
.61126 .12607 L
.61128 .11016 L
.61131 .12607 L
.61132 .14198 L
.61133 .15789 L
.61143 .1738 L
.61145 .15789 L
.6116 .1738 L
.61163 .15789 L
.61176 .1738 L
.6118 .15789 L
.6118 .14198 L
.61187 .12607 L
.61189 .11016 L
Mistroke
.61191 .12607 L
.61202 .14198 L
.61203 .15789 L
.61212 .14198 L
.61219 .15789 L
.61224 .1738 L
.61226 .18971 L
.61226 .1738 L
.6123 .15789 L
.61235 .1738 L
.61236 .18971 L
.61244 .20561 L
.61249 .22152 L
.6125 .20561 L
.61252 .18971 L
.61262 .1738 L
.61262 .18971 L
.61266 .1738 L
.61271 .18971 L
.61281 .1738 L
.61286 .15789 L
.613 .14198 L
.61303 .15789 L
.61319 .14198 L
.61325 .15789 L
.61328 .14198 L
.6134 .15789 L
.61341 .1738 L
.61345 .18971 L
.61356 .1738 L
.61369 .18971 L
.61372 .1738 L
.61379 .15789 L
.61382 .1738 L
.61401 .18971 L
.61402 .20561 L
.61405 .18971 L
.61408 .20561 L
.6141 .18971 L
.61412 .1738 L
.61413 .15789 L
.61413 .1738 L
.61417 .15789 L
.61426 .14198 L
.61433 .15789 L
.61434 .14198 L
.61439 .15789 L
.61446 .14198 L
.61474 .12607 L
.61479 .14198 L
Mistroke
.61487 .12607 L
.61488 .11016 L
.61489 .12607 L
.6149 .11016 L
.61492 .09426 L
.61506 .07835 L
.6151 .09426 L
.61513 .11016 L
.61528 .09426 L
.61539 .07835 L
.61545 .06244 L
.61546 .04653 L
.61551 .06244 L
.61558 .07835 L
.61559 .09426 L
.61563 .11016 L
.61566 .09426 L
.61569 .07835 L
.61573 .09426 L
.61594 .07835 L
.61597 .09426 L
.616 .07835 L
.61611 .09426 L
.61616 .07835 L
.61617 .09426 L
.61619 .07835 L
.61629 .06244 L
.61633 .07835 L
.61635 .06244 L
.61647 .04653 L
.61649 .06244 L
.61662 .04653 L
.61665 .03062 L
.61671 .04653 L
.61677 .03062 L
.61679 .04653 L
.61681 .03062 L
.61686 .01472 L
.61704 .03062 L
.61705 .04653 L
.61708 .03062 L
.6172 .04653 L
.61728 .03062 L
.61732 .04653 L
.61733 .06244 L
.61735 .04653 L
.61742 .03062 L
.61749 .04653 L
.61753 .06244 L
.61757 .07835 L
Mistroke
.61761 .06244 L
.61761 .04653 L
.61763 .03062 L
.61764 .04653 L
.61765 .03062 L
.61771 .04653 L
.61781 .06244 L
.61787 .04653 L
.61792 .03062 L
.618 .01472 L
.61814 .03062 L
.61826 .04653 L
.6185 .06244 L
.61866 .04653 L
.61868 .03062 L
.61869 .01472 L
.61873 .03062 L
.61875 .04653 L
.61883 .03062 L
.61889 .01472 L
.6189 .03062 L
.61894 .04653 L
.619 .06244 L
.619 .07835 L
.61903 .06244 L
.61909 .04653 L
.61917 .03062 L
.6192 .04653 L
.6192 .03062 L
.61928 .04653 L
.6193 .06244 L
.61931 .04653 L
.61938 .06244 L
.61946 .07835 L
.61949 .06244 L
.6195 .04653 L
.61956 .06244 L
.61965 .07835 L
.61968 .06244 L
.6197 .07835 L
.61987 .06244 L
.61987 .07835 L
.61988 .09426 L
.61993 .11016 L
.62 .09426 L
.62002 .07835 L
.62005 .06244 L
.6201 .04653 L
.62021 .03062 L
.62036 .01472 L
Mistroke
.62047 .03062 L
.62052 .01472 L
.62054 .03062 L
.62055 .01472 L
.6206 .03062 L
.62063 .04653 L
.62067 .03062 L
.62067 .01472 L
.62084 .03062 L
.62094 .01472 L
.62098 .03062 L
.62099 .01472 L
.621 .03062 L
.62102 .04653 L
.62116 .06244 L
.6212 .07835 L
.62121 .06244 L
.62132 .07835 L
.62139 .06244 L
.62149 .04653 L
.62154 .03062 L
.62156 .04653 L
.62168 .06244 L
.62173 .07835 L
.62176 .09426 L
.62177 .11016 L
.62177 .09426 L
.62182 .11016 L
.62186 .12607 L
.62186 .11016 L
.62187 .12607 L
.62189 .14198 L
.62192 .12607 L
.62194 .14198 L
.62198 .12607 L
.62214 .14198 L
.62223 .12607 L
.62224 .14198 L
.6223 .12607 L
.62232 .11016 L
.62237 .09426 L
.6224 .07835 L
.62247 .06244 L
.62254 .07835 L
.62257 .06244 L
.62257 .04653 L
.62269 .03062 L
.62275 .01472 L
.62278 .03062 L
.62281 .01472 L
Mistroke
.62286 .03062 L
.62296 .04653 L
.62302 .06244 L
.62305 .07835 L
.62306 .09426 L
.62307 .11016 L
.62312 .09426 L
.62315 .07835 L
.6232 .06244 L
.6232 .04653 L
.62321 .03062 L
.62329 .04653 L
.62331 .03062 L
.62337 .01472 L
.62343 .03062 L
.62343 .01472 L
.62343 .03062 L
.62344 .04653 L
.62345 .06244 L
.62347 .07835 L
.62348 .06244 L
.6235 .04653 L
.62353 .06244 L
.6236 .07835 L
.62361 .09426 L
.62364 .11016 L
.62386 .09426 L
.62386 .07835 L
.62387 .06244 L
.62393 .07835 L
.62394 .09426 L
.62395 .11016 L
.62397 .09426 L
.62399 .11016 L
.624 .12607 L
.62403 .14198 L
.62405 .12607 L
.62414 .11016 L
.62422 .09426 L
.62435 .11016 L
.62436 .12607 L
.62442 .14198 L
.62449 .15789 L
.62454 .1738 L
.62454 .15789 L
.62455 .14198 L
.62457 .15789 L
.62463 .1738 L
.62465 .18971 L
.6247 .20561 L
Mistroke
.62484 .22152 L
.62487 .20561 L
.62488 .22152 L
.62495 .23743 L
.62495 .22152 L
.625 .23743 L
.62505 .25334 L
.62506 .23743 L
.62514 .22152 L
.62525 .20561 L
.62533 .22152 L
.62533 .20561 L
.62533 .18971 L
.62552 .20561 L
.62559 .22152 L
.62565 .20561 L
.62568 .22152 L
.62568 .23743 L
.62569 .22152 L
.62574 .20561 L
.62574 .22152 L
.62578 .20561 L
.62582 .18971 L
.62584 .20561 L
.62586 .18971 L
.62595 .20561 L
.62598 .22152 L
.626 .20561 L
.626 .22152 L
.6261 .20561 L
.62611 .18971 L
.6262 .20561 L
.62634 .22152 L
.62638 .20561 L
.62646 .18971 L
.6266 .20561 L
.6267 .18971 L
.62678 .1738 L
.62682 .18971 L
.62686 .1738 L
.62687 .18971 L
.62688 .1738 L
.6269 .15789 L
.6269 .1738 L
.62694 .18971 L
.62705 .1738 L
.62713 .18971 L
.62719 .1738 L
.62719 .15789 L
.6272 .14198 L
Mistroke
.62724 .15789 L
.62726 .1738 L
.6273 .18971 L
.6273 .20561 L
.62737 .22152 L
.62738 .20561 L
.62739 .22152 L
.62739 .20561 L
.62742 .18971 L
.62744 .1738 L
.62747 .18971 L
.62751 .20561 L
.62753 .22152 L
.62753 .20561 L
.62753 .22152 L
.62762 .20561 L
.62767 .18971 L
.6277 .20561 L
.62772 .22152 L
.62772 .20561 L
.62773 .22152 L
.6278 .20561 L
.62789 .18971 L
.62796 .1738 L
.62803 .15789 L
.62813 .14198 L
.62814 .15789 L
.62817 .14198 L
.62821 .12607 L
.62823 .11016 L
.62829 .12607 L
.62836 .11016 L
.62842 .09426 L
.62846 .07835 L
.62846 .06244 L
.62859 .04653 L
.62862 .06244 L
.62863 .04653 L
.62865 .06244 L
.62866 .04653 L
.62877 .06244 L
.62882 .04653 L
.62889 .03062 L
.62891 .04653 L
.62895 .03062 L
.62895 .04653 L
.62896 .03062 L
.62899 .01472 L
.62904 .03062 L
.62907 .04653 L
Mistroke
.62907 .03062 L
.62922 .04653 L
.62923 .03062 L
.62923 .04653 L
.62933 .06244 L
.62934 .07835 L
.62951 .09426 L
.62953 .11016 L
.62955 .09426 L
.6296 .11016 L
.62966 .12607 L
.62968 .11016 L
.6297 .09426 L
.62974 .07835 L
.6298 .09426 L
.62981 .11016 L
.62982 .12607 L
.62998 .14198 L
.63002 .15789 L
.63011 .14198 L
.63013 .15789 L
.63018 .14198 L
.63023 .12607 L
.63023 .11016 L
.63026 .12607 L
.63027 .11016 L
.63034 .12607 L
.63038 .11016 L
.63054 .12607 L
.63059 .14198 L
.63064 .15789 L
.63073 .14198 L
.63093 .12607 L
.63093 .11016 L
.63094 .09426 L
.63101 .11016 L
.63108 .09426 L
.63109 .11016 L
.63119 .09426 L
.6313 .11016 L
.63134 .09426 L
.63135 .11016 L
.63136 .12607 L
.63136 .11016 L
.63137 .12607 L
.6314 .11016 L
.63141 .12607 L
.63141 .11016 L
.63142 .09426 L
.63146 .11016 L
Mistroke
.63147 .09426 L
.63147 .07835 L
.63154 .06244 L
.63154 .04653 L
.63159 .03062 L
.6316 .04653 L
.63162 .03062 L
.63167 .04653 L
.63171 .06244 L
.63172 .04653 L
.63173 .06244 L
.63177 .04653 L
.63177 .06244 L
.63182 .04653 L
.63183 .03062 L
.63185 .04653 L
.63186 .03062 L
.63186 .01472 L
.63191 .03062 L
.63192 .04653 L
.63198 .06244 L
.63198 .07835 L
.63199 .09426 L
.63208 .11016 L
.6321 .09426 L
.63211 .11016 L
.63213 .12607 L
.63236 .14198 L
.63236 .15789 L
.63239 .14198 L
.63243 .12607 L
.63243 .14198 L
.63249 .15789 L
.63249 .1738 L
.63254 .18971 L
.63262 .20561 L
.63264 .18971 L
.63266 .20561 L
.63274 .22152 L
.63285 .23743 L
.63288 .22152 L
.63288 .23743 L
.63296 .25334 L
.63297 .23743 L
.63299 .22152 L
.633 .23743 L
.63301 .22152 L
.63308 .23743 L
.63314 .22152 L
.63316 .20561 L
Mistroke
.63321 .18971 L
.63322 .1738 L
.63324 .18971 L
.63325 .20561 L
.63329 .18971 L
.6333 .1738 L
.63333 .15789 L
.63335 .14198 L
.63338 .12607 L
.6334 .14198 L
.63345 .12607 L
.63346 .11016 L
.6335 .09426 L
.63352 .07835 L
.63352 .09426 L
.63354 .11016 L
.63355 .09426 L
.63359 .11016 L
.63368 .09426 L
.63369 .07835 L
.63369 .09426 L
.63371 .07835 L
.63371 .06244 L
.63379 .07835 L
.63384 .09426 L
.63385 .11016 L
.63386 .12607 L
.63393 .14198 L
.63396 .15789 L
.63402 .1738 L
.63407 .18971 L
.63408 .1738 L
.6342 .18971 L
.63422 .1738 L
.63423 .18971 L
.63428 .20561 L
.63432 .18971 L
.63434 .1738 L
.63436 .18971 L
.63444 .1738 L
.63448 .18971 L
.6345 .20561 L
.63459 .18971 L
.6346 .20561 L
.63461 .22152 L
.63462 .23743 L
.63464 .22152 L
.63471 .20561 L
.6348 .22152 L
.6348 .20561 L
Mistroke
.63485 .18971 L
.6349 .20561 L
.6349 .18971 L
.63494 .20561 L
.63495 .18971 L
.635 .1738 L
.63509 .15789 L
.63516 .1738 L
.63518 .18971 L
.63521 .1738 L
.63524 .18971 L
.63526 .1738 L
.63527 .15789 L
.63533 .1738 L
.63535 .15789 L
.63544 .14198 L
.63544 .12607 L
.63547 .14198 L
.63553 .15789 L
.63554 .1738 L
.63558 .18971 L
.63558 .20561 L
.63565 .22152 L
.6357 .23743 L
.63571 .25334 L
.63577 .26925 L
.63595 .25334 L
.63603 .26925 L
.63603 .25334 L
.6361 .23743 L
.63612 .22152 L
.63613 .20561 L
.6362 .18971 L
.63624 .1738 L
.63625 .15789 L
.63627 .14198 L
.63634 .12607 L
.6364 .14198 L
.63642 .12607 L
.63644 .14198 L
.63646 .15789 L
.63648 .14198 L
.63656 .12607 L
.63668 .14198 L
.63669 .15789 L
.63675 .14198 L
.63675 .12607 L
.63677 .14198 L
.63677 .15789 L
.63678 .1738 L
Mistroke
.63685 .15789 L
.63688 .1738 L
.63716 .15789 L
.63718 .14198 L
.63719 .15789 L
.6372 .1738 L
.63721 .18971 L
.63723 .20561 L
.63726 .18971 L
.63726 .1738 L
.6373 .15789 L
.63734 .1738 L
.63736 .15789 L
.63747 .14198 L
.63748 .12607 L
.63749 .11016 L
.6375 .09426 L
.6375 .07835 L
.63756 .06244 L
.63756 .04653 L
.6376 .03062 L
.63764 .01472 L
.63774 .03062 L
.63777 .01472 L
.63789 .03062 L
.63789 .01472 L
.63812 .03062 L
.63814 .04653 L
.63825 .03062 L
.63829 .01472 L
.63834 .03062 L
.63835 .04653 L
.63838 .06244 L
.6384 .07835 L
.6384 .09426 L
.63842 .11016 L
.63845 .09426 L
.63848 .07835 L
.63855 .06244 L
.63858 .04653 L
.63859 .03062 L
.6386 .01472 L
.63861 .03062 L
.63867 .04653 L
.63874 .03062 L
.63886 .01472 L
.63886 .03062 L
.63892 .01472 L
.63898 .03062 L
.63908 .01472 L
Mistroke
.63928 .03062 L
.63934 .04653 L
.63935 .06244 L
.63938 .07835 L
.63939 .06244 L
.63942 .04653 L
.63958 .06244 L
.63959 .07835 L
.63976 .09426 L
.63979 .07835 L
.6398 .06244 L
.63984 .04653 L
.63997 .06244 L
.63999 .04653 L
.64002 .03062 L
.64011 .01472 L
.64037 .03062 L
.64042 .04653 L
.64043 .03062 L
.64043 .04653 L
.64054 .06244 L
.64056 .07835 L
.64058 .09426 L
.64059 .11016 L
.64062 .09426 L
.64082 .11016 L
.64084 .12607 L
.64101 .14198 L
.64105 .15789 L
.6411 .14198 L
.64112 .12607 L
.64114 .11016 L
.64132 .12607 L
.64134 .11016 L
.64137 .12607 L
.64137 .11016 L
.64145 .12607 L
.64147 .14198 L
.64153 .12607 L
.64166 .14198 L
.64167 .15789 L
.64171 .14198 L
.64172 .12607 L
.64177 .14198 L
.64178 .15789 L
.64179 .14198 L
.64183 .12607 L
.64184 .11016 L
.6419 .09426 L
.64191 .11016 L
Mistroke
.64191 .09426 L
.64194 .07835 L
.64207 .09426 L
.64209 .07835 L
.64213 .06244 L
.6422 .04653 L
.64227 .03062 L
.6423 .04653 L
.64236 .03062 L
.64236 .04653 L
.64242 .03062 L
.64243 .01472 L
.64269 .03062 L
.6427 .04653 L
.6427 .03062 L
.64275 .04653 L
.64292 .06244 L
.643 .07835 L
.64304 .06244 L
.64313 .04653 L
.64313 .06244 L
.64331 .04653 L
.64335 .06244 L
.64335 .04653 L
.64336 .03062 L
.64347 .04653 L
.64348 .06244 L
.6437 .07835 L
.64372 .06244 L
.64372 .07835 L
.64378 .09426 L
.64379 .07835 L
.64381 .09426 L
.64384 .07835 L
.64385 .09426 L
.64401 .07835 L
.64404 .09426 L
.6441 .11016 L
.64414 .12607 L
.64424 .11016 L
.64428 .12607 L
.64432 .14198 L
.64433 .15789 L
.64435 .1738 L
.64437 .18971 L
.64437 .1738 L
.64451 .15789 L
.64465 .14198 L
.64467 .12607 L
.64483 .14198 L
Mistroke
.64489 .12607 L
.64496 .14198 L
.64503 .12607 L
.64507 .14198 L
.64512 .15789 L
.6452 .14198 L
.6453 .15789 L
.64534 .14198 L
.64538 .12607 L
.64542 .11016 L
.64548 .09426 L
.64551 .11016 L
.64552 .09426 L
.64558 .11016 L
.6456 .12607 L
.64561 .14198 L
.64562 .15789 L
.64563 .14198 L
.64572 .12607 L
.64584 .14198 L
.64591 .12607 L
.64597 .11016 L
.64608 .12607 L
.64628 .11016 L
.64631 .12607 L
.64633 .14198 L
.64635 .15789 L
.64638 .14198 L
.64638 .12607 L
.64651 .14198 L
.64655 .15789 L
.64657 .14198 L
.64669 .12607 L
.64676 .11016 L
.64678 .09426 L
.64679 .07835 L
.6468 .09426 L
.64686 .07835 L
.64692 .06244 L
.64695 .07835 L
.64701 .06244 L
.64701 .04653 L
.6471 .06244 L
.64712 .04653 L
.64715 .03062 L
.64721 .04653 L
.64723 .03062 L
.64728 .01472 L
.64733 .03062 L
.64746 .04653 L
Mistroke
.64748 .03062 L
.64762 .04653 L
.6477 .03062 L
.64777 .01472 L
.6478 .03062 L
.64789 .04653 L
.64794 .03062 L
.64794 .01472 L
.64799 .03062 L
.64802 .01472 L
.64814 .03062 L
.64817 .04653 L
.64817 .03062 L
.64821 .01472 L
.64836 .03062 L
.64843 .04653 L
.64844 .06244 L
.64846 .04653 L
.64861 .06244 L
.64865 .07835 L
.64866 .09426 L
.64874 .11016 L
.64876 .12607 L
.64889 .11016 L
.64889 .09426 L
.64896 .07835 L
.64898 .06244 L
.64904 .07835 L
.64907 .06244 L
.64912 .07835 L
.64914 .09426 L
.64917 .07835 L
.64917 .09426 L
.6492 .11016 L
.64932 .09426 L
.64934 .11016 L
.64936 .12607 L
.64942 .11016 L
.64948 .09426 L
.64951 .07835 L
.64953 .06244 L
.6496 .07835 L
.64962 .06244 L
.64964 .04653 L
.64971 .03062 L
.6498 .01472 L
.64981 .03062 L
.64984 .01472 L
.64998 .03062 L
.64998 .01472 L
Mistroke
.65002 .03062 L
.65011 .04653 L
.65012 .03062 L
.65013 .01472 L
.65016 .03062 L
.65016 .01472 L
.65016 .03062 L
.65019 .04653 L
.65026 .03062 L
.65033 .04653 L
.65036 .03062 L
.65042 .01472 L
.65058 .03062 L
.65059 .04653 L
.65059 .03062 L
.65062 .01472 L
.6507 .03062 L
.65071 .04653 L
.65076 .03062 L
.65085 .01472 L
.65088 .03062 L
.65089 .01472 L
.6509 .03062 L
.65097 .04653 L
.65099 .03062 L
.65105 .01472 L
.65107 .03062 L
.65108 .04653 L
.65112 .03062 L
.65116 .04653 L
.65117 .03062 L
.65131 .01472 L
.65136 .03062 L
.65149 .01472 L
.65153 .03062 L
.65156 .01472 L
.65181 .03062 L
.65192 .01472 L
.65197 .03062 L
.65197 .01472 L
.65199 .03062 L
.65202 .01472 L
.65211 .03062 L
.65215 .01472 L
.65216 .03062 L
.65218 .01472 L
.65222 .03062 L
.65234 .01472 L
.65248 .03062 L
.65257 .01472 L
Mistroke
.65263 .03062 L
.65266 .01472 L
.6528 .03062 L
.65282 .01472 L
.65283 .03062 L
.65288 .01472 L
.65312 .03062 L
.65316 .04653 L
.65316 .06244 L
.65317 .04653 L
.65318 .03062 L
.65325 .04653 L
.65329 .03062 L
.6533 .01472 L
.65338 .03062 L
.65343 .01472 L
.65358 .03062 L
.65362 .04653 L
.65367 .06244 L
.65371 .04653 L
.65372 .06244 L
.65374 .04653 L
.65375 .03062 L
.65381 .04653 L
.65383 .03062 L
.65389 .04653 L
.65394 .06244 L
.65396 .04653 L
.65401 .03062 L
.65403 .04653 L
.65403 .06244 L
.65404 .04653 L
.65413 .06244 L
.65418 .07835 L
.65434 .06244 L
.65435 .04653 L
.65437 .06244 L
.65438 .04653 L
.65445 .06244 L
.65451 .07835 L
.65453 .09426 L
.65454 .11016 L
.65461 .12607 L
.65462 .11016 L
.65469 .12607 L
.6547 .14198 L
.65477 .12607 L
.65479 .11016 L
.65485 .09426 L
.65486 .07835 L
Mistroke
.65493 .09426 L
.65494 .11016 L
.65497 .12607 L
.65507 .11016 L
.65508 .12607 L
.6551 .11016 L
.65514 .12607 L
.65515 .14198 L
.65516 .12607 L
.65517 .11016 L
.65523 .09426 L
.65538 .11016 L
.65545 .09426 L
.65548 .07835 L
.65574 .09426 L
.65581 .07835 L
.65587 .06244 L
.65589 .07835 L
.65595 .09426 L
.65597 .11016 L
.65601 .12607 L
.65602 .11016 L
.65605 .12607 L
.65607 .14198 L
.65608 .15789 L
.65615 .1738 L
.65623 .15789 L
.65624 .1738 L
.65629 .18971 L
.65634 .1738 L
.65641 .18971 L
.65647 .20561 L
.65671 .22152 L
.65684 .20561 L
.65689 .18971 L
.65695 .1738 L
.657 .15789 L
.65705 .1738 L
.65716 .18971 L
.65726 .20561 L
.65728 .18971 L
.65729 .20561 L
.65734 .18971 L
.65735 .20561 L
.65738 .22152 L
.65744 .20561 L
.6575 .18971 L
.65753 .1738 L
.65762 .15789 L
.65766 .14198 L
Mistroke
.65768 .15789 L
.65777 .1738 L
.65785 .18971 L
.65789 .1738 L
.65793 .15789 L
.65799 .14198 L
.65804 .15789 L
.65805 .1738 L
.65816 .15789 L
.65817 .14198 L
.65833 .15789 L
.65835 .1738 L
.65836 .15789 L
.65838 .1738 L
.65844 .15789 L
.65845 .1738 L
.65846 .15789 L
.65847 .14198 L
.65872 .12607 L
.65877 .11016 L
.65884 .09426 L
.65889 .11016 L
.65889 .12607 L
.65891 .11016 L
.65893 .09426 L
.65893 .07835 L
.65897 .06244 L
.65903 .07835 L
.65904 .09426 L
.65905 .11016 L
.65912 .12607 L
.65916 .14198 L
.65918 .12607 L
.6592 .14198 L
.65924 .12607 L
.65924 .14198 L
.65926 .15789 L
.65927 .14198 L
.65927 .15789 L
.6593 .14198 L
.65932 .12607 L
.65936 .11016 L
.65938 .12607 L
.65939 .14198 L
.65948 .12607 L
.65948 .14198 L
.65952 .15789 L
.65959 .1738 L
.6596 .15789 L
.65961 .1738 L
Mistroke
.65961 .18971 L
.65963 .1738 L
.65969 .15789 L
.65971 .14198 L
.65972 .12607 L
.65976 .11016 L
.65979 .12607 L
.65985 .11016 L
.65985 .09426 L
.65988 .07835 L
.65989 .09426 L
.65995 .11016 L
.66001 .12607 L
.66005 .11016 L
.66006 .12607 L
.66021 .14198 L
.66025 .15789 L
.66026 .1738 L
.66027 .18971 L
.66036 .20561 L
.66036 .18971 L
.66037 .1738 L
.66039 .15789 L
.66056 .14198 L
.66056 .15789 L
.66065 .1738 L
.66065 .18971 L
.66066 .1738 L
.66074 .15789 L
.66082 .14198 L
.66084 .12607 L
.66093 .14198 L
.66101 .15789 L
.66107 .1738 L
.66108 .18971 L
.66109 .1738 L
.66111 .15789 L
.66119 .14198 L
.6612 .15789 L
.66123 .14198 L
.66132 .12607 L
.66134 .14198 L
.66135 .12607 L
.6614 .11016 L
.66142 .12607 L
.66144 .11016 L
.66154 .12607 L
.66156 .11016 L
.66171 .09426 L
.66172 .07835 L
Mistroke
.66179 .06244 L
.66181 .04653 L
.66183 .06244 L
.66185 .04653 L
.66193 .03062 L
.66201 .04653 L
.66205 .06244 L
.66217 .04653 L
.66221 .06244 L
.66226 .07835 L
.6623 .09426 L
.66249 .07835 L
.66253 .09426 L
.66254 .11016 L
.66257 .12607 L
.66258 .11016 L
.66262 .12607 L
.66265 .11016 L
.66267 .09426 L
.66271 .11016 L
.66282 .12607 L
.66282 .11016 L
.66287 .09426 L
.66293 .11016 L
.66296 .09426 L
.66309 .11016 L
.66313 .09426 L
.66313 .11016 L
.66313 .12607 L
.66318 .11016 L
.66325 .09426 L
.66338 .11016 L
.6634 .09426 L
.66348 .07835 L
.6635 .09426 L
.6635 .11016 L
.66358 .12607 L
.66365 .11016 L
.66374 .12607 L
.66376 .14198 L
.66377 .15789 L
.66383 .1738 L
.6639 .15789 L
.6639 .1738 L
.66393 .15789 L
.664 .1738 L
.66401 .18971 L
.66403 .1738 L
.66409 .15789 L
.66411 .1738 L
Mistroke
.66412 .15789 L
.66414 .1738 L
.66427 .15789 L
.66433 .14198 L
.66437 .12607 L
.66437 .14198 L
.6644 .15789 L
.66444 .1738 L
.66449 .18971 L
.66452 .20561 L
.66454 .22152 L
.66457 .20561 L
.66464 .18971 L
.66467 .1738 L
.66468 .18971 L
.66477 .1738 L
.6648 .18971 L
.66481 .1738 L
.66482 .18971 L
.66485 .1738 L
.6649 .18971 L
.66494 .1738 L
.66496 .18971 L
.665 .20561 L
.66507 .22152 L
.66508 .23743 L
.66511 .25334 L
.66513 .23743 L
.66516 .22152 L
.66517 .20561 L
.66522 .22152 L
.66539 .20561 L
.66548 .18971 L
.66548 .1738 L
.6655 .15789 L
.66555 .1738 L
.6656 .15789 L
.66561 .1738 L
.66563 .18971 L
.66565 .1738 L
.66569 .15789 L
.6657 .14198 L
.66576 .15789 L
.66576 .1738 L
.66578 .18971 L
.66579 .1738 L
.66581 .15789 L
.66585 .14198 L
.66586 .12607 L
.66587 .14198 L
Mistroke
.6659 .12607 L
.66596 .11016 L
.666 .09426 L
.66604 .07835 L
.66605 .09426 L
.66605 .11016 L
.66614 .09426 L
.66618 .11016 L
.66633 .09426 L
.66636 .11016 L
.66636 .12607 L
.66636 .11016 L
.6665 .09426 L
.66656 .11016 L
.6666 .09426 L
.66664 .11016 L
.66668 .09426 L
.66672 .07835 L
.66675 .09426 L
.66677 .07835 L
.66693 .09426 L
.66701 .11016 L
.66704 .09426 L
.66712 .11016 L
.66737 .09426 L
.66744 .07835 L
.66748 .09426 L
.66753 .07835 L
.66765 .09426 L
.66772 .07835 L
.66784 .06244 L
.6679 .07835 L
.66791 .06244 L
.66791 .07835 L
.66792 .09426 L
.66793 .11016 L
.66795 .12607 L
.66801 .14198 L
.66808 .15789 L
.66817 .14198 L
.66818 .15789 L
.66835 .14198 L
.66839 .12607 L
.66845 .11016 L
.66846 .12607 L
.66865 .11016 L
.66872 .09426 L
.66879 .11016 L
.66894 .09426 L
.66911 .11016 L
Mistroke
.66912 .12607 L
.66913 .14198 L
.66913 .15789 L
.66941 .14198 L
.66942 .15789 L
.66944 .14198 L
.66945 .12607 L
.66951 .11016 L
.66958 .09426 L
.66966 .07835 L
.66976 .06244 L
.66978 .04653 L
.66978 .06244 L
.6698 .04653 L
.66983 .03062 L
.66991 .01472 L
.66992 .03062 L
.66996 .01472 L
.66998 .03062 L
.67 .04653 L
.67006 .03062 L
.67007 .01472 L
.67019 .03062 L
.67022 .04653 L
.67025 .03062 L
.67033 .01472 L
.67042 .03062 L
.67046 .04653 L
.67059 .06244 L
.67062 .07835 L
.67066 .06244 L
.67066 .04653 L
.67069 .03062 L
.67074 .04653 L
.67078 .06244 L
.67082 .04653 L
.67083 .03062 L
.67088 .01472 L
.67091 .03062 L
.67096 .01472 L
.67099 .03062 L
.67099 .01472 L
.67101 .03062 L
.67105 .04653 L
.6711 .06244 L
.67111 .07835 L
.67118 .09426 L
.6712 .07835 L
.67131 .09426 L
.67143 .07835 L
Mistroke
.67145 .09426 L
.67147 .07835 L
.6715 .06244 L
.67151 .07835 L
.67152 .09426 L
.67153 .11016 L
.67156 .09426 L
.67157 .11016 L
.67159 .09426 L
.67161 .07835 L
.67165 .09426 L
.67166 .11016 L
.67167 .09426 L
.67168 .07835 L
.67168 .09426 L
.67169 .07835 L
.67177 .06244 L
.67177 .04653 L
.67179 .06244 L
.67181 .07835 L
.67183 .09426 L
.67187 .11016 L
.67189 .09426 L
.67189 .07835 L
.67193 .09426 L
.67193 .07835 L
.67205 .06244 L
.67215 .07835 L
.6722 .09426 L
.67224 .07835 L
.67229 .06244 L
.67233 .07835 L
.67233 .09426 L
.67235 .11016 L
.67235 .12607 L
.67239 .11016 L
.67258 .12607 L
.67262 .14198 L
.67263 .12607 L
.6727 .11016 L
.67275 .12607 L
.67277 .14198 L
.67281 .15789 L
.67289 .14198 L
.67294 .15789 L
.67299 .1738 L
.67304 .18971 L
.67312 .1738 L
.67315 .18971 L
.67319 .20561 L
Mistroke
.67326 .22152 L
.6733 .23743 L
.67331 .22152 L
.67333 .20561 L
.67339 .22152 L
.67347 .20561 L
.67363 .18971 L
.67364 .1738 L
.67368 .18971 L
.67389 .20561 L
.67392 .18971 L
.674 .1738 L
.67403 .15789 L
.67404 .1738 L
.67411 .18971 L
.67412 .20561 L
.67412 .18971 L
.67413 .20561 L
.67423 .22152 L
.67424 .20561 L
.67428 .22152 L
.67432 .23743 L
.67437 .22152 L
.6745 .20561 L
.67451 .22152 L
.67452 .23743 L
.67454 .25334 L
.67455 .26925 L
.67459 .28515 L
.67463 .30106 L
.67469 .28515 L
.67478 .26925 L
.67478 .28515 L
.67478 .26925 L
.67481 .28515 L
.67491 .26925 L
.67491 .25334 L
.67492 .26925 L
.67502 .28515 L
.67505 .30106 L
.67505 .28515 L
.67508 .30106 L
.6751 .28515 L
.67513 .30106 L
.67515 .31697 L
.67516 .30106 L
.67517 .31697 L
.67518 .33288 L
.67528 .31697 L
.67535 .33288 L
Mistroke
.67542 .31697 L
.67551 .33288 L
.67551 .34879 L
.67558 .3647 L
.67563 .3806 L
.67573 .3647 L
.67582 .3806 L
.67583 .39651 L
.67591 .41242 L
.67603 .42833 L
.67607 .44424 L
.67614 .46014 L
.67616 .47605 L
.67618 .46014 L
.67619 .44424 L
.67623 .42833 L
.67623 .41242 L
.67629 .42833 L
.67631 .41242 L
.67633 .42833 L
.67644 .44424 L
.67663 .46014 L
.67667 .47605 L
.67668 .46014 L
.67683 .44424 L
.6769 .42833 L
.67693 .41242 L
.67708 .39651 L
.67714 .3806 L
.67726 .39651 L
.67729 .41242 L
.6773 .39651 L
.67734 .41242 L
.67736 .39651 L
.67741 .41242 L
.67742 .42833 L
.67749 .41242 L
.6775 .39651 L
.67762 .3806 L
.67768 .3647 L
.67771 .3806 L
.67781 .3647 L
.67791 .34879 L
.67793 .33288 L
.67795 .34879 L
.67797 .3647 L
.67797 .34879 L
.67801 .33288 L
.67804 .34879 L
.67812 .3647 L
Mistroke
.67821 .34879 L
.67822 .3647 L
.67824 .3806 L
.67828 .3647 L
.67832 .34879 L
.67835 .3647 L
.67845 .34879 L
.67848 .33288 L
.67848 .31697 L
.67861 .30106 L
.67863 .28515 L
.67864 .26925 L
.67864 .25334 L
.67874 .23743 L
.67882 .25334 L
.67884 .23743 L
.67885 .25334 L
.67891 .26925 L
.67892 .28515 L
.67897 .26925 L
.67898 .25334 L
.67899 .26925 L
.67902 .28515 L
.67903 .26925 L
.67905 .28515 L
.67907 .26925 L
.67908 .25334 L
.67911 .23743 L
.67915 .22152 L
.67916 .20561 L
.67917 .22152 L
.67919 .20561 L
.67919 .18971 L
.67927 .1738 L
.6793 .18971 L
.6793 .20561 L
.67931 .18971 L
.67938 .20561 L
.67942 .22152 L
.67944 .20561 L
.67947 .18971 L
.6795 .20561 L
.67951 .22152 L
.67952 .20561 L
.67952 .22152 L
.67974 .20561 L
.67976 .18971 L
.67984 .1738 L
.67994 .18971 L
.68002 .20561 L
Mistroke
.68005 .18971 L
.6801 .1738 L
.68015 .18971 L
.68018 .20561 L
.68019 .22152 L
.68019 .20561 L
.68023 .18971 L
.68024 .1738 L
.68025 .18971 L
.68025 .20561 L
.6805 .22152 L
.68061 .23743 L
.68065 .22152 L
.68066 .23743 L
.68068 .22152 L
.68073 .23743 L
.68077 .25334 L
.68079 .23743 L
.68085 .25334 L
.68099 .26925 L
.68099 .25334 L
.68113 .23743 L
.68114 .25334 L
.68121 .26925 L
.68122 .25334 L
.68124 .23743 L
.68134 .25334 L
.68134 .26925 L
.68135 .25334 L
.68146 .26925 L
.68147 .28515 L
.68147 .30106 L
.68147 .28515 L
.68148 .26925 L
.68152 .25334 L
.68152 .23743 L
.68155 .22152 L
.6816 .23743 L
.68166 .25334 L
.68167 .23743 L
.68171 .25334 L
.68176 .23743 L
.68191 .22152 L
.68193 .23743 L
.68203 .25334 L
.68204 .26925 L
.68206 .28515 L
.68207 .26925 L
.68209 .25334 L
.6821 .26925 L
Mistroke
.68211 .28515 L
.68218 .26925 L
.68221 .28515 L
.68223 .26925 L
.68243 .25334 L
.68247 .23743 L
.68254 .22152 L
.68257 .20561 L
.68259 .18971 L
.6826 .20561 L
.68267 .18971 L
.6827 .20561 L
.68273 .22152 L
.68274 .20561 L
.68275 .22152 L
.68287 .20561 L
.6829 .22152 L
.68293 .23743 L
.68295 .25334 L
.68297 .26925 L
.68298 .25334 L
.68306 .23743 L
.68306 .22152 L
.68308 .20561 L
.68309 .18971 L
.68324 .1738 L
.68331 .18971 L
.68332 .1738 L
.68338 .15789 L
.68342 .14198 L
.68349 .15789 L
.68361 .14198 L
.68368 .15789 L
.6837 .1738 L
.68377 .15789 L
.68378 .14198 L
.68379 .12607 L
.68386 .11016 L
.68386 .09426 L
.6839 .07835 L
.68391 .09426 L
.68398 .11016 L
.68408 .12607 L
.68411 .11016 L
.68412 .12607 L
.68418 .11016 L
.68421 .09426 L
.68422 .07835 L
.6843 .09426 L
.68431 .11016 L
Mistroke
.68443 .09426 L
.68443 .11016 L
.68444 .09426 L
.68445 .07835 L
.68446 .06244 L
.68461 .07835 L
.68471 .06244 L
.68475 .07835 L
.68475 .09426 L
.68478 .07835 L
.68495 .09426 L
.68496 .07835 L
.68497 .06244 L
.68512 .07835 L
.68527 .06244 L
.68535 .04653 L
.68545 .03062 L
.68552 .01472 L
.68573 .03062 L
.68576 .04653 L
.6858 .06244 L
.68585 .04653 L
.68589 .03062 L
.68599 .01472 L
.68607 .03062 L
.68611 .01472 L
.68614 .03062 L
.68625 .01472 L
.68635 .03062 L
.68649 .04653 L
.68649 .06244 L
.68649 .07835 L
.6865 .09426 L
.6865 .07835 L
.68651 .09426 L
.68653 .11016 L
.68655 .12607 L
.68666 .11016 L
.68676 .09426 L
.68679 .11016 L
.68693 .09426 L
.68694 .07835 L
.68694 .09426 L
.68696 .07835 L
.68702 .06244 L
.68708 .04653 L
.68709 .03062 L
.68723 .01472 L
.68733 .03062 L
.68736 .04653 L
Mistroke
.68737 .06244 L
.68744 .07835 L
.68745 .09426 L
.68746 .07835 L
.68747 .06244 L
.68751 .07835 L
.68751 .09426 L
.68756 .11016 L
.68772 .12607 L
.68772 .11016 L
.68774 .12607 L
.68774 .11016 L
.68777 .09426 L
.68781 .07835 L
.68783 .06244 L
.68784 .04653 L
.68794 .03062 L
.68795 .04653 L
.68801 .06244 L
.68805 .04653 L
.68812 .03062 L
.68823 .04653 L
.68825 .06244 L
.68832 .04653 L
.68841 .06244 L
.68845 .04653 L
.6885 .06244 L
.68859 .04653 L
.68864 .06244 L
.68865 .07835 L
.68875 .06244 L
.68877 .07835 L
.68882 .06244 L
.6889 .04653 L
.68892 .03062 L
.68893 .04653 L
.68896 .03062 L
.68896 .01472 L
.68916 .03062 L
.68924 .04653 L
.68924 .06244 L
.68925 .07835 L
.68926 .06244 L
.68926 .07835 L
.68929 .06244 L
.68931 .04653 L
.68935 .03062 L
.68939 .01472 L
.68964 .03062 L
.68968 .04653 L
Mistroke
.68972 .06244 L
.68973 .04653 L
.68979 .03062 L
.68979 .01472 L
.68979 .03062 L
.68981 .04653 L
.68998 .06244 L
.69003 .07835 L
.69006 .06244 L
.69022 .04653 L
.69026 .06244 L
.6903 .04653 L
.69043 .06244 L
.69044 .04653 L
.69063 .03062 L
.69064 .04653 L
.69069 .03062 L
.69075 .04653 L
.69081 .03062 L
.69081 .01472 L
.6909 .03062 L
.69094 .01472 L
.69101 .03062 L
.69106 .01472 L
.69108 .03062 L
.69112 .04653 L
.69125 .03062 L
.6913 .01472 L
.69136 .03062 L
.69138 .04653 L
.69139 .06244 L
.69154 .07835 L
.69156 .09426 L
.69158 .07835 L
.69165 .06244 L
.69168 .04653 L
.6918 .03062 L
.69185 .01472 L
.69187 .03062 L
.69189 .01472 L
.6919 .03062 L
.69193 .04653 L
.692 .06244 L
.692 .04653 L
.69202 .03062 L
.69205 .01472 L
.69208 .03062 L
.69208 .04653 L
.6921 .06244 L
.69211 .07835 L
Mistroke
.69211 .09426 L
.69212 .11016 L
.69214 .12607 L
.69221 .11016 L
.69225 .09426 L
.6923 .07835 L
.69231 .09426 L
.69234 .11016 L
.69236 .09426 L
.69242 .11016 L
.69251 .09426 L
.69253 .07835 L
.69254 .06244 L
.69265 .04653 L
.69281 .03062 L
.69281 .01472 L
.69288 .03062 L
.69288 .04653 L
.69294 .06244 L
.69294 .07835 L
.69296 .09426 L
.69297 .07835 L
.69308 .06244 L
.69318 .07835 L
.6932 .09426 L
.69325 .07835 L
.69328 .06244 L
.69334 .04653 L
.6934 .06244 L
.69348 .04653 L
.69357 .03062 L
.69365 .01472 L
.6939 .03062 L
.6939 .04653 L
.69397 .03062 L
.69403 .04653 L
.69409 .06244 L
.69416 .04653 L
.69422 .06244 L
.69427 .04653 L
.69427 .06244 L
.69431 .07835 L
.69436 .09426 L
.69437 .11016 L
.69443 .09426 L
.69444 .11016 L
.69444 .09426 L
.69445 .07835 L
.69447 .06244 L
.69462 .04653 L
Mistroke
.69462 .06244 L
.69473 .07835 L
.69474 .06244 L
.69474 .04653 L
.69475 .03062 L
.69479 .01472 L
.69491 .03062 L
.69498 .01472 L
.69501 .03062 L
.69502 .04653 L
.69503 .06244 L
.69507 .04653 L
.69508 .06244 L
.69519 .07835 L
.6952 .09426 L
.69522 .07835 L
.69523 .09426 L
.69523 .11016 L
.69531 .09426 L
.69535 .11016 L
.69537 .12607 L
.69538 .14198 L
.69541 .15789 L
.69543 .14198 L
.69547 .15789 L
.69548 .1738 L
.6955 .15789 L
.69552 .1738 L
.69557 .15789 L
.69566 .1738 L
.69567 .15789 L
.69575 .1738 L
.69581 .15789 L
.69586 .1738 L
.69591 .18971 L
.69591 .1738 L
.69601 .18971 L
.69602 .1738 L
.69605 .15789 L
.69607 .14198 L
.69611 .15789 L
.69618 .1738 L
.6962 .15789 L
.69623 .14198 L
.69625 .12607 L
.69626 .14198 L
.69628 .15789 L
.6963 .1738 L
.6963 .18971 L
.69632 .1738 L
Mistroke
.6964 .15789 L
.69641 .14198 L
.69646 .15789 L
.69649 .1738 L
.69651 .18971 L
.6966 .20561 L
.6966 .18971 L
.69663 .1738 L
.69665 .15789 L
.69671 .14198 L
.69677 .15789 L
.69693 .14198 L
.69697 .12607 L
.69698 .11016 L
.69698 .09426 L
.69703 .11016 L
.69705 .12607 L
.6971 .14198 L
.69719 .15789 L
.69721 .1738 L
.69728 .18971 L
.69729 .20561 L
.6974 .22152 L
.69744 .20561 L
.69749 .18971 L
.69753 .1738 L
.69756 .18971 L
.69758 .1738 L
.69763 .18971 L
.69764 .1738 L
.69765 .18971 L
.69766 .1738 L
.69768 .15789 L
.69776 .1738 L
.69777 .15789 L
.69779 .1738 L
.69781 .15789 L
.69784 .14198 L
.69786 .15789 L
.69786 .14198 L
.69788 .12607 L
.69791 .11016 L
.69803 .12607 L
.69804 .11016 L
.6982 .09426 L
.69824 .07835 L
.69825 .09426 L
.69828 .07835 L
.6983 .06244 L
.69831 .04653 L
Mistroke
.69835 .06244 L
.69838 .04653 L
.6984 .06244 L
.69848 .07835 L
.69849 .06244 L
.69852 .04653 L
.69857 .03062 L
.69858 .01472 L
.69859 .03062 L
.69861 .01472 L
.69872 .03062 L
.69874 .04653 L
.69875 .03062 L
.69879 .01472 L
.69882 .03062 L
.69888 .04653 L
.69892 .06244 L
.69903 .04653 L
.69903 .03062 L
.69915 .01472 L
.69917 .03062 L
.69924 .04653 L
.69924 .06244 L
.69941 .07835 L
.69942 .06244 L
.69943 .04653 L
.69946 .03062 L
.69951 .04653 L
.69954 .06244 L
.69965 .04653 L
.69977 .03062 L
.69985 .04653 L
.69992 .06244 L
.69993 .04653 L
.69999 .03062 L
.70006 .01472 L
.70007 .03062 L
.70008 .01472 L
.70032 .03062 L
.70037 .04653 L
.70042 .03062 L
.70043 .01472 L
.70045 .03062 L
.7005 .04653 L
.70051 .06244 L
.70056 .07835 L
.70059 .09426 L
.70071 .07835 L
.70072 .09426 L
.70072 .07835 L
Mistroke
.70085 .06244 L
.70106 .04653 L
.70115 .06244 L
.70124 .04653 L
.70126 .03062 L
.70126 .01472 L
.7013 .03062 L
.70136 .04653 L
.7014 .03062 L
.70145 .01472 L
.70173 .03062 L
.70181 .04653 L
.70181 .03062 L
.7019 .04653 L
.70194 .03062 L
.702 .01472 L
.7022 .03062 L
.70222 .04653 L
.70235 .03062 L
.7024 .01472 L
.70241 .03062 L
.70241 .01472 L
.70257 .03062 L
.70263 .01472 L
.70266 .03062 L
.70267 .04653 L
.70268 .03062 L
.70271 .01472 L
.70276 .03062 L
.70277 .01472 L
.70279 .03062 L
.7028 .04653 L
.70284 .06244 L
.70287 .04653 L
.70292 .06244 L
.70298 .04653 L
.70298 .03062 L
.70303 .04653 L
.70312 .06244 L
.70319 .07835 L
.70321 .06244 L
.70326 .04653 L
.70327 .03062 L
.70328 .01472 L
.70332 .03062 L
.70333 .01472 L
.70343 .03062 L
.70344 .04653 L
.70351 .03062 L
.70353 .04653 L
Mistroke
.7036 .06244 L
.70364 .07835 L
.70368 .06244 L
.70369 .07835 L
.70372 .06244 L
.70382 .04653 L
.70393 .03062 L
.70393 .01472 L
.70404 .03062 L
.70414 .01472 L
.70422 .03062 L
.70422 .01472 L
.70425 .03062 L
.70427 .01472 L
.70427 .03062 L
.70443 .04653 L
.70449 .06244 L
.7045 .07835 L
.70454 .09426 L
.70461 .07835 L
.70461 .09426 L
.70462 .07835 L
.70475 .09426 L
.70478 .11016 L
.70481 .12607 L
.70485 .14198 L
.70486 .12607 L
.70491 .14198 L
.70491 .15789 L
.70491 .14198 L
.70492 .12607 L
.70493 .11016 L
.70494 .12607 L
.70496 .14198 L
.70498 .12607 L
.70502 .11016 L
.70506 .09426 L
.7051 .11016 L
.70511 .12607 L
.70517 .14198 L
.70518 .12607 L
.70521 .11016 L
.70524 .12607 L
.70528 .11016 L
.70531 .09426 L
.70536 .07835 L
.70536 .09426 L
.70539 .11016 L
.7054 .09426 L
.70544 .11016 L
Mistroke
.70573 .09426 L
.70574 .11016 L
.70576 .09426 L
.70591 .07835 L
.70597 .09426 L
.70613 .07835 L
.70617 .06244 L
.70624 .04653 L
.70626 .06244 L
.70634 .04653 L
.70636 .03062 L
.70636 .04653 L
.70637 .03062 L
.70649 .04653 L
.70662 .03062 L
.70669 .04653 L
.70672 .03062 L
.70679 .01472 L
.7068 .03062 L
.70685 .04653 L
.70687 .06244 L
.7069 .04653 L
.70693 .03062 L
.70698 .04653 L
.7071 .03062 L
.70714 .01472 L
.70723 .03062 L
.70726 .04653 L
.70728 .03062 L
.70742 .01472 L
.7076 .03062 L
.70764 .04653 L
.70764 .06244 L
.70774 .04653 L
.70776 .06244 L
.70779 .07835 L
.70781 .06244 L
.70791 .04653 L
.70795 .06244 L
.70799 .04653 L
.70799 .03062 L
.708 .01472 L
.70804 .03062 L
.70807 .01472 L
.70809 .03062 L
.70814 .04653 L
.70821 .03062 L
.70827 .01472 L
.70827 .03062 L
.70832 .01472 L
Mistroke
.70834 .03062 L
.70834 .01472 L
.7084 .03062 L
.70847 .04653 L
.70848 .06244 L
.70848 .04653 L
.7085 .03062 L
.70851 .01472 L
.70854 .03062 L
.70859 .04653 L
.7086 .03062 L
.70862 .04653 L
.70866 .03062 L
.7087 .04653 L
.70871 .03062 L
.70876 .01472 L
.7088 .03062 L
.70881 .01472 L
.70881 .03062 L
.70884 .04653 L
.70889 .06244 L
.70892 .04653 L
.70901 .03062 L
.70901 .04653 L
.70904 .03062 L
.70913 .01472 L
.70927 .03062 L
.70929 .04653 L
.70937 .03062 L
.70942 .01472 L
.70945 .03062 L
.70953 .01472 L
.70958 .03062 L
.70963 .04653 L
.70969 .06244 L
.70984 .04653 L
.70985 .03062 L
.70986 .04653 L
.7099 .03062 L
.71 .01472 L
.71005 .03062 L
.71009 .01472 L
.71016 .03062 L
.71026 .04653 L
.71029 .06244 L
.71052 .07835 L
.71056 .06244 L
.71056 .07835 L
.71067 .06244 L
.71067 .07835 L
Mistroke
.71074 .09426 L
.71077 .07835 L
.71078 .06244 L
.71078 .04653 L
.71087 .03062 L
.71091 .01472 L
.71107 .03062 L
.71108 .04653 L
.71114 .06244 L
.71116 .04653 L
.71117 .06244 L
.71119 .04653 L
.71121 .03062 L
.71125 .04653 L
.71129 .03062 L
.71134 .04653 L
.71144 .03062 L
.71153 .01472 L
.71162 .03062 L
.71163 .01472 L
.71166 .03062 L
.71166 .04653 L
.71166 .06244 L
.7117 .07835 L
.71177 .09426 L
.71181 .11016 L
.71186 .12607 L
.71186 .11016 L
.71187 .09426 L
.71205 .07835 L
.71208 .09426 L
.7121 .11016 L
.7121 .09426 L
.71213 .11016 L
.71215 .09426 L
.7122 .11016 L
.71224 .12607 L
.71226 .14198 L
.71227 .12607 L
.71229 .11016 L
.7123 .12607 L
.71231 .14198 L
.71232 .15789 L
.71236 .14198 L
.71241 .15789 L
.71244 .14198 L
.71251 .15789 L
.71253 .1738 L
.71255 .15789 L
.71266 .1738 L
Mistroke
.71267 .18971 L
.71272 .20561 L
.7128 .22152 L
.71281 .23743 L
.71286 .25334 L
.71287 .23743 L
.71296 .22152 L
.71296 .20561 L
.71298 .22152 L
.71302 .23743 L
.71303 .22152 L
.71305 .20561 L
.71306 .18971 L
.71313 .20561 L
.71317 .18971 L
.71321 .1738 L
.71324 .18971 L
.71324 .20561 L
.71328 .18971 L
.7133 .20561 L
.71334 .22152 L
.71338 .23743 L
.71343 .22152 L
.7136 .23743 L
.71369 .22152 L
.7137 .20561 L
.71374 .22152 L
.71392 .23743 L
.71396 .25334 L
.71398 .26925 L
.71398 .28515 L
.71401 .26925 L
.71404 .28515 L
.71407 .26925 L
.71408 .28515 L
.71412 .30106 L
.71428 .28515 L
.71435 .30106 L
.71435 .31697 L
.71443 .33288 L
.71444 .34879 L
.71451 .33288 L
.71459 .34879 L
.71462 .33288 L
.71462 .34879 L
.71468 .3647 L
.71469 .3806 L
.71474 .39651 L
.71475 .3806 L
.71487 .39651 L
Mistroke
.71487 .41242 L
.71491 .42833 L
.71493 .44424 L
.71496 .46014 L
.71505 .47605 L
.71506 .49196 L
.71522 .50787 L
.71542 .52378 L
.71546 .53969 L
.71547 .52378 L
.71552 .50787 L
.71557 .49196 L
.71559 .50787 L
.71565 .49196 L
.71571 .47605 L
.71577 .46014 L
.71584 .44424 L
.71584 .42833 L
.71587 .44424 L
.71587 .46014 L
.71593 .44424 L
.71593 .42833 L
.71608 .44424 L
.71615 .42833 L
.71618 .41242 L
.71619 .42833 L
.71632 .44424 L
.71636 .46014 L
.71638 .47605 L
.7164 .46014 L
.7164 .47605 L
.71644 .49196 L
.71648 .50787 L
.71657 .49196 L
.71662 .47605 L
.71665 .46014 L
.71689 .44424 L
.71699 .46014 L
.71702 .44424 L
.71706 .42833 L
.71707 .44424 L
.71707 .46014 L
.71715 .47605 L
.71717 .49196 L
.71719 .47605 L
.71731 .46014 L
.7174 .47605 L
.71742 .46014 L
.71744 .47605 L
.71752 .49196 L
Mistroke
.71755 .50787 L
.71757 .49196 L
.71759 .50787 L
.71762 .49196 L
.7178 .50787 L
.7178 .52378 L
.71784 .50787 L
.71791 .49196 L
.71797 .47605 L
.71799 .46014 L
.71801 .47605 L
.71806 .46014 L
.71807 .47605 L
.71812 .46014 L
.71813 .44424 L
.71824 .42833 L
.71825 .44424 L
.71828 .42833 L
.71829 .41242 L
.71835 .39651 L
.71844 .3806 L
.71846 .39651 L
.71852 .3806 L
.71853 .3647 L
.71854 .34879 L
.71857 .3647 L
.71868 .34879 L
.71876 .33288 L
.71879 .31697 L
.71885 .30106 L
.71893 .28515 L
.71893 .26925 L
.719 .25334 L
.71903 .26925 L
.71906 .28515 L
.71907 .26925 L
.71912 .28515 L
.71913 .30106 L
.71913 .31697 L
.71915 .33288 L
.71915 .34879 L
.71918 .3647 L
.71926 .3806 L
.71929 .3647 L
.71932 .3806 L
.71942 .39651 L
.71955 .41242 L
.71956 .39651 L
.71966 .41242 L
.71972 .42833 L
Mistroke
.71972 .41242 L
.71974 .42833 L
.71979 .44424 L
.71981 .46014 L
.71984 .47605 L
.71985 .49196 L
.71986 .47605 L
.71987 .46014 L
.71989 .44424 L
.72 .42833 L
.72011 .41242 L
.72013 .39651 L
.72021 .3806 L
.72021 .39651 L
.72029 .41242 L
.72029 .39651 L
.7203 .3806 L
.72036 .39651 L
.7204 .3806 L
.72041 .3647 L
.72056 .3806 L
.72058 .3647 L
.72061 .34879 L
.72072 .3647 L
.72074 .3806 L
.72075 .3647 L
.72076 .34879 L
.72077 .33288 L
.72078 .34879 L
.72081 .33288 L
.72103 .31697 L
.72108 .33288 L
.72115 .31697 L
.72118 .30106 L
.72128 .28515 L
.72136 .30106 L
.72136 .28515 L
.72144 .26925 L
.72152 .28515 L
.72157 .26925 L
.7216 .25334 L
.72163 .26925 L
.72174 .28515 L
.72185 .26925 L
.72186 .28515 L
.72187 .26925 L
.72188 .28515 L
.7219 .30106 L
.72193 .31697 L
.72197 .33288 L
Mistroke
.72198 .34879 L
.72198 .3647 L
.72199 .3806 L
.722 .39651 L
.72203 .41242 L
.72205 .39651 L
.72208 .41242 L
.72217 .42833 L
.72221 .41242 L
.72227 .42833 L
.72233 .44424 L
.72239 .46014 L
.72241 .47605 L
.72242 .49196 L
.72244 .50787 L
.72245 .52378 L
.72245 .53969 L
.72245 .55559 L
.72246 .53969 L
.72247 .52378 L
.72256 .50787 L
.72256 .52378 L
.7226 .50787 L
.72261 .49196 L
.72267 .50787 L
.72267 .52378 L
.72268 .53969 L
.72276 .52378 L
.72276 .53969 L
.72278 .52378 L
.72284 .53969 L
.72285 .52378 L
.72288 .50787 L
.72288 .52378 L
.72291 .50787 L
.72295 .52378 L
.72296 .50787 L
.72297 .52378 L
.72302 .53969 L
.72302 .52378 L
.72304 .53969 L
.72308 .52378 L
.72308 .53969 L
.72311 .52378 L
.72316 .53969 L
.72325 .55559 L
.72329 .53969 L
.72332 .55559 L
.72341 .5715 L
.72353 .55559 L
Mistroke
.72366 .5715 L
.72366 .58741 L
.72369 .5715 L
.7237 .55559 L
.72374 .5715 L
.72378 .55559 L
.72382 .5715 L
.72385 .55559 L
.72386 .5715 L
.72387 .58741 L
.72388 .5715 L
.72388 .58741 L
.72391 .5715 L
.72406 .58741 L
.72407 .5715 L
.72413 .58741 L
.72415 .60332 L
Mfstroke
.72416 .61803 m
.72415 .60332 L
s
.72416 .61803 m
.72422 .60332 L
s
.72422 .60332 m
0 0 rlineto
.72424 .61803 m
.72422 .60332 L
s
.72424 .61803 m
.72425 .60332 L
s
.72425 .60332 m
0 0 rlineto
.72425 .61803 m
.72425 .60332 L
s
.72426 .61803 m
.72431 .60332 L
s
.72431 .60332 m
0 0 rlineto
.72433 .61803 m
.72431 .60332 L
s
.72434 .61803 m
.72436 .60332 L
s
.72436 .60332 m
0 0 rlineto
.72441 .61803 m
.72436 .60332 L
s
s
s
s
s
.72452 .61803 m
.72456 .60332 L
s
.72456 .60332 m
.72457 .58741 L
.72462 .60332 L
s
.72463 .61803 m
.72462 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
s
.72553 .61803 m
.72556 .60332 L
s
.72556 .60332 m
.72561 .58741 L
.72565 .60332 L
.72567 .58741 L
.72572 .60332 L
.72576 .58741 L
.72586 .60332 L
s
.72611 .61803 m
.72586 .60332 L
s
.72613 .61803 m
.72616 .60332 L
s
.72616 .60332 m
.72626 .58741 L
.72629 .5715 L
.7263 .55559 L
.7264 .5715 L
.72645 .58741 L
.72656 .60332 L
s
.72656 .61803 m
.72656 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
.72692 .61803 m
.72695 .60332 L
s
.72695 .60332 m
0 0 rlineto
.72698 .61803 m
.72695 .60332 L
s
s
s
.72703 .61803 m
.72707 .60332 L
s
.72707 .60332 m
0 0 rlineto
.72722 .61803 m
.72707 .60332 L
s
.72724 .61803 m
.72727 .60332 L
s
.72727 .60332 m
.72728 .58741 L
.72734 .60332 L
s
.72736 .61803 m
.72734 .60332 L
s
.72736 .61803 m
.72741 .60332 L
s
.72741 .60332 m
.72742 .58741 L
.72746 .60332 L
s
.72747 .61803 m
.72746 .60332 L
s
.72748 .61803 m
.72753 .60332 L
s
.72753 .60332 m
0 0 rlineto
.72754 .61803 m
.72753 .60332 L
s
s
s
.72772 .61803 m
.72772 .60332 L
s
.72772 .60332 m
.72773 .58741 L
.7279 .5715 L
.72797 .58741 L
.72798 .60332 L
.72801 .58741 L
.72804 .5715 L
.72808 .55559 L
.72812 .53969 L
.72815 .52378 L
.72823 .50787 L
.72825 .52378 L
.72825 .50787 L
.72828 .52378 L
.72842 .50787 L
.72846 .49196 L
.72847 .50787 L
.72851 .52378 L
.72854 .53969 L
.72855 .55559 L
.72858 .53969 L
.72861 .52378 L
.72863 .53969 L
.7288 .52378 L
.72887 .50787 L
.72896 .49196 L
.72898 .47605 L
.729 .49196 L
.729 .47605 L
.72901 .49196 L
.72903 .50787 L
.72905 .52378 L
.72905 .53969 L
.72908 .55559 L
.72919 .53969 L
.72922 .55559 L
.72926 .5715 L
.72929 .55559 L
.72931 .5715 L
.72932 .58741 L
.72935 .60332 L
.72939 .58741 L
.72943 .60332 L
s
.72946 .61803 m
.72943 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
.72966 .61803 m
.72972 .60332 L
s
.72972 .60332 m
0 0 rlineto
.72974 .61803 m
.72972 .60332 L
s
.72974 .61803 m
.72975 .60332 L
s
.72975 .60332 m
.72978 .58741 L
.72982 .5715 L
.7299 .55559 L
.7299 .5715 L
.73 .55559 L
.73001 .5715 L
.73008 .58741 L
.7301 .60332 L
s
.73012 .61803 m
.7301 .60332 L
s
.73012 .61803 m
.73013 .60332 L
s
.73013 .60332 m
.73017 .58741 L
.73023 .60332 L
s
.73025 .61803 m
.73023 .60332 L
s
.73025 .61803 m
.73027 .60332 L
s
.73027 .60332 m
0 0 rlineto
.73029 .61803 m
.73027 .60332 L
s
s
s
s
s
.73039 .61803 m
.73056 .60332 L
s
.73056 .60332 m
0 0 rlineto
.73064 .61803 m
.73056 .60332 L
s
s
s
s
s
s
s
s
s
s
s
s
s
.73115 .61803 m
.73118 .60332 L
s
.73118 .60332 m
.7312 .58741 L
.73128 .5715 L
.73149 .55559 L
.73149 .53969 L
.7315 .52378 L
.7315 .50787 L
.73154 .52378 L
.73155 .50787 L
.73156 .52378 L
.73159 .50787 L
.7316 .49196 L
.73164 .47605 L
.73166 .49196 L
.7317 .47605 L
.73171 .46014 L
.73174 .44424 L
.73179 .42833 L
.73184 .41242 L
.73188 .39651 L
.73192 .3806 L
.73196 .3647 L
.73196 .3806 L
.73201 .39651 L
.73224 .3806 L
.73247 .3647 L
.73254 .3806 L
.73263 .3647 L
.73271 .34879 L
.73274 .33288 L
.73281 .31697 L
.73281 .30106 L
.73281 .28515 L
.7329 .26925 L
.73299 .25334 L
.73302 .23743 L
.73305 .25334 L
.73306 .23743 L
.73308 .22152 L
.73313 .20561 L
.73318 .18971 L
.73323 .20561 L
.73326 .22152 L
.73328 .23743 L
.73334 .22152 L
.73335 .20561 L
.73336 .22152 L
.73338 .20561 L
.73339 .18971 L
.73341 .1738 L
Mistroke
.73347 .15789 L
.73353 .14198 L
.73356 .12607 L
.73358 .11016 L
.73359 .12607 L
.73367 .14198 L
.73381 .15789 L
.73392 .14198 L
.73404 .12607 L
.73406 .14198 L
.73411 .12607 L
.73422 .14198 L
.73428 .15789 L
.73433 .14198 L
.73438 .12607 L
.73444 .14198 L
.73447 .12607 L
.73449 .11016 L
.73451 .12607 L
.73455 .11016 L
.73467 .09426 L
.73482 .11016 L
.73485 .12607 L
.73491 .11016 L
.73497 .09426 L
.73497 .11016 L
.73509 .12607 L
.73509 .11016 L
.73515 .09426 L
.73515 .07835 L
.73525 .09426 L
.73526 .11016 L
.73526 .12607 L
.73528 .14198 L
.73531 .15789 L
.73542 .1738 L
.73545 .15789 L
.73545 .14198 L
.73548 .15789 L
.7355 .1738 L
.73553 .15789 L
.73556 .1738 L
.73558 .15789 L
.73561 .14198 L
.73578 .15789 L
.73592 .1738 L
.73594 .18971 L
.73603 .1738 L
.7361 .15789 L
.7361 .14198 L
Mistroke
.73611 .12607 L
.73614 .11016 L
.73621 .09426 L
.73623 .11016 L
.73623 .09426 L
.73623 .11016 L
.73631 .09426 L
.73633 .07835 L
.73633 .06244 L
.73644 .04653 L
.73645 .06244 L
.73655 .04653 L
.73666 .06244 L
.73667 .04653 L
.73669 .03062 L
.73676 .04653 L
.73678 .06244 L
.73679 .04653 L
.7368 .03062 L
.7368 .04653 L
.73681 .06244 L
.73684 .04653 L
.73692 .03062 L
.73693 .04653 L
.73693 .03062 L
.73694 .04653 L
.73724 .06244 L
.73735 .04653 L
.73748 .06244 L
.73748 .07835 L
.73761 .06244 L
.73765 .07835 L
.73766 .09426 L
.73791 .07835 L
.73793 .06244 L
.73793 .07835 L
.73795 .06244 L
.73799 .07835 L
.73801 .06244 L
.73802 .04653 L
.73812 .06244 L
.73815 .07835 L
.73816 .06244 L
.73827 .07835 L
.73835 .09426 L
.73837 .07835 L
.73842 .06244 L
.73844 .07835 L
.73845 .06244 L
.73848 .04653 L
Mistroke
.73852 .03062 L
.73852 .04653 L
.73855 .03062 L
.73859 .01472 L
.73863 .03062 L
.73864 .01472 L
.73871 .03062 L
.73873 .01472 L
.7389 .03062 L
.73896 .04653 L
.73898 .03062 L
.73899 .01472 L
.7392 .03062 L
.73934 .01472 L
.73969 .03062 L
.73971 .01472 L
.73971 .03062 L
.73975 .01472 L
.73984 .03062 L
.73989 .04653 L
.73991 .06244 L
.74 .04653 L
.74001 .03062 L
.74007 .01472 L
.74009 .03062 L
.74018 .04653 L
.7402 .06244 L
.7402 .07835 L
.74023 .06244 L
.74023 .07835 L
.74024 .06244 L
.74032 .07835 L
.74034 .06244 L
.74036 .07835 L
.74045 .09426 L
.74047 .11016 L
.74065 .12607 L
.74073 .11016 L
.74074 .09426 L
.74078 .11016 L
.74088 .12607 L
.74094 .11016 L
.74096 .09426 L
.74107 .07835 L
.7411 .09426 L
.7411 .11016 L
.74124 .12607 L
.74124 .14198 L
.74125 .12607 L
.7413 .14198 L
Mistroke
.74135 .15789 L
.74136 .1738 L
.74144 .15789 L
.74152 .1738 L
.74156 .15789 L
.7416 .14198 L
.74174 .15789 L
.7419 .14198 L
.74192 .12607 L
.74195 .11016 L
.74197 .09426 L
.74199 .07835 L
.74203 .06244 L
.74209 .07835 L
.7421 .09426 L
.74214 .11016 L
.74217 .12607 L
.7422 .14198 L
.74226 .12607 L
.74226 .14198 L
.74229 .15789 L
.7423 .1738 L
.74235 .15789 L
.74235 .14198 L
.74247 .15789 L
.74248 .14198 L
.74251 .12607 L
.74255 .11016 L
.74258 .09426 L
.7426 .07835 L
.7426 .06244 L
.74278 .04653 L
.74278 .06244 L
.74278 .07835 L
.74279 .09426 L
.74279 .11016 L
.74294 .09426 L
.743 .07835 L
.74301 .09426 L
.74313 .11016 L
.74323 .09426 L
.74323 .11016 L
.74329 .12607 L
.7433 .14198 L
.74332 .15789 L
.74333 .1738 L
.74337 .18971 L
.74339 .20561 L
.7434 .18971 L
.74343 .20561 L
Mistroke
.74343 .22152 L
.74347 .23743 L
.74348 .25334 L
.74357 .26925 L
.74358 .25334 L
.74359 .23743 L
.74363 .25334 L
.74365 .26925 L
.74367 .25334 L
.74369 .26925 L
.74378 .25334 L
.7438 .23743 L
.74388 .22152 L
.7439 .20561 L
.74392 .22152 L
.74396 .23743 L
.744 .22152 L
.74404 .23743 L
.74404 .22152 L
.74406 .23743 L
.74406 .22152 L
.74408 .23743 L
.7441 .25334 L
.74411 .23743 L
.74415 .22152 L
.74422 .20561 L
.74424 .18971 L
.7443 .20561 L
.74455 .18971 L
.74461 .1738 L
.74472 .15789 L
.74496 .14198 L
.74502 .12607 L
.74505 .11016 L
.74506 .09426 L
.74506 .07835 L
.74508 .09426 L
.74512 .11016 L
.74518 .09426 L
.74518 .11016 L
.7452 .12607 L
.74521 .14198 L
.74524 .15789 L
.74528 .14198 L
.7453 .12607 L
.74535 .11016 L
.74537 .09426 L
.74538 .11016 L
.74551 .12607 L
.74558 .14198 L
Mistroke
.7456 .12607 L
.74565 .11016 L
.74566 .12607 L
.74571 .14198 L
.74581 .15789 L
.74586 .1738 L
.7459 .18971 L
.74606 .1738 L
.74614 .18971 L
.74616 .20561 L
.74633 .22152 L
.74639 .20561 L
.74652 .18971 L
.74652 .20561 L
.74653 .22152 L
.74654 .23743 L
.74661 .25334 L
.74667 .23743 L
.74669 .25334 L
.7467 .26925 L
.74678 .25334 L
.74679 .23743 L
.7468 .22152 L
.74699 .23743 L
.747 .22152 L
.74708 .20561 L
.7471 .22152 L
.74718 .20561 L
.74718 .22152 L
.74728 .20561 L
.7473 .18971 L
.74732 .20561 L
.74738 .22152 L
.7474 .20561 L
.74742 .18971 L
.74762 .20561 L
.74765 .18971 L
.74769 .1738 L
.74771 .15789 L
.74771 .1738 L
.74774 .15789 L
.74775 .14198 L
.7478 .12607 L
.74786 .11016 L
.7479 .12607 L
.74796 .14198 L
.74798 .12607 L
.748 .14198 L
.74813 .12607 L
.74819 .14198 L
Mistroke
.7482 .12607 L
.74821 .11016 L
.74822 .12607 L
.74824 .11016 L
.74826 .09426 L
.74846 .11016 L
.74847 .09426 L
.74847 .07835 L
.74854 .09426 L
.74854 .07835 L
.74858 .09426 L
.74874 .11016 L
.74875 .09426 L
.74876 .07835 L
.74881 .06244 L
.74886 .04653 L
.74892 .06244 L
.74893 .04653 L
.74912 .03062 L
.74914 .04653 L
.74916 .06244 L
.74917 .04653 L
.74917 .06244 L
.74924 .04653 L
.74926 .03062 L
.74932 .04653 L
.74936 .03062 L
.74938 .01472 L
.74943 .03062 L
.74944 .01472 L
.74968 .03062 L
.7497 .01472 L
.74973 .03062 L
.74973 .04653 L
.7499 .06244 L
.74998 .04653 L
.75002 .06244 L
.75002 .07835 L
.75016 .06244 L
.75019 .07835 L
.75021 .09426 L
.75022 .07835 L
.75026 .06244 L
.75029 .07835 L
.7503 .09426 L
.75034 .07835 L
.75045 .09426 L
.7505 .11016 L
.75053 .09426 L
.75054 .07835 L
Mistroke
.75064 .06244 L
.75068 .04653 L
.75069 .06244 L
.75074 .04653 L
.75077 .03062 L
.75079 .01472 L
.75121 .03062 L
.75124 .01472 L
.75139 .03062 L
.75141 .04653 L
.75143 .06244 L
.75143 .04653 L
.75144 .06244 L
.75148 .07835 L
.75148 .09426 L
.75157 .07835 L
.75158 .06244 L
.75159 .04653 L
.7516 .06244 L
.75161 .04653 L
.75162 .03062 L
.75167 .01472 L
.75184 .03062 L
.75196 .01472 L
.75212 .03062 L
.75219 .04653 L
.75219 .06244 L
.75226 .07835 L
.75229 .09426 L
.75233 .11016 L
.75233 .12607 L
.75236 .14198 L
.7524 .12607 L
.75246 .11016 L
.75249 .12607 L
.75251 .14198 L
.75251 .15789 L
.75254 .1738 L
.75255 .18971 L
.75257 .1738 L
.75259 .15789 L
.75263 .14198 L
.75267 .12607 L
.7527 .11016 L
.7527 .12607 L
.75272 .11016 L
.75273 .09426 L
.75274 .07835 L
.75285 .06244 L
.75288 .04653 L
Mistroke
.753 .03062 L
.75309 .04653 L
.75312 .06244 L
.75314 .04653 L
.75314 .03062 L
.75323 .01472 L
.75325 .03062 L
.75335 .01472 L
.75351 .03062 L
.75354 .01472 L
.75362 .03062 L
.75365 .01472 L
.75374 .03062 L
.75375 .01472 L
.754 .03062 L
.75402 .01472 L
.75407 .03062 L
.75408 .01472 L
.75432 .03062 L
.75434 .04653 L
.75437 .03062 L
.75449 .01472 L
.75453 .03062 L
.75458 .04653 L
.75463 .03062 L
.75478 .04653 L
.75479 .06244 L
.7548 .07835 L
.75483 .09426 L
.75487 .07835 L
.75488 .09426 L
.75495 .11016 L
.75496 .09426 L
.75499 .07835 L
.75499 .06244 L
.755 .04653 L
.75501 .06244 L
.75509 .04653 L
.75532 .03062 L
.75539 .01472 L
.75543 .03062 L
.75551 .04653 L
.75563 .03062 L
.75564 .01472 L
.75566 .03062 L
.75567 .01472 L
.75577 .03062 L
.75581 .04653 L
.75582 .03062 L
.75584 .01472 L
Mistroke
.75599 .03062 L
.75601 .04653 L
.75611 .03062 L
.75613 .04653 L
.75632 .03062 L
.75644 .01472 L
.7566 .03062 L
.75663 .04653 L
.7567 .06244 L
.75679 .04653 L
.75679 .03062 L
.75685 .04653 L
.75691 .06244 L
.75694 .07835 L
.75706 .06244 L
.75706 .07835 L
.75713 .06244 L
.75713 .07835 L
.75713 .06244 L
.75718 .07835 L
.75718 .06244 L
.75728 .07835 L
.7573 .09426 L
.7574 .07835 L
.7574 .06244 L
.75751 .04653 L
.75753 .03062 L
.75758 .04653 L
.7576 .06244 L
.75767 .04653 L
.75771 .06244 L
.75773 .04653 L
.75782 .06244 L
.75795 .04653 L
.758 .03062 L
.75802 .04653 L
.75804 .06244 L
.75814 .07835 L
.7582 .09426 L
.75821 .11016 L
.75822 .12607 L
.75827 .11016 L
.75828 .12607 L
.75848 .14198 L
.75848 .12607 L
.75855 .14198 L
.75866 .15789 L
.75867 .14198 L
.75873 .12607 L
.75886 .14198 L
Mistroke
.75907 .12607 L
.75912 .11016 L
.75915 .09426 L
.75916 .07835 L
.75922 .06244 L
.75929 .07835 L
.75929 .09426 L
.75931 .07835 L
.75938 .06244 L
.7594 .04653 L
.75945 .06244 L
.75949 .04653 L
.75949 .06244 L
.75952 .04653 L
.75953 .06244 L
.75955 .07835 L
.75958 .09426 L
.75962 .07835 L
.7597 .09426 L
.75975 .11016 L
.75977 .12607 L
.75977 .11016 L
.75989 .09426 L
.7599 .11016 L
.75993 .12607 L
.75993 .11016 L
.75998 .09426 L
.76 .07835 L
.76006 .09426 L
.76009 .11016 L
.76035 .09426 L
.76036 .11016 L
.76042 .09426 L
.76046 .07835 L
.7605 .06244 L
.76064 .07835 L
.76064 .06244 L
.76065 .04653 L
.76065 .03062 L
.76068 .01472 L
.76072 .03062 L
.76076 .01472 L
.76085 .03062 L
.76089 .04653 L
.76089 .06244 L
.76102 .04653 L
.76109 .06244 L
.76122 .04653 L
.76129 .06244 L
.7613 .07835 L
Mistroke
.76131 .06244 L
.76139 .07835 L
.76144 .09426 L
.76147 .11016 L
.76152 .09426 L
.76153 .11016 L
.76153 .09426 L
.76157 .11016 L
.76159 .09426 L
.76171 .07835 L
.76176 .09426 L
.76182 .07835 L
.76185 .09426 L
.76192 .07835 L
.76193 .09426 L
.762 .07835 L
.76201 .09426 L
.76206 .07835 L
.76208 .06244 L
.76213 .07835 L
.76217 .06244 L
.76221 .04653 L
.76223 .06244 L
.76231 .07835 L
.76232 .09426 L
.76234 .11016 L
.76249 .12607 L
.76256 .11016 L
.7626 .09426 L
.76261 .11016 L
.76266 .12607 L
.76279 .11016 L
.76283 .12607 L
.76301 .14198 L
.76301 .12607 L
.76302 .11016 L
.76303 .12607 L
.76305 .11016 L
.76307 .12607 L
.76309 .11016 L
.76314 .12607 L
.76318 .11016 L
.76323 .12607 L
.76343 .11016 L
.76347 .09426 L
.76351 .07835 L
.76351 .06244 L
.76355 .04653 L
.76363 .03062 L
.76368 .01472 L
Mistroke
.76369 .03062 L
.76376 .04653 L
.76379 .03062 L
.76383 .01472 L
.76393 .03062 L
.76398 .01472 L
.76405 .03062 L
.76407 .04653 L
.7641 .06244 L
.76413 .07835 L
.76419 .09426 L
.76419 .11016 L
.76421 .12607 L
.76425 .11016 L
.76427 .12607 L
.76435 .14198 L
.76441 .12607 L
.76441 .14198 L
.76441 .15789 L
.76451 .1738 L
.76455 .18971 L
.76462 .20561 L
.76463 .22152 L
.76465 .23743 L
.76466 .22152 L
.76472 .20561 L
.76474 .22152 L
.76476 .23743 L
.7648 .22152 L
.76482 .23743 L
.76485 .22152 L
.76488 .20561 L
.76495 .22152 L
.76503 .20561 L
.76513 .22152 L
.76516 .23743 L
.76519 .22152 L
.7652 .20561 L
.76526 .18971 L
.76532 .20561 L
.76536 .18971 L
.76541 .20561 L
.76544 .18971 L
.76548 .20561 L
.76549 .22152 L
.76554 .23743 L
.7656 .22152 L
.7657 .20561 L
.76571 .22152 L
.76574 .20561 L
Mistroke
.76574 .18971 L
.7659 .20561 L
.76599 .22152 L
.76601 .20561 L
.76604 .22152 L
.76613 .20561 L
.76614 .18971 L
.76624 .20561 L
.76632 .22152 L
.76635 .20561 L
.76635 .18971 L
.76639 .1738 L
.76641 .18971 L
.76643 .1738 L
.76654 .18971 L
.76655 .1738 L
.76661 .15789 L
.76662 .14198 L
.76663 .12607 L
.76664 .11016 L
.76665 .09426 L
.76668 .07835 L
.76669 .06244 L
.76673 .04653 L
.76673 .03062 L
.767 .04653 L
.76703 .06244 L
.76719 .04653 L
.76726 .06244 L
.76728 .04653 L
.76731 .03062 L
.76732 .01472 L
.76742 .03062 L
.76743 .04653 L
.76744 .03062 L
.76744 .01472 L
.76774 .03062 L
.76775 .01472 L
.7678 .03062 L
.76787 .04653 L
.76795 .03062 L
.76796 .04653 L
.76811 .03062 L
.76824 .04653 L
.76825 .03062 L
.7683 .01472 L
.76881 .03062 L
.76883 .04653 L
.76884 .06244 L
.76894 .04653 L
Mistroke
.76899 .03062 L
.769 .01472 L
.76908 .03062 L
.76909 .04653 L
.7691 .06244 L
.7691 .07835 L
.7691 .06244 L
.76911 .07835 L
.76919 .09426 L
.76928 .11016 L
.76932 .09426 L
.76932 .07835 L
.76952 .06244 L
.76955 .07835 L
.76966 .09426 L
.76977 .07835 L
.76978 .06244 L
.76979 .04653 L
.76982 .03062 L
.76991 .01472 L
.76994 .03062 L
.77 .01472 L
.77 .03062 L
.77002 .01472 L
.77027 .03062 L
.77032 .01472 L
.77035 .03062 L
.77053 .04653 L
.77059 .06244 L
.77064 .04653 L
.7707 .03062 L
.77076 .04653 L
.77079 .06244 L
.77083 .07835 L
.77089 .06244 L
.77094 .07835 L
.77097 .06244 L
.77098 .07835 L
.77098 .09426 L
.77103 .11016 L
.77111 .12607 L
.77117 .14198 L
.77117 .15789 L
.77123 .14198 L
.77126 .15789 L
.77129 .14198 L
.77134 .15789 L
.77145 .14198 L
.77148 .15789 L
.77148 .14198 L
Mistroke
.77149 .12607 L
.7715 .14198 L
.77157 .15789 L
.77162 .14198 L
.77164 .15789 L
.77165 .1738 L
.77172 .18971 L
.77185 .20561 L
.77204 .18971 L
.77208 .1738 L
.77208 .15789 L
.77213 .1738 L
.77217 .18971 L
.77225 .1738 L
.77226 .15789 L
.77229 .14198 L
.77231 .12607 L
.77241 .11016 L
.77243 .12607 L
.77245 .11016 L
.7725 .09426 L
.77252 .07835 L
.77254 .09426 L
.77258 .11016 L
.77261 .09426 L
.77263 .07835 L
.77266 .06244 L
.77267 .04653 L
.77272 .03062 L
.77272 .01472 L
.77282 .03062 L
.77283 .04653 L
.77284 .03062 L
.77289 .04653 L
.77297 .06244 L
.77299 .04653 L
.77301 .06244 L
.77301 .07835 L
.77305 .06244 L
.77309 .07835 L
.7731 .09426 L
.7731 .07835 L
.77311 .06244 L
.77313 .07835 L
.77314 .06244 L
.77315 .07835 L
.77318 .06244 L
.77319 .04653 L
.7732 .03062 L
.77324 .04653 L
Mistroke
.77339 .06244 L
.7735 .07835 L
.77353 .06244 L
.77361 .07835 L
.77362 .06244 L
.77363 .07835 L
.77364 .09426 L
.77389 .11016 L
.7739 .12607 L
.7739 .11016 L
.77394 .12607 L
.77395 .11016 L
.77396 .09426 L
.77417 .11016 L
.77418 .12607 L
.7743 .14198 L
.77432 .12607 L
.77437 .14198 L
.77441 .12607 L
.7746 .14198 L
.77465 .12607 L
.77469 .11016 L
.77476 .09426 L
.77478 .11016 L
.77478 .09426 L
.7748 .11016 L
.77484 .09426 L
.77486 .07835 L
.77489 .09426 L
.77491 .11016 L
.77501 .09426 L
.77502 .11016 L
.77503 .12607 L
.77504 .11016 L
.77507 .12607 L
.77508 .11016 L
.77509 .12607 L
.77509 .11016 L
.77511 .12607 L
.77513 .11016 L
.77517 .12607 L
.77519 .11016 L
.77524 .09426 L
.77525 .07835 L
.77529 .09426 L
.77537 .11016 L
.77544 .09426 L
.77556 .11016 L
.7756 .12607 L
.77563 .14198 L
Mistroke
.77565 .15789 L
.77568 .14198 L
.77572 .12607 L
.77573 .14198 L
.77574 .15789 L
.77576 .1738 L
.77582 .15789 L
.7759 .14198 L
.77595 .12607 L
.77596 .14198 L
.77597 .15789 L
.77597 .14198 L
.776 .12607 L
.77601 .14198 L
.77605 .15789 L
.77617 .14198 L
.77622 .15789 L
.77628 .1738 L
.77629 .15789 L
.77634 .14198 L
.77634 .15789 L
.77636 .1738 L
.7764 .18971 L
.77642 .1738 L
.77649 .15789 L
.77649 .1738 L
.77652 .18971 L
.77656 .20561 L
.77658 .18971 L
.7766 .1738 L
.77661 .18971 L
.77665 .20561 L
.77692 .18971 L
.77694 .20561 L
.77694 .22152 L
.77696 .23743 L
.77699 .22152 L
.77705 .23743 L
.77706 .22152 L
.77709 .20561 L
.77712 .18971 L
.77714 .20561 L
.77717 .18971 L
.77719 .20561 L
.77722 .22152 L
.77724 .20561 L
.77724 .18971 L
.77737 .20561 L
.77738 .22152 L
.77742 .23743 L
Mistroke
.7775 .22152 L
.77755 .23743 L
.77755 .25334 L
.77756 .23743 L
.77758 .22152 L
.77762 .20561 L
.77765 .18971 L
.77769 .20561 L
.77779 .18971 L
.77791 .1738 L
.77797 .15789 L
.77802 .1738 L
.77802 .15789 L
.77803 .14198 L
.77812 .15789 L
.77816 .1738 L
.77816 .18971 L
.7782 .1738 L
.77821 .15789 L
.77843 .14198 L
.77843 .15789 L
.77851 .14198 L
.77856 .15789 L
.77858 .1738 L
.7786 .15789 L
.77863 .14198 L
.77867 .12607 L
.77868 .14198 L
.77872 .12607 L
.7788 .11016 L
.77881 .12607 L
.77906 .14198 L
.77909 .12607 L
.77911 .11016 L
.77919 .12607 L
.7792 .14198 L
.77929 .12607 L
.77932 .11016 L
.77935 .12607 L
.77941 .14198 L
.77946 .15789 L
.77947 .14198 L
.77951 .12607 L
.77952 .14198 L
.77953 .12607 L
.77958 .14198 L
.77964 .12607 L
.7797 .14198 L
.77974 .15789 L
.77974 .1738 L
Mistroke
.77982 .18971 L
.77984 .20561 L
.77985 .18971 L
.77989 .1738 L
.77994 .15789 L
.77999 .1738 L
.78008 .15789 L
.78014 .14198 L
.78022 .12607 L
.7803 .11016 L
.78034 .09426 L
.78046 .07835 L
.78064 .09426 L
.78064 .11016 L
.78071 .12607 L
.78073 .11016 L
.7808 .12607 L
.78081 .14198 L
.78081 .12607 L
.78082 .14198 L
.78083 .12607 L
.78086 .14198 L
.78093 .12607 L
.78101 .14198 L
.78105 .15789 L
.78107 .14198 L
.78107 .15789 L
.78109 .1738 L
.7811 .15789 L
.7811 .14198 L
.78114 .15789 L
.78116 .1738 L
.78121 .18971 L
.78123 .1738 L
.78127 .15789 L
.78129 .14198 L
.78129 .12607 L
.7813 .14198 L
.78134 .12607 L
.78135 .11016 L
.78146 .12607 L
.78151 .11016 L
.78154 .12607 L
.78164 .14198 L
.78167 .15789 L
.78168 .14198 L
.7817 .12607 L
.7817 .11016 L
.78186 .12607 L
.78192 .11016 L
Mistroke
.78192 .09426 L
.78194 .07835 L
.78203 .06244 L
.78211 .07835 L
.7822 .09426 L
.78225 .07835 L
.78235 .06244 L
.78235 .07835 L
.78237 .09426 L
.7824 .07835 L
.78246 .09426 L
.78248 .07835 L
.78257 .06244 L
.78261 .07835 L
.78267 .06244 L
.78273 .04653 L
.78282 .03062 L
.78289 .01472 L
.78308 .03062 L
.78308 .04653 L
.78313 .06244 L
.78316 .04653 L
.78317 .06244 L
.78319 .07835 L
.78321 .06244 L
.78325 .07835 L
.78328 .09426 L
.78343 .07835 L
.78344 .09426 L
.78349 .07835 L
.78351 .09426 L
.78352 .07835 L
.78352 .06244 L
.7836 .07835 L
.78363 .06244 L
.78367 .04653 L
.78381 .06244 L
.78397 .07835 L
.78409 .06244 L
.78418 .07835 L
.7843 .06244 L
.78433 .04653 L
.78434 .06244 L
.78437 .04653 L
.7844 .06244 L
.78447 .07835 L
.78448 .06244 L
.7845 .07835 L
.7845 .09426 L
.78468 .07835 L
Mistroke
.78483 .06244 L
.78483 .07835 L
.78485 .09426 L
.78487 .07835 L
.78491 .09426 L
.78493 .07835 L
.78498 .06244 L
.785 .07835 L
.78508 .09426 L
.78513 .07835 L
.78523 .09426 L
.78534 .11016 L
.78557 .09426 L
.78566 .11016 L
.78569 .12607 L
.78572 .11016 L
.78573 .09426 L
.78575 .11016 L
.78579 .09426 L
.78591 .07835 L
.78604 .06244 L
.78608 .07835 L
.78613 .09426 L
.7862 .07835 L
.78649 .06244 L
.78655 .04653 L
.7866 .03062 L
.7866 .01472 L
.78688 .03062 L
.7869 .04653 L
.78696 .03062 L
.78697 .01472 L
.78698 .03062 L
.78706 .04653 L
.78711 .03062 L
.78738 .04653 L
.78754 .06244 L
.78754 .04653 L
.78757 .06244 L
.78757 .04653 L
.78759 .03062 L
.78765 .01472 L
.78774 .03062 L
.78775 .04653 L
.78778 .03062 L
.78779 .04653 L
.7878 .06244 L
.78785 .04653 L
.78807 .06244 L
.78808 .07835 L
Mistroke
.7881 .06244 L
.78811 .04653 L
.7882 .06244 L
.78828 .07835 L
.78828 .06244 L
.78829 .07835 L
.78834 .06244 L
.78838 .07835 L
.78842 .09426 L
.78845 .11016 L
.78847 .09426 L
.78852 .11016 L
.78854 .12607 L
.78856 .14198 L
.78857 .15789 L
.78858 .14198 L
.7886 .15789 L
.7886 .1738 L
.78866 .18971 L
.78871 .1738 L
.78873 .18971 L
.78876 .1738 L
.78877 .18971 L
.78883 .1738 L
.78906 .18971 L
.78907 .1738 L
.78908 .15789 L
.78913 .14198 L
.78915 .12607 L
.78918 .11016 L
.78921 .09426 L
.78935 .07835 L
.78938 .09426 L
.78943 .07835 L
.78943 .06244 L
.78948 .07835 L
.78954 .09426 L
.78957 .07835 L
.78959 .09426 L
.78963 .11016 L
.78966 .09426 L
.78966 .11016 L
.78967 .12607 L
.78968 .11016 L
.78969 .12607 L
.78978 .11016 L
.78979 .09426 L
.7898 .11016 L
.78982 .09426 L
.78989 .11016 L
Mistroke
.78994 .12607 L
.79001 .11016 L
.79001 .09426 L
.79004 .11016 L
.79008 .09426 L
.79009 .11016 L
.79009 .12607 L
.7901 .11016 L
.79038 .12607 L
.79042 .11016 L
.79043 .09426 L
.79045 .07835 L
.79047 .09426 L
.79051 .07835 L
.79056 .09426 L
.79061 .11016 L
.79067 .12607 L
.7907 .14198 L
.79077 .12607 L
.79084 .14198 L
.7909 .12607 L
.79093 .14198 L
.79098 .15789 L
.79108 .14198 L
.79113 .12607 L
.79129 .14198 L
.79148 .12607 L
.79153 .11016 L
.79159 .09426 L
.79161 .07835 L
.79162 .09426 L
.79166 .07835 L
.79168 .06244 L
.7917 .04653 L
.79179 .03062 L
.79183 .01472 L
.7919 .03062 L
.7919 .04653 L
.79194 .06244 L
.79199 .07835 L
.79207 .06244 L
.79212 .04653 L
.79217 .03062 L
.79222 .01472 L
.79224 .03062 L
.79248 .01472 L
.7925 .03062 L
.79251 .01472 L
.79261 .03062 L
.79263 .04653 L
Mistroke
.79264 .06244 L
.79272 .04653 L
.79278 .06244 L
.79279 .04653 L
.79279 .06244 L
.79286 .04653 L
.79289 .03062 L
.79294 .04653 L
.79296 .06244 L
.79311 .07835 L
.79312 .06244 L
.79328 .07835 L
.79332 .09426 L
.79342 .07835 L
.79342 .06244 L
.79348 .04653 L
.79355 .06244 L
.79358 .04653 L
.79358 .03062 L
.7936 .04653 L
.79363 .06244 L
.79366 .07835 L
.79367 .09426 L
.7937 .07835 L
.7937 .06244 L
.7937 .04653 L
.79374 .06244 L
.79375 .07835 L
.79376 .06244 L
.79381 .04653 L
.79383 .03062 L
.79386 .04653 L
.7939 .03062 L
.79392 .01472 L
.79407 .03062 L
.79413 .01472 L
.79432 .03062 L
.79432 .04653 L
.7944 .06244 L
.79441 .07835 L
.79442 .06244 L
.79442 .07835 L
.79456 .06244 L
.79465 .04653 L
.79466 .03062 L
.79468 .04653 L
.79474 .03062 L
.79475 .01472 L
.79484 .03062 L
.79486 .01472 L
Mistroke
.79499 .03062 L
.79502 .04653 L
.79506 .03062 L
.79506 .01472 L
.79515 .03062 L
.79515 .01472 L
.79524 .03062 L
.79538 .01472 L
.79542 .03062 L
.79548 .01472 L
.79552 .03062 L
.79553 .01472 L
.79567 .03062 L
.79569 .04653 L
.79578 .03062 L
.79579 .04653 L
.79579 .06244 L
.79584 .04653 L
.79591 .06244 L
.79592 .04653 L
.79593 .06244 L
.79609 .04653 L
.79617 .03062 L
.79619 .04653 L
.79627 .03062 L
.79627 .01472 L
.79641 .03062 L
.79643 .04653 L
.79647 .06244 L
.79651 .07835 L
.79651 .06244 L
.79652 .04653 L
.7966 .06244 L
.79668 .07835 L
.79671 .06244 L
.79674 .07835 L
.79677 .06244 L
.7969 .04653 L
.79697 .06244 L
.79703 .04653 L
.79703 .06244 L
.79705 .07835 L
.79706 .06244 L
.79707 .04653 L
.79708 .06244 L
.79711 .07835 L
.79712 .06244 L
.79715 .07835 L
.79715 .09426 L
.79716 .11016 L
Mistroke
.79719 .09426 L
.79728 .11016 L
.79731 .09426 L
.79733 .11016 L
.79735 .12607 L
.79738 .11016 L
.79738 .09426 L
.79745 .07835 L
.79746 .06244 L
.79747 .04653 L
.79751 .03062 L
.79754 .01472 L
.79764 .03062 L
.79765 .01472 L
.79767 .03062 L
.79768 .01472 L
.79773 .03062 L
.79774 .04653 L
.79776 .06244 L
.79782 .04653 L
.79789 .03062 L
.79791 .04653 L
.79811 .03062 L
.79811 .04653 L
.79823 .06244 L
.7984 .07835 L
.7984 .09426 L
.79845 .11016 L
.79852 .09426 L
.79865 .11016 L
.7987 .12607 L
.79871 .11016 L
.79876 .09426 L
.79881 .11016 L
.79888 .09426 L
.79892 .07835 L
.79896 .06244 L
.79897 .04653 L
.799 .03062 L
.79906 .04653 L
.79915 .06244 L
.79924 .04653 L
.79926 .06244 L
.79934 .04653 L
.79938 .03062 L
.79944 .04653 L
.79951 .03062 L
.79955 .01472 L
.79959 .03062 L
.7996 .04653 L
Mistroke
.79976 .03062 L
.79995 .04653 L
.79996 .06244 L
.80004 .04653 L
.80005 .06244 L
.80005 .04653 L
.80007 .06244 L
.80009 .07835 L
.80013 .06244 L
.80017 .07835 L
.8002 .09426 L
.80024 .07835 L
.80031 .06244 L
.80035 .04653 L
.80042 .03062 L
.80047 .04653 L
.80053 .03062 L
.80055 .04653 L
.80055 .03062 L
.80056 .04653 L
.80069 .06244 L
.80082 .04653 L
.80096 .03062 L
.80097 .01472 L
.8011 .03062 L
.80125 .04653 L
.80127 .03062 L
.80146 .04653 L
.80148 .06244 L
.80158 .04653 L
.80158 .06244 L
.80158 .07835 L
.8016 .09426 L
.8016 .07835 L
.80163 .06244 L
.80174 .07835 L
.80174 .06244 L
.80175 .07835 L
.80178 .09426 L
.80178 .11016 L
.80185 .12607 L
.80185 .14198 L
.80191 .12607 L
.80193 .11016 L
.80194 .09426 L
.80197 .11016 L
.80199 .12607 L
.80206 .14198 L
.80212 .15789 L
.80218 .14198 L
Mistroke
.80219 .15789 L
.8022 .14198 L
.80221 .12607 L
.80222 .11016 L
.80224 .12607 L
.80225 .11016 L
.80226 .09426 L
.80227 .07835 L
.80236 .09426 L
.80239 .11016 L
.80245 .09426 L
.80245 .11016 L
.80247 .12607 L
.80248 .14198 L
.80248 .12607 L
.80248 .11016 L
.80249 .12607 L
.8025 .11016 L
.80252 .12607 L
.80268 .11016 L
.8027 .09426 L
.80275 .11016 L
.8028 .09426 L
.80281 .07835 L
.80288 .06244 L
.80292 .07835 L
.80296 .09426 L
.803 .11016 L
.80302 .09426 L
.80307 .07835 L
.8032 .06244 L
.80327 .04653 L
.80333 .03062 L
.80339 .01472 L
.80392 .03062 L
.80395 .01472 L
.80401 .03062 L
.8041 .01472 L
.80415 .03062 L
.80415 .01472 L
.80416 .03062 L
.80424 .04653 L
.80425 .06244 L
.80431 .07835 L
.80443 .09426 L
.80452 .11016 L
.80457 .09426 L
.80473 .11016 L
.80475 .12607 L
.80483 .14198 L
Mistroke
.80485 .15789 L
.80488 .14198 L
.80493 .12607 L
.80494 .11016 L
.80523 .12607 L
.80528 .14198 L
.80533 .12607 L
.80537 .11016 L
.80542 .09426 L
.8055 .11016 L
.80564 .09426 L
.80567 .11016 L
.80583 .09426 L
.80585 .11016 L
.80589 .12607 L
.8059 .14198 L
.80592 .12607 L
.80594 .11016 L
.80601 .09426 L
.80603 .11016 L
.80603 .09426 L
.80605 .11016 L
.80611 .09426 L
.80612 .11016 L
.80624 .12607 L
.80626 .11016 L
.80627 .12607 L
.8063 .11016 L
.80639 .12607 L
.80645 .11016 L
.80646 .09426 L
.8065 .07835 L
.80651 .06244 L
.80657 .04653 L
.80659 .06244 L
.80663 .04653 L
.80665 .03062 L
.80675 .04653 L
.80675 .06244 L
.80689 .04653 L
.80689 .03062 L
.80693 .01472 L
.80705 .03062 L
.80707 .01472 L
.80717 .03062 L
.80733 .04653 L
.80733 .06244 L
.80741 .07835 L
.80742 .06244 L
.80746 .04653 L
Mistroke
.80747 .06244 L
.80767 .07835 L
.80767 .06244 L
.80768 .07835 L
.8077 .09426 L
.80773 .11016 L
.80777 .12607 L
.8078 .14198 L
.80785 .15789 L
.80791 .1738 L
.808 .18971 L
.80807 .20561 L
.80807 .22152 L
.80807 .23743 L
.80808 .22152 L
.80809 .23743 L
.80822 .22152 L
.80827 .23743 L
.80827 .25334 L
.80827 .23743 L
.80831 .22152 L
.80833 .20561 L
.80835 .22152 L
.80837 .20561 L
.80839 .18971 L
.80839 .1738 L
.80845 .18971 L
.80849 .20561 L
.80851 .22152 L
.80868 .23743 L
.80877 .22152 L
.80878 .20561 L
.80878 .22152 L
.80882 .23743 L
.80886 .22152 L
.80887 .20561 L
.80891 .22152 L
.80895 .23743 L
.80895 .22152 L
.80899 .20561 L
.809 .18971 L
.80901 .20561 L
.80901 .18971 L
.80907 .20561 L
.80912 .22152 L
.8092 .20561 L
.8093 .18971 L
.80934 .20561 L
.8094 .18971 L
.80949 .1738 L
Mistroke
.80949 .18971 L
.80957 .20561 L
.8096 .18971 L
.80965 .20561 L
.80967 .18971 L
.80968 .1738 L
.80972 .15789 L
.80977 .1738 L
.80978 .15789 L
.80979 .14198 L
.80983 .12607 L
.81 .14198 L
.81005 .15789 L
.81008 .1738 L
.81009 .18971 L
.81019 .1738 L
.81024 .15789 L
.81026 .1738 L
.81028 .15789 L
.81035 .1738 L
.8104 .18971 L
.81041 .1738 L
.8105 .15789 L
.81051 .14198 L
.81052 .12607 L
.81053 .14198 L
.81061 .15789 L
.81063 .1738 L
.81063 .18971 L
.81068 .20561 L
.8107 .22152 L
.8107 .23743 L
.81086 .25334 L
.8109 .23743 L
.811 .22152 L
.81106 .20561 L
.81114 .18971 L
.81116 .1738 L
.81117 .18971 L
.81125 .1738 L
.81134 .15789 L
.81137 .14198 L
.81154 .12607 L
.81158 .14198 L
.81161 .15789 L
.81164 .14198 L
.8117 .15789 L
.81177 .14198 L
.81179 .15789 L
.81179 .1738 L
Mistroke
.81184 .18971 L
.81184 .20561 L
.81185 .18971 L
.81198 .1738 L
.8122 .18971 L
.81221 .1738 L
.81224 .15789 L
.81227 .14198 L
.81228 .12607 L
.81237 .11016 L
.81243 .12607 L
.81243 .11016 L
.81246 .09426 L
.81255 .07835 L
.81263 .06244 L
.81268 .07835 L
.81269 .09426 L
.81282 .07835 L
.81303 .09426 L
.81304 .11016 L
.81314 .12607 L
.8132 .14198 L
.8132 .15789 L
.81326 .1738 L
.81327 .15789 L
.81328 .14198 L
.81329 .12607 L
.81336 .14198 L
.81341 .15789 L
.81344 .14198 L
.81351 .15789 L
.81357 .14198 L
.81359 .15789 L
.81367 .14198 L
.81368 .12607 L
.81369 .11016 L
.81371 .12607 L
.81377 .14198 L
.81385 .12607 L
.8139 .14198 L
.81392 .12607 L
.81394 .11016 L
.81394 .12607 L
.81395 .14198 L
.81403 .12607 L
.81405 .11016 L
.81411 .09426 L
.81413 .07835 L
.81416 .09426 L
.81416 .11016 L
Mistroke
.81421 .12607 L
.81423 .11016 L
.81427 .12607 L
.81428 .11016 L
.81428 .09426 L
.81431 .07835 L
.81447 .06244 L
.81452 .04653 L
.81455 .03062 L
.81457 .01472 L
.81459 .03062 L
.81469 .01472 L
.81474 .03062 L
.81479 .04653 L
.8148 .06244 L
.815 .04653 L
.81501 .03062 L
.81506 .04653 L
.8151 .06244 L
.81514 .04653 L
.81518 .06244 L
.8152 .04653 L
.81521 .06244 L
.81524 .04653 L
.81529 .03062 L
.8153 .01472 L
.81532 .03062 L
.81534 .04653 L
.81537 .06244 L
.81541 .04653 L
.8155 .03062 L
.8155 .04653 L
.81553 .03062 L
.81553 .04653 L
.81558 .03062 L
.81566 .01472 L
.81583 .03062 L
.81589 .01472 L
.81604 .03062 L
.81608 .01472 L
.81624 .03062 L
.81635 .01472 L
.81651 .03062 L
.81658 .04653 L
.81663 .06244 L
.81666 .07835 L
.81673 .06244 L
.81677 .04653 L
.81677 .06244 L
.81678 .07835 L
Mistroke
.81682 .06244 L
.81684 .07835 L
.81685 .06244 L
.81688 .07835 L
.81689 .09426 L
.81694 .11016 L
.81697 .12607 L
.81699 .11016 L
.81704 .12607 L
.81707 .14198 L
.81708 .12607 L
.81714 .11016 L
.81716 .09426 L
.81737 .07835 L
.81748 .06244 L
.81748 .07835 L
.81754 .06244 L
.81774 .07835 L
.81782 .06244 L
.81786 .07835 L
.81788 .09426 L
.8179 .07835 L
.81797 .09426 L
.81798 .07835 L
.81799 .06244 L
.81802 .04653 L
.81806 .03062 L
.81812 .04653 L
.81815 .03062 L
.81815 .04653 L
.81825 .06244 L
.8183 .04653 L
.81835 .03062 L
.81844 .04653 L
.81849 .06244 L
.81853 .07835 L
.81854 .09426 L
.81856 .07835 L
.81858 .09426 L
.8186 .11016 L
.81868 .09426 L
.8187 .11016 L
.81873 .09426 L
.81886 .07835 L
.81893 .09426 L
.81894 .11016 L
.81895 .12607 L
.81901 .11016 L
.81903 .09426 L
.81911 .11016 L
Mistroke
.81913 .09426 L
.81917 .11016 L
.81933 .09426 L
.81937 .07835 L
.8194 .06244 L
.81944 .07835 L
.81945 .09426 L
.81946 .07835 L
.81953 .09426 L
.81961 .07835 L
.81969 .06244 L
.81969 .04653 L
.81971 .03062 L
.81974 .01472 L
.81988 .03062 L
.81991 .04653 L
.81993 .03062 L
.81993 .01472 L
.82008 .03062 L
.82016 .04653 L
.82018 .03062 L
.82019 .01472 L
.82039 .03062 L
.82042 .01472 L
.82046 .03062 L
.8206 .04653 L
.82067 .03062 L
.82073 .04653 L
.82076 .06244 L
.82082 .04653 L
.82083 .03062 L
.82085 .01472 L
.82091 .03062 L
.82091 .01472 L
.82094 .03062 L
.82094 .01472 L
.82095 .03062 L
.82099 .04653 L
.82108 .03062 L
.82117 .01472 L
.82125 .03062 L
.82131 .04653 L
.82135 .03062 L
.82135 .04653 L
.82143 .06244 L
.8216 .07835 L
.82162 .06244 L
.82168 .04653 L
.82174 .06244 L
.82175 .07835 L
Mistroke
.82176 .06244 L
.82181 .07835 L
.82184 .06244 L
.82185 .07835 L
.82186 .09426 L
.82188 .11016 L
.82198 .09426 L
.82204 .07835 L
.82209 .09426 L
.82211 .11016 L
.82211 .09426 L
.82216 .11016 L
.82217 .09426 L
.82224 .07835 L
.82234 .06244 L
.82235 .07835 L
.82254 .09426 L
.82254 .11016 L
.82255 .12607 L
.82256 .11016 L
.82256 .09426 L
.8228 .11016 L
.82286 .09426 L
.8229 .11016 L
.82292 .09426 L
.82296 .07835 L
.82298 .09426 L
.82304 .11016 L
.8231 .12607 L
.82317 .11016 L
.82318 .12607 L
.8232 .14198 L
.82322 .15789 L
.82324 .14198 L
.82326 .15789 L
.82329 .14198 L
.82329 .15789 L
.82333 .1738 L
.82335 .18971 L
.8234 .20561 L
.82348 .22152 L
.82363 .20561 L
.82364 .22152 L
.82365 .23743 L
.82369 .25334 L
.82377 .26925 L
.82378 .28515 L
.82383 .30106 L
.82389 .28515 L
.82394 .26925 L
Mistroke
.82397 .25334 L
.82397 .26925 L
.82398 .28515 L
.82402 .26925 L
.82404 .28515 L
.82405 .26925 L
.82411 .25334 L
.82422 .23743 L
.82423 .25334 L
.82423 .26925 L
.82424 .25334 L
.82426 .26925 L
.82429 .28515 L
.82431 .30106 L
.82439 .28515 L
.82447 .26925 L
.82451 .25334 L
.82452 .26925 L
.8246 .25334 L
.82462 .26925 L
.82465 .25334 L
.82467 .23743 L
.82469 .22152 L
.82475 .23743 L
.82478 .25334 L
.8248 .23743 L
.82509 .25334 L
.82509 .23743 L
.82511 .25334 L
.82511 .23743 L
.82514 .22152 L
.82514 .20561 L
.82517 .22152 L
.82519 .20561 L
.82521 .22152 L
.82523 .20561 L
.82524 .18971 L
.82527 .20561 L
.82527 .22152 L
.8253 .23743 L
.82537 .22152 L
.82544 .20561 L
.82549 .22152 L
.82551 .20561 L
.82552 .22152 L
.82555 .23743 L
.82556 .22152 L
.82563 .23743 L
.82572 .22152 L
.82577 .20561 L
Mistroke
.82586 .18971 L
.82587 .1738 L
.8259 .18971 L
.82596 .1738 L
.82599 .18971 L
.82608 .1738 L
.8261 .15789 L
.82612 .1738 L
.82613 .18971 L
.82618 .20561 L
.82621 .18971 L
.82626 .1738 L
.82627 .15789 L
.82628 .1738 L
.82632 .18971 L
.82638 .20561 L
.82645 .18971 L
.82645 .20561 L
.82646 .22152 L
.82649 .23743 L
.82657 .22152 L
.82657 .20561 L
.82658 .22152 L
.82661 .20561 L
.82662 .22152 L
.82665 .20561 L
.82667 .18971 L
.82678 .1738 L
.82684 .15789 L
.8269 .14198 L
.82693 .15789 L
.82701 .1738 L
.82702 .15789 L
.82702 .14198 L
.8271 .12607 L
.82712 .11016 L
.8272 .12607 L
.82722 .14198 L
.82724 .15789 L
.82727 .14198 L
.82729 .12607 L
.82734 .11016 L
.8274 .12607 L
.8275 .11016 L
.82752 .09426 L
.82753 .07835 L
.82754 .09426 L
.82757 .11016 L
.82766 .12607 L
.82767 .14198 L
Mistroke
.82767 .12607 L
.82767 .14198 L
.82775 .12607 L
.82776 .11016 L
.82778 .12607 L
.82779 .14198 L
.8278 .15789 L
.82782 .1738 L
.82782 .15789 L
.82788 .14198 L
.82791 .12607 L
.828 .11016 L
.82801 .09426 L
.82803 .07835 L
.82805 .09426 L
.82805 .11016 L
.82806 .12607 L
.82806 .11016 L
.82809 .12607 L
.82823 .14198 L
.82826 .12607 L
.82828 .11016 L
.82829 .09426 L
.82833 .11016 L
.82838 .09426 L
.82838 .07835 L
.82839 .06244 L
.82846 .07835 L
.82847 .06244 L
.82855 .07835 L
.82855 .09426 L
.82858 .07835 L
.82863 .09426 L
.82893 .07835 L
.82894 .09426 L
.82897 .11016 L
.82898 .12607 L
.829 .11016 L
.82901 .12607 L
.82915 .11016 L
.82917 .09426 L
.82933 .11016 L
.82933 .12607 L
.82935 .14198 L
.82939 .15789 L
.8294 .14198 L
.82945 .15789 L
.8296 .1738 L
.82964 .18971 L
.82967 .20561 L
Mistroke
.82972 .22152 L
.82986 .20561 L
.83 .22152 L
.83001 .20561 L
.83004 .22152 L
.83005 .20561 L
.83014 .22152 L
.83018 .20561 L
.83019 .22152 L
.83021 .20561 L
.83023 .18971 L
.83029 .20561 L
.8303 .18971 L
.83031 .20561 L
.83032 .18971 L
.83032 .1738 L
.83033 .18971 L
.83036 .1738 L
.83048 .18971 L
.83049 .1738 L
.83053 .18971 L
.83054 .1738 L
.83058 .18971 L
.8306 .20561 L
.83067 .18971 L
.83075 .1738 L
.8308 .15789 L
.8309 .1738 L
.83093 .18971 L
.83096 .1738 L
.83097 .15789 L
.83101 .1738 L
.83107 .15789 L
.8311 .1738 L
.83112 .18971 L
.83114 .1738 L
.83119 .15789 L
.83126 .14198 L
.83127 .12607 L
.8314 .11016 L
.83149 .09426 L
.83153 .11016 L
.83181 .12607 L
.83183 .11016 L
.83184 .09426 L
.83191 .07835 L
.83193 .06244 L
.83195 .07835 L
.83197 .09426 L
.83198 .07835 L
Mistroke
.832 .09426 L
.83205 .07835 L
.83215 .09426 L
.83216 .11016 L
.83226 .09426 L
.83226 .07835 L
.8323 .06244 L
.83232 .07835 L
.83251 .09426 L
.83254 .11016 L
.83257 .09426 L
.83257 .11016 L
.83258 .12607 L
.83261 .14198 L
.83262 .15789 L
.83265 .14198 L
.83267 .12607 L
.83269 .14198 L
.83276 .12607 L
.83278 .11016 L
.83278 .09426 L
.83299 .11016 L
.83301 .12607 L
.83303 .14198 L
.83304 .15789 L
.83308 .1738 L
.8331 .18971 L
.83312 .20561 L
.83335 .18971 L
.83342 .20561 L
.83343 .22152 L
.83343 .20561 L
.83348 .18971 L
.83354 .20561 L
.83359 .18971 L
.83363 .1738 L
.83366 .15789 L
.83371 .14198 L
.83377 .15789 L
.83378 .1738 L
.83382 .15789 L
.83384 .14198 L
.83385 .12607 L
.83408 .14198 L
.83409 .12607 L
.8341 .11016 L
.83434 .09426 L
.83439 .11016 L
.83439 .09426 L
.83445 .07835 L
Mistroke
.83453 .09426 L
.83458 .07835 L
.83459 .06244 L
.83464 .04653 L
.83473 .06244 L
.83474 .04653 L
.83478 .06244 L
.83485 .04653 L
.83488 .06244 L
.83491 .04653 L
.83492 .06244 L
.835 .04653 L
.83503 .06244 L
.83506 .07835 L
.83506 .09426 L
.83507 .07835 L
.83511 .09426 L
.83514 .07835 L
.83523 .06244 L
.83524 .04653 L
.83525 .03062 L
.83528 .04653 L
.83528 .03062 L
.83529 .01472 L
.83533 .03062 L
.83551 .01472 L
.83553 .03062 L
.83557 .01472 L
.83562 .03062 L
.83562 .04653 L
.83564 .03062 L
.83565 .04653 L
.83569 .06244 L
.8358 .04653 L
.83587 .03062 L
.8359 .01472 L
.8359 .03062 L
.836 .04653 L
.83609 .06244 L
.8362 .07835 L
.83622 .09426 L
.83625 .07835 L
.83634 .06244 L
.83639 .07835 L
.83653 .06244 L
.83655 .07835 L
.83659 .06244 L
.83666 .04653 L
.83671 .03062 L
.83681 .01472 L
Mistroke
.83684 .03062 L
.83685 .01472 L
.83686 .03062 L
.83693 .01472 L
.83714 .03062 L
.83717 .01472 L
.83749 .03062 L
.83758 .04653 L
.83759 .06244 L
.83785 .07835 L
.83791 .09426 L
.83794 .11016 L
.83796 .12607 L
.83802 .14198 L
.83807 .15789 L
.83813 .1738 L
.83816 .18971 L
.83817 .1738 L
.83823 .18971 L
.83826 .20561 L
.83845 .18971 L
.83845 .1738 L
.83849 .15789 L
.8385 .14198 L
.83855 .15789 L
.83857 .1738 L
.83857 .18971 L
.83865 .1738 L
.83869 .18971 L
.83872 .1738 L
.83877 .15789 L
.83882 .1738 L
.83888 .18971 L
.83891 .20561 L
.83892 .22152 L
.83894 .20561 L
.83897 .18971 L
.83901 .1738 L
.83901 .15789 L
.83905 .14198 L
.83906 .12607 L
.83907 .14198 L
.83909 .12607 L
.83922 .11016 L
.83924 .09426 L
.83924 .11016 L
.83927 .12607 L
.83936 .14198 L
.83939 .15789 L
.83945 .1738 L
Mistroke
.83948 .18971 L
.83949 .1738 L
.83958 .15789 L
.83961 .1738 L
.83965 .15789 L
.83968 .1738 L
.83971 .18971 L
.83973 .20561 L
.83976 .22152 L
.83977 .20561 L
.8398 .18971 L
.83981 .20561 L
.83984 .18971 L
.83986 .20561 L
.83986 .18971 L
.83987 .1738 L
.83988 .18971 L
.83988 .1738 L
.84001 .15789 L
.84002 .1738 L
.84004 .15789 L
.84012 .14198 L
.84016 .12607 L
.84024 .14198 L
.84028 .15789 L
.84037 .1738 L
.84043 .15789 L
.84046 .1738 L
.84047 .18971 L
.8405 .20561 L
.84058 .18971 L
.8406 .1738 L
.84066 .15789 L
.84071 .1738 L
.84072 .18971 L
.84078 .20561 L
.8408 .18971 L
.84083 .1738 L
.84089 .18971 L
.84092 .20561 L
.84094 .18971 L
.84096 .1738 L
.84117 .18971 L
.8412 .1738 L
.84121 .18971 L
.8413 .20561 L
.84141 .18971 L
.84142 .20561 L
.84143 .22152 L
.84145 .20561 L
Mistroke
.84152 .18971 L
.84152 .20561 L
.84156 .18971 L
.84164 .20561 L
.84167 .18971 L
.84169 .1738 L
.84171 .15789 L
.84175 .14198 L
.84176 .15789 L
.84186 .1738 L
.84189 .18971 L
.84191 .1738 L
.84201 .15789 L
.84209 .14198 L
.84216 .15789 L
.84222 .14198 L
.84232 .12607 L
.84237 .11016 L
.84238 .09426 L
.84238 .07835 L
.84243 .06244 L
.84258 .04653 L
.8426 .03062 L
.84265 .01472 L
.84267 .03062 L
.84267 .04653 L
.84272 .03062 L
.84277 .04653 L
.84282 .06244 L
.84283 .04653 L
.84297 .03062 L
.84304 .04653 L
.84309 .06244 L
.84312 .07835 L
.84322 .06244 L
.84323 .04653 L
.84323 .06244 L
.8433 .04653 L
.84331 .06244 L
.84332 .07835 L
.84335 .09426 L
.84336 .11016 L
.84339 .12607 L
.8434 .14198 L
.84351 .15789 L
.8436 .14198 L
.84361 .15789 L
.84366 .14198 L
.84373 .12607 L
.84375 .14198 L
Mistroke
.84378 .15789 L
.84384 .14198 L
.84385 .15789 L
.84386 .14198 L
.84389 .12607 L
.84393 .14198 L
.84406 .12607 L
.84414 .11016 L
.84415 .09426 L
.84419 .11016 L
.84424 .09426 L
.84426 .11016 L
.84435 .12607 L
.8444 .14198 L
.84444 .15789 L
.84446 .14198 L
.84447 .12607 L
.84448 .14198 L
.84459 .15789 L
.84468 .1738 L
.84473 .15789 L
.8448 .14198 L
.84485 .12607 L
.84492 .14198 L
.84496 .15789 L
.84502 .1738 L
.84504 .15789 L
.84505 .14198 L
.84513 .12607 L
.84516 .11016 L
.84516 .12607 L
.84523 .14198 L
.84526 .15789 L
.84544 .1738 L
.84565 .18971 L
.84565 .1738 L
.84568 .15789 L
.84571 .1738 L
.84571 .15789 L
.84575 .14198 L
.84577 .12607 L
.8458 .14198 L
.84581 .12607 L
.84589 .11016 L
.84595 .12607 L
.84615 .11016 L
.84627 .09426 L
.84631 .11016 L
.84641 .09426 L
.84642 .07835 L
Mistroke
.84649 .06244 L
.84651 .04653 L
.84652 .06244 L
.84654 .04653 L
.84661 .06244 L
.84667 .07835 L
.84668 .06244 L
.84684 .07835 L
.84714 .06244 L
.84714 .07835 L
.84721 .06244 L
.84722 .07835 L
.84723 .09426 L
.8473 .07835 L
.84734 .09426 L
.84743 .11016 L
.84744 .12607 L
.84756 .11016 L
.84759 .12607 L
.8476 .14198 L
.84766 .12607 L
.84769 .11016 L
.84785 .12607 L
.84787 .11016 L
.84787 .09426 L
.84791 .07835 L
.84792 .09426 L
.84798 .11016 L
.84808 .12607 L
.8481 .11016 L
.84811 .09426 L
.84811 .07835 L
.84812 .06244 L
.84815 .07835 L
.84815 .09426 L
.84818 .07835 L
.8482 .09426 L
.84822 .07835 L
.84825 .09426 L
.84829 .07835 L
.8484 .06244 L
.84841 .07835 L
.84843 .06244 L
.84844 .07835 L
.84859 .06244 L
.84862 .04653 L
.84868 .03062 L
.84873 .01472 L
.84889 .03062 L
.84892 .04653 L
Mistroke
.84892 .06244 L
.84895 .04653 L
.84898 .03062 L
.84903 .01472 L
.84905 .03062 L
.84913 .04653 L
.84914 .06244 L
.84915 .07835 L
.84915 .09426 L
.84919 .07835 L
.84919 .06244 L
.84922 .04653 L
.84925 .06244 L
.84925 .04653 L
.84934 .06244 L
.84948 .04653 L
.84952 .06244 L
.84953 .04653 L
.84956 .06244 L
.84963 .04653 L
.84974 .06244 L
.84975 .07835 L
.84989 .06244 L
.8499 .07835 L
.84992 .06244 L
.84995 .07835 L
.84997 .09426 L
.84997 .07835 L
.85 .09426 L
.85001 .11016 L
.85004 .12607 L
.85011 .14198 L
.85021 .15789 L
.85025 .14198 L
.85025 .12607 L
.85027 .11016 L
.85027 .09426 L
.8503 .11016 L
.85034 .12607 L
.85046 .11016 L
.85049 .12607 L
.85051 .14198 L
.85058 .12607 L
.85083 .11016 L
.85087 .09426 L
.85089 .11016 L
.8509 .09426 L
.85093 .07835 L
.85094 .06244 L
.85109 .07835 L
Mistroke
.8511 .06244 L
.85111 .04653 L
.85123 .06244 L
.85125 .04653 L
.85132 .06244 L
.85142 .07835 L
.85146 .09426 L
.85147 .11016 L
.85147 .09426 L
.85159 .11016 L
.85159 .09426 L
.8516 .07835 L
.85165 .09426 L
.8517 .11016 L
.85182 .12607 L
.85183 .14198 L
.85196 .15789 L
.85199 .1738 L
.85211 .15789 L
.85212 .14198 L
.85223 .12607 L
.85233 .14198 L
.85237 .12607 L
.8524 .11016 L
.85243 .12607 L
.85247 .14198 L
.8525 .15789 L
.85252 .1738 L
.85253 .15789 L
.85259 .14198 L
.8526 .15789 L
.85269 .14198 L
.85272 .15789 L
.85274 .1738 L
.8528 .15789 L
.85292 .14198 L
.85307 .15789 L
.85308 .1738 L
.85311 .18971 L
.8532 .1738 L
.8533 .18971 L
.85331 .1738 L
.85333 .18971 L
.85336 .20561 L
.85359 .18971 L
.85359 .20561 L
.85367 .18971 L
.8537 .1738 L
.85385 .15789 L
.85389 .1738 L
Mistroke
.854 .18971 L
.85405 .1738 L
.85405 .18971 L
.85405 .20561 L
.85405 .18971 L
.85407 .20561 L
.85407 .22152 L
.85408 .23743 L
.8541 .22152 L
.85414 .20561 L
.85424 .22152 L
.85424 .20561 L
.85426 .22152 L
.85432 .20561 L
.85434 .22152 L
.85444 .20561 L
.85462 .22152 L
.85463 .20561 L
.85472 .22152 L
.85476 .20561 L
.85478 .18971 L
.85485 .1738 L
.8549 .15789 L
.85498 .14198 L
.85502 .12607 L
.85504 .11016 L
.85504 .09426 L
.85511 .07835 L
.85515 .06244 L
.85516 .07835 L
.85528 .06244 L
.85535 .04653 L
.85544 .06244 L
.85553 .07835 L
.85578 .09426 L
.85584 .11016 L
.85586 .09426 L
.85588 .07835 L
.85594 .06244 L
.85605 .07835 L
.85609 .06244 L
.8561 .07835 L
.85611 .09426 L
.85613 .11016 L
.8562 .12607 L
.85623 .14198 L
.85626 .12607 L
.85631 .11016 L
.8564 .09426 L
.85641 .11016 L
Mistroke
.85644 .12607 L
.85645 .11016 L
.85646 .09426 L
.85646 .07835 L
.8565 .06244 L
.85656 .04653 L
.8566 .03062 L
.85662 .01472 L
.85667 .03062 L
.85677 .04653 L
.85685 .03062 L
.8569 .01472 L
.85713 .03062 L
.85713 .01472 L
.85715 .03062 L
.85716 .04653 L
.85732 .06244 L
.85732 .07835 L
.85741 .09426 L
.85747 .11016 L
.85748 .09426 L
.85751 .11016 L
.85752 .09426 L
.85759 .07835 L
.85761 .06244 L
.85761 .07835 L
.85762 .09426 L
.85768 .07835 L
.85775 .09426 L
.8578 .11016 L
.85786 .09426 L
.85787 .07835 L
.85793 .06244 L
.85794 .07835 L
.85796 .09426 L
.85807 .11016 L
.85808 .09426 L
.85811 .11016 L
.85817 .09426 L
.85822 .11016 L
.85822 .09426 L
.8583 .07835 L
.85835 .06244 L
.85837 .07835 L
.85838 .06244 L
.85838 .07835 L
.85844 .09426 L
.85851 .11016 L
.85856 .12607 L
.85856 .11016 L
Mistroke
.85856 .09426 L
.8586 .07835 L
.85861 .06244 L
.85864 .04653 L
.8587 .06244 L
.85872 .04653 L
.85878 .03062 L
.85905 .01472 L
.85918 .03062 L
.85918 .01472 L
.85978 .03062 L
.85981 .01472 L
.85993 .03062 L
.85997 .04653 L
.86001 .03062 L
.86001 .04653 L
.86002 .03062 L
.86012 .04653 L
.86014 .03062 L
.86014 .01472 L
.8602 .03062 L
.86025 .01472 L
.86027 .03062 L
.86028 .04653 L
.86049 .03062 L
.8605 .01472 L
.86073 .03062 L
.86076 .01472 L
.86086 .03062 L
.86088 .04653 L
.86095 .03062 L
.86099 .01472 L
.86101 .03062 L
.86104 .04653 L
.86109 .03062 L
.8611 .01472 L
.86134 .03062 L
.86157 .04653 L
.86164 .06244 L
.86164 .04653 L
.86167 .06244 L
.86192 .04653 L
.86195 .03062 L
.86196 .04653 L
.8621 .06244 L
.86215 .04653 L
.86226 .06244 L
.8623 .04653 L
.86239 .06244 L
.8624 .07835 L
Mistroke
.86247 .09426 L
.86251 .11016 L
.86255 .12607 L
.86259 .14198 L
.86264 .15789 L
.8627 .14198 L
.86279 .15789 L
.8628 .14198 L
.86281 .15789 L
.8629 .14198 L
.8629 .12607 L
.86293 .11016 L
.86298 .09426 L
.86299 .11016 L
.86301 .09426 L
.86304 .11016 L
.86304 .12607 L
.86307 .11016 L
.8631 .09426 L
.86313 .07835 L
.86313 .09426 L
.86317 .07835 L
.86322 .06244 L
.86327 .04653 L
.86339 .03062 L
.86348 .04653 L
.86348 .06244 L
.86351 .04653 L
.86359 .06244 L
.86361 .04653 L
.86366 .03062 L
.86369 .01472 L
.86373 .03062 L
.86374 .01472 L
.86376 .03062 L
.86381 .04653 L
.86387 .06244 L
.86389 .07835 L
.8639 .06244 L
.86399 .07835 L
.86405 .06244 L
.86411 .04653 L
.86416 .03062 L
.86416 .04653 L
.86417 .03062 L
.86425 .04653 L
.86427 .06244 L
.86437 .07835 L
.86438 .09426 L
.86447 .07835 L
Mistroke
.86451 .06244 L
.86453 .04653 L
.86463 .03062 L
.86473 .04653 L
.86476 .03062 L
.86477 .04653 L
.86481 .03062 L
.86488 .04653 L
.8649 .03062 L
.86498 .01472 L
.86521 .03062 L
.86523 .04653 L
.86535 .03062 L
.86536 .04653 L
.86536 .03062 L
.86541 .01472 L
.86543 .03062 L
.86566 .04653 L
.8657 .03062 L
.86575 .01472 L
.86594 .03062 L
.86601 .01472 L
.86605 .03062 L
.86607 .01472 L
.86609 .03062 L
.86617 .04653 L
.86621 .06244 L
.86624 .07835 L
.86628 .06244 L
.86633 .04653 L
.86634 .06244 L
.86637 .07835 L
.86638 .06244 L
.86643 .07835 L
.8665 .09426 L
.86653 .07835 L
.86669 .06244 L
.86669 .04653 L
.86675 .06244 L
.86682 .04653 L
.86684 .06244 L
.86689 .04653 L
.86704 .03062 L
.86705 .01472 L
.86722 .03062 L
.86725 .01472 L
.86746 .03062 L
.86757 .04653 L
.8676 .06244 L
.86764 .07835 L
Mistroke
.86765 .09426 L
.86766 .07835 L
.8677 .06244 L
.86775 .04653 L
.86776 .06244 L
.86792 .07835 L
.86794 .09426 L
.86794 .07835 L
.86797 .09426 L
.868 .11016 L
.86803 .09426 L
.86803 .07835 L
.86811 .09426 L
.86812 .07835 L
.86814 .09426 L
.86815 .07835 L
.86815 .06244 L
.8682 .04653 L
.86827 .06244 L
.86836 .07835 L
.86841 .06244 L
.86842 .07835 L
.86843 .06244 L
.86843 .04653 L
.86845 .06244 L
.86849 .07835 L
.86858 .09426 L
.86861 .07835 L
.86865 .09426 L
.86868 .07835 L
.8687 .09426 L
.86872 .11016 L
.86874 .12607 L
.86882 .14198 L
.86903 .15789 L
.86909 .14198 L
.86918 .15789 L
.86921 .1738 L
.86925 .18971 L
.86931 .1738 L
.86957 .15789 L
.8696 .14198 L
.86964 .15789 L
.86965 .1738 L
.86969 .18971 L
.86969 .1738 L
.86972 .15789 L
.86974 .14198 L
.86976 .15789 L
.86977 .14198 L
Mistroke
.87 .15789 L
.87004 .1738 L
.87009 .15789 L
.87012 .14198 L
.87013 .12607 L
.87017 .14198 L
.87027 .12607 L
.87028 .11016 L
.87032 .12607 L
.87046 .11016 L
.87047 .09426 L
.8705 .11016 L
.87055 .09426 L
.87061 .07835 L
.87064 .06244 L
.87067 .04653 L
.87095 .06244 L
.87104 .07835 L
.87113 .09426 L
.8712 .07835 L
.87122 .09426 L
.87123 .07835 L
.8713 .09426 L
.87132 .07835 L
.87132 .09426 L
.87133 .11016 L
.87134 .09426 L
.87137 .11016 L
.87148 .12607 L
.87152 .11016 L
.87153 .09426 L
.87157 .11016 L
.87183 .12607 L
.87195 .14198 L
.87197 .12607 L
.87222 .14198 L
.87223 .12607 L
.87223 .14198 L
.87227 .12607 L
.87227 .14198 L
.87232 .12607 L
.87233 .11016 L
.87235 .12607 L
.87235 .11016 L
.87235 .09426 L
.87248 .11016 L
.87251 .12607 L
.87252 .11016 L
.87257 .09426 L
.87263 .11016 L
Mistroke
.87266 .09426 L
.87273 .07835 L
.8728 .06244 L
.87287 .04653 L
.87294 .03062 L
.87296 .01472 L
.87298 .03062 L
.873 .01472 L
.87341 .03062 L
.87341 .01472 L
.87346 .03062 L
.87346 .04653 L
.87357 .06244 L
.87358 .07835 L
.87366 .09426 L
.87373 .07835 L
.87373 .06244 L
.87374 .04653 L
.8738 .06244 L
.87381 .07835 L
.87381 .09426 L
.87382 .07835 L
.87387 .06244 L
.87387 .04653 L
.87393 .06244 L
.87397 .07835 L
.87408 .06244 L
.87409 .07835 L
.87413 .09426 L
.87414 .07835 L
.87417 .09426 L
.87417 .07835 L
.8742 .09426 L
.87421 .07835 L
.87423 .06244 L
.87425 .04653 L
.87427 .03062 L
.8743 .01472 L
.8743 .03062 L
.87431 .01472 L
.87432 .03062 L
.87433 .04653 L
.87438 .06244 L
.87439 .07835 L
.87442 .06244 L
.87443 .07835 L
.87448 .09426 L
.87448 .11016 L
.87452 .09426 L
.87458 .11016 L
Mistroke
.87461 .09426 L
.87469 .11016 L
.87472 .12607 L
.87474 .11016 L
.87475 .09426 L
.87477 .11016 L
.8748 .09426 L
.87488 .11016 L
.8749 .12607 L
.87495 .11016 L
.87498 .09426 L
.87498 .11016 L
.87505 .09426 L
.87505 .07835 L
.87508 .06244 L
.87512 .07835 L
.87519 .09426 L
.87524 .11016 L
.87525 .12607 L
.87528 .11016 L
.8753 .12607 L
.87535 .14198 L
.87536 .12607 L
.87538 .11016 L
.87548 .12607 L
.87549 .14198 L
.87554 .15789 L
.87559 .1738 L
.87561 .18971 L
.87573 .1738 L
.87578 .15789 L
.87579 .1738 L
.87584 .18971 L
.87589 .20561 L
.87589 .22152 L
.87591 .23743 L
.87593 .22152 L
.876 .23743 L
.87615 .25334 L
.87632 .23743 L
.87635 .25334 L
.87646 .26925 L
.87652 .28515 L
.87655 .30106 L
.87658 .31697 L
.87663 .33288 L
.87682 .34879 L
.87683 .3647 L
.87701 .3806 L
.87713 .3647 L
Mistroke
.87717 .3806 L
.8772 .39651 L
.8772 .41242 L
.87724 .42833 L
.87724 .41242 L
.87728 .42833 L
.87729 .41242 L
.8774 .39651 L
.87741 .3806 L
.87749 .39651 L
.8775 .41242 L
.87755 .39651 L
.87758 .41242 L
.87762 .39651 L
.87769 .41242 L
.87769 .39651 L
.87776 .3806 L
.87778 .3647 L
.87782 .3806 L
.87788 .3647 L
.8779 .34879 L
.87791 .3647 L
.87801 .34879 L
.87806 .33288 L
.87809 .31697 L
.87811 .33288 L
.8782 .31697 L
.87821 .30106 L
.87826 .31697 L
.87836 .33288 L
.87845 .31697 L
.87851 .33288 L
.87853 .31697 L
.87854 .33288 L
.87856 .31697 L
.87857 .30106 L
.87859 .28515 L
.8786 .30106 L
.87863 .28515 L
.87863 .26925 L
.87864 .28515 L
.87868 .30106 L
.87872 .28515 L
.87879 .26925 L
.87882 .28515 L
.87884 .26925 L
.87894 .28515 L
.87894 .30106 L
.87895 .31697 L
.87897 .33288 L
Mistroke
.87899 .31697 L
.879 .33288 L
.87901 .31697 L
.87907 .33288 L
.87914 .34879 L
.87917 .3647 L
.87917 .3806 L
.87921 .3647 L
.8793 .34879 L
.87937 .33288 L
.8794 .34879 L
.87944 .33288 L
.87948 .31697 L
.8795 .30106 L
.8795 .31697 L
.87952 .33288 L
.87954 .31697 L
.87961 .30106 L
.87975 .28515 L
.87976 .26925 L
.87978 .28515 L
.87979 .30106 L
.87997 .31697 L
.8801 .30106 L
.88027 .31697 L
.8803 .30106 L
.8803 .28515 L
.88033 .26925 L
.88035 .28515 L
.88039 .26925 L
.8804 .28515 L
.88041 .30106 L
.88042 .31697 L
.88043 .33288 L
.88045 .34879 L
.8805 .33288 L
.8805 .34879 L
.88051 .3647 L
.88051 .34879 L
.88057 .3647 L
.88058 .34879 L
.8807 .33288 L
.88094 .34879 L
.88103 .3647 L
.88104 .3806 L
.88104 .39651 L
.88113 .41242 L
.88126 .39651 L
.8815 .3806 L
.88158 .39651 L
Mistroke
.88164 .41242 L
.88167 .39651 L
.88193 .41242 L
.88195 .42833 L
.88195 .41242 L
.88203 .42833 L
.88204 .44424 L
.88205 .46014 L
.88206 .47605 L
.88212 .49196 L
.88213 .50787 L
.88219 .52378 L
.88223 .50787 L
.88225 .52378 L
.88231 .53969 L
.88232 .55559 L
.88238 .5715 L
.88241 .55559 L
.88252 .53969 L
.88256 .52378 L
.88258 .53969 L
.88283 .55559 L
.88295 .53969 L
.88297 .52378 L
.88298 .53969 L
.88303 .52378 L
.88309 .50787 L
.88314 .49196 L
.88314 .50787 L
.88321 .49196 L
.88325 .50787 L
.88329 .52378 L
.88329 .50787 L
.88336 .49196 L
.88337 .50787 L
.88346 .49196 L
.88356 .47605 L
.88359 .49196 L
.8836 .50787 L
.88365 .52378 L
.88365 .53969 L
.88382 .52378 L
.88386 .50787 L
.88397 .52378 L
.88398 .53969 L
.88399 .55559 L
.88403 .5715 L
.88405 .58741 L
.88415 .5715 L
.88415 .58741 L
Mistroke
.88415 .5715 L
.88421 .55559 L
.8843 .53969 L
.8843 .52378 L
.88431 .50787 L
.88436 .49196 L
.88436 .50787 L
.88437 .52378 L
.88441 .50787 L
.88454 .49196 L
.88468 .47605 L
.88482 .49196 L
.88482 .50787 L
.88483 .49196 L
.88488 .47605 L
.8849 .49196 L
.88505 .47605 L
.88509 .46014 L
.88512 .44424 L
.88524 .42833 L
.88528 .41242 L
.88537 .39651 L
.88538 .41242 L
.88546 .42833 L
.88557 .41242 L
.88559 .39651 L
.8856 .3806 L
.88564 .3647 L
.88565 .3806 L
.88567 .3647 L
.88573 .3806 L
.8858 .39651 L
.88583 .41242 L
.88589 .39651 L
.88594 .3806 L
.88602 .3647 L
.88602 .3806 L
.88603 .3647 L
.88608 .3806 L
.88617 .3647 L
.88622 .3806 L
.88628 .39651 L
.8863 .3806 L
.88632 .3647 L
.88642 .3806 L
.8865 .3647 L
.88664 .3806 L
.88679 .39651 L
.88681 .3806 L
.88683 .39651 L
Mistroke
.88693 .3806 L
.887 .3647 L
.88705 .34879 L
.88707 .3647 L
.88715 .34879 L
.88722 .3647 L
.88726 .3806 L
.88732 .39651 L
.88739 .41242 L
.8874 .42833 L
.88753 .44424 L
.88753 .42833 L
.88754 .41242 L
.88762 .42833 L
.88774 .41242 L
.88777 .39651 L
.88778 .3806 L
.88779 .3647 L
.88781 .34879 L
.88783 .33288 L
.88789 .31697 L
.88794 .33288 L
.88796 .31697 L
.88797 .30106 L
.88806 .31697 L
.88807 .33288 L
.88812 .34879 L
.88815 .3647 L
.88817 .34879 L
.88818 .33288 L
.88823 .34879 L
.88832 .33288 L
.88834 .31697 L
.8884 .30106 L
.8884 .28515 L
.88842 .30106 L
.88843 .31697 L
.88844 .30106 L
.88847 .31697 L
.88848 .33288 L
.88857 .34879 L
.88859 .33288 L
.88861 .31697 L
.88863 .33288 L
.88864 .31697 L
.88872 .33288 L
.88873 .31697 L
.88876 .30106 L
.88886 .28515 L
.88887 .30106 L
Mistroke
.88889 .28515 L
.88892 .30106 L
.88897 .31697 L
.88899 .33288 L
.8891 .31697 L
.8891 .30106 L
.88914 .28515 L
.88917 .30106 L
.8892 .31697 L
.88933 .33288 L
.88961 .31697 L
.88961 .30106 L
.88963 .28515 L
.88966 .30106 L
.88976 .31697 L
.88978 .30106 L
.88981 .31697 L
.88983 .33288 L
.88995 .31697 L
.88996 .33288 L
.88996 .31697 L
.89001 .33288 L
.89004 .31697 L
.89004 .33288 L
.89004 .34879 L
.89005 .3647 L
.89007 .3806 L
.8901 .3647 L
.89014 .34879 L
.89021 .33288 L
.89022 .34879 L
.89024 .33288 L
.89026 .31697 L
.89027 .33288 L
.89029 .31697 L
.89031 .30106 L
.89032 .28515 L
.89035 .26925 L
.89038 .25334 L
.89039 .23743 L
.89044 .25334 L
.8905 .23743 L
.89058 .25334 L
.89058 .23743 L
.89062 .22152 L
.89063 .20561 L
.89063 .18971 L
.89064 .20561 L
.89071 .22152 L
.89082 .20561 L
Mistroke
.89083 .22152 L
.89085 .23743 L
.8909 .25334 L
.89091 .26925 L
.89092 .25334 L
.89095 .26925 L
.89104 .25334 L
.89111 .23743 L
.89116 .22152 L
.89119 .20561 L
.89122 .18971 L
.89124 .20561 L
.8913 .18971 L
.89131 .20561 L
.89138 .22152 L
.89139 .20561 L
.89142 .18971 L
.8915 .1738 L
.8915 .18971 L
.89152 .1738 L
.89162 .15789 L
.89164 .1738 L
.89167 .18971 L
.89169 .1738 L
.89169 .18971 L
.89176 .20561 L
.89177 .22152 L
.89177 .23743 L
.892 .22152 L
.8921 .23743 L
.89223 .22152 L
.89224 .23743 L
.89224 .25334 L
.89227 .26925 L
.8923 .25334 L
.89233 .26925 L
.89239 .25334 L
.8924 .26925 L
.89241 .25334 L
.89242 .23743 L
.8925 .22152 L
.89252 .23743 L
.89256 .25334 L
.89262 .26925 L
.89263 .25334 L
.89263 .23743 L
.8927 .22152 L
.89274 .20561 L
.89274 .18971 L
.89276 .20561 L
Mistroke
.89278 .18971 L
.89279 .1738 L
.89281 .18971 L
.89292 .1738 L
.89293 .18971 L
.89298 .1738 L
.89298 .18971 L
.89304 .1738 L
.89309 .15789 L
.89324 .1738 L
.89328 .15789 L
.89329 .1738 L
.89338 .15789 L
.89341 .1738 L
.89355 .15789 L
.89356 .14198 L
.89363 .12607 L
.89364 .11016 L
.89366 .09426 L
.89368 .11016 L
.8937 .12607 L
.89372 .14198 L
.89392 .12607 L
.89393 .14198 L
.89397 .12607 L
.89402 .11016 L
.89405 .12607 L
.89406 .14198 L
.8941 .15789 L
.89415 .1738 L
.89425 .15789 L
.89433 .1738 L
.89439 .18971 L
.89445 .20561 L
.89459 .22152 L
.89466 .23743 L
.89471 .22152 L
.89472 .20561 L
.89474 .22152 L
.89475 .20561 L
.89477 .18971 L
.89477 .20561 L
.89478 .18971 L
.89487 .1738 L
.89488 .15789 L
.89489 .1738 L
.89493 .15789 L
.89494 .14198 L
.89497 .15789 L
.89506 .1738 L
Mistroke
.89509 .18971 L
.8951 .20561 L
.89515 .22152 L
.89526 .20561 L
.89526 .22152 L
.89537 .20561 L
.89538 .18971 L
.89549 .1738 L
.89549 .15789 L
.89553 .14198 L
.89561 .15789 L
.89568 .14198 L
.8957 .12607 L
.89572 .11016 L
.89573 .09426 L
.89583 .11016 L
.89587 .09426 L
.8959 .11016 L
.89593 .12607 L
.89596 .14198 L
.89604 .15789 L
.89609 .14198 L
.89615 .15789 L
.89623 .14198 L
.89625 .12607 L
.89638 .11016 L
.89644 .09426 L
.89651 .11016 L
.89656 .12607 L
.89656 .11016 L
.89657 .09426 L
.89671 .11016 L
.89672 .12607 L
.89673 .14198 L
.89673 .15789 L
.89675 .1738 L
.89682 .15789 L
.89683 .1738 L
.89699 .15789 L
.89706 .1738 L
.8971 .18971 L
.8971 .1738 L
.89714 .18971 L
.89723 .1738 L
.89724 .18971 L
.89728 .20561 L
.89731 .22152 L
.89738 .23743 L
.8974 .25334 L
.89746 .26925 L
Mistroke
.89747 .28515 L
.89749 .26925 L
.8975 .28515 L
.89758 .30106 L
.89762 .31697 L
.89764 .33288 L
.89765 .34879 L
.89765 .33288 L
.89767 .31697 L
.89773 .33288 L
.89776 .31697 L
.8978 .30106 L
.89781 .28515 L
.89783 .30106 L
.89787 .31697 L
.89788 .33288 L
.89789 .31697 L
.89789 .33288 L
.8979 .31697 L
.89799 .30106 L
.898 .31697 L
.89801 .30106 L
.89823 .28515 L
.89828 .26925 L
.89841 .28515 L
.89846 .30106 L
.89852 .31697 L
.89853 .33288 L
.89854 .34879 L
.89855 .3647 L
.89857 .34879 L
.89864 .3647 L
.89866 .34879 L
.8987 .3647 L
.89873 .3806 L
.89877 .39651 L
.89878 .41242 L
.89881 .39651 L
.89888 .41242 L
.8989 .42833 L
.89892 .44424 L
.89905 .46014 L
.89906 .47605 L
.89911 .46014 L
.89914 .47605 L
.89915 .49196 L
.89916 .47605 L
.8993 .46014 L
.89945 .47605 L
.89947 .46014 L
Mistroke
.89953 .47605 L
.89959 .46014 L
.89961 .44424 L
.89964 .46014 L
.89967 .44424 L
.89967 .46014 L
.89969 .44424 L
.8997 .42833 L
.89973 .41242 L
.89974 .42833 L
.89978 .41242 L
.89983 .42833 L
.89984 .41242 L
.89988 .42833 L
.89989 .41242 L
.8999 .39651 L
.89993 .41242 L
.89999 .39651 L
.9 .3806 L
.90002 .39651 L
.90005 .41242 L
.90005 .42833 L
.90008 .44424 L
.90009 .46014 L
.9002 .47605 L
.90024 .46014 L
.90025 .47605 L
.9003 .49196 L
.90051 .50787 L
.90052 .49196 L
.90057 .47605 L
.90066 .49196 L
.90067 .47605 L
.90071 .46014 L
.90073 .47605 L
.90075 .46014 L
.90078 .47605 L
.901 .49196 L
.90101 .50787 L
.90103 .49196 L
.9012 .50787 L
.90121 .49196 L
.90127 .47605 L
.90136 .49196 L
.90142 .47605 L
.90151 .49196 L
.90152 .50787 L
.90156 .52378 L
.90158 .50787 L
.90168 .49196 L
Mistroke
.90169 .50787 L
.90175 .52378 L
.90188 .50787 L
.90199 .49196 L
.90199 .50787 L
.90205 .49196 L
.90205 .47605 L
.90206 .46014 L
.90215 .44424 L
.90216 .42833 L
.90231 .41242 L
.90232 .42833 L
.90239 .44424 L
.90239 .42833 L
.9024 .44424 L
.90245 .46014 L
.90247 .47605 L
.90256 .49196 L
.90261 .50787 L
.90267 .52378 L
.90268 .53969 L
.9027 .52378 L
.9028 .53969 L
.90283 .52378 L
.90286 .50787 L
.90289 .52378 L
.90304 .50787 L
.90305 .52378 L
.90312 .50787 L
.90314 .52378 L
.90316 .50787 L
.90317 .52378 L
.90323 .50787 L
.90324 .52378 L
.90327 .50787 L
.90343 .52378 L
.90345 .50787 L
.90347 .52378 L
.90347 .50787 L
.90348 .49196 L
.9035 .50787 L
.90355 .49196 L
.90356 .47605 L
.90371 .46014 L
.90373 .47605 L
.90385 .46014 L
.90389 .47605 L
.90407 .49196 L
.90408 .50787 L
.90408 .49196 L
Mistroke
.9041 .47605 L
.90411 .49196 L
.90413 .50787 L
.90417 .49196 L
.90424 .50787 L
.90426 .49196 L
.90428 .47605 L
.90441 .46014 L
.90456 .47605 L
.90457 .49196 L
.90459 .50787 L
.90472 .52378 L
.90484 .50787 L
.9049 .52378 L
.90494 .50787 L
.90499 .49196 L
.90507 .47605 L
.90508 .49196 L
.90509 .50787 L
.90515 .49196 L
.90529 .47605 L
.90538 .46014 L
.90546 .44424 L
.90547 .42833 L
.90569 .44424 L
.90571 .42833 L
.90593 .41242 L
.90595 .39651 L
.90607 .41242 L
.90619 .39651 L
.90619 .41242 L
.90624 .39651 L
.9063 .3806 L
.90631 .39651 L
.90632 .41242 L
.90646 .42833 L
.90647 .41242 L
.90671 .39651 L
.90671 .3806 L
.90674 .3647 L
.90677 .3806 L
.90679 .3647 L
.90681 .34879 L
.90687 .33288 L
.90687 .34879 L
.90689 .33288 L
.90689 .34879 L
.90693 .33288 L
.90696 .31697 L
.90705 .33288 L
Mistroke
.90709 .34879 L
.90716 .33288 L
.90722 .34879 L
.90726 .3647 L
.90729 .34879 L
.90729 .33288 L
.90741 .34879 L
.90744 .33288 L
.90744 .31697 L
.9075 .33288 L
.9075 .34879 L
.9075 .33288 L
.90757 .31697 L
.90758 .33288 L
.90761 .34879 L
.90762 .33288 L
.90762 .31697 L
.90763 .30106 L
.9077 .31697 L
.90773 .30106 L
.90779 .31697 L
.90784 .33288 L
.90792 .31697 L
.90802 .33288 L
.90802 .34879 L
.90803 .3647 L
.90804 .34879 L
.90805 .33288 L
.90814 .34879 L
.90816 .33288 L
.90817 .34879 L
.90818 .3647 L
.90819 .34879 L
.90821 .3647 L
.90827 .3806 L
.9083 .3647 L
.90843 .34879 L
.90845 .33288 L
.90849 .31697 L
.9085 .30106 L
.90852 .28515 L
.90857 .26925 L
.90861 .25334 L
.90865 .26925 L
.90871 .25334 L
.90873 .23743 L
.90888 .25334 L
.90892 .26925 L
.90899 .28515 L
.90905 .30106 L
Mistroke
.90911 .28515 L
.90911 .30106 L
.90917 .31697 L
.9093 .30106 L
.90932 .31697 L
.90933 .30106 L
.90933 .31697 L
.90934 .30106 L
.90935 .28515 L
.90946 .26925 L
.90946 .28515 L
.90963 .30106 L
.90966 .31697 L
.90984 .33288 L
.90985 .31697 L
.90988 .33288 L
.90992 .31697 L
.90995 .33288 L
.90998 .31697 L
.91 .30106 L
.91011 .31697 L
.91011 .33288 L
.91015 .31697 L
.91015 .33288 L
.91024 .34879 L
.91031 .3647 L
.91037 .3806 L
.9105 .3647 L
.91051 .3806 L
.91062 .39651 L
.91065 .3806 L
.91066 .3647 L
.91069 .3806 L
.91073 .3647 L
.91085 .3806 L
.91087 .39651 L
.91091 .41242 L
.91095 .42833 L
.91099 .44424 L
.91099 .46014 L
.9111 .47605 L
.91115 .46014 L
.91117 .47605 L
.91119 .49196 L
.9112 .47605 L
.91122 .46014 L
.91128 .44424 L
.91132 .46014 L
.91139 .47605 L
.9114 .46014 L
Mistroke
.91142 .47605 L
.91154 .49196 L
.91154 .50787 L
.91159 .52378 L
.91162 .50787 L
.91169 .52378 L
.9117 .50787 L
.9117 .52378 L
.91171 .50787 L
.91178 .49196 L
.91179 .50787 L
.91181 .49196 L
.91184 .50787 L
.91186 .52378 L
.91187 .50787 L
.91188 .52378 L
.91192 .53969 L
.91197 .52378 L
.91203 .53969 L
.91204 .52378 L
.91205 .53969 L
.91206 .52378 L
.91209 .50787 L
.91223 .49196 L
.91229 .47605 L
.91236 .49196 L
.91237 .50787 L
.91245 .52378 L
.91248 .50787 L
.91251 .52378 L
.91257 .53969 L
.91268 .52378 L
.91274 .53969 L
.91275 .55559 L
.91281 .53969 L
.91284 .52378 L
.91287 .53969 L
.91291 .52378 L
.91305 .50787 L
.91305 .52378 L
.91309 .53969 L
.91311 .55559 L
.91313 .5715 L
.91315 .58741 L
.91316 .60332 L
.91321 .58741 L
.91324 .5715 L
.91326 .58741 L
.91331 .5715 L
.91332 .55559 L
Mistroke
.91335 .5715 L
.91337 .58741 L
.91344 .5715 L
.91351 .58741 L
.91351 .5715 L
.91352 .58741 L
.91353 .60332 L
Mfstroke
.91356 .61803 m
.91353 .60332 L
s
s
s
s
s
s
s
.9138 .61803 m
.91384 .60332 L
s
.91384 .60332 m
.91391 .58741 L
.91398 .5715 L
.91399 .58741 L
.91404 .60332 L
s
.91407 .61803 m
.91404 .60332 L
s
.91407 .61803 m
.91409 .60332 L
s
.91409 .60332 m
.91412 .58741 L
.91413 .5715 L
.91415 .55559 L
.91419 .53969 L
.91422 .55559 L
.91423 .5715 L
.91424 .58741 L
.91429 .5715 L
.91435 .55559 L
.91452 .5715 L
.91487 .55559 L
.91491 .53969 L
.91497 .55559 L
.915 .53969 L
.91508 .55559 L
.91511 .5715 L
.91516 .55559 L
.91517 .53969 L
.91518 .52378 L
.91518 .53969 L
.91531 .52378 L
.91531 .50787 L
.91535 .52378 L
.91537 .50787 L
.91543 .52378 L
.91546 .50787 L
.91548 .52378 L
.91552 .53969 L
.91561 .55559 L
.91563 .53969 L
.91564 .55559 L
.91565 .53969 L
.91572 .55559 L
.91575 .5715 L
.91581 .55559 L
.91583 .5715 L
.91593 .58741 L
.91595 .5715 L
.91596 .58741 L
.91597 .5715 L
.91597 .58741 L
.91603 .60332 L
s
.91609 .61803 m
.91603 .60332 L
s
s
s
s
s
s
s
.91636 .61803 m
.9164 .60332 L
s
.9164 .60332 m
0 0 rlineto
.91644 .61803 m
.9164 .60332 L
s
.91645 .61803 m
.91652 .60332 L
s
.91652 .60332 m
0 0 rlineto
.91662 .61803 m
.91652 .60332 L
s
.91664 .61803 m
.91672 .60332 L
s
.91672 .60332 m
0 0 rlineto
.91673 .61803 m
.91672 .60332 L
s
.91673 .61803 m
.91673 .60332 L
s
.91673 .60332 m
.91674 .58741 L
.91676 .60332 L
s
.91677 .61803 m
.91676 .60332 L
s
.91678 .61803 m
.91696 .60332 L
s
.91696 .60332 m
.91698 .58741 L
.91699 .5715 L
.91728 .55559 L
.9173 .53969 L
.91733 .55559 L
.91743 .53969 L
.91748 .52378 L
.91752 .50787 L
.91757 .52378 L
.91761 .50787 L
.91764 .52378 L
.91767 .50787 L
.91769 .52378 L
.91774 .50787 L
.91776 .52378 L
.91778 .53969 L
.91778 .52378 L
.91779 .53969 L
.91782 .55559 L
.91784 .5715 L
.91787 .55559 L
.91789 .53969 L
.91794 .55559 L
.91795 .53969 L
.91797 .52378 L
.918 .50787 L
.91806 .49196 L
.91818 .50787 L
.91823 .49196 L
.91824 .47605 L
.91826 .46014 L
.91828 .47605 L
.91835 .46014 L
.91845 .44424 L
.91847 .42833 L
.91847 .41242 L
.91847 .39651 L
.91853 .41242 L
.91854 .39651 L
.91864 .41242 L
.91867 .39651 L
.91869 .41242 L
.91869 .39651 L
.91872 .3806 L
.91872 .39651 L
.91876 .3806 L
.91878 .3647 L
.9188 .34879 L
.91886 .33288 L
Mistroke
.91893 .31697 L
.91893 .33288 L
.91894 .34879 L
.91896 .33288 L
.91901 .31697 L
.91904 .30106 L
.91911 .31697 L
.91925 .33288 L
.91929 .31697 L
.91934 .33288 L
.91935 .31697 L
.91936 .33288 L
.91946 .31697 L
.91947 .33288 L
.91948 .31697 L
.91951 .30106 L
.91952 .28515 L
.91953 .26925 L
.91955 .28515 L
.91959 .26925 L
.91968 .25334 L
.91969 .26925 L
.9197 .25334 L
.91971 .23743 L
.91985 .25334 L
.91989 .23743 L
.9199 .25334 L
.91992 .23743 L
.91995 .22152 L
.91997 .23743 L
.92002 .22152 L
.92003 .20561 L
.92004 .22152 L
.92005 .20561 L
.92006 .18971 L
.92007 .1738 L
.9201 .18971 L
.92014 .1738 L
.92019 .15789 L
.9202 .1738 L
.92024 .15789 L
.92026 .14198 L
.92031 .15789 L
.92032 .1738 L
.92033 .15789 L
.92033 .14198 L
.92034 .12607 L
.92039 .14198 L
.9204 .12607 L
.92041 .11016 L
Mistroke
.92043 .09426 L
.92043 .11016 L
.92043 .12607 L
.92051 .14198 L
.92053 .15789 L
.92055 .1738 L
.92065 .18971 L
.92076 .20561 L
.92078 .22152 L
.92079 .23743 L
.92084 .22152 L
.92085 .23743 L
.92086 .22152 L
.9209 .20561 L
.92102 .18971 L
.92102 .1738 L
.92108 .15789 L
.92114 .14198 L
.9212 .12607 L
.92123 .11016 L
.92123 .09426 L
.92124 .11016 L
.92125 .09426 L
.92138 .07835 L
.9214 .06244 L
.92148 .04653 L
.92153 .06244 L
.92163 .07835 L
.92163 .06244 L
.92179 .04653 L
.92189 .06244 L
.92189 .07835 L
.92194 .06244 L
.92198 .04653 L
.92201 .03062 L
.92203 .04653 L
.92217 .03062 L
.92218 .01472 L
.92224 .03062 L
.92225 .04653 L
.92227 .06244 L
.92239 .04653 L
.9225 .06244 L
.92252 .07835 L
.92254 .06244 L
.92255 .04653 L
.92257 .06244 L
.92259 .07835 L
.92262 .06244 L
.92264 .07835 L
Mistroke
.92268 .06244 L
.92272 .07835 L
.92279 .09426 L
.92279 .07835 L
.92285 .09426 L
.92288 .07835 L
.923 .09426 L
.92308 .11016 L
.92309 .09426 L
.92313 .07835 L
.92319 .09426 L
.9232 .07835 L
.92323 .09426 L
.92325 .07835 L
.92331 .06244 L
.92338 .07835 L
.9234 .09426 L
.9234 .07835 L
.92344 .09426 L
.92344 .11016 L
.92351 .09426 L
.92358 .07835 L
.92359 .06244 L
.9236 .04653 L
.92364 .03062 L
.92366 .04653 L
.92369 .03062 L
.92372 .04653 L
.92375 .03062 L
.92376 .01472 L
.92377 .03062 L
.92397 .01472 L
.92409 .03062 L
.92418 .04653 L
.92418 .03062 L
.92422 .01472 L
.92422 .03062 L
.92422 .01472 L
.92448 .03062 L
.92459 .01472 L
.92499 .03062 L
.925 .04653 L
.92503 .03062 L
.92511 .01472 L
.92515 .03062 L
.92519 .01472 L
.9253 .03062 L
.92533 .01472 L
.92545 .03062 L
.92563 .01472 L
Mistroke
.92567 .03062 L
.92571 .04653 L
.92577 .06244 L
.92579 .04653 L
.92582 .06244 L
.92591 .04653 L
.92603 .06244 L
.92603 .07835 L
.92607 .06244 L
.92608 .04653 L
.92613 .03062 L
.92614 .01472 L
.92635 .03062 L
.92635 .04653 L
.92646 .03062 L
.9265 .04653 L
.92653 .06244 L
.92653 .07835 L
.92656 .06244 L
.92657 .04653 L
.92658 .06244 L
.92659 .07835 L
.9266 .09426 L
.92661 .07835 L
.92669 .09426 L
.9268 .11016 L
.92683 .09426 L
.92688 .07835 L
.9269 .06244 L
.92692 .07835 L
.92701 .06244 L
.92703 .07835 L
.92705 .06244 L
.92714 .04653 L
.92716 .06244 L
.92727 .07835 L
.92731 .06244 L
.92738 .04653 L
.92739 .03062 L
.92755 .04653 L
.92757 .03062 L
.92761 .04653 L
.92788 .06244 L
.92788 .07835 L
.92794 .06244 L
.92801 .04653 L
.92801 .03062 L
.92802 .01472 L
.92805 .03062 L
.92826 .01472 L
Mistroke
.92839 .03062 L
.92841 .04653 L
.92842 .03062 L
.92844 .04653 L
.9285 .03062 L
.92851 .04653 L
.92859 .03062 L
.9286 .04653 L
.92871 .03062 L
.92872 .01472 L
.92873 .03062 L
.92882 .01472 L
.92896 .03062 L
.92898 .01472 L
.92912 .03062 L
.92917 .04653 L
.92921 .03062 L
.92931 .01472 L
.92937 .03062 L
.92942 .04653 L
.92943 .06244 L
.92945 .04653 L
.92948 .06244 L
.92954 .04653 L
.92963 .03062 L
.92964 .04653 L
.92966 .06244 L
.92967 .04653 L
.92967 .03062 L
.92969 .04653 L
.92977 .06244 L
.92977 .04653 L
.92981 .03062 L
.92985 .04653 L
.92988 .03062 L
.92995 .04653 L
.92999 .03062 L
.93003 .01472 L
.93007 .03062 L
.93008 .01472 L
.9301 .03062 L
.9302 .01472 L
.93028 .03062 L
.93034 .01472 L
.93045 .03062 L
.93045 .01472 L
.9306 .03062 L
.93065 .04653 L
.93076 .03062 L
.93086 .01472 L
Mistroke
.93105 .03062 L
.93108 .04653 L
.93118 .06244 L
.93118 .04653 L
.9313 .06244 L
.93131 .07835 L
.93132 .09426 L
.93136 .11016 L
.93153 .09426 L
.93155 .11016 L
.93158 .09426 L
.93162 .11016 L
.93162 .12607 L
.93163 .11016 L
.93174 .12607 L
.93177 .11016 L
.93177 .09426 L
.93183 .11016 L
.93189 .09426 L
.93192 .07835 L
.93194 .06244 L
.93196 .07835 L
.93197 .06244 L
.932 .07835 L
.93201 .09426 L
.93202 .07835 L
.9321 .06244 L
.93211 .07835 L
.93218 .06244 L
.93227 .04653 L
.93228 .03062 L
.9323 .01472 L
.93238 .03062 L
.93242 .01472 L
.93247 .03062 L
.93249 .01472 L
.93255 .03062 L
.93262 .01472 L
.93267 .03062 L
.93268 .04653 L
.93279 .06244 L
.93283 .07835 L
.93284 .09426 L
.9329 .07835 L
.93292 .09426 L
.93293 .07835 L
.93302 .06244 L
.93304 .07835 L
.93311 .09426 L
.93312 .11016 L
Mistroke
.9332 .12607 L
.93323 .11016 L
.93323 .09426 L
.93326 .07835 L
.93326 .09426 L
.93327 .11016 L
.93331 .09426 L
.93332 .07835 L
.93334 .06244 L
.93339 .07835 L
.9335 .06244 L
.93374 .04653 L
.93377 .03062 L
.93377 .01472 L
.93387 .03062 L
.93387 .04653 L
.93397 .06244 L
.93414 .04653 L
.93418 .03062 L
.93419 .01472 L
.93425 .03062 L
.93426 .04653 L
.93429 .06244 L
.93429 .04653 L
.93436 .06244 L
.93438 .07835 L
.93441 .06244 L
.93462 .04653 L
.93467 .06244 L
.93469 .04653 L
.93479 .06244 L
.93481 .04653 L
.93493 .03062 L
.93503 .04653 L
.93506 .03062 L
.93512 .01472 L
.93571 .03062 L
.93585 .01472 L
.93596 .03062 L
.93602 .01472 L
.93632 .03062 L
.93635 .04653 L
.93636 .06244 L
.93637 .04653 L
.93637 .06244 L
.93642 .04653 L
.93643 .03062 L
.93652 .04653 L
.93654 .03062 L
.93655 .01472 L
Mistroke
.93662 .03062 L
.93663 .01472 L
.93671 .03062 L
.93676 .01472 L
.93682 .03062 L
.93686 .01472 L
.93702 .03062 L
.93712 .01472 L
.93716 .03062 L
.93736 .01472 L
.93737 .03062 L
.93755 .04653 L
.93755 .03062 L
.93759 .01472 L
.93777 .03062 L
.93782 .01472 L
.93785 .03062 L
.93805 .04653 L
.93808 .03062 L
.9381 .04653 L
.93811 .06244 L
.93812 .04653 L
.93815 .03062 L
.93817 .01472 L
.93825 .03062 L
.93826 .01472 L
.93831 .03062 L
.93832 .04653 L
.93841 .06244 L
.93842 .04653 L
.93844 .06244 L
.93855 .04653 L
.93855 .03062 L
.93856 .04653 L
.93862 .06244 L
.93872 .04653 L
.93874 .03062 L
.93878 .04653 L
.9388 .03062 L
.93891 .01472 L
.93897 .03062 L
.93904 .01472 L
.93924 .03062 L
.93928 .01472 L
.9393 .03062 L
.93933 .01472 L
.93948 .03062 L
.9395 .01472 L
.93959 .03062 L
.93961 .01472 L
Mistroke
.93964 .03062 L
.93969 .01472 L
.93973 .03062 L
.93978 .01472 L
.93987 .03062 L
.93991 .04653 L
.93991 .03062 L
.93991 .04653 L
.93999 .03062 L
.94 .01472 L
.94009 .03062 L
.9401 .01472 L
.94012 .03062 L
.94017 .01472 L
.94045 .03062 L
.94049 .04653 L
.94052 .03062 L
.94053 .01472 L
.94056 .03062 L
.94058 .01472 L
.94062 .03062 L
.94079 .04653 L
.9408 .06244 L
.94082 .07835 L
.94085 .09426 L
.94089 .07835 L
.94089 .06244 L
.94095 .04653 L
.94104 .03062 L
.94105 .01472 L
.94112 .03062 L
.94113 .01472 L
.94115 .03062 L
.94116 .04653 L
.94145 .06244 L
.94146 .04653 L
.94147 .06244 L
.94156 .07835 L
.94166 .09426 L
.94167 .11016 L
.94173 .09426 L
.94179 .07835 L
.94182 .09426 L
.94183 .11016 L
.94183 .09426 L
.94187 .07835 L
.94189 .06244 L
.9419 .07835 L
.94194 .06244 L
.94195 .04653 L
Mistroke
.94207 .06244 L
.94216 .07835 L
.94216 .06244 L
.94221 .04653 L
.94224 .06244 L
.94231 .07835 L
.94234 .06244 L
.94238 .04653 L
.94241 .06244 L
.94245 .07835 L
.94245 .09426 L
.94252 .07835 L
.94257 .06244 L
.94259 .07835 L
.9426 .06244 L
.9426 .04653 L
.94276 .06244 L
.94279 .04653 L
.943 .03062 L
.94305 .01472 L
.94309 .03062 L
.94322 .04653 L
.94324 .03062 L
.94327 .04653 L
.94331 .03062 L
.94334 .01472 L
.94349 .03062 L
.94362 .01472 L
.94366 .03062 L
.94369 .04653 L
.94373 .06244 L
.94383 .07835 L
.94389 .06244 L
.94413 .07835 L
.94423 .09426 L
.94425 .11016 L
.94427 .09426 L
.94433 .07835 L
.9444 .09426 L
.94443 .11016 L
.94444 .09426 L
.94444 .11016 L
.94448 .09426 L
.9446 .11016 L
.94462 .12607 L
.94463 .11016 L
.94469 .09426 L
.94473 .07835 L
.94483 .06244 L
.945 .04653 L
Mistroke
.94503 .06244 L
.94503 .04653 L
.94504 .03062 L
.94508 .01472 L
.94523 .03062 L
.94524 .01472 L
.94533 .03062 L
.94536 .04653 L
.94547 .06244 L
.94555 .04653 L
.94556 .06244 L
.94559 .04653 L
.94563 .06244 L
.94565 .04653 L
.94572 .03062 L
.94572 .01472 L
.94577 .03062 L
.94579 .01472 L
.9458 .03062 L
.94584 .01472 L
.94592 .03062 L
.94595 .01472 L
.94598 .03062 L
.94598 .01472 L
.94605 .03062 L
.94607 .01472 L
.94611 .03062 L
.9462 .01472 L
.94621 .03062 L
.94622 .01472 L
.94636 .03062 L
.94641 .04653 L
.94642 .06244 L
.94648 .04653 L
.94658 .06244 L
.9466 .04653 L
.94662 .03062 L
.94664 .01472 L
.94667 .03062 L
.94667 .04653 L
.94669 .03062 L
.94669 .01472 L
.94671 .03062 L
.94675 .04653 L
.94687 .03062 L
.94697 .04653 L
.94698 .03062 L
.94711 .04653 L
.94712 .03062 L
.94717 .04653 L
Mistroke
.94718 .03062 L
.94718 .04653 L
.94719 .03062 L
.94723 .01472 L
.94728 .03062 L
.94732 .01472 L
.9474 .03062 L
.94747 .04653 L
.94748 .03062 L
.9475 .01472 L
.9477 .03062 L
.94774 .01472 L
.94796 .03062 L
.94816 .04653 L
.94818 .03062 L
.94822 .01472 L
.94825 .03062 L
.94825 .01472 L
.94833 .03062 L
.94842 .01472 L
.94844 .03062 L
.94847 .01472 L
.94858 .03062 L
.9486 .01472 L
.94861 .03062 L
.94863 .01472 L
.94871 .03062 L
.9488 .04653 L
.94884 .03062 L
.94899 .01472 L
.94903 .03062 L
.94904 .04653 L
.94904 .06244 L
.94905 .04653 L
.94906 .06244 L
.94907 .07835 L
.94915 .09426 L
.94915 .07835 L
.94923 .09426 L
.94927 .07835 L
.9494 .06244 L
.94941 .07835 L
.94944 .06244 L
.94954 .04653 L
.94957 .06244 L
.94964 .04653 L
.94965 .06244 L
.94967 .07835 L
.94968 .06244 L
.94974 .04653 L
Mistroke
.94976 .03062 L
.94987 .01472 L
.94997 .03062 L
.95 .04653 L
.95001 .03062 L
.95008 .01472 L
.95019 .03062 L
.95022 .04653 L
.95029 .03062 L
.95033 .04653 L
.95034 .06244 L
.95036 .07835 L
.95042 .06244 L
.95044 .07835 L
.95047 .09426 L
.9506 .11016 L
.95063 .09426 L
.95068 .07835 L
.9507 .06244 L
.95072 .07835 L
.9508 .09426 L
.95082 .07835 L
.95093 .09426 L
.95097 .11016 L
.95097 .09426 L
.951 .07835 L
.95108 .06244 L
.95115 .04653 L
.95117 .06244 L
.95117 .04653 L
.95117 .06244 L
.95119 .07835 L
.95148 .09426 L
.95148 .11016 L
.95153 .12607 L
.95163 .11016 L
.95165 .12607 L
.9517 .11016 L
.95172 .09426 L
.95175 .11016 L
.95175 .12607 L
.95176 .14198 L
.95179 .15789 L
.9518 .14198 L
.95192 .15789 L
.95193 .14198 L
.95197 .15789 L
.95198 .14198 L
.95198 .12607 L
.95206 .11016 L
Mistroke
.95207 .12607 L
.9521 .14198 L
.95219 .12607 L
.95221 .14198 L
.95224 .15789 L
.95227 .1738 L
.95234 .18971 L
.95244 .20561 L
.95249 .18971 L
.9525 .20561 L
.95251 .18971 L
.95259 .20561 L
.9526 .22152 L
.95263 .20561 L
.95265 .18971 L
.95267 .1738 L
.95268 .15789 L
.95275 .14198 L
.95278 .12607 L
.95279 .11016 L
.95281 .12607 L
.95281 .11016 L
.95288 .09426 L
.95294 .07835 L
.95294 .09426 L
.95297 .11016 L
.95301 .09426 L
.95303 .11016 L
.95303 .09426 L
.9531 .11016 L
.95313 .12607 L
.95315 .14198 L
.9532 .12607 L
.9533 .14198 L
.95337 .15789 L
.95341 .1738 L
.95344 .15789 L
.95353 .14198 L
.95367 .15789 L
.95369 .1738 L
.95369 .18971 L
.95371 .1738 L
.95372 .15789 L
.95375 .1738 L
.9538 .15789 L
.95391 .1738 L
.95412 .15789 L
.95416 .14198 L
.9542 .15789 L
.9542 .14198 L
Mistroke
.95423 .15789 L
.95434 .1738 L
.95434 .18971 L
.95439 .1738 L
.95455 .15789 L
.95458 .1738 L
.95465 .18971 L
.95465 .1738 L
.95473 .18971 L
.95481 .20561 L
.95486 .22152 L
.95493 .23743 L
.95497 .22152 L
.95509 .20561 L
.95513 .18971 L
.95531 .1738 L
.95531 .18971 L
.95533 .1738 L
.95536 .15789 L
.95538 .14198 L
.95543 .15789 L
.95543 .1738 L
.95549 .18971 L
.95553 .20561 L
.95557 .22152 L
.95561 .20561 L
.95562 .22152 L
.95575 .20561 L
.95575 .18971 L
.95581 .20561 L
.95599 .22152 L
.95602 .23743 L
.95605 .22152 L
.95607 .23743 L
.95609 .22152 L
.95621 .23743 L
.95627 .25334 L
.95627 .26925 L
.95632 .28515 L
.95642 .30106 L
.95642 .31697 L
.95645 .33288 L
.95652 .31697 L
.95655 .33288 L
.95659 .31697 L
.9566 .33288 L
.95669 .31697 L
.95675 .33288 L
.95676 .34879 L
.9568 .33288 L
Mistroke
.95681 .34879 L
.95684 .3647 L
.95686 .34879 L
.95691 .33288 L
.95693 .31697 L
.95699 .30106 L
.95705 .28515 L
.9571 .26925 L
.95712 .28515 L
.95715 .30106 L
.95716 .28515 L
.95717 .26925 L
.95722 .28515 L
.95724 .26925 L
.9573 .25334 L
.95732 .26925 L
.95738 .28515 L
.95742 .30106 L
.95745 .28515 L
.95759 .30106 L
.9576 .28515 L
.95763 .26925 L
.95767 .25334 L
.95768 .23743 L
.95787 .22152 L
.95795 .20561 L
.958 .18971 L
.958 .1738 L
.95803 .18971 L
.95804 .20561 L
.95804 .18971 L
.95811 .1738 L
.95825 .18971 L
.95826 .1738 L
.95835 .18971 L
.95837 .1738 L
.95837 .15789 L
.95841 .14198 L
.95843 .15789 L
.95849 .14198 L
.95853 .12607 L
.95854 .14198 L
.95858 .15789 L
.95859 .1738 L
.95864 .15789 L
.9587 .1738 L
.95876 .15789 L
.95879 .14198 L
.95881 .15789 L
.95884 .1738 L
Mistroke
.95889 .15789 L
.95904 .1738 L
.95907 .18971 L
.95915 .1738 L
.95917 .15789 L
.95918 .14198 L
.95922 .12607 L
.95923 .11016 L
.95924 .12607 L
.95929 .14198 L
.95931 .15789 L
.95948 .1738 L
.95954 .18971 L
.95962 .20561 L
.95965 .22152 L
.95973 .20561 L
.95979 .18971 L
.95985 .20561 L
.95988 .18971 L
.95994 .20561 L
.96002 .18971 L
.96003 .20561 L
.96016 .22152 L
.9602 .23743 L
.96024 .22152 L
.9603 .20561 L
.96032 .18971 L
.9604 .1738 L
.96041 .15789 L
.96043 .1738 L
.96045 .15789 L
.96057 .14198 L
.9606 .12607 L
.96066 .14198 L
.96071 .12607 L
.96078 .14198 L
.96079 .15789 L
.96082 .1738 L
.96084 .15789 L
.96084 .14198 L
.9609 .15789 L
.96111 .14198 L
.96112 .15789 L
.96113 .14198 L
.96118 .12607 L
.96123 .14198 L
.96126 .15789 L
.96127 .1738 L
.96134 .18971 L
.96139 .1738 L
Mistroke
.96148 .18971 L
.96158 .20561 L
.96158 .18971 L
.96171 .1738 L
.96176 .18971 L
.96177 .1738 L
.96177 .15789 L
.96179 .14198 L
.96182 .12607 L
.96187 .11016 L
.9619 .09426 L
.96195 .07835 L
.96196 .06244 L
.96196 .04653 L
.96198 .03062 L
.96199 .04653 L
.96199 .03062 L
.96203 .01472 L
.96213 .03062 L
.96223 .01472 L
.96224 .03062 L
.96226 .04653 L
.96227 .03062 L
.96233 .01472 L
.9624 .03062 L
.96247 .04653 L
.96254 .06244 L
.96259 .07835 L
.96292 .09426 L
.96302 .07835 L
.96302 .09426 L
.96303 .07835 L
.96307 .09426 L
.96315 .07835 L
.96322 .09426 L
.96323 .07835 L
.96327 .09426 L
.96327 .11016 L
.96333 .09426 L
.9634 .07835 L
.96341 .09426 L
.96346 .07835 L
.96351 .06244 L
.96352 .04653 L
.96357 .06244 L
.96363 .04653 L
.96378 .03062 L
.9638 .01472 L
.96395 .03062 L
.96399 .04653 L
Mistroke
.96405 .06244 L
.9641 .04653 L
.96412 .03062 L
.96412 .01472 L
.96424 .03062 L
.96431 .01472 L
.96431 .03062 L
.96433 .04653 L
.96435 .06244 L
.96435 .04653 L
.9644 .06244 L
.96452 .07835 L
.96457 .09426 L
.96473 .07835 L
.96487 .09426 L
.96492 .07835 L
.96495 .09426 L
.96499 .07835 L
.96511 .06244 L
.96529 .04653 L
.96532 .06244 L
.96535 .07835 L
.96542 .09426 L
.96547 .11016 L
.9655 .09426 L
.96559 .07835 L
.9656 .06244 L
.96567 .04653 L
.96567 .03062 L
.96586 .04653 L
.96588 .06244 L
.966 .04653 L
.96604 .06244 L
.96609 .04653 L
.96619 .06244 L
.9662 .07835 L
.96625 .09426 L
.96626 .11016 L
.96643 .12607 L
.96645 .14198 L
.96649 .12607 L
.96653 .14198 L
.96661 .12607 L
.96663 .14198 L
.96664 .15789 L
.96665 .14198 L
.96666 .12607 L
.96672 .11016 L
.96673 .09426 L
.96675 .11016 L
Mistroke
.96691 .09426 L
.96691 .07835 L
.96694 .06244 L
.96704 .07835 L
.96723 .09426 L
.96724 .11016 L
.96734 .09426 L
.96738 .11016 L
.96738 .09426 L
.96742 .07835 L
.96746 .06244 L
.96752 .07835 L
.96755 .06244 L
.96761 .07835 L
.96786 .06244 L
.96787 .07835 L
.96793 .09426 L
.96794 .07835 L
.96798 .09426 L
.96799 .07835 L
.96805 .06244 L
.96812 .04653 L
.96814 .06244 L
.96816 .07835 L
.96817 .09426 L
.96818 .07835 L
.9682 .06244 L
.9682 .07835 L
.96823 .09426 L
.96825 .11016 L
.96826 .09426 L
.96831 .11016 L
.96835 .12607 L
.96843 .11016 L
.96844 .09426 L
.9685 .07835 L
.96856 .09426 L
.96856 .07835 L
.96861 .09426 L
.96862 .07835 L
.96866 .09426 L
.96866 .11016 L
.96875 .12607 L
.96885 .11016 L
.96886 .09426 L
.96891 .07835 L
.96891 .09426 L
.96897 .07835 L
.96897 .09426 L
.96904 .11016 L
Mistroke
.96906 .12607 L
.96911 .14198 L
.9692 .12607 L
.96923 .11016 L
.96923 .12607 L
.96924 .14198 L
.96927 .12607 L
.96932 .11016 L
.96935 .09426 L
.9694 .11016 L
.9695 .12607 L
.96955 .14198 L
.96959 .12607 L
.96965 .14198 L
.96971 .12607 L
.96976 .11016 L
.9698 .12607 L
.96991 .11016 L
.96995 .09426 L
.96996 .11016 L
.97 .12607 L
.97 .11016 L
.97003 .12607 L
.97004 .14198 L
.97017 .12607 L
.97023 .11016 L
.97026 .12607 L
.9703 .14198 L
.9703 .12607 L
.97031 .11016 L
.97032 .09426 L
.97045 .07835 L
.97047 .06244 L
.97047 .07835 L
.97047 .06244 L
.97055 .07835 L
.97057 .09426 L
.97058 .11016 L
.97061 .09426 L
.97063 .07835 L
.97066 .09426 L
.97068 .07835 L
.9707 .09426 L
.97081 .07835 L
.97083 .09426 L
.97083 .11016 L
.97088 .09426 L
.97089 .11016 L
.97092 .09426 L
.97123 .11016 L
Mistroke
.97125 .09426 L
.97128 .07835 L
.9713 .09426 L
.97138 .11016 L
.97142 .09426 L
.97148 .07835 L
.9715 .09426 L
.9715 .11016 L
.97155 .09426 L
.97157 .11016 L
.97161 .09426 L
.97174 .07835 L
.97177 .09426 L
.97177 .07835 L
.97181 .06244 L
.97187 .04653 L
.972 .03062 L
.97202 .01472 L
.97208 .03062 L
.97215 .04653 L
.97217 .06244 L
.97221 .04653 L
.97223 .06244 L
.97239 .07835 L
.97245 .09426 L
.97248 .07835 L
.97248 .09426 L
.97269 .11016 L
.97278 .12607 L
.9728 .11016 L
.97285 .09426 L
.97289 .07835 L
.97296 .09426 L
.97297 .11016 L
.97316 .09426 L
.97325 .07835 L
.97334 .06244 L
.97334 .07835 L
.97335 .09426 L
.97337 .07835 L
.97338 .06244 L
.97341 .07835 L
.97345 .06244 L
.97361 .07835 L
.97361 .09426 L
.97362 .11016 L
.97363 .09426 L
.97369 .11016 L
.97376 .09426 L
.97384 .11016 L
Mistroke
.97393 .12607 L
.97395 .14198 L
.97398 .12607 L
.97409 .14198 L
.97411 .15789 L
.97412 .14198 L
.97417 .12607 L
.97422 .11016 L
.97426 .12607 L
.97426 .14198 L
.97428 .12607 L
.9743 .14198 L
.97431 .15789 L
.97435 .1738 L
.97436 .18971 L
.9744 .1738 L
.97451 .18971 L
.97454 .20561 L
.97456 .22152 L
.97457 .23743 L
.97459 .22152 L
.97462 .23743 L
.97464 .22152 L
.97477 .20561 L
.97489 .22152 L
.97497 .20561 L
.97498 .22152 L
.97516 .20561 L
.97518 .18971 L
.97521 .20561 L
.97524 .22152 L
.97537 .23743 L
.97549 .22152 L
.97552 .20561 L
.97558 .18971 L
.9757 .20561 L
.9758 .22152 L
.97582 .23743 L
.97582 .22152 L
.97586 .23743 L
.97616 .22152 L
.97618 .20561 L
.97619 .18971 L
Mfstroke
% End of Graphics
MathPictureEnd

:[font = print; inactive; preserveAspect]
maximum waiting time = 55.708
average waiting time = 8.89343
maximum queue size = 57
average queue size = 9.92561
The next two graphs show the distributions of
queue waiting times and queue lengths.
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; startGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.015873 0.0147151 7.23465 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .18254 0 0 2 Msboxa
[(20)] .34127 0 0 2 Msboxa
[(30)] .5 0 0 2 Msboxa
[(40)] .65873 0 0 2 Msboxa
[(50)] .81746 0 0 2 Msboxa
[(60)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .15941 1 0 Msboxa
[(0.04)] -0.0125 .3041 1 0 Msboxa
[(0.06)] -0.0125 .44879 1 0 Msboxa
[(0.08)] -0.0125 .59349 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.18254 0 m
.18254 .00625 L
s
P
[(10)] .18254 0 0 2 Mshowa
p
.002 w
.34127 0 m
.34127 .00625 L
s
P
[(20)] .34127 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(30)] .5 0 0 2 Mshowa
p
.002 w
.65873 0 m
.65873 .00625 L
s
P
[(40)] .65873 0 0 2 Mshowa
p
.002 w
.81746 0 m
.81746 .00625 L
s
P
[(50)] .81746 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(60)] .97619 0 0 2 Mshowa
p
.001 w
.05556 0 m
.05556 .00375 L
s
P
p
.001 w
.0873 0 m
.0873 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.15079 0 m
.15079 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.24603 0 m
.24603 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.37302 0 m
.37302 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.43651 0 m
.43651 .00375 L
s
P
p
.001 w
.46825 0 m
.46825 .00375 L
s
P
p
.001 w
.53175 0 m
.53175 .00375 L
s
P
p
.001 w
.56349 0 m
.56349 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.62698 0 m
.62698 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75397 0 m
.75397 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.84921 0 m
.84921 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.9127 0 m
.9127 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .15941 m
.00625 .15941 L
s
P
[(0.02)] -0.0125 .15941 1 0 Mshowa
p
.002 w
0 .3041 m
.00625 .3041 L
s
P
[(0.04)] -0.0125 .3041 1 0 Mshowa
p
.002 w
0 .44879 m
.00625 .44879 L
s
P
[(0.06)] -0.0125 .44879 1 0 Mshowa
p
.002 w
0 .59349 m
.00625 .59349 L
s
P
[(0.08)] -0.0125 .59349 1 0 Mshowa
p
.001 w
0 .04365 m
.00375 .04365 L
s
P
p
.001 w
0 .07259 m
.00375 .07259 L
s
P
p
.001 w
0 .10153 m
.00375 .10153 L
s
P
p
.001 w
0 .13047 m
.00375 .13047 L
s
P
p
.001 w
0 .18835 m
.00375 .18835 L
s
P
p
.001 w
0 .21729 m
.00375 .21729 L
s
P
p
.001 w
0 .24622 m
.00375 .24622 L
s
P
p
.001 w
0 .27516 m
.00375 .27516 L
s
P
p
.001 w
0 .33304 m
.00375 .33304 L
s
P
p
.001 w
0 .36198 m
.00375 .36198 L
s
P
p
.001 w
0 .39092 m
.00375 .39092 L
s
P
p
.001 w
0 .41986 m
.00375 .41986 L
s
P
p
.001 w
0 .47773 m
.00375 .47773 L
s
P
p
.001 w
0 .50667 m
.00375 .50667 L
s
P
p
.001 w
0 .53561 m
.00375 .53561 L
s
P
p
.001 w
0 .56455 m
.00375 .56455 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.18254 .61178 m
.18254 .61803 L
s
P
p
.002 w
.34127 .61178 m
.34127 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.65873 .61178 m
.65873 .61803 L
s
P
p
.002 w
.81746 .61178 m
.81746 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.05556 .61428 m
.05556 .61803 L
s
P
p
.001 w
.0873 .61428 m
.0873 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.15079 .61428 m
.15079 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.24603 .61428 m
.24603 .61803 L
s
P
p
.001 w
.27778 .61428 m
.27778 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.37302 .61428 m
.37302 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.43651 .61428 m
.43651 .61803 L
s
P
p
.001 w
.46825 .61428 m
.46825 .61803 L
s
P
p
.001 w
.53175 .61428 m
.53175 .61803 L
s
P
p
.001 w
.56349 .61428 m
.56349 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.62698 .61428 m
.62698 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.72222 .61428 m
.72222 .61803 L
s
P
p
.001 w
.75397 .61428 m
.75397 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.84921 .61428 m
.84921 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.9127 .61428 m
.9127 .61803 L
s
P
p
.001 w
.94444 .61428 m
.94444 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .15941 m
1 .15941 L
s
P
p
.002 w
.99375 .3041 m
1 .3041 L
s
P
p
.002 w
.99375 .44879 m
1 .44879 L
s
P
p
.002 w
.99375 .59349 m
1 .59349 L
s
P
p
.001 w
.99625 .04365 m
1 .04365 L
s
P
p
.001 w
.99625 .07259 m
1 .07259 L
s
P
p
.001 w
.99625 .10153 m
1 .10153 L
s
P
p
.001 w
.99625 .13047 m
1 .13047 L
s
P
p
.001 w
.99625 .18835 m
1 .18835 L
s
P
p
.001 w
.99625 .21729 m
1 .21729 L
s
P
p
.001 w
.99625 .24622 m
1 .24622 L
s
P
p
.001 w
.99625 .27516 m
1 .27516 L
s
P
p
.001 w
.99625 .33304 m
1 .33304 L
s
P
p
.001 w
.99625 .36198 m
1 .36198 L
s
P
p
.001 w
.99625 .39092 m
1 .39092 L
s
P
p
.001 w
.99625 .41986 m
1 .41986 L
s
P
p
.001 w
.99625 .47773 m
1 .47773 L
s
P
p
.001 w
.99625 .50667 m
1 .50667 L
s
P
p
.001 w
.99625 .53561 m
1 .53561 L
s
P
p
.001 w
.99625 .56455 m
1 .56455 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
0 0 1 r
.02381 .01472 m
.02381 .60332 L
.11905 .60332 L
.11905 .01472 L
F
.11905 .01472 m
.11905 .34788 L
.21429 .34788 L
.21429 .01472 L
F
.21429 .01472 m
.21429 .13946 L
.30952 .13946 L
.30952 .01472 L
F
.30952 .01472 m
.30952 .06042 L
.40476 .06042 L
.40476 .01472 L
F
.40476 .01472 m
.40476 .06995 L
.5 .06995 L
.5 .01472 L
F
.5 .01472 m
.5 .04293 L
.59524 .04293 L
.59524 .01472 L
F
.59524 .01472 m
.59524 .02852 L
.69048 .02852 L
.69048 .01472 L
F
.69048 .01472 m
.69048 .02662 L
.78571 .02662 L
.78571 .01472 L
F
.78571 .01472 m
.78571 .01829 L
.88095 .01829 L
.88095 .01472 L
F
.88095 .01472 m
.88095 .01555 L
.97619 .01555 L
.97619 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .60332 L
s
.11905 .01472 m
.11905 .60332 L
s
.02381 .60332 m
.11905 .60332 L
s
.11905 .01472 m
.11905 .34788 L
s
.21429 .01472 m
.21429 .34788 L
s
.11905 .34788 m
.21429 .34788 L
s
.21429 .01472 m
.21429 .13946 L
s
.30952 .01472 m
.30952 .13946 L
s
.21429 .13946 m
.30952 .13946 L
s
.30952 .01472 m
.30952 .06042 L
s
.40476 .01472 m
.40476 .06042 L
s
.30952 .06042 m
.40476 .06042 L
s
.40476 .01472 m
.40476 .06995 L
s
.5 .01472 m
.5 .06995 L
s
.40476 .06995 m
.5 .06995 L
s
.5 .01472 m
.5 .04293 L
s
.59524 .01472 m
.59524 .04293 L
s
.5 .04293 m
.59524 .04293 L
s
.59524 .01472 m
.59524 .02852 L
s
.69048 .01472 m
.69048 .02852 L
s
.59524 .02852 m
.69048 .02852 L
s
.69048 .01472 m
.69048 .02662 L
s
.78571 .01472 m
.78571 .02662 L
s
.69048 .02662 m
.78571 .02662 L
s
.78571 .01472 m
.78571 .01829 L
s
.88095 .01472 m
.88095 .01829 L
s
.78571 .01829 m
.88095 .01829 L
s
.88095 .01472 m
.88095 .01555 L
s
.97619 .01472 m
.97619 .01555 L
s
.88095 .01555 m
.97619 .01555 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174; endGroup; endGroup]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0167084 0.0147151 7.30351 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .19089 0 0 2 Msboxa
[(20)] .35798 0 0 2 Msboxa
[(30)] .52506 0 0 2 Msboxa
[(40)] .69215 0 0 2 Msboxa
[(50)] .85923 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .16079 1 0 Msboxa
[(0.04)] -0.0125 .30686 1 0 Msboxa
[(0.06)] -0.0125 .45293 1 0 Msboxa
[(0.08)] -0.0125 .599 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.19089 0 m
.19089 .00625 L
s
P
[(10)] .19089 0 0 2 Mshowa
p
.002 w
.35798 0 m
.35798 .00625 L
s
P
[(20)] .35798 0 0 2 Mshowa
p
.002 w
.52506 0 m
.52506 .00625 L
s
P
[(30)] .52506 0 0 2 Mshowa
p
.002 w
.69215 0 m
.69215 .00625 L
s
P
[(40)] .69215 0 0 2 Mshowa
p
.002 w
.85923 0 m
.85923 .00625 L
s
P
[(50)] .85923 0 0 2 Mshowa
p
.001 w
.05723 0 m
.05723 .00375 L
s
P
p
.001 w
.09064 0 m
.09064 .00375 L
s
P
p
.001 w
.12406 0 m
.12406 .00375 L
s
P
p
.001 w
.15748 0 m
.15748 .00375 L
s
P
p
.001 w
.22431 0 m
.22431 .00375 L
s
P
p
.001 w
.25773 0 m
.25773 .00375 L
s
P
p
.001 w
.29114 0 m
.29114 .00375 L
s
P
p
.001 w
.32456 0 m
.32456 .00375 L
s
P
p
.001 w
.3914 0 m
.3914 .00375 L
s
P
p
.001 w
.42481 0 m
.42481 .00375 L
s
P
p
.001 w
.45823 0 m
.45823 .00375 L
s
P
p
.001 w
.49165 0 m
.49165 .00375 L
s
P
p
.001 w
.55848 0 m
.55848 .00375 L
s
P
p
.001 w
.5919 0 m
.5919 .00375 L
s
P
p
.001 w
.62531 0 m
.62531 .00375 L
s
P
p
.001 w
.65873 0 m
.65873 .00375 L
s
P
p
.001 w
.72556 0 m
.72556 .00375 L
s
P
p
.001 w
.75898 0 m
.75898 .00375 L
s
P
p
.001 w
.7924 0 m
.7924 .00375 L
s
P
p
.001 w
.82581 0 m
.82581 .00375 L
s
P
p
.001 w
.89265 0 m
.89265 .00375 L
s
P
p
.001 w
.92607 0 m
.92607 .00375 L
s
P
p
.001 w
.95948 0 m
.95948 .00375 L
s
P
p
.001 w
.9929 0 m
.9929 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .16079 m
.00625 .16079 L
s
P
[(0.02)] -0.0125 .16079 1 0 Mshowa
p
.002 w
0 .30686 m
.00625 .30686 L
s
P
[(0.04)] -0.0125 .30686 1 0 Mshowa
p
.002 w
0 .45293 m
.00625 .45293 L
s
P
[(0.06)] -0.0125 .45293 1 0 Mshowa
p
.002 w
0 .599 m
.00625 .599 L
s
P
[(0.08)] -0.0125 .599 1 0 Mshowa
p
.001 w
0 .04393 m
.00375 .04393 L
s
P
p
.001 w
0 .07314 m
.00375 .07314 L
s
P
p
.001 w
0 .10236 m
.00375 .10236 L
s
P
p
.001 w
0 .13157 m
.00375 .13157 L
s
P
p
.001 w
0 .19 m
.00375 .19 L
s
P
p
.001 w
0 .21921 m
.00375 .21921 L
s
P
p
.001 w
0 .24843 m
.00375 .24843 L
s
P
p
.001 w
0 .27764 m
.00375 .27764 L
s
P
p
.001 w
0 .33607 m
.00375 .33607 L
s
P
p
.001 w
0 .36528 m
.00375 .36528 L
s
P
p
.001 w
0 .3945 m
.00375 .3945 L
s
P
p
.001 w
0 .42371 m
.00375 .42371 L
s
P
p
.001 w
0 .48214 m
.00375 .48214 L
s
P
p
.001 w
0 .51135 m
.00375 .51135 L
s
P
p
.001 w
0 .54057 m
.00375 .54057 L
s
P
p
.001 w
0 .56978 m
.00375 .56978 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.19089 .61178 m
.19089 .61803 L
s
P
p
.002 w
.35798 .61178 m
.35798 .61803 L
s
P
p
.002 w
.52506 .61178 m
.52506 .61803 L
s
P
p
.002 w
.69215 .61178 m
.69215 .61803 L
s
P
p
.002 w
.85923 .61178 m
.85923 .61803 L
s
P
p
.001 w
.05723 .61428 m
.05723 .61803 L
s
P
p
.001 w
.09064 .61428 m
.09064 .61803 L
s
P
p
.001 w
.12406 .61428 m
.12406 .61803 L
s
P
p
.001 w
.15748 .61428 m
.15748 .61803 L
s
P
p
.001 w
.22431 .61428 m
.22431 .61803 L
s
P
p
.001 w
.25773 .61428 m
.25773 .61803 L
s
P
p
.001 w
.29114 .61428 m
.29114 .61803 L
s
P
p
.001 w
.32456 .61428 m
.32456 .61803 L
s
P
p
.001 w
.3914 .61428 m
.3914 .61803 L
s
P
p
.001 w
.42481 .61428 m
.42481 .61803 L
s
P
p
.001 w
.45823 .61428 m
.45823 .61803 L
s
P
p
.001 w
.49165 .61428 m
.49165 .61803 L
s
P
p
.001 w
.55848 .61428 m
.55848 .61803 L
s
P
p
.001 w
.5919 .61428 m
.5919 .61803 L
s
P
p
.001 w
.62531 .61428 m
.62531 .61803 L
s
P
p
.001 w
.65873 .61428 m
.65873 .61803 L
s
P
p
.001 w
.72556 .61428 m
.72556 .61803 L
s
P
p
.001 w
.75898 .61428 m
.75898 .61803 L
s
P
p
.001 w
.7924 .61428 m
.7924 .61803 L
s
P
p
.001 w
.82581 .61428 m
.82581 .61803 L
s
P
p
.001 w
.89265 .61428 m
.89265 .61803 L
s
P
p
.001 w
.92607 .61428 m
.92607 .61803 L
s
P
p
.001 w
.95948 .61428 m
.95948 .61803 L
s
P
p
.001 w
.9929 .61428 m
.9929 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .16079 m
1 .16079 L
s
P
p
.002 w
.99375 .30686 m
1 .30686 L
s
P
p
.002 w
.99375 .45293 m
1 .45293 L
s
P
p
.002 w
.99375 .599 m
1 .599 L
s
P
p
.001 w
.99625 .04393 m
1 .04393 L
s
P
p
.001 w
.99625 .07314 m
1 .07314 L
s
P
p
.001 w
.99625 .10236 m
1 .10236 L
s
P
p
.001 w
.99625 .13157 m
1 .13157 L
s
P
p
.001 w
.99625 .19 m
1 .19 L
s
P
p
.001 w
.99625 .21921 m
1 .21921 L
s
P
p
.001 w
.99625 .24843 m
1 .24843 L
s
P
p
.001 w
.99625 .27764 m
1 .27764 L
s
P
p
.001 w
.99625 .33607 m
1 .33607 L
s
P
p
.001 w
.99625 .36528 m
1 .36528 L
s
P
p
.001 w
.99625 .3945 m
1 .3945 L
s
P
p
.001 w
.99625 .42371 m
1 .42371 L
s
P
p
.001 w
.99625 .48214 m
1 .48214 L
s
P
p
.001 w
.99625 .51135 m
1 .51135 L
s
P
p
.001 w
.99625 .54057 m
1 .54057 L
s
P
p
.001 w
.99625 .56978 m
1 .56978 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
.004 w
.02381 .60332 m
.02381 .01472 L
s
.04052 .55585 m
.04052 .01472 L
s
.05723 .51715 m
.05723 .01472 L
s
.07393 .50254 m
.07393 .01472 L
s
.09064 .46091 m
.09064 .01472 L
s
.10735 .48501 m
.10735 .01472 L
s
.12406 .44923 m
.12406 .01472 L
s
.14077 .38204 m
.14077 .01472 L
s
.15748 .36014 m
.15748 .01472 L
s
.17419 .33604 m
.17419 .01472 L
s
.19089 .32727 m
.19089 .01472 L
s
.2076 .31413 m
.2076 .01472 L
s
.22431 .27908 m
.22431 .01472 L
s
.24102 .2411 m
.24102 .01472 L
s
.25773 .23234 m
.25773 .01472 L
s
.27444 .16807 m
.27444 .01472 L
s
.29114 .14617 m
.29114 .01472 L
s
.30785 .10454 m
.30785 .01472 L
s
.32456 .10819 m
.32456 .01472 L
s
.34127 .09943 m
.34127 .01472 L
s
.35798 .07679 m
.35798 .01472 L
s
.37469 .06803 m
.37469 .01472 L
s
.3914 .06437 m
.3914 .01472 L
s
.4081 .06364 m
.4081 .01472 L
s
.42481 .06803 m
.42481 .01472 L
s
.44152 .04466 m
.44152 .01472 L
s
.45823 .04758 m
.45823 .01472 L
s
.47494 .04904 m
.47494 .01472 L
s
.49165 .05707 m
.49165 .01472 L
s
.50835 .04831 m
.50835 .01472 L
s
.52506 .04612 m
.52506 .01472 L
s
.54177 .0578 m
.54177 .01472 L
s
.55848 .04758 m
.55848 .01472 L
s
.57519 .04758 m
.57519 .01472 L
s
.5919 .0432 m
.5919 .01472 L
s
.6086 .05196 m
.6086 .01472 L
s
.62531 .04027 m
.62531 .01472 L
s
.64202 .03589 m
.64202 .01472 L
s
.65873 .03954 m
.65873 .01472 L
s
.67544 .03005 m
.67544 .01472 L
s
.69215 .02567 m
.69215 .01472 L
s
.70886 .02275 m
.70886 .01472 L
s
.72556 .02421 m
.72556 .01472 L
s
.74227 .0264 m
.74227 .01472 L
s
.75898 .02275 m
.75898 .01472 L
s
.77569 .02494 m
.77569 .01472 L
s
.7924 .02348 m
.7924 .01472 L
s
.80911 .02932 m
.80911 .01472 L
s
.82581 .02713 m
.82581 .01472 L
s
.84252 .02421 m
.84252 .01472 L
s
.85923 .03443 m
.85923 .01472 L
s
.87594 .03224 m
.87594 .01472 L
s
.89265 .03589 m
.89265 .01472 L
s
.90936 .02859 m
.90936 .01472 L
s
.92607 .02494 m
.92607 .01472 L
s
.94277 .01691 m
.94277 .01472 L
s
.95948 .01545 m
.95948 .01472 L
s
.97619 .01764 m
.97619 .01472 L
s
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = input; preserveAspect]
SpikeData[%54[[2]]];
:[font = input; preserveAspect; startGroup]
SpikegraphWithDots[%55, 0, 50, {0, 0, 1}, True]
:[font = print; inactive; preserveAspect]
Note:  some outcome values lie outside the user-defined interval.
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 7.30351 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .21429 0 0 2 Msboxa
[(20)] .40476 0 0 2 Msboxa
[(30)] .59524 0 0 2 Msboxa
[(40)] .78571 0 0 2 Msboxa
[(50)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .16079 1 0 Msboxa
[(0.04)] -0.0125 .30686 1 0 Msboxa
[(0.06)] -0.0125 .45293 1 0 Msboxa
[(0.08)] -0.0125 .599 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.21429 0 m
.21429 .00625 L
s
P
[(10)] .21429 0 0 2 Mshowa
p
.002 w
.40476 0 m
.40476 .00625 L
s
P
[(20)] .40476 0 0 2 Mshowa
p
.002 w
.59524 0 m
.59524 .00625 L
s
P
[(30)] .59524 0 0 2 Mshowa
p
.002 w
.78571 0 m
.78571 .00625 L
s
P
[(40)] .78571 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(50)] .97619 0 0 2 Mshowa
p
.001 w
.0619 0 m
.0619 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.1381 0 m
.1381 .00375 L
s
P
p
.001 w
.17619 0 m
.17619 .00375 L
s
P
p
.001 w
.25238 0 m
.25238 .00375 L
s
P
p
.001 w
.29048 0 m
.29048 .00375 L
s
P
p
.001 w
.32857 0 m
.32857 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.44286 0 m
.44286 .00375 L
s
P
p
.001 w
.48095 0 m
.48095 .00375 L
s
P
p
.001 w
.51905 0 m
.51905 .00375 L
s
P
p
.001 w
.55714 0 m
.55714 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.67143 0 m
.67143 .00375 L
s
P
p
.001 w
.70952 0 m
.70952 .00375 L
s
P
p
.001 w
.74762 0 m
.74762 .00375 L
s
P
p
.001 w
.82381 0 m
.82381 .00375 L
s
P
p
.001 w
.8619 0 m
.8619 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.9381 0 m
.9381 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .16079 m
.00625 .16079 L
s
P
[(0.02)] -0.0125 .16079 1 0 Mshowa
p
.002 w
0 .30686 m
.00625 .30686 L
s
P
[(0.04)] -0.0125 .30686 1 0 Mshowa
p
.002 w
0 .45293 m
.00625 .45293 L
s
P
[(0.06)] -0.0125 .45293 1 0 Mshowa
p
.002 w
0 .599 m
.00625 .599 L
s
P
[(0.08)] -0.0125 .599 1 0 Mshowa
p
.001 w
0 .04393 m
.00375 .04393 L
s
P
p
.001 w
0 .07314 m
.00375 .07314 L
s
P
p
.001 w
0 .10236 m
.00375 .10236 L
s
P
p
.001 w
0 .13157 m
.00375 .13157 L
s
P
p
.001 w
0 .19 m
.00375 .19 L
s
P
p
.001 w
0 .21921 m
.00375 .21921 L
s
P
p
.001 w
0 .24843 m
.00375 .24843 L
s
P
p
.001 w
0 .27764 m
.00375 .27764 L
s
P
p
.001 w
0 .33607 m
.00375 .33607 L
s
P
p
.001 w
0 .36528 m
.00375 .36528 L
s
P
p
.001 w
0 .3945 m
.00375 .3945 L
s
P
p
.001 w
0 .42371 m
.00375 .42371 L
s
P
p
.001 w
0 .48214 m
.00375 .48214 L
s
P
p
.001 w
0 .51135 m
.00375 .51135 L
s
P
p
.001 w
0 .54057 m
.00375 .54057 L
s
P
p
.001 w
0 .56978 m
.00375 .56978 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.21429 .61178 m
.21429 .61803 L
s
P
p
.002 w
.40476 .61178 m
.40476 .61803 L
s
P
p
.002 w
.59524 .61178 m
.59524 .61803 L
s
P
p
.002 w
.78571 .61178 m
.78571 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.0619 .61428 m
.0619 .61803 L
s
P
p
.001 w
.1 .61428 m
.1 .61803 L
s
P
p
.001 w
.1381 .61428 m
.1381 .61803 L
s
P
p
.001 w
.17619 .61428 m
.17619 .61803 L
s
P
p
.001 w
.25238 .61428 m
.25238 .61803 L
s
P
p
.001 w
.29048 .61428 m
.29048 .61803 L
s
P
p
.001 w
.32857 .61428 m
.32857 .61803 L
s
P
p
.001 w
.36667 .61428 m
.36667 .61803 L
s
P
p
.001 w
.44286 .61428 m
.44286 .61803 L
s
P
p
.001 w
.48095 .61428 m
.48095 .61803 L
s
P
p
.001 w
.51905 .61428 m
.51905 .61803 L
s
P
p
.001 w
.55714 .61428 m
.55714 .61803 L
s
P
p
.001 w
.63333 .61428 m
.63333 .61803 L
s
P
p
.001 w
.67143 .61428 m
.67143 .61803 L
s
P
p
.001 w
.70952 .61428 m
.70952 .61803 L
s
P
p
.001 w
.74762 .61428 m
.74762 .61803 L
s
P
p
.001 w
.82381 .61428 m
.82381 .61803 L
s
P
p
.001 w
.8619 .61428 m
.8619 .61803 L
s
P
p
.001 w
.9 .61428 m
.9 .61803 L
s
P
p
.001 w
.9381 .61428 m
.9381 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .16079 m
1 .16079 L
s
P
p
.002 w
.99375 .30686 m
1 .30686 L
s
P
p
.002 w
.99375 .45293 m
1 .45293 L
s
P
p
.002 w
.99375 .599 m
1 .599 L
s
P
p
.001 w
.99625 .04393 m
1 .04393 L
s
P
p
.001 w
.99625 .07314 m
1 .07314 L
s
P
p
.001 w
.99625 .10236 m
1 .10236 L
s
P
p
.001 w
.99625 .13157 m
1 .13157 L
s
P
p
.001 w
.99625 .19 m
1 .19 L
s
P
p
.001 w
.99625 .21921 m
1 .21921 L
s
P
p
.001 w
.99625 .24843 m
1 .24843 L
s
P
p
.001 w
.99625 .27764 m
1 .27764 L
s
P
p
.001 w
.99625 .33607 m
1 .33607 L
s
P
p
.001 w
.99625 .36528 m
1 .36528 L
s
P
p
.001 w
.99625 .3945 m
1 .3945 L
s
P
p
.001 w
.99625 .42371 m
1 .42371 L
s
P
p
.001 w
.99625 .48214 m
1 .48214 L
s
P
p
.001 w
.99625 .51135 m
1 .51135 L
s
P
p
.001 w
.99625 .54057 m
1 .54057 L
s
P
p
.001 w
.99625 .56978 m
1 .56978 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
p
.004 w
.02381 .60332 m
.02381 .01472 L
s
.04286 .55585 m
.04286 .01472 L
s
.0619 .51715 m
.0619 .01472 L
s
.08095 .50254 m
.08095 .01472 L
s
.1 .46091 m
.1 .01472 L
s
.11905 .48501 m
.11905 .01472 L
s
.1381 .44923 m
.1381 .01472 L
s
.15714 .38204 m
.15714 .01472 L
s
.17619 .36014 m
.17619 .01472 L
s
.19524 .33604 m
.19524 .01472 L
s
.21429 .32727 m
.21429 .01472 L
s
.23333 .31413 m
.23333 .01472 L
s
.25238 .27908 m
.25238 .01472 L
s
.27143 .2411 m
.27143 .01472 L
s
.29048 .23234 m
.29048 .01472 L
s
.30952 .16807 m
.30952 .01472 L
s
.32857 .14617 m
.32857 .01472 L
s
.34762 .10454 m
.34762 .01472 L
s
.36667 .10819 m
.36667 .01472 L
s
.38571 .09943 m
.38571 .01472 L
s
.40476 .07679 m
.40476 .01472 L
s
.42381 .06803 m
.42381 .01472 L
s
.44286 .06437 m
.44286 .01472 L
s
.4619 .06364 m
.4619 .01472 L
s
.48095 .06803 m
.48095 .01472 L
s
.5 .04466 m
.5 .01472 L
s
.51905 .04758 m
.51905 .01472 L
s
.5381 .04904 m
.5381 .01472 L
s
.55714 .05707 m
.55714 .01472 L
s
.57619 .04831 m
.57619 .01472 L
s
.59524 .04612 m
.59524 .01472 L
s
.61429 .0578 m
.61429 .01472 L
s
.63333 .04758 m
.63333 .01472 L
s
.65238 .04758 m
.65238 .01472 L
s
.67143 .0432 m
.67143 .01472 L
s
.69048 .05196 m
.69048 .01472 L
s
.70952 .04027 m
.70952 .01472 L
s
.72857 .03589 m
.72857 .01472 L
s
.74762 .03954 m
.74762 .01472 L
s
.76667 .03005 m
.76667 .01472 L
s
.78571 .02567 m
.78571 .01472 L
s
.80476 .02275 m
.80476 .01472 L
s
.82381 .02421 m
.82381 .01472 L
s
.84286 .0264 m
.84286 .01472 L
s
.8619 .02275 m
.8619 .01472 L
s
.88095 .02494 m
.88095 .01472 L
s
.9 .02348 m
.9 .01472 L
s
.91905 .02932 m
.91905 .01472 L
s
.9381 .02713 m
.9381 .01472 L
s
.95714 .02421 m
.95714 .01472 L
s
.97619 .03443 m
.97619 .01472 L
s
P
p
0 0 1 r
p
.02 w
.02381 .60332 Mdot
.04286 .55585 Mdot
.0619 .51715 Mdot
.08095 .50254 Mdot
.1 .46091 Mdot
.11905 .48501 Mdot
.1381 .44923 Mdot
.15714 .38204 Mdot
.17619 .36014 Mdot
.19524 .33604 Mdot
.21429 .32727 Mdot
.23333 .31413 Mdot
.25238 .27908 Mdot
.27143 .2411 Mdot
.29048 .23234 Mdot
.30952 .16807 Mdot
.32857 .14617 Mdot
.34762 .10454 Mdot
.36667 .10819 Mdot
.38571 .09943 Mdot
.40476 .07679 Mdot
.42381 .06803 Mdot
.44286 .06437 Mdot
.4619 .06364 Mdot
.48095 .06803 Mdot
.5 .04466 Mdot
.51905 .04758 Mdot
.5381 .04904 Mdot
.55714 .05707 Mdot
.57619 .04831 Mdot
.59524 .04612 Mdot
.61429 .0578 Mdot
.63333 .04758 Mdot
.65238 .04758 Mdot
.67143 .0432 Mdot
.69048 .05196 Mdot
.70952 .04027 Mdot
.72857 .03589 Mdot
.74762 .03954 Mdot
.76667 .03005 Mdot
.78571 .02567 Mdot
.80476 .02275 Mdot
.82381 .02421 Mdot
.84286 .0264 Mdot
.8619 .02275 Mdot
.88095 .02494 Mdot
.9 .02348 Mdot
.91905 .02932 Mdot
.9381 .02713 Mdot
.95714 .02421 Mdot
.97619 .03443 Mdot
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
:[font = input; preserveAspect]
dist = Table[{j, N[(1/11)*(10/11)^(j-1)]}, {j, 0, 100}];
:[font = input; preserveAspect; startGroup]
SpikegraphWithDots[%57, 0, 50, {1, 0, 0}, True]
:[font = print; inactive; preserveAspect]
Note:  some outcome values lie outside the user-defined interval.
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 5.88604 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .21429 0 0 2 Msboxa
[(20)] .40476 0 0 2 Msboxa
[(30)] .59524 0 0 2 Msboxa
[(40)] .78571 0 0 2 Msboxa
[(50)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .13244 1 0 Msboxa
[(0.04)] -0.0125 .25016 1 0 Msboxa
[(0.06)] -0.0125 .36788 1 0 Msboxa
[(0.08)] -0.0125 .4856 1 0 Msboxa
[(0.1)] -0.0125 .60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.21429 0 m
.21429 .00625 L
s
P
[(10)] .21429 0 0 2 Mshowa
p
.002 w
.40476 0 m
.40476 .00625 L
s
P
[(20)] .40476 0 0 2 Mshowa
p
.002 w
.59524 0 m
.59524 .00625 L
s
P
[(30)] .59524 0 0 2 Mshowa
p
.002 w
.78571 0 m
.78571 .00625 L
s
P
[(40)] .78571 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(50)] .97619 0 0 2 Mshowa
p
.001 w
.0619 0 m
.0619 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.1381 0 m
.1381 .00375 L
s
P
p
.001 w
.17619 0 m
.17619 .00375 L
s
P
p
.001 w
.25238 0 m
.25238 .00375 L
s
P
p
.001 w
.29048 0 m
.29048 .00375 L
s
P
p
.001 w
.32857 0 m
.32857 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.44286 0 m
.44286 .00375 L
s
P
p
.001 w
.48095 0 m
.48095 .00375 L
s
P
p
.001 w
.51905 0 m
.51905 .00375 L
s
P
p
.001 w
.55714 0 m
.55714 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.67143 0 m
.67143 .00375 L
s
P
p
.001 w
.70952 0 m
.70952 .00375 L
s
P
p
.001 w
.74762 0 m
.74762 .00375 L
s
P
p
.001 w
.82381 0 m
.82381 .00375 L
s
P
p
.001 w
.8619 0 m
.8619 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.9381 0 m
.9381 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .13244 m
.00625 .13244 L
s
P
[(0.02)] -0.0125 .13244 1 0 Mshowa
p
.002 w
0 .25016 m
.00625 .25016 L
s
P
[(0.04)] -0.0125 .25016 1 0 Mshowa
p
.002 w
0 .36788 m
.00625 .36788 L
s
P
[(0.06)] -0.0125 .36788 1 0 Mshowa
p
.002 w
0 .4856 m
.00625 .4856 L
s
P
[(0.08)] -0.0125 .4856 1 0 Mshowa
p
.002 w
0 .60332 m
.00625 .60332 L
s
P
[(0.1)] -0.0125 .60332 1 0 Mshowa
p
.001 w
0 .03826 m
.00375 .03826 L
s
P
p
.001 w
0 .0618 m
.00375 .0618 L
s
P
p
.001 w
0 .08535 m
.00375 .08535 L
s
P
p
.001 w
0 .10889 m
.00375 .10889 L
s
P
p
.001 w
0 .15598 m
.00375 .15598 L
s
P
p
.001 w
0 .17952 m
.00375 .17952 L
s
P
p
.001 w
0 .20307 m
.00375 .20307 L
s
P
p
.001 w
0 .22661 m
.00375 .22661 L
s
P
p
.001 w
0 .2737 m
.00375 .2737 L
s
P
p
.001 w
0 .29724 m
.00375 .29724 L
s
P
p
.001 w
0 .32079 m
.00375 .32079 L
s
P
p
.001 w
0 .34433 m
.00375 .34433 L
s
P
p
.001 w
0 .39142 m
.00375 .39142 L
s
P
p
.001 w
0 .41497 m
.00375 .41497 L
s
P
p
.001 w
0 .43851 m
.00375 .43851 L
s
P
p
.001 w
0 .46205 m
.00375 .46205 L
s
P
p
.001 w
0 .50914 m
.00375 .50914 L
s
P
p
.001 w
0 .53269 m
.00375 .53269 L
s
P
p
.001 w
0 .55623 m
.00375 .55623 L
s
P
p
.001 w
0 .57977 m
.00375 .57977 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.21429 .61178 m
.21429 .61803 L
s
P
p
.002 w
.40476 .61178 m
.40476 .61803 L
s
P
p
.002 w
.59524 .61178 m
.59524 .61803 L
s
P
p
.002 w
.78571 .61178 m
.78571 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.0619 .61428 m
.0619 .61803 L
s
P
p
.001 w
.1 .61428 m
.1 .61803 L
s
P
p
.001 w
.1381 .61428 m
.1381 .61803 L
s
P
p
.001 w
.17619 .61428 m
.17619 .61803 L
s
P
p
.001 w
.25238 .61428 m
.25238 .61803 L
s
P
p
.001 w
.29048 .61428 m
.29048 .61803 L
s
P
p
.001 w
.32857 .61428 m
.32857 .61803 L
s
P
p
.001 w
.36667 .61428 m
.36667 .61803 L
s
P
p
.001 w
.44286 .61428 m
.44286 .61803 L
s
P
p
.001 w
.48095 .61428 m
.48095 .61803 L
s
P
p
.001 w
.51905 .61428 m
.51905 .61803 L
s
P
p
.001 w
.55714 .61428 m
.55714 .61803 L
s
P
p
.001 w
.63333 .61428 m
.63333 .61803 L
s
P
p
.001 w
.67143 .61428 m
.67143 .61803 L
s
P
p
.001 w
.70952 .61428 m
.70952 .61803 L
s
P
p
.001 w
.74762 .61428 m
.74762 .61803 L
s
P
p
.001 w
.82381 .61428 m
.82381 .61803 L
s
P
p
.001 w
.8619 .61428 m
.8619 .61803 L
s
P
p
.001 w
.9 .61428 m
.9 .61803 L
s
P
p
.001 w
.9381 .61428 m
.9381 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .13244 m
1 .13244 L
s
P
p
.002 w
.99375 .25016 m
1 .25016 L
s
P
p
.002 w
.99375 .36788 m
1 .36788 L
s
P
p
.002 w
.99375 .4856 m
1 .4856 L
s
P
p
.002 w
.99375 .60332 m
1 .60332 L
s
P
p
.001 w
.99625 .03826 m
1 .03826 L
s
P
p
.001 w
.99625 .0618 m
1 .0618 L
s
P
p
.001 w
.99625 .08535 m
1 .08535 L
s
P
p
.001 w
.99625 .10889 m
1 .10889 L
s
P
p
.001 w
.99625 .15598 m
1 .15598 L
s
P
p
.001 w
.99625 .17952 m
1 .17952 L
s
P
p
.001 w
.99625 .20307 m
1 .20307 L
s
P
p
.001 w
.99625 .22661 m
1 .22661 L
s
P
p
.001 w
.99625 .2737 m
1 .2737 L
s
P
p
.001 w
.99625 .29724 m
1 .29724 L
s
P
p
.001 w
.99625 .32079 m
1 .32079 L
s
P
p
.001 w
.99625 .34433 m
1 .34433 L
s
P
p
.001 w
.99625 .39142 m
1 .39142 L
s
P
p
.001 w
.99625 .41497 m
1 .41497 L
s
P
p
.001 w
.99625 .43851 m
1 .43851 L
s
P
p
.001 w
.99625 .46205 m
1 .46205 L
s
P
p
.001 w
.99625 .50914 m
1 .50914 L
s
P
p
.001 w
.99625 .53269 m
1 .53269 L
s
P
p
.001 w
.99625 .55623 m
1 .55623 L
s
P
p
.001 w
.99625 .57977 m
1 .57977 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
p
.004 w
.02381 .60332 m
.02381 .01472 L
s
.04286 .54981 m
.04286 .01472 L
s
.0619 .50116 m
.0619 .01472 L
s
.08095 .45694 m
.08095 .01472 L
s
.1 .41674 m
.1 .01472 L
s
.11905 .38019 m
.11905 .01472 L
s
.1381 .34697 m
.1381 .01472 L
s
.15714 .31676 m
.15714 .01472 L
s
.17619 .2893 m
.17619 .01472 L
s
.19524 .26434 m
.19524 .01472 L
s
.21429 .24165 m
.21429 .01472 L
s
.23333 .22102 m
.23333 .01472 L
s
.25238 .20226 m
.25238 .01472 L
s
.27143 .18521 m
.27143 .01472 L
s
.29048 .16971 m
.29048 .01472 L
s
.30952 .15562 m
.30952 .01472 L
s
.32857 .14281 m
.32857 .01472 L
s
.34762 .13117 m
.34762 .01472 L
s
.36667 .12058 m
.36667 .01472 L
s
.38571 .11096 m
.38571 .01472 L
s
.40476 .10221 m
.40476 .01472 L
s
.42381 .09425 m
.42381 .01472 L
s
.44286 .08702 m
.44286 .01472 L
s
.4619 .08045 m
.4619 .01472 L
s
.48095 .07447 m
.48095 .01472 L
s
.5 .06904 m
.5 .01472 L
s
.51905 .0641 m
.51905 .01472 L
s
.5381 .05961 m
.5381 .01472 L
s
.55714 .05553 m
.55714 .01472 L
s
.57619 .05182 m
.57619 .01472 L
s
.59524 .04845 m
.59524 .01472 L
s
.61429 .04538 m
.61429 .01472 L
s
.63333 .04259 m
.63333 .01472 L
s
.65238 .04006 m
.65238 .01472 L
s
.67143 .03775 m
.67143 .01472 L
s
.69048 .03566 m
.69048 .01472 L
s
.70952 .03376 m
.70952 .01472 L
s
.72857 .03202 m
.72857 .01472 L
s
.74762 .03045 m
.74762 .01472 L
s
.76667 .02902 m
.76667 .01472 L
s
.78571 .02772 m
.78571 .01472 L
s
.80476 .02654 m
.80476 .01472 L
s
.82381 .02546 m
.82381 .01472 L
s
.84286 .02449 m
.84286 .01472 L
s
.8619 .0236 m
.8619 .01472 L
s
.88095 .02279 m
.88095 .01472 L
s
.9 .02206 m
.9 .01472 L
s
.91905 .02139 m
.91905 .01472 L
s
.9381 .02078 m
.9381 .01472 L
s
.95714 .02023 m
.95714 .01472 L
s
.97619 .01973 m
.97619 .01472 L
s
P
p
1 0 0 r
p
.02 w
.02381 .60332 Mdot
.04286 .54981 Mdot
.0619 .50116 Mdot
.08095 .45694 Mdot
.1 .41674 Mdot
.11905 .38019 Mdot
.1381 .34697 Mdot
.15714 .31676 Mdot
.17619 .2893 Mdot
.19524 .26434 Mdot
.21429 .24165 Mdot
.23333 .22102 Mdot
.25238 .20226 Mdot
.27143 .18521 Mdot
.29048 .16971 Mdot
.30952 .15562 Mdot
.32857 .14281 Mdot
.34762 .13117 Mdot
.36667 .12058 Mdot
.38571 .11096 Mdot
.40476 .10221 Mdot
.42381 .09425 Mdot
.44286 .08702 Mdot
.4619 .08045 Mdot
.48095 .07447 Mdot
.5 .06904 Mdot
.51905 .0641 Mdot
.5381 .05961 Mdot
.55714 .05553 Mdot
.57619 .05182 Mdot
.59524 .04845 Mdot
.61429 .04538 Mdot
.63333 .04259 Mdot
.65238 .04006 Mdot
.67143 .03775 Mdot
.69048 .03566 Mdot
.70952 .03376 Mdot
.72857 .03202 Mdot
.74762 .03045 Mdot
.76667 .02902 Mdot
.78571 .02772 Mdot
.80476 .02654 Mdot
.82381 .02546 Mdot
.84286 .02449 Mdot
.8619 .0236 Mdot
.88095 .02279 Mdot
.9 .02206 Mdot
.91905 .02139 Mdot
.9381 .02078 Mdot
.95714 .02023 Mdot
.97619 .01973 Mdot
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
:[font = input; preserveAspect; startGroup]
Show[%58, %56]
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 5.88604 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .21429 0 0 2 Msboxa
[(20)] .40476 0 0 2 Msboxa
[(30)] .59524 0 0 2 Msboxa
[(40)] .78571 0 0 2 Msboxa
[(50)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .13244 1 0 Msboxa
[(0.04)] -0.0125 .25016 1 0 Msboxa
[(0.06)] -0.0125 .36788 1 0 Msboxa
[(0.08)] -0.0125 .4856 1 0 Msboxa
[(0.1)] -0.0125 .60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.21429 0 m
.21429 .00625 L
s
P
[(10)] .21429 0 0 2 Mshowa
p
.002 w
.40476 0 m
.40476 .00625 L
s
P
[(20)] .40476 0 0 2 Mshowa
p
.002 w
.59524 0 m
.59524 .00625 L
s
P
[(30)] .59524 0 0 2 Mshowa
p
.002 w
.78571 0 m
.78571 .00625 L
s
P
[(40)] .78571 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(50)] .97619 0 0 2 Mshowa
p
.001 w
.0619 0 m
.0619 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.1381 0 m
.1381 .00375 L
s
P
p
.001 w
.17619 0 m
.17619 .00375 L
s
P
p
.001 w
.25238 0 m
.25238 .00375 L
s
P
p
.001 w
.29048 0 m
.29048 .00375 L
s
P
p
.001 w
.32857 0 m
.32857 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.44286 0 m
.44286 .00375 L
s
P
p
.001 w
.48095 0 m
.48095 .00375 L
s
P
p
.001 w
.51905 0 m
.51905 .00375 L
s
P
p
.001 w
.55714 0 m
.55714 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.67143 0 m
.67143 .00375 L
s
P
p
.001 w
.70952 0 m
.70952 .00375 L
s
P
p
.001 w
.74762 0 m
.74762 .00375 L
s
P
p
.001 w
.82381 0 m
.82381 .00375 L
s
P
p
.001 w
.8619 0 m
.8619 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.9381 0 m
.9381 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .13244 m
.00625 .13244 L
s
P
[(0.02)] -0.0125 .13244 1 0 Mshowa
p
.002 w
0 .25016 m
.00625 .25016 L
s
P
[(0.04)] -0.0125 .25016 1 0 Mshowa
p
.002 w
0 .36788 m
.00625 .36788 L
s
P
[(0.06)] -0.0125 .36788 1 0 Mshowa
p
.002 w
0 .4856 m
.00625 .4856 L
s
P
[(0.08)] -0.0125 .4856 1 0 Mshowa
p
.002 w
0 .60332 m
.00625 .60332 L
s
P
[(0.1)] -0.0125 .60332 1 0 Mshowa
p
.001 w
0 .03826 m
.00375 .03826 L
s
P
p
.001 w
0 .0618 m
.00375 .0618 L
s
P
p
.001 w
0 .08535 m
.00375 .08535 L
s
P
p
.001 w
0 .10889 m
.00375 .10889 L
s
P
p
.001 w
0 .15598 m
.00375 .15598 L
s
P
p
.001 w
0 .17952 m
.00375 .17952 L
s
P
p
.001 w
0 .20307 m
.00375 .20307 L
s
P
p
.001 w
0 .22661 m
.00375 .22661 L
s
P
p
.001 w
0 .2737 m
.00375 .2737 L
s
P
p
.001 w
0 .29724 m
.00375 .29724 L
s
P
p
.001 w
0 .32079 m
.00375 .32079 L
s
P
p
.001 w
0 .34433 m
.00375 .34433 L
s
P
p
.001 w
0 .39142 m
.00375 .39142 L
s
P
p
.001 w
0 .41497 m
.00375 .41497 L
s
P
p
.001 w
0 .43851 m
.00375 .43851 L
s
P
p
.001 w
0 .46205 m
.00375 .46205 L
s
P
p
.001 w
0 .50914 m
.00375 .50914 L
s
P
p
.001 w
0 .53269 m
.00375 .53269 L
s
P
p
.001 w
0 .55623 m
.00375 .55623 L
s
P
p
.001 w
0 .57977 m
.00375 .57977 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.21429 .61178 m
.21429 .61803 L
s
P
p
.002 w
.40476 .61178 m
.40476 .61803 L
s
P
p
.002 w
.59524 .61178 m
.59524 .61803 L
s
P
p
.002 w
.78571 .61178 m
.78571 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.0619 .61428 m
.0619 .61803 L
s
P
p
.001 w
.1 .61428 m
.1 .61803 L
s
P
p
.001 w
.1381 .61428 m
.1381 .61803 L
s
P
p
.001 w
.17619 .61428 m
.17619 .61803 L
s
P
p
.001 w
.25238 .61428 m
.25238 .61803 L
s
P
p
.001 w
.29048 .61428 m
.29048 .61803 L
s
P
p
.001 w
.32857 .61428 m
.32857 .61803 L
s
P
p
.001 w
.36667 .61428 m
.36667 .61803 L
s
P
p
.001 w
.44286 .61428 m
.44286 .61803 L
s
P
p
.001 w
.48095 .61428 m
.48095 .61803 L
s
P
p
.001 w
.51905 .61428 m
.51905 .61803 L
s
P
p
.001 w
.55714 .61428 m
.55714 .61803 L
s
P
p
.001 w
.63333 .61428 m
.63333 .61803 L
s
P
p
.001 w
.67143 .61428 m
.67143 .61803 L
s
P
p
.001 w
.70952 .61428 m
.70952 .61803 L
s
P
p
.001 w
.74762 .61428 m
.74762 .61803 L
s
P
p
.001 w
.82381 .61428 m
.82381 .61803 L
s
P
p
.001 w
.8619 .61428 m
.8619 .61803 L
s
P
p
.001 w
.9 .61428 m
.9 .61803 L
s
P
p
.001 w
.9381 .61428 m
.9381 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .13244 m
1 .13244 L
s
P
p
.002 w
.99375 .25016 m
1 .25016 L
s
P
p
.002 w
.99375 .36788 m
1 .36788 L
s
P
p
.002 w
.99375 .4856 m
1 .4856 L
s
P
p
.002 w
.99375 .60332 m
1 .60332 L
s
P
p
.001 w
.99625 .03826 m
1 .03826 L
s
P
p
.001 w
.99625 .0618 m
1 .0618 L
s
P
p
.001 w
.99625 .08535 m
1 .08535 L
s
P
p
.001 w
.99625 .10889 m
1 .10889 L
s
P
p
.001 w
.99625 .15598 m
1 .15598 L
s
P
p
.001 w
.99625 .17952 m
1 .17952 L
s
P
p
.001 w
.99625 .20307 m
1 .20307 L
s
P
p
.001 w
.99625 .22661 m
1 .22661 L
s
P
p
.001 w
.99625 .2737 m
1 .2737 L
s
P
p
.001 w
.99625 .29724 m
1 .29724 L
s
P
p
.001 w
.99625 .32079 m
1 .32079 L
s
P
p
.001 w
.99625 .34433 m
1 .34433 L
s
P
p
.001 w
.99625 .39142 m
1 .39142 L
s
P
p
.001 w
.99625 .41497 m
1 .41497 L
s
P
p
.001 w
.99625 .43851 m
1 .43851 L
s
P
p
.001 w
.99625 .46205 m
1 .46205 L
s
P
p
.001 w
.99625 .50914 m
1 .50914 L
s
P
p
.001 w
.99625 .53269 m
1 .53269 L
s
P
p
.001 w
.99625 .55623 m
1 .55623 L
s
P
p
.001 w
.99625 .57977 m
1 .57977 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
P
p
p
p
.004 w
.02381 .60332 m
.02381 .01472 L
s
.04286 .54981 m
.04286 .01472 L
s
.0619 .50116 m
.0619 .01472 L
s
.08095 .45694 m
.08095 .01472 L
s
.1 .41674 m
.1 .01472 L
s
.11905 .38019 m
.11905 .01472 L
s
.1381 .34697 m
.1381 .01472 L
s
.15714 .31676 m
.15714 .01472 L
s
.17619 .2893 m
.17619 .01472 L
s
.19524 .26434 m
.19524 .01472 L
s
.21429 .24165 m
.21429 .01472 L
s
.23333 .22102 m
.23333 .01472 L
s
.25238 .20226 m
.25238 .01472 L
s
.27143 .18521 m
.27143 .01472 L
s
.29048 .16971 m
.29048 .01472 L
s
.30952 .15562 m
.30952 .01472 L
s
.32857 .14281 m
.32857 .01472 L
s
.34762 .13117 m
.34762 .01472 L
s
.36667 .12058 m
.36667 .01472 L
s
.38571 .11096 m
.38571 .01472 L
s
.40476 .10221 m
.40476 .01472 L
s
.42381 .09425 m
.42381 .01472 L
s
.44286 .08702 m
.44286 .01472 L
s
.4619 .08045 m
.4619 .01472 L
s
.48095 .07447 m
.48095 .01472 L
s
.5 .06904 m
.5 .01472 L
s
.51905 .0641 m
.51905 .01472 L
s
.5381 .05961 m
.5381 .01472 L
s
.55714 .05553 m
.55714 .01472 L
s
.57619 .05182 m
.57619 .01472 L
s
.59524 .04845 m
.59524 .01472 L
s
.61429 .04538 m
.61429 .01472 L
s
.63333 .04259 m
.63333 .01472 L
s
.65238 .04006 m
.65238 .01472 L
s
.67143 .03775 m
.67143 .01472 L
s
.69048 .03566 m
.69048 .01472 L
s
.70952 .03376 m
.70952 .01472 L
s
.72857 .03202 m
.72857 .01472 L
s
.74762 .03045 m
.74762 .01472 L
s
.76667 .02902 m
.76667 .01472 L
s
.78571 .02772 m
.78571 .01472 L
s
.80476 .02654 m
.80476 .01472 L
s
.82381 .02546 m
.82381 .01472 L
s
.84286 .02449 m
.84286 .01472 L
s
.8619 .0236 m
.8619 .01472 L
s
.88095 .02279 m
.88095 .01472 L
s
.9 .02206 m
.9 .01472 L
s
.91905 .02139 m
.91905 .01472 L
s
.9381 .02078 m
.9381 .01472 L
s
.95714 .02023 m
.95714 .01472 L
s
.97619 .01973 m
.97619 .01472 L
s
P
p
1 0 0 r
p
.02 w
.02381 .60332 Mdot
.04286 .54981 Mdot
.0619 .50116 Mdot
.08095 .45694 Mdot
.1 .41674 Mdot
.11905 .38019 Mdot
.1381 .34697 Mdot
.15714 .31676 Mdot
.17619 .2893 Mdot
.19524 .26434 Mdot
.21429 .24165 Mdot
.23333 .22102 Mdot
.25238 .20226 Mdot
.27143 .18521 Mdot
.29048 .16971 Mdot
.30952 .15562 Mdot
.32857 .14281 Mdot
.34762 .13117 Mdot
.36667 .12058 Mdot
.38571 .11096 Mdot
.40476 .10221 Mdot
.42381 .09425 Mdot
.44286 .08702 Mdot
.4619 .08045 Mdot
.48095 .07447 Mdot
.5 .06904 Mdot
.51905 .0641 Mdot
.5381 .05961 Mdot
.55714 .05553 Mdot
.57619 .05182 Mdot
.59524 .04845 Mdot
.61429 .04538 Mdot
.63333 .04259 Mdot
.65238 .04006 Mdot
.67143 .03775 Mdot
.69048 .03566 Mdot
.70952 .03376 Mdot
.72857 .03202 Mdot
.74762 .03045 Mdot
.76667 .02902 Mdot
.78571 .02772 Mdot
.80476 .02654 Mdot
.82381 .02546 Mdot
.84286 .02449 Mdot
.8619 .0236 Mdot
.88095 .02279 Mdot
.9 .02206 Mdot
.91905 .02139 Mdot
.9381 .02078 Mdot
.95714 .02023 Mdot
.97619 .01973 Mdot
P
P
P
p
p
.004 w
.02381 .48908 m
.02381 .01472 L
s
.04286 .45083 m
.04286 .01472 L
s
.0619 .41963 m
.0619 .01472 L
s
.08095 .40786 m
.08095 .01472 L
s
.1 .37432 m
.1 .01472 L
s
.11905 .39374 m
.11905 .01472 L
s
.1381 .3649 m
.1381 .01472 L
s
.15714 .31075 m
.15714 .01472 L
s
.17619 .2931 m
.17619 .01472 L
s
.19524 .27367 m
.19524 .01472 L
s
.21429 .26661 m
.21429 .01472 L
s
.23333 .25602 m
.23333 .01472 L
s
.25238 .22777 m
.25238 .01472 L
s
.27143 .19716 m
.27143 .01472 L
s
.29048 .1901 m
.29048 .01472 L
s
.30952 .13831 m
.30952 .01472 L
s
.32857 .12065 m
.32857 .01472 L
s
.34762 .08711 m
.34762 .01472 L
s
.36667 .09005 m
.36667 .01472 L
s
.38571 .08299 m
.38571 .01472 L
s
.40476 .06474 m
.40476 .01472 L
s
.42381 .05768 m
.42381 .01472 L
s
.44286 .05474 m
.44286 .01472 L
s
.4619 .05415 m
.4619 .01472 L
s
.48095 .05768 m
.48095 .01472 L
s
.5 .03885 m
.5 .01472 L
s
.51905 .0412 m
.51905 .01472 L
s
.5381 .04238 m
.5381 .01472 L
s
.55714 .04885 m
.55714 .01472 L
s
.57619 .04179 m
.57619 .01472 L
s
.59524 .04002 m
.59524 .01472 L
s
.61429 .04944 m
.61429 .01472 L
s
.63333 .0412 m
.63333 .01472 L
s
.65238 .0412 m
.65238 .01472 L
s
.67143 .03767 m
.67143 .01472 L
s
.69048 .04473 m
.69048 .01472 L
s
.70952 .03531 m
.70952 .01472 L
s
.72857 .03178 m
.72857 .01472 L
s
.74762 .03473 m
.74762 .01472 L
s
.76667 .02707 m
.76667 .01472 L
s
.78571 .02354 m
.78571 .01472 L
s
.80476 .02119 m
.80476 .01472 L
s
.82381 .02237 m
.82381 .01472 L
s
.84286 .02413 m
.84286 .01472 L
s
.8619 .02119 m
.8619 .01472 L
s
.88095 .02295 m
.88095 .01472 L
s
.9 .02178 m
.9 .01472 L
s
.91905 .02649 m
.91905 .01472 L
s
.9381 .02472 m
.9381 .01472 L
s
.95714 .02237 m
.95714 .01472 L
s
.97619 .03061 m
.97619 .01472 L
s
P
p
0 0 1 r
p
.02 w
.02381 .48908 Mdot
.04286 .45083 Mdot
.0619 .41963 Mdot
.08095 .40786 Mdot
.1 .37432 Mdot
.11905 .39374 Mdot
.1381 .3649 Mdot
.15714 .31075 Mdot
.17619 .2931 Mdot
.19524 .27367 Mdot
.21429 .26661 Mdot
.23333 .25602 Mdot
.25238 .22777 Mdot
.27143 .19716 Mdot
.29048 .1901 Mdot
.30952 .13831 Mdot
.32857 .12065 Mdot
.34762 .08711 Mdot
.36667 .09005 Mdot
.38571 .08299 Mdot
.40476 .06474 Mdot
.42381 .05768 Mdot
.44286 .05474 Mdot
.4619 .05415 Mdot
.48095 .05768 Mdot
.5 .03885 Mdot
.51905 .0412 Mdot
.5381 .04238 Mdot
.55714 .04885 Mdot
.57619 .04179 Mdot
.59524 .04002 Mdot
.61429 .04944 Mdot
.63333 .0412 Mdot
.65238 .0412 Mdot
.67143 .03767 Mdot
.69048 .04473 Mdot
.70952 .03531 Mdot
.72857 .03178 Mdot
.74762 .03473 Mdot
.76667 .02707 Mdot
.78571 .02354 Mdot
.80476 .02119 Mdot
.82381 .02237 Mdot
.84286 .02413 Mdot
.8619 .02119 Mdot
.88095 .02295 Mdot
.9 .02178 Mdot
.91905 .02649 Mdot
.9381 .02472 Mdot
.95714 .02237 Mdot
.97619 .03061 Mdot
P
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
:[font = input; preserveAspect]
f[x_] := .1*E^(-.1 x)
:[font = input; preserveAspect; startGroup]
Plot[f[x], {x, 0, 60}]
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.015873 0.0147151 5.88604 [
[(10)] .18254 .01472 0 2 Msboxa
[(20)] .34127 .01472 0 2 Msboxa
[(30)] .5 .01472 0 2 Msboxa
[(40)] .65873 .01472 0 2 Msboxa
[(50)] .81746 .01472 0 2 Msboxa
[(60)] .97619 .01472 0 2 Msboxa
[(0.02)] .01131 .13244 1 0 Msboxa
[(0.04)] .01131 .25016 1 0 Msboxa
[(0.06)] .01131 .36788 1 0 Msboxa
[(0.08)] .01131 .4856 1 0 Msboxa
[(0.1)] .01131 .60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.18254 .01472 m
.18254 .02097 L
s
P
[(10)] .18254 .01472 0 2 Mshowa
p
.002 w
.34127 .01472 m
.34127 .02097 L
s
P
[(20)] .34127 .01472 0 2 Mshowa
p
.002 w
.5 .01472 m
.5 .02097 L
s
P
[(30)] .5 .01472 0 2 Mshowa
p
.002 w
.65873 .01472 m
.65873 .02097 L
s
P
[(40)] .65873 .01472 0 2 Mshowa
p
.002 w
.81746 .01472 m
.81746 .02097 L
s
P
[(50)] .81746 .01472 0 2 Mshowa
p
.002 w
.97619 .01472 m
.97619 .02097 L
s
P
[(60)] .97619 .01472 0 2 Mshowa
p
.001 w
.05556 .01472 m
.05556 .01847 L
s
P
p
.001 w
.0873 .01472 m
.0873 .01847 L
s
P
p
.001 w
.11905 .01472 m
.11905 .01847 L
s
P
p
.001 w
.15079 .01472 m
.15079 .01847 L
s
P
p
.001 w
.21429 .01472 m
.21429 .01847 L
s
P
p
.001 w
.24603 .01472 m
.24603 .01847 L
s
P
p
.001 w
.27778 .01472 m
.27778 .01847 L
s
P
p
.001 w
.30952 .01472 m
.30952 .01847 L
s
P
p
.001 w
.37302 .01472 m
.37302 .01847 L
s
P
p
.001 w
.40476 .01472 m
.40476 .01847 L
s
P
p
.001 w
.43651 .01472 m
.43651 .01847 L
s
P
p
.001 w
.46825 .01472 m
.46825 .01847 L
s
P
p
.001 w
.53175 .01472 m
.53175 .01847 L
s
P
p
.001 w
.56349 .01472 m
.56349 .01847 L
s
P
p
.001 w
.59524 .01472 m
.59524 .01847 L
s
P
p
.001 w
.62698 .01472 m
.62698 .01847 L
s
P
p
.001 w
.69048 .01472 m
.69048 .01847 L
s
P
p
.001 w
.72222 .01472 m
.72222 .01847 L
s
P
p
.001 w
.75397 .01472 m
.75397 .01847 L
s
P
p
.001 w
.78571 .01472 m
.78571 .01847 L
s
P
p
.001 w
.84921 .01472 m
.84921 .01847 L
s
P
p
.001 w
.88095 .01472 m
.88095 .01847 L
s
P
p
.001 w
.9127 .01472 m
.9127 .01847 L
s
P
p
.001 w
.94444 .01472 m
.94444 .01847 L
s
P
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 .13244 m
.03006 .13244 L
s
P
[(0.02)] .01131 .13244 1 0 Mshowa
p
.002 w
.02381 .25016 m
.03006 .25016 L
s
P
[(0.04)] .01131 .25016 1 0 Mshowa
p
.002 w
.02381 .36788 m
.03006 .36788 L
s
P
[(0.06)] .01131 .36788 1 0 Mshowa
p
.002 w
.02381 .4856 m
.03006 .4856 L
s
P
[(0.08)] .01131 .4856 1 0 Mshowa
p
.002 w
.02381 .60332 m
.03006 .60332 L
s
P
[(0.1)] .01131 .60332 1 0 Mshowa
p
.001 w
.02381 .03826 m
.02756 .03826 L
s
P
p
.001 w
.02381 .0618 m
.02756 .0618 L
s
P
p
.001 w
.02381 .08535 m
.02756 .08535 L
s
P
p
.001 w
.02381 .10889 m
.02756 .10889 L
s
P
p
.001 w
.02381 .15598 m
.02756 .15598 L
s
P
p
.001 w
.02381 .17952 m
.02756 .17952 L
s
P
p
.001 w
.02381 .20307 m
.02756 .20307 L
s
P
p
.001 w
.02381 .22661 m
.02756 .22661 L
s
P
p
.001 w
.02381 .2737 m
.02756 .2737 L
s
P
p
.001 w
.02381 .29724 m
.02756 .29724 L
s
P
p
.001 w
.02381 .32079 m
.02756 .32079 L
s
P
p
.001 w
.02381 .34433 m
.02756 .34433 L
s
P
p
.001 w
.02381 .39142 m
.02756 .39142 L
s
P
p
.001 w
.02381 .41497 m
.02756 .41497 L
s
P
p
.001 w
.02381 .43851 m
.02756 .43851 L
s
P
p
.001 w
.02381 .46205 m
.02756 .46205 L
s
P
p
.001 w
.02381 .50914 m
.02756 .50914 L
s
P
p
.001 w
.02381 .53269 m
.02756 .53269 L
s
P
p
.001 w
.02381 .55623 m
.02756 .55623 L
s
P
p
.001 w
.02381 .57977 m
.02756 .57977 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
.004 w
.02381 .60332 m
.06349 .47312 L
.10317 .37172 L
.14286 .29275 L
.18254 .23125 L
.22222 .18335 L
.2619 .14605 L
.30159 .117 L
.34127 .09437 L
.38095 .07675 L
.42063 .06303 L
.46032 .05234 L
.5 .04402 L
.53968 .03754 L
.57937 .03249 L
.61905 .02856 L
.65873 .0255 L
.69841 .02311 L
.7381 .02125 L
.77778 .01981 L
.81746 .01868 L
.85714 .0178 L
.89683 .01712 L
.93651 .01659 L
.97619 .01617 L
s
P
P
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
:[font = input; preserveAspect; startGroup]
Areabargraph[%54[[1]], 0, 50, 10]
:[font = print; inactive; preserveAspect]
Note:  some data values lie outside the user-defined interval.
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0190476 0.0147151 6.81124 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .21429 0 0 2 Msboxa
[(20)] .40476 0 0 2 Msboxa
[(30)] .59524 0 0 2 Msboxa
[(40)] .78571 0 0 2 Msboxa
[(50)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .15094 1 0 Msboxa
[(0.04)] -0.0125 .28716 1 0 Msboxa
[(0.06)] -0.0125 .42339 1 0 Msboxa
[(0.08)] -0.0125 .55961 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.21429 0 m
.21429 .00625 L
s
P
[(10)] .21429 0 0 2 Mshowa
p
.002 w
.40476 0 m
.40476 .00625 L
s
P
[(20)] .40476 0 0 2 Mshowa
p
.002 w
.59524 0 m
.59524 .00625 L
s
P
[(30)] .59524 0 0 2 Mshowa
p
.002 w
.78571 0 m
.78571 .00625 L
s
P
[(40)] .78571 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(50)] .97619 0 0 2 Mshowa
p
.001 w
.0619 0 m
.0619 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.1381 0 m
.1381 .00375 L
s
P
p
.001 w
.17619 0 m
.17619 .00375 L
s
P
p
.001 w
.25238 0 m
.25238 .00375 L
s
P
p
.001 w
.29048 0 m
.29048 .00375 L
s
P
p
.001 w
.32857 0 m
.32857 .00375 L
s
P
p
.001 w
.36667 0 m
.36667 .00375 L
s
P
p
.001 w
.44286 0 m
.44286 .00375 L
s
P
p
.001 w
.48095 0 m
.48095 .00375 L
s
P
p
.001 w
.51905 0 m
.51905 .00375 L
s
P
p
.001 w
.55714 0 m
.55714 .00375 L
s
P
p
.001 w
.63333 0 m
.63333 .00375 L
s
P
p
.001 w
.67143 0 m
.67143 .00375 L
s
P
p
.001 w
.70952 0 m
.70952 .00375 L
s
P
p
.001 w
.74762 0 m
.74762 .00375 L
s
P
p
.001 w
.82381 0 m
.82381 .00375 L
s
P
p
.001 w
.8619 0 m
.8619 .00375 L
s
P
p
.001 w
.9 0 m
.9 .00375 L
s
P
p
.001 w
.9381 0 m
.9381 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .15094 m
.00625 .15094 L
s
P
[(0.02)] -0.0125 .15094 1 0 Mshowa
p
.002 w
0 .28716 m
.00625 .28716 L
s
P
[(0.04)] -0.0125 .28716 1 0 Mshowa
p
.002 w
0 .42339 m
.00625 .42339 L
s
P
[(0.06)] -0.0125 .42339 1 0 Mshowa
p
.002 w
0 .55961 m
.00625 .55961 L
s
P
[(0.08)] -0.0125 .55961 1 0 Mshowa
p
.001 w
0 .04196 m
.00375 .04196 L
s
P
p
.001 w
0 .0692 m
.00375 .0692 L
s
P
p
.001 w
0 .09645 m
.00375 .09645 L
s
P
p
.001 w
0 .12369 m
.00375 .12369 L
s
P
p
.001 w
0 .17818 m
.00375 .17818 L
s
P
p
.001 w
0 .20543 m
.00375 .20543 L
s
P
p
.001 w
0 .23267 m
.00375 .23267 L
s
P
p
.001 w
0 .25992 m
.00375 .25992 L
s
P
p
.001 w
0 .31441 m
.00375 .31441 L
s
P
p
.001 w
0 .34165 m
.00375 .34165 L
s
P
p
.001 w
0 .3689 m
.00375 .3689 L
s
P
p
.001 w
0 .39614 m
.00375 .39614 L
s
P
p
.001 w
0 .45063 m
.00375 .45063 L
s
P
p
.001 w
0 .47788 m
.00375 .47788 L
s
P
p
.001 w
0 .50512 m
.00375 .50512 L
s
P
p
.001 w
0 .53237 m
.00375 .53237 L
s
P
p
.001 w
0 .58686 m
.00375 .58686 L
s
P
p
.001 w
0 .6141 m
.00375 .6141 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.21429 .61178 m
.21429 .61803 L
s
P
p
.002 w
.40476 .61178 m
.40476 .61803 L
s
P
p
.002 w
.59524 .61178 m
.59524 .61803 L
s
P
p
.002 w
.78571 .61178 m
.78571 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.0619 .61428 m
.0619 .61803 L
s
P
p
.001 w
.1 .61428 m
.1 .61803 L
s
P
p
.001 w
.1381 .61428 m
.1381 .61803 L
s
P
p
.001 w
.17619 .61428 m
.17619 .61803 L
s
P
p
.001 w
.25238 .61428 m
.25238 .61803 L
s
P
p
.001 w
.29048 .61428 m
.29048 .61803 L
s
P
p
.001 w
.32857 .61428 m
.32857 .61803 L
s
P
p
.001 w
.36667 .61428 m
.36667 .61803 L
s
P
p
.001 w
.44286 .61428 m
.44286 .61803 L
s
P
p
.001 w
.48095 .61428 m
.48095 .61803 L
s
P
p
.001 w
.51905 .61428 m
.51905 .61803 L
s
P
p
.001 w
.55714 .61428 m
.55714 .61803 L
s
P
p
.001 w
.63333 .61428 m
.63333 .61803 L
s
P
p
.001 w
.67143 .61428 m
.67143 .61803 L
s
P
p
.001 w
.70952 .61428 m
.70952 .61803 L
s
P
p
.001 w
.74762 .61428 m
.74762 .61803 L
s
P
p
.001 w
.82381 .61428 m
.82381 .61803 L
s
P
p
.001 w
.8619 .61428 m
.8619 .61803 L
s
P
p
.001 w
.9 .61428 m
.9 .61803 L
s
P
p
.001 w
.9381 .61428 m
.9381 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .15094 m
1 .15094 L
s
P
p
.002 w
.99375 .28716 m
1 .28716 L
s
P
p
.002 w
.99375 .42339 m
1 .42339 L
s
P
p
.002 w
.99375 .55961 m
1 .55961 L
s
P
p
.001 w
.99625 .04196 m
1 .04196 L
s
P
p
.001 w
.99625 .0692 m
1 .0692 L
s
P
p
.001 w
.99625 .09645 m
1 .09645 L
s
P
p
.001 w
.99625 .12369 m
1 .12369 L
s
P
p
.001 w
.99625 .17818 m
1 .17818 L
s
P
p
.001 w
.99625 .20543 m
1 .20543 L
s
P
p
.001 w
.99625 .23267 m
1 .23267 L
s
P
p
.001 w
.99625 .25992 m
1 .25992 L
s
P
p
.001 w
.99625 .31441 m
1 .31441 L
s
P
p
.001 w
.99625 .34165 m
1 .34165 L
s
P
p
.001 w
.99625 .3689 m
1 .3689 L
s
P
p
.001 w
.99625 .39614 m
1 .39614 L
s
P
p
.001 w
.99625 .45063 m
1 .45063 L
s
P
p
.001 w
.99625 .47788 m
1 .47788 L
s
P
p
.001 w
.99625 .50512 m
1 .50512 L
s
P
p
.001 w
.99625 .53237 m
1 .53237 L
s
P
p
.001 w
.99625 .58686 m
1 .58686 L
s
P
p
.001 w
.99625 .6141 m
1 .6141 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
0 0 1 r
.02381 .01472 m
.02381 .60332 L
.11905 .60332 L
.11905 .01472 L
F
.11905 .01472 m
.11905 .37027 L
.21429 .37027 L
.21429 .01472 L
F
.21429 .01472 m
.21429 .20917 L
.30952 .20917 L
.30952 .01472 L
F
.30952 .01472 m
.30952 .07752 L
.40476 .07752 L
.40476 .01472 L
F
.40476 .01472 m
.40476 .05654 L
.5 .05654 L
.5 .01472 L
F
.5 .01472 m
.5 .06783 L
.59524 .06783 L
.59524 .01472 L
F
.59524 .01472 m
.59524 .04322 L
.69048 .04322 L
.69048 .01472 L
F
.69048 .01472 m
.69048 .02507 L
.78571 .02507 L
.78571 .01472 L
F
.78571 .01472 m
.78571 .02991 L
.88095 .02991 L
.88095 .01472 L
F
.88095 .01472 m
.88095 .02426 L
.97619 .02426 L
.97619 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .60332 L
s
.11905 .01472 m
.11905 .60332 L
s
.02381 .60332 m
.11905 .60332 L
s
.11905 .01472 m
.11905 .37027 L
s
.21429 .01472 m
.21429 .37027 L
s
.11905 .37027 m
.21429 .37027 L
s
.21429 .01472 m
.21429 .20917 L
s
.30952 .01472 m
.30952 .20917 L
s
.21429 .20917 m
.30952 .20917 L
s
.30952 .01472 m
.30952 .07752 L
s
.40476 .01472 m
.40476 .07752 L
s
.30952 .07752 m
.40476 .07752 L
s
.40476 .01472 m
.40476 .05654 L
s
.5 .01472 m
.5 .05654 L
s
.40476 .05654 m
.5 .05654 L
s
.5 .01472 m
.5 .06783 L
s
.59524 .01472 m
.59524 .06783 L
s
.5 .06783 m
.59524 .06783 L
s
.59524 .01472 m
.59524 .04322 L
s
.69048 .01472 m
.69048 .04322 L
s
.59524 .04322 m
.69048 .04322 L
s
.69048 .01472 m
.69048 .02507 L
s
.78571 .01472 m
.78571 .02507 L
s
.69048 .02507 m
.78571 .02507 L
s
.78571 .01472 m
.78571 .02991 L
s
.88095 .01472 m
.88095 .02991 L
s
.78571 .02991 m
.88095 .02991 L
s
.88095 .01472 m
.88095 .02426 L
s
.97619 .01472 m
.97619 .02426 L
s
.88095 .02426 m
.97619 .02426 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
:[font = input; preserveAspect; startGroup]
Show[%62, %61]
:[font = postscript; PostScript; formatAsPostScript; output; inactive; preserveAspect; pictureLeft = 34; pictureWidth = 282; pictureHeight = 174]
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.015873 0.0147151 5.88604 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .18254 0 0 2 Msboxa
[(20)] .34127 0 0 2 Msboxa
[(30)] .5 0 0 2 Msboxa
[(40)] .65873 0 0 2 Msboxa
[(50)] .81746 0 0 2 Msboxa
[(60)] .97619 0 0 2 Msboxa
[(0)] -0.0125 .01472 1 0 Msboxa
[(0.02)] -0.0125 .13244 1 0 Msboxa
[(0.04)] -0.0125 .25016 1 0 Msboxa
[(0.06)] -0.0125 .36788 1 0 Msboxa
[(0.08)] -0.0125 .4856 1 0 Msboxa
[(0.1)] -0.0125 .60332 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.18254 0 m
.18254 .00625 L
s
P
[(10)] .18254 0 0 2 Mshowa
p
.002 w
.34127 0 m
.34127 .00625 L
s
P
[(20)] .34127 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(30)] .5 0 0 2 Mshowa
p
.002 w
.65873 0 m
.65873 .00625 L
s
P
[(40)] .65873 0 0 2 Mshowa
p
.002 w
.81746 0 m
.81746 .00625 L
s
P
[(50)] .81746 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(60)] .97619 0 0 2 Mshowa
p
.001 w
.05556 0 m
.05556 .00375 L
s
P
p
.001 w
.0873 0 m
.0873 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.15079 0 m
.15079 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.24603 0 m
.24603 .00375 L
s
P
p
.001 w
.27778 0 m
.27778 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.37302 0 m
.37302 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.43651 0 m
.43651 .00375 L
s
P
p
.001 w
.46825 0 m
.46825 .00375 L
s
P
p
.001 w
.53175 0 m
.53175 .00375 L
s
P
p
.001 w
.56349 0 m
.56349 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.62698 0 m
.62698 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.72222 0 m
.72222 .00375 L
s
P
p
.001 w
.75397 0 m
.75397 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.84921 0 m
.84921 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.9127 0 m
.9127 .00375 L
s
P
p
.001 w
.94444 0 m
.94444 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 .01472 m
.00625 .01472 L
s
P
[(0)] -0.0125 .01472 1 0 Mshowa
p
.002 w
0 .13244 m
.00625 .13244 L
s
P
[(0.02)] -0.0125 .13244 1 0 Mshowa
p
.002 w
0 .25016 m
.00625 .25016 L
s
P
[(0.04)] -0.0125 .25016 1 0 Mshowa
p
.002 w
0 .36788 m
.00625 .36788 L
s
P
[(0.06)] -0.0125 .36788 1 0 Mshowa
p
.002 w
0 .4856 m
.00625 .4856 L
s
P
[(0.08)] -0.0125 .4856 1 0 Mshowa
p
.002 w
0 .60332 m
.00625 .60332 L
s
P
[(0.1)] -0.0125 .60332 1 0 Mshowa
p
.001 w
0 .03826 m
.00375 .03826 L
s
P
p
.001 w
0 .0618 m
.00375 .0618 L
s
P
p
.001 w
0 .08535 m
.00375 .08535 L
s
P
p
.001 w
0 .10889 m
.00375 .10889 L
s
P
p
.001 w
0 .15598 m
.00375 .15598 L
s
P
p
.001 w
0 .17952 m
.00375 .17952 L
s
P
p
.001 w
0 .20307 m
.00375 .20307 L
s
P
p
.001 w
0 .22661 m
.00375 .22661 L
s
P
p
.001 w
0 .2737 m
.00375 .2737 L
s
P
p
.001 w
0 .29724 m
.00375 .29724 L
s
P
p
.001 w
0 .32079 m
.00375 .32079 L
s
P
p
.001 w
0 .34433 m
.00375 .34433 L
s
P
p
.001 w
0 .39142 m
.00375 .39142 L
s
P
p
.001 w
0 .41497 m
.00375 .41497 L
s
P
p
.001 w
0 .43851 m
.00375 .43851 L
s
P
p
.001 w
0 .46205 m
.00375 .46205 L
s
P
p
.001 w
0 .50914 m
.00375 .50914 L
s
P
p
.001 w
0 .53269 m
.00375 .53269 L
s
P
p
.001 w
0 .55623 m
.00375 .55623 L
s
P
p
.001 w
0 .57977 m
.00375 .57977 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.02381 .61178 m
.02381 .61803 L
s
P
p
.002 w
.18254 .61178 m
.18254 .61803 L
s
P
p
.002 w
.34127 .61178 m
.34127 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.65873 .61178 m
.65873 .61803 L
s
P
p
.002 w
.81746 .61178 m
.81746 .61803 L
s
P
p
.002 w
.97619 .61178 m
.97619 .61803 L
s
P
p
.001 w
.05556 .61428 m
.05556 .61803 L
s
P
p
.001 w
.0873 .61428 m
.0873 .61803 L
s
P
p
.001 w
.11905 .61428 m
.11905 .61803 L
s
P
p
.001 w
.15079 .61428 m
.15079 .61803 L
s
P
p
.001 w
.21429 .61428 m
.21429 .61803 L
s
P
p
.001 w
.24603 .61428 m
.24603 .61803 L
s
P
p
.001 w
.27778 .61428 m
.27778 .61803 L
s
P
p
.001 w
.30952 .61428 m
.30952 .61803 L
s
P
p
.001 w
.37302 .61428 m
.37302 .61803 L
s
P
p
.001 w
.40476 .61428 m
.40476 .61803 L
s
P
p
.001 w
.43651 .61428 m
.43651 .61803 L
s
P
p
.001 w
.46825 .61428 m
.46825 .61803 L
s
P
p
.001 w
.53175 .61428 m
.53175 .61803 L
s
P
p
.001 w
.56349 .61428 m
.56349 .61803 L
s
P
p
.001 w
.59524 .61428 m
.59524 .61803 L
s
P
p
.001 w
.62698 .61428 m
.62698 .61803 L
s
P
p
.001 w
.69048 .61428 m
.69048 .61803 L
s
P
p
.001 w
.72222 .61428 m
.72222 .61803 L
s
P
p
.001 w
.75397 .61428 m
.75397 .61803 L
s
P
p
.001 w
.78571 .61428 m
.78571 .61803 L
s
P
p
.001 w
.84921 .61428 m
.84921 .61803 L
s
P
p
.001 w
.88095 .61428 m
.88095 .61803 L
s
P
p
.001 w
.9127 .61428 m
.9127 .61803 L
s
P
p
.001 w
.94444 .61428 m
.94444 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
p
.002 w
.99375 .01472 m
1 .01472 L
s
P
p
.002 w
.99375 .13244 m
1 .13244 L
s
P
p
.002 w
.99375 .25016 m
1 .25016 L
s
P
p
.002 w
.99375 .36788 m
1 .36788 L
s
P
p
.002 w
.99375 .4856 m
1 .4856 L
s
P
p
.002 w
.99375 .60332 m
1 .60332 L
s
P
p
.001 w
.99625 .03826 m
1 .03826 L
s
P
p
.001 w
.99625 .0618 m
1 .0618 L
s
P
p
.001 w
.99625 .08535 m
1 .08535 L
s
P
p
.001 w
.99625 .10889 m
1 .10889 L
s
P
p
.001 w
.99625 .15598 m
1 .15598 L
s
P
p
.001 w
.99625 .17952 m
1 .17952 L
s
P
p
.001 w
.99625 .20307 m
1 .20307 L
s
P
p
.001 w
.99625 .22661 m
1 .22661 L
s
P
p
.001 w
.99625 .2737 m
1 .2737 L
s
P
p
.001 w
.99625 .29724 m
1 .29724 L
s
P
p
.001 w
.99625 .32079 m
1 .32079 L
s
P
p
.001 w
.99625 .34433 m
1 .34433 L
s
P
p
.001 w
.99625 .39142 m
1 .39142 L
s
P
p
.001 w
.99625 .41497 m
1 .41497 L
s
P
p
.001 w
.99625 .43851 m
1 .43851 L
s
P
p
.001 w
.99625 .46205 m
1 .46205 L
s
P
p
.001 w
.99625 .50914 m
1 .50914 L
s
P
p
.001 w
.99625 .53269 m
1 .53269 L
s
P
p
.001 w
.99625 .55623 m
1 .55623 L
s
P
p
.001 w
.99625 .57977 m
1 .57977 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
p
.002 w
0 .01472 m
1 .01472 L
s
P
p
.002 w
.02381 0 m
.02381 .61803 L
s
P
P
p
p
p
0 0 1 r
.02381 .01472 m
.02381 .52337 L
.10317 .52337 L
.10317 .01472 L
F
.10317 .01472 m
.10317 .32197 L
.18254 .32197 L
.18254 .01472 L
F
.18254 .01472 m
.18254 .18275 L
.2619 .18275 L
.2619 .01472 L
F
.2619 .01472 m
.2619 .06899 L
.34127 .06899 L
.34127 .01472 L
F
.34127 .01472 m
.34127 .05086 L
.42063 .05086 L
.42063 .01472 L
F
.42063 .01472 m
.42063 .06062 L
.5 .06062 L
.5 .01472 L
F
.5 .01472 m
.5 .03935 L
.57937 .03935 L
.57937 .01472 L
F
.57937 .01472 m
.57937 .02366 L
.65873 .02366 L
.65873 .01472 L
F
.65873 .01472 m
.65873 .02785 L
.7381 .02785 L
.7381 .01472 L
F
.7381 .01472 m
.7381 .02297 L
.81746 .02297 L
.81746 .01472 L
F
P
p
.004 w
.02381 .01472 m
.02381 .52337 L
s
.10317 .01472 m
.10317 .52337 L
s
.02381 .52337 m
.10317 .52337 L
s
.10317 .01472 m
.10317 .32197 L
s
.18254 .01472 m
.18254 .32197 L
s
.10317 .32197 m
.18254 .32197 L
s
.18254 .01472 m
.18254 .18275 L
s
.2619 .01472 m
.2619 .18275 L
s
.18254 .18275 m
.2619 .18275 L
s
.2619 .01472 m
.2619 .06899 L
s
.34127 .01472 m
.34127 .06899 L
s
.2619 .06899 m
.34127 .06899 L
s
.34127 .01472 m
.34127 .05086 L
s
.42063 .01472 m
.42063 .05086 L
s
.34127 .05086 m
.42063 .05086 L
s
.42063 .01472 m
.42063 .06062 L
s
.5 .01472 m
.5 .06062 L
s
.42063 .06062 m
.5 .06062 L
s
.5 .01472 m
.5 .03935 L
s
.57937 .01472 m
.57937 .03935 L
s
.5 .03935 m
.57937 .03935 L
s
.57937 .01472 m
.57937 .02366 L
s
.65873 .01472 m
.65873 .02366 L
s
.57937 .02366 m
.65873 .02366 L
s
.65873 .01472 m
.65873 .02785 L
s
.7381 .01472 m
.7381 .02785 L
s
.65873 .02785 m
.7381 .02785 L
s
.7381 .01472 m
.7381 .02297 L
s
.81746 .01472 m
.81746 .02297 L
s
.7381 .02297 m
.81746 .02297 L
s
P
P
p
p
.004 w
.02381 .60332 m
.06349 .47312 L
.10317 .37172 L
.14286 .29275 L
.18254 .23125 L
.22222 .18335 L
.2619 .14605 L
.30159 .117 L
.34127 .09437 L
.38095 .07675 L
.42063 .06303 L
.46032 .05234 L
.5 .04402 L
.53968 .03754 L
.57937 .03249 L
.61905 .02856 L
.65873 .0255 L
.69841 .02311 L
.7381 .02125 L
.77778 .01981 L
.81746 .01868 L
.85714 .0178 L
.89683 .01712 L
.93651 .01659 L
.97619 .01617 L
s
P
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd

:[font = output; output; inactive; preserveAspect; endGroup]
Graphics["<<>>"]
;[o]
-Graphics-
^*)
