(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6894,        128]*)
(*NotebookOutlinePosition[      8002,        165]*)
(*  CellTagsIndexPosition[      7958,        161]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[TextData[{
  StyleBox[
  "These programs accompany the book\n \n \t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tIntroduction to Probability\n \t\t\t\t\t\
\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tJ. Laurie \
Snell and Charles M. Grinstead\n \t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t\t\t\t\t\t\t\t\tPublishers, etc.\n \t\t\t\t\t\t\t\t\t\t\t\t\t\t\
\t\t\t\t\t\t\t\t\t\t\t\t\t\n and are arranged according to the chapters in \
that text.  Descriptions of the programs in each chapter X can be found in \
the file \"Chapter X Descriptions\" in the \"Program Descriptions\" folder.  \
In the \"Program Index\" file is an alphabetical list of all programs  and \
the folders and files in which they can be found.\n \n **  In addition to the \
chapter programs, there are a number of programs in the file \"Important \
Programs,\" all of which should be initialized before any other programs are \
run.  These are programs that are frequently used (such as \"Areabargraph\" \
and \"SpikeData\"), or are called by programs in diverse locations.  To \
initialize these programs, simply open \"Important Programs\" and click on \
\"Yes\" when you are asked if you would like to initialize all cells.  \
Descriptions of the programs in \"Important Programs\" can be found in the \
file \"Important Program Descriptions\" in the \"Program Descriptions\" \
folder.\n \n**  In addition to the textual program descriptions in the \
\"Program Descriptions\" files, we have included in the file \"Usage \
Statements\" usage statements for all the programs.  A program's usage \
statement contains a description of that program, and shows the form a call \
to that program should have.  The description found here is usually briefer \
than that found in the program's textual description.  The advantage to usage \
statements is that they are easily accessed, if their cells in the \"Usage \
Statements\" file have been initialized:  to find out what program \"foo\" \
does, simply type \"?foo\", and a description of foo will be displayed on the \
screen.  If you are unfamiliar with these programs, it might be useful to \
initialize all the cells in \"Usage Statements\" immediately after \
initializing those in \"Important Programs\";  however, it takes some time, \
so it is suggested that after you become familiar with the programs you no \
longer initialize these usage cells.\n\n**  Frequently the synopsis of a \
program \"foo\" will note that programs X, Y, etc., must be initialized \
before \"foo\" is run.  Many of these noted programs are found in the \
\"Important Programs\" file, and thus will presumably already be initialized \
when foo is called.  However, occasionally a program will require the \
initialization of a program not included in \"Important Programs.\"  In this \
case, or if you have not initialized the cells in \"Important Programs,\" \
look up the required program in the \"Program Index,\" open the file it is \
contained in, and initialize it from there.\n\n**  Sometimes a program also \
requires that a certain package, or packages, be loaded in.  All these \
required packages are loaded in by commands in the \"Important Programs\" \
file, so if that file's cells have been initialized, you need do nothing \
else.  If they haven't been initialized, you can load in package \
\"Stuff`Morestuff`\" by typing \"<<Stuff`Morestuff` \".\n\n**  In \
\"ImportantPrograms\" you will find a series of \"Off[__::__]\" commands.  \
These simply switch off warning messages, to prevent their printing to the \
screen.  Examples of warnings that have been supressed are warnings about \
possible spelling errors (Off[General::spell]) and warnings that during a \
graphing command ",
    FontFamily->"Helvetica"],
  StyleBox["Mathematica",
    FontFamily->"Helvetica",
    FontSlant->"Italic"],
  StyleBox[
  "  could not raise 0^0 (Off[Power::indet]).  If you would like to turn on \
the display of any of these warning messages, type \"On[__::__]\" with the \
blanks filled in appropriately.\n\n**  We often refer to a \"probability list\
\" or a \"distribution list\" in the description and/or body of a program.  \
By the former, we mean a list of nonnegative real numbers which sum to 1, \
representing the probabilities of all the outcomes of an experiment.  By the \
latter, we mean a list of ordered pairs of the form (x_i, p(x_i)), where \
p(x_i) is the probability x_i is the outcome of an experiment.  This list of \
pairs should include all possible outcomes of the experiment and their \
probabilities; it thereby represents the distribution of a discrete random \
variable.  When input into a program, it is not assumed to be in \
lexicographic order.  Each entry of a probability list and/or distribution \
list can be a decimal or a rational number, unless otherwise noted.\n\n**  \
The program \"SteppingStone\" is a stand-alone TrueBasic program, which \
implements the Stepping Stone model in Chapter 11.  The program does not\n\
require a copy of TrueBasic in order for it to run.",
    FontFamily->"Helvetica"]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 800}, {0, 580}},
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{520, 485},
WindowMargins->{{20, Automatic}, {Automatic, 28}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1711, 51, 5180, 76, 70, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
